# coding: utf8
from __future__ import unicode_literals


AUXILIARY_VERBS_IRREG = {
    "suis": ("être",),
    "es": ("être",),
    "est": ("être",),
    "sommes": ("être",),
    "êtes": ("être",),
    "sont": ("être",),
    "étais": ("être",),
    "étais": ("être",),
    "était": ("être",),
    "étions": ("être",),
    "étiez": ("être",),
    "étaient": ("être",),
    "fus": ("être",),
    "fut": ("être",),
    "fûmes": ("être",),
    "fûtes": ("être",),
    "furent": ("être",),
    "serai": ("être",),
    "seras": ("être",),
    "sera": ("être",),
    "serons": ("être",),
    "serez": ("être",),
    "seront": ("être",),
    "serais": ("être",),
    "serait": ("être",),
    "serions": ("être",),
    "seriez": ("être",),
    "seraient": ("être",),
    "sois": ("être",),
    "soit": ("être",),
    "soyons": ("être",),
    "soyez": ("être",),
    "soient": ("être",),
    "fusse": ("être",),
    "fusses": ("être",),
    "fût": ("être",),
    "fussions": ("être",),
    "fussiez": ("être",),
    "fussent": ("être",),
    "étant": ("être",),
    "ai": ("avoir",),
    "as": ("avoir",),
    "a": ("avoir",),
    "avons": ("avoir",),
    "avez": ("avoir",),
    "ont": ("avoir",),
    "avais": ("avoir",),
    "avait": ("avoir",),
    "avions": ("avoir",),
    "aviez": ("avoir",),
    "avaient": ("avoir",),
    "eus": ("avoir",),
    "eut": ("avoir",),
    "eûmes": ("avoir",),
    "eûtes": ("avoir",),
    "eurent": ("avoir",),
    "aurai": ("avoir",),
    "auras": ("avoir",),
    "aura": ("avoir",),
    "aurons": ("avoir",),
    "aurez": ("avoir",),
    "auront": ("avoir",),
    "aurais": ("avoir",),
    "aurait": ("avoir",),
    "aurions": ("avoir",),
    "auriez": ("avoir",),
    "auraient": ("avoir",),
    "aie": ("avoir",),
    "aies": ("avoir",),
    "ait": ("avoir",),
    "ayons": ("avoir",),
    "ayez": ("avoir",),
    "aient": ("avoir",),
    "eusse": ("avoir",),
    "eusses": ("avoir",),
    "eût": ("avoir",),
    "eussions": ("avoir",),
    "eussiez": ("avoir",),
    "eussent": ("avoir",),
    "ayant": ("avoir",)
}
