# coding: utf8
from __future__ import unicode_literals


LOOKUP = {
    "Aaronsonnak": "﻿Aaronson",
    "Aaronsont": "Aaronson",
    "Abbáziában": "Abbázia",
    "Adyn": "Ady",
    "Adyt": "Ady",
    "Afrikában": "Afrika",
    "Afrikája": "Afrika",
    "Afrikát": "Afrika",
    "Ajkán": "Ajka",
    "Aladárét": "Aladár",
    "Alattunk": "alatt",
    "Albertet": "Albert",
    "Alija": "Ali",
    "Amerika-barátnak": "Amerika-barát",
    "Amerikába": "Amerika",
    "Amerikából": "Amerika",
    "Amerikát": "Amerika",
    "Amerikával": "Amerika",
    "Amershambe": "Amersham",
    "Ampleforthot": "Ampleforth",
    "Ampleforthra": "Ampleforth",
    "Amplefortht": "Ampleforth",
    "Amállal": "Amál",
    "Amálnak": "Amál",
    "Amálról": "Amál",
    "Amált": "Amál",
    "Andort": "Andor",
    "Angelesben": "Angeles",
    "Angliába": "Anglia",
    "Angliának": "Anglia",
    "Angolával": "Angola",
    "Angszocban": "Angszoc",
    "Angszocnak": "Angszoc",
    "Angszoct": "Angszoc",
    "Angyalföldön": "Angyalföld",
    "Ankarában": "Ankara",
    "Annától": "Anna",
    "Antall-kormánynak": "Antall-kormány",
    "Antalt": "Antal",
    "Aradon": "Arad",
    "Argentínában": "Argentína",
    "Arizonától": "Arizona",
    "Astaróthnak": "Astaróth",
    "Athénban": "Athén",
    "Attilát": "Attila",
    "Ausztriában": "Ausztria",
    "Ausztriából": "Ausztria",
    "Ausztriának": "Ausztria",
    "Ausztriát": "Ausztria",
    "Ausztráliában": "Ausztrália",
    "Ausztrálázsiát": "Ausztrálázsia",
    "Avenue-": "Avenue",
    "Avenue-n": "Avenue",
    "BMW-ből": "BMW",
    "Bachot": "Bach",
    "Baján": "Baja",
    "Balatontól": "Balaton",
    "Balázstól": "Balázs",
    "Bandit": "Bandi",
    "Bartók-szemináriumoknak": "Bartók-szeminárium",
    "Bartókkal": "Bartók",
    "Baálnak": "Baál",
    "Beethovent": "Beethoven",
    "Belgiumba": "Belgium",
    "Belgiumban": "Belgium",
    "Belgrádba": "Belgrád",
    "Belgrádban": "Belgrád",
    "Belgrádot": "Belgrád",
    "Bering-szorosig": "Bering-szoros",
    "Berkhamstedbe": "Berkhamsted",
    "Bernátnak": "Bernát",
    "Bodrogon": "Bodrog",
    "Bonnt": "Bonn",
    "Borsod-Abaúj-Zemplénben": "Borsod-Abaúj-Zemplén",
    "Borsodban": "Borsod",
    "Bostonban": "Boston",
    "Boszniába": "Bosznia",
    "Boszniában": "Bosznia",
    "Boszniából": "Bosznia",
    "Boszniának": "Bosznia",
    "Brahmsot": "Brahms",
    "Brassóba": "Brassó",
    "Brassóban": "Brassó",
    "Brassóig": "Brassó",
    "Brassóra": "Brassó",
    "Brazíliában": "Brazília",
    "Brüsszelben": "Brüsszel",
    "Budapesten": "Budapest",
    "Budapestet": "Budapest",
    "Budapestre": "Budapest",
    "Budapesttel": "Budapest",
    "Budán": "Buda",
    "Bukarestbe": "Bukarest",
    "Bukarestben": "Bukarest",
    "Bukarestig": "Bukarest",
    "Bukarestnek": "Bukarest",
    "Bálinttal": "Bálint",
    "Bécsbe": "Bécs",
    "Bécsben": "Bécs",
    "Békásmegyert": "Békásmegyer",
    "Békésben": "Békés",
    "Békéscsabára": "Békéscsaba",
    "Bélának": "Béla",
    "Bélára": "Béla",
    "Bélát": "Béla",
    "Bélával": "Béla",
    "Béninek": "Béni",
    "Bözsitől": "Bözsi",
    "CD-ről": "CD",
    "Cannes-i": "Cannes",
    "Charringtonnal": "Charrington",
    "Charringtont": "Charrington",
    "Clintont": "Clinton",
    "Colchesterre": "Colchester",
    "Csabák": "Csaba",
    "Csabától": "Csaba",
    "Csehországba": "Csehország",
    "Csehországról": "Csehország",
    "Csehszlovákiába": "Csehszlovákia",
    "Csepelig": "Csepel",
    "Debrecenbe": "Debrecen",
    "Debrecenben": "Debrecen",
    "Debrecennek": "Debrecen",
    "Dezsőn": "Dezső",
    "Dezsőnél": "Dezső",
    "Dezsőt": "Dezső",
    "Dezsővel": "Dezső",
    "Duna-kiöntésében": "Duna-kiöntés",
    "Duna-tüntetést": "Duna-tüntetés",
    "Dunáig": "Duna",
    "Dunántúlon": "Dunántúl",
    "Dunántúlról": "Dunántúl",
    "Dániában": "Dánia",
    "Eiffel-tornyot": "Eiffel-torony",
    "Előttünk": "előtt",
    "Ercsiből": "Ercsi",
    "Erdélybe": "Erdély",
    "Erdélyben": "Erdély",
    "Erdélyből": "Erdély",
    "Ernőt": "Ernő",
    "Esterházyval": "Esterházy",
    "Eszterben": "Eszter",
    "Eszternek": "Eszter",
    "Eszterre": "Eszter",
    "Eszterrel": "Eszter",
    "Esztert": "Eszter",
    "Esztertől": "Eszter",
    "Esztivel": "Eszti",
    "Etelkával": "Etelka",
    "Eurázsiában": "Eurázsia",
    "Eurázsiára": "Eurázsia",
    "Eurázsiát": "Eurázsia",
    "Eurázsiával": "Eurázsia",
    "Európa-bajnokságon": "Európa-bajnokság",
    "Európa-bajnokságra": "Európa-bajnokság",
    "Európába": "Európa",
    "Európában": "Európa",
    "Európából": "Európa",
    "Európához": "Európa",
    "Európának": "Európa",
    "Fasót": "Faso",
    "Ferenc-emlékéremmel": "Ferenc-emlékérem",
    "Ferencnek": "Ferenc",
    "Ferencre": "Ferenc",
    "Ferencvárosban": "Ferencváros",
    "Festetics-kastélyban": "Festetics-kastély",
    "Fidesszel": "Fidesz",
    "Fidesznek": "Fidesz",
    "Fideszt": "Fidesz",
    "Franciaországban": "Franciaország",
    "Franciaországgal": "Franciaország",
    "Franciaországnak": "Franciaország",
    "Ft-on": "Ft",
    "Ft/négyzetméter": "Ft",
    "Fábiánhoz": "Fábián",
    "Fábiánnak": "Fábián",
    "Földközi-tengeren": "Földközi-tenger",
    "Fürt": "Für",
    "Ganéháznak": "Ganéház",
    "Genfi-tóhoz": "Genfi-tó",
    "Gershwin-parafrázisokat": "Gershwin-parafrázis",
    "Gittácskát": "Gittácská",
    "Gittája": "Gitta",
    "Gittát": "Gitta",
    "Gogol-regények": "Gogol-regény",
    "Goldsteinnek": "Goldstein",
    "Goldsteinnel": "Goldstein",
    "Goldsteinre": "Goldstein",
    "Goldsteinről": "Goldstein",
    "Goldsteint": "Goldstein",
    "Goldsteintől": "Goldstein",
    "Guatemalát": "Guatemala",
    "Gyulától": "Gyula",
    "Gyöngyikét": "Gyöngyi",
    "Györgyit": "Györgyi",
    "Györgynek": "György",
    "Györgytől": "György",
    "Györgyöt": "György",
    "Gáborhoz": "Gábor",
    "Gábort": "Gábor",
    "Gödöllőhöz": "Gödöllő",
    "Gödöllőn": "Gödöllő",
    "Görögországnak": "Görögország",
    "Habsburg-dinasztiához": "Habsburg-dinasztia",
    "Haydnt": "Haydn",
    "Hollandiában": "Hollandia",
    "Horthynak": "Horthy",
    "Hágában": "Hága",
    "Hófehérkét": "Hófehérke",
    "IBM-számítógépeket": "IBM-számítógép",
    "Ilon-hangra": "Ilon-hang",
    "Ilont": "Ilon",
    "Imrének": "Imre",
    "Imrétől": "Imre",
    "Indiai-óceánból": "Indiai-óceán",
    "Indiában": "India",
    "Indiából": "India",
    "Indiát": "India",
    "Istvánnal": "István",
    "Istvántól": "István",
    "Ivánnal": "Iván",
    "Ivánt": "Iván",
    "Izraelbe": "Izrael",
    "Izraelben": "Izrael",
    "Izraellel": "Izrael",
    "Jancsit": "Jancsi",
    "Jancsival": "Jancsi",
    "Japánnal": "Japán",
    "Jehovát": "Jehova",
    "Jenőtől": "Jenő",
    "Jeruzsálemben": "Jeruzsálem",
    "Jonest": "Jones",
    "Jugoszláviától": "Jugoszlávia",
    "Julcsámat": "Julcsa",
    "Julcsámnak": "Julcsa",
    "Juliának": "Julia",
    "Juliára": "Julia",
    "Juliáról": "Julia",
    "Juliát": "Julia",
    "Juliával": "Julia",
    "Juliáé": "Julia",
    "Jupiter-kutatók": "Jupiter-kutató",
    "Jupiterbe": "Jupiter",
    "Jupiteren": "Jupiter",
    "Jánosban": "János",
    "Jánosnak": "János",
    "Jánosnál": "János",
    "Jánost": "János",
    "Jánostól": "János",
    "Jóskával": "Jóska",
    "Józsefben": "József",
    "Józsefből": "József",
    "Józsefemre": "József",
    "Józsefet": "József",
    "Józseffel": "József",
    "Józsefnek": "József",
    "Józseftől": "József",
    "Józsefvárosban": "Józsefváros",
    "Józsiban": "Józsi",
    "Józsikám": "Józsika",
    "Józsikát": "Józsika",
    "Józsira": "Józsi",
    "Júliát": "Júlia",
    "K-országokból": "K-ország",
    "KDNP-nek": "KDNP",
    "KDNP-t": "KDNP",
    "Kanadába": "Kanada",
    "Kanadában": "Kanada",
    "Kaposváron": "Kaposvár",
    "Kaposvárott": "Kaposvár",
    "Kaposvárra": "Kaposvár",
    "Kaposvárról": "Kaposvár",
    "Karcsi-bábut": "Karcsi-bábu",
    "Karcsi-bábút": "Karcsi-bábú",
    "Karcsit": "Karcsi",
    "Kassán": "Kassa",
    "Katharine-hez": "Katharine",
    "Katharine-t": "Katharine",
    "Katival": "Kati",
    "Kazincbarcikáról": "Kazincbarcika",
    "Kecskeméten": "Kecskemét",
    "Kecskemétnél": "Kecskemét",
    "Kelet-Boszniában": "kelet-Bosznia",
    "Kelet-Európában": "Kelet-Európa",
    "Kelet-Jeruzsálemben": "Kelet-Jeruzsálem",
    "Keletázsiában": "Keletázsia",
    "Keletázsiára": "Keletázsia",
    "Keletázsiát": "Keletázsia",
    "Keletázsiával": "Keletázsia",
    "Kennedy-testvérekig": "Kennedy-testvér",
    "Kissé": "Kiss",
    "Klárában": "Klára",
    "Klárához": "Klára",
    "Klárának": "Klára",
    "Klárára": "Klára",
    "Klárát": "Klára",
    "Klárával": "Klára",
    "Kodályt": "Kodály",
    "Kolozsváron": "Kolozsvár",
    "Kolumbuszéinál": "Kolumbusz",
    "Kornéliának": "Kornélia",
    "Kornéliát": "Kornélia",
    "Kornéliával": "Kornélia",
    "Kossuth-díjaikat": "Kossuth-díj",
    "Kossuth-díjakat": "Kossuth-díj",
    "Kristófhoz": "Kristóf",
    "Kristófnak": "Kristóf",
    "Kristófot": "Kristóf",
    "Kristófra": "Kristóf",
    "Kristófról": "Kristóf",
    "Krisztina-babát": "Krisztina-baba",
    "Krisztinából": "Krisztina",
    "Krisztinának": "Krisztina",
    "Krisztinára": "Krisztina",
    "Krisztináról": "Krisztina",
    "Krisztinát": "Krisztina",
    "Krisztinától": "Krisztina",
    "Krisztinával": "Krisztina",
    "Krisztináé": "Krisztina",
    "Krisztussal": "Krisztus",
    "Kupa-mérkőzésen": "Kupa-mérkőzés",
    "Károlynak": "Károly",
    "Károlyról": "Károly",
    "Károlyt": "Károly",
    "Károlytól": "Károly",
    "Kárpátaljáról": "Kárpátalja",
    "Kínában": "Kína",
    "Kínát": "Kína",
    "Közel-Keleten": "Közel-Kelet",
    "Közép-Boszniába": "Közép-Bosznia",
    "Közép-Európában": "Közép-Európa",
    "Ladájukkal": "Lada",
    "Lajosról": "Lajos",
    "Lajossal": "Lajos",
    "Lajost": "Lajos",
    "Lajtán": "Lajta",
    "Lengyelországból": "Lengyelország",
    "Lettországból": "Lettország",
    "Libanonban": "Libanon",
    "Libanonnal": "Libanon",
    "Lilinek": "Lili",
    "Lilire": "Lili",
    "Lipótot": "Lipót",
    "Litvániából": "Litvánie",
    "Liverpoolban": "Liverpool",
    "Londonban": "London",
    "Londonnak": "London",
    "Londonra": "London",
    "Londont": "London",
    "Lászlónak": "László",
    "Lászlótól": "László",
    "Lászlóval": "László",
    "Líbiából": "Líbia",
    "Lőrincet": "Lőrinc",
    "Lőrincnek": "Lőrinc",
    "Lőrincre": "Lőrinc",
    "MDF-et": "MDF",
    "MDF-fel": "MDF",
    "MSZOSZ-esek": "MSZOSZ-es",
    "MSZP-képviselők": "MSZP-képviselő",
    "MSZP-listáról": "MSZP-lista",
    "MSZP-n": "MSZP",
    "MSZP-tagok": "MSZP-tag",
    "Macedóniával": "Macedónia",
    "Magdolnától": "Magdolna",
    "Magdát": "Magda",
    "Magyarországgal": "Magyarország",
    "Magyarországnak": "Magyarország",
    "Magyarországon": "Magyarország",
    "Magyarországra": "Magyarország",
    "Magyarországról": "Magyarország",
    "Malévnál": "Malév",
    "Malévnél": "Malév",
    "Mancit": "Manci",
    "Mandzsúriának": "Mandzsúria",
    "Marosvásárhelyen": "Marosvásárhely",
    "Martin's-in-the-Fieldsnek": "Martin's-in-the-Fields",
    "Mecseken": "Mecsek",
    "Melbourne-ben": "Melbourne",
    "Mihálynál": "Mihály",
    "Mihályt": "Mihály",
    "Miklósig": "Miklós",
    "Miklóssal": "Miklós",
    "Miklóst": "Miklós",
    "Miklóstól": "Miklós",
    "Milánóban": "Milánó",
    "Miskolcon": "Miskolc",
    "Mongóliában": "Mongólia",
    "Mongóliából": "Mongólia",
    "Mongóliának": "Mongólia",
    "Moszkvában": "Moszkva",
    "Moszkvából": "Moszkva",
    "Moszkvának": "Moszkva",
    "Moszkvát": "Moszkva",
    "Mozambikot": "Mozambik",
    "Mozart-szerelmesei": "Mozart-szerelmes",
    "Munkácsyt": "Munkácsy",
    "Murányitól": "Murányi",
    "MÁV-nak": "MÁV",
    "Máriaként": "Mária",
    "Mártonnál": "Márton",
    "Mártától": "Márta",
    "Mártával": "Márta",
    "Mátraalján": "Mátraalja",
    "Mónikát": "Mónika",
    "Mögötte": "mögött",
    "N.-t": "N.",
    "NATO-tagságának": "NATO-tagság",
    "Nagy-Britanniában": "Nagy-Britannia",
    "Nagy-Britanniának": "Nagy-Britannia",
    "Nagy-szonettet": "Nagy-szonett",
    "Nagykanizsán": "Nagykanizsa",
    "Nagyváradig": "Nagyvárad",
    "Nagyváradnak": "Nagyvárad",
    "Nagyváradra": "Nagyvárad",
    "Nekem": "én",
    "Neobolsevizmusnak": "Neobolsevizmus",
    "Nikét": "Niké",
    "Nyugat-Dunántúlon": "Nyugat-Dunántúl",
    "Nyugat-Európában": "Nyugat-Európa",
    "Nyugat-Európával": "Nyugat-Európa",
    "Nyíregyházán": "Nyíregyháza",
    "Németországban": "Németország",
    "Németországnak": "Németország",
    "Nógrádban": "Nógrád",
    "O'Brienhez": "O'Brien",
    "O'Briennek": "O'Brien",
    "O'Briennel": "O'Brien",
    "O'Brienre": "O'Brien",
    "O'Brient": "O'Brien",
    "O'Brientől": "O'Brien",
    "OTP-t": "OTP",
    "Olaszországban": "Olaszország",
    "Olaszországból": "Olaszország",
    "Ontariói": "Ontario",
    "Oroszországba": "Oroszország",
    "Oroszországból": "Oroszország",
    "Oroszországgal": "Oroszország",
    "Oroszországnak": "Oroszország",
    "Oroszországot": "Oroszország",
    "Oroszországával": "Oroszország",
    "Oscar-díjat": "Oscar-díj",
    "Ottónak": "Ottó",
    "Ozirisznak": "Ozirisz",
    "Paddington-állomásról": "Paddington-állomás",
    "Paksra": "Paks",
    "Pakstól": "Paks",
    "Parsonsnak": "Parsons",
    "Parsonst": "Parsons",
    "Pasteur-intézetbe": "Pasteur-intézet",
    "Petőfit": "Petőfi",
    "Pilátusig": "Pilátus",
    "Piri-bábut": "Piri-bábu",
    "Piriben": "Piri",
    "Pirit": "Piri",
    "Pirivel": "Piri",
    "Piroskához": "Piroska",
    "Piroskát": "Piroska",
    "Pistának": "Pista",
    "Pistával": "Pista",
    "Portugáliától": "Portugália",
    "Prágát": "Prága",
    "Pállal": "Pál",
    "Páltól": "Pál",
    "Párizsban": "Párizs",
    "Párizst": "Párizs",
    "Pécsett": "Pécs",
    "Péternek": "Péter",
    "Rajnáig": "Rajna",
    "Rajtunk": "mi",
    "Robin": "Robi",
    "Romániába": "Románia",
    "Romániában": "Románia",
    "Romániából": "Románia",
    "Romániával": "Románia",
    "Rotterdammal": "Rotterdam",
    "Rt-től": "Rt",
    "Rutherfordnak": "Rutherford",
    "Rutherfordot": "Rutherford",
    "Róbertet": "Róbert",
    "Róbertnél": "Róbert",
    "Róberttel": "Róbert",
    "Rómában": "Róma",
    "Rózsadombon": "Rózsadomb",
    "Rózsit": "Rózsi",
    "SS-házmesterrel": "SS-házmester",
    "SZDSZ-ről": "SZDSZ",
    "SZDSZ-szel": "SZDSZ",
    "SZDSZ-t": "SZDSZ",
    "Salgótarjánba": "Salgótarján",
    "Salgótarjánban": "Salgótarján",
    "Salzburgban": "Salzburg",
    "Sanyiban": "Sanyi",
    "Sanyiból": "Sanyi",
    "Sanyihoz": "Sanyi",
    "Sanyikám": "Sanyika",
    "Sanyinak": "Sanyi",
    "Sanyit": "Sanyi",
    "Sanyitól": "Sanyi",
    "Sanyival": "Sanyi",
    "Sebestyént": "Sebestyén",
    "Smithnek": "Smith",
    "Somában": "Soma",
    "Somával": "Soma",
    "Sopronba": "Sopron",
    "Sopronban": "Sopron",
    "Sopronét": "Sopron",
    "Sorbonne-on": "Sorbonne",
    "Spanyolországban": "Spanyolország",
    "Spanyolországból": "Spanyolország",
    "Stepneyben": "Stepney",
    "Suzuki-eladások": "Suzuki-eladás",
    "Svájcba": "Svájc",
    "Svájcban": "Svájc",
    "Syme-mal": "Syme",
    "Syme-ot": "Syme",
    "Syme-ra": "Syme",
    "Szabolcsban": "Szabolcs",
    "Szaharában": "Szahara",
    "Szarajevóban": "Szarajevó",
    "Szarajevótól": "Szarajevó",
    "Szegeden": "Szeged",
    "Szegedre": "Szeged",
    "Szentek-utcájára": "Szentek-utcája",
    "Szentgotthárdon": "Szentgotthárd",
    "Szerencse": "Szerencs",
    "Szerencsen": "Szerencs",
    "Szerencsére": "Szerencs",
    "Szerintük": "szerint",
    "Szibériába": "Szibéria",
    "Szkopjét": "Szkopje",
    "Szlovákiába": "Szlovákia",
    "Szlovákiában": "Szlovákia",
    "Szlovákiáért": "Szlovákia",
    "Szolnokra": "Szolnok",
    "Szondi-tesztet": "Szondi-teszt",
    "Szondi-tesztjének": "Szondi-teszt",
    "Szondinál": "Szondi",
    "Szondit": "Szondi",
    "Szonditól": "Szondi",
    "Szovjetunióból": "Szovjetunió",
    "Székesfehérváron": "Székesfehérvár",
    "Szíriával": "Szíria",
    "Sándornak": "Sándor",
    "Sándorral": "Sándor",
    "Sándort": "Sándor",
    "Sándortól": "Sándor",
    "Tacitusát": "Tacitus",
    "Tanzániából": "Tanzánia",
    "Terézvárosban": "Terézváros",
    "Tibetnek": "Tibet",
    "Tiborét": "Tibor",
    "Tihanyi": "Tihany",
    "Tillotsont": "Tillotson",
    "Times-ba": "Times",
    "Times-ban": "Times",
    "Times-ból": "Times",
    "Times-vezércikkből": "Times-vezárcikk",
    "Tisza-tavon": "Tisza-tó",
    "Tiszába": "Tisza",
    "Tiszán": "Tisza",
    "Tiszántúlt": "Tiszántúl",
    "Tiszától": "Tisza",
    "Tivadarral": "Tivadar",
    "Torinóban": "Torinó",
    "Torontói": "Toronto",
    "Transsylvaniában": "Transsylvania",
    "Törökbálintot": "Törökbálint",
    "Ukrajnába": "Ukrajna",
    "Ukrajnában": "Ukrajna",
    "Ukrajnából": "Ukrajna",
    "Ukrajnával": "Ukrajna",
    "Veled": "te",
    "Velencében": "Velence",
    "Verditől": "Verdi",
    "Vergiliushoz": "Vergilius",
    "Veszprémben": "Veszprém",
    "Visegrádra": "Visegrád",
    "Visztuláig": "Visztula",
    "Wagner-rendezéseivel": "Wagner-rendezés",
    "Wallenberg-csoporthoz": "Wallenberg-csoport",
    "Washingtonban": "Washington",
    "Washingtontól": "Washington",
    "Winstonba": "Winston",
    "Winstonban": "Winston",
    "Winstonból": "Winston",
    "Winstonhoz": "Winston",
    "Winstonnak": "Winston",
    "Winstonnal": "Winston",
    "Winstonon": "Winston",
    "Winstonra": "Winston",
    "Winstonról": "Winston",
    "Winstont": "Winston",
    "Winstontól": "Winston",
    "Winstoné": "Winston",
    "Winstonékat": "Winstonék",
    "Winstonéval": "Winston",
    "Witherst": "Withers",
    "Yorkban": "York",
    "Yorkjának": "York",
    "Zalaegerszegen": "Zalaegerszeg",
    "Zalában": "Zala",
    "Zoltánok": "Zoltán",
    "Zoltánt": "Zoltán",
    "Zsigmondnál": "Zsigmond",
    "Zsigához": "Zsiga",
    "Zsigát": "Zsiga",
    "Zsoltot": "Zsolt",
    "Zsuzsannát": "Zsuzsanna",
    "Zsuzsának": "Zsuzsa",
    "Zsuzsáéból": "Zsuzsa",
    "Zágrábban": "Zágráb",
    "Zágrábból": "Zágráb",
    "Zürichbe": "Zürich",
    "Zürichben": "Zürich",
    "abba": "az",
    "abbahagyni": "abbahagy",
    "abbahagyta": "abbahagy",
    "abbahagytam": "abbahagy",
    "abbahagytuk": "abbahagy",
    "abbahagyták": "abbahagy",
    "abbamaradni": "abbamarad",
    "abbamaradt": "abbamarad",
    "abban": "az",
    "abból": "az",
    "ablaka": "ablak",
    "ablakai": "ablak",
    "ablakaik": "ablak",
    "ablakaikkal": "ablak",
    "ablakainak": "ablak",
    "ablakba": "ablak",
    "ablakfára": "ablakfa",
    "ablakhoz": "ablak",
    "ablakkal": "ablak",
    "ablakok": "ablak",
    "ablakokat": "ablak",
    "ablakokba": "ablak",
    "ablakokkal": "ablak",
    "ablakokon": "ablak",
    "ablakon": "ablak",
    "ablakot": "ablak",
    "ablakpárkánynak": "ablakpárkány",
    "ablakpárkányra": "ablakpárkány",
    "ablakrésekhez": "ablakrés",
    "ablaksorukból": "ablaksor",
    "ablakában": "ablak",
    "ablakából": "ablak",
    "ablakán": "ablak",
    "ablakát": "ablak",
    "ablaküvegeiről": "ablaküveg",
    "ablaküvegen": "ablaküveg",
    "abortuszok": "abortusz",
    "abortuszt": "abortusz",
    "abszurdnak": "abszurd",
    "acatot": "acat",
    "acélajtókon": "acélajtó",
    "acélból": "acél",
    "acélművet": "acélmű",
    "acélozta": "acéloz",
    "acélról": "acél",
    "acélrúddal": "acélrúd",
    "adagban": "adag",
    "adagjánál": "adag",
    "adagot": "adag",
    "adata": "adat",
    "adatai": "adat",
    "adataiba": "adat",
    "adatainak": "adat",
    "adatait": "adat",
    "adatnyilvántartásban": "adatnyilvántartás",
    "adatnál": "adatik",
    "adatok": "adatik",
    "adatokat": "adat",
    "adatokkal": "adat",
    "adatoknak": "adat",
    "adatott": "adatik",
    "add": "ad",
    "addig": "az",
    "adhassa": "adhat",
    "adhassunk": "adhat",
    "adhatja": "adhat",
    "adhatják": "adhat",
    "adhatna": "adhat",
    "adhatnak": "adhat",
    "adhatom": "adhat",
    "adhatott": "adhat",
    "adhatsz": "adhat",
    "adhattam": "adhat",
    "adja": "ad",
    "adja-veszi": "ad-vesz",
    "adjak": "ad",
    "adjanak": "ad",
    "adjatok": "ad",
    "adjon": "ad",
    "adjuk": "ad",
    "adjunk": "ad",
    "adják": "ad",
    "admirálist": "admirális",
    "adna": "ad",
    "adnak": "ad",
    "adni": "ad",
    "adnia": "ad",
    "adná": "ad",
    "adod": "ad",
    "adogatásaival": "adogatás",
    "adok": "ad",
    "adom": "ad",
    "adományokat": "adomány",
    "adományozott": "adományoz",
    "adományozta": "adományoz",
    "adományából": "adomány",
    "adott": "ad",
    "adottak": "adott",
    "adottnak": "adott",
    "adottságainknak": "adottság",
    "adottságokat": "adottság",
    "adta": "ad",
    "adtad": "ad",
    "adtak": "ad",
    "adtam": "ad",
    "adtuk": "ad",
    "adtunk": "ad",
    "adták": "adta",
    "adunk": "adu",
    "adásban": "adás",
    "adások": "adás",
    "adást": "adás",
    "adásához": "adás",
    "adásáról": "adás",
    "adásával": "adás",
    "adóalanyok": "adóalany",
    "adóalanyt": "adóalany",
    "adóbevallásban": "adóbevallás",
    "adóbevételek": "adóbevétel",
    "adóból": "adó",
    "adócsalással": "adócsalás",
    "adócsökkentésről": "adócsökkentés",
    "adódnak": "adódik",
    "adódott": "adódik",
    "adódóan": "adódó",
    "adóelengedéssel": "adóelengedés",
    "adófajták": "adófajtá",
    "adófizetői": "adófizető",
    "adófizetőket": "adófizető",
    "adóhatósága": "adóhatóság",
    "adóhatóságok": "adóhatóság",
    "adóhivatalba": "adóhivatal",
    "adóhivatallal": "adóhivatal",
    "adójogszabályok": "adójogszabály",
    "adóját": "adó",
    "adók": "adó",
    "adókat": "adó",
    "adókból": "adó",
    "adókedvezménye": "adókedvezmény",
    "adókedvezményre": "adókedvezmény",
    "adókedvezményt": "adókedvezmény",
    "adókkal": "adó",
    "adókról": "adó",
    "adómentesnek": "adómentes",
    "adórendszert": "adórendszer",
    "adósak": "adós",
    "adósodott": "adósod",
    "adósok": "adós",
    "adósság-átütemezést": "adósság-átütemezés",
    "adóssága": "adósság",
    "adósságait": "adósság",
    "adósságcsapdában": "adósságcsapda",
    "adósságokat": "adósság",
    "adósságot": "adósság",
    "adósságterhéből": "adósságteher",
    "adósságából": "adósság",
    "adósságállománnyal": "adósságállomány",
    "adósságállományt": "adósságállomány",
    "adósságának": "adósság",
    "adósságát": "adósság",
    "adósságért": "adósság",
    "adósunk": "adós",
    "adószabályozást": "adószabályozás",
    "adószabályozásunk": "adószabályozás",
    "adószám-tulajdonost": "adószám-tulajdonos",
    "adószámhoz": "adószám",
    "adószámmal": "adószám",
    "adószámok": "adószám",
    "adószámot": "adószám",
    "adósávok": "adósáv",
    "adót": "adó",
    "adótartozása": "adótartozás",
    "adótartozásainak": "adótartozás",
    "adótartozásokról": "adótartozás",
    "adótartozását": "adótartozás",
    "adóterheinket": "adóteher",
    "adóterhek": "adóteher",
    "adótörvények": "adótörvény",
    "adóval": "adó",
    "adózott": "adózik",
    "adózók": "adózó",
    "adózóknak": "adózó",
    "aggatott": "aggat",
    "aggodalmak": "aggodalom",
    "aggodalmakat": "aggodalom",
    "aggodalmam": "aggodalom",
    "aggodalmasan": "aggodalmas",
    "aggodalmat": "aggodalom",
    "aggodalmát": "aggodalom",
    "aggodalomra": "aggodalom",
    "aggok": "agg",
    "aggályaira": "aggály",
    "aggályok": "aggály",
    "aggályosnak": "aggályos",
    "aggódj": "aggódik",
    "aggódni": "aggódik",
    "aggódom": "aggódik",
    "aggódott": "aggódik",
    "aggódtak": "aggódik",
    "aggódást": "aggódás",
    "aggódón": "aggódó",
    "agresszivitásuk": "agresszivitás",
    "agya": "agy",
    "agyafúrtak": "agyafúrt",
    "agyak": "agy",
    "agyaként": "agy",
    "agyalt": "agyal",
    "agyam": "agy",
    "agyamban": "agy",
    "agyaráért": "agyara",
    "agyat": "agy",
    "agyban": "agy",
    "agyközpontok": "agyközpont",
    "agyon": "agy",
    "agyonlövetése": "agyonlövetés",
    "agyonlövik": "agyonlő",
    "agyonlőni": "agyonlő",
    "agyonlőnék": "agyonlő",
    "agyonlőttek": "agyonlőtt",
    "agyonmacerálták": "agyonmacerál",
    "agyonstrapált": "agyonstrapál",
    "agyontaposnak": "agyontapos",
    "agyontapossák": "agyontapos",
    "agyonunja": "agyonun",
    "agyonverni": "agyonver",
    "agyonvágták": "agyonvág",
    "agyonéheztették": "agyonéheztet",
    "agyra": "agy",
    "agyról": "agy",
    "agytornafélére": "agytornaféle",
    "agyunkban": "agy",
    "agyába": "agy",
    "agyában": "agy",
    "agyából": "agy",
    "agyán": "agy",
    "agyát": "agy",
    "ahhoz": "az",
    "ahányat": "ahány",
    "ajakkal": "ajak",
    "ajka": "ajak",
    "ajkak": "ajak",
    "ajkuk": "ajak",
    "ajkán": "ajak",
    "ajkának": "ajak",
    "ajkára": "ajak",
    "ajkát": "ajak",
    "ajtaja": "ajtó",
    "ajtaján": "ajtó",
    "ajtaját": "ajtó",
    "ajtóból": "ajtó",
    "ajtók": "ajtó",
    "ajtókeretek": "ajtókeret",
    "ajtón": "ajtó",
    "ajtónak": "ajtó",
    "ajtónál": "ajtó",
    "ajtóra": "ajtó",
    "ajtót": "ajtó",
    "ajtótól": "ajtó",
    "ajtóval": "ajtó",
    "ajándékba": "ajándék",
    "ajándékot": "ajándék",
    "ajándékoztuk": "ajándékoz",
    "ajánlanak": "ajánl",
    "ajánlani": "ajánl",
    "ajánlanánk": "ajánl",
    "ajánlata": "ajánlat",
    "ajánlatadásra": "ajánlatadás",
    "ajánlatai": "ajánlat",
    "ajánlathoz": "ajánlat",
    "ajánlatnak": "ajánlat",
    "ajánlatok": "ajánlat",
    "ajánlaton": "ajánlat",
    "ajánlatot": "ajánlat",
    "ajánlattevők": "ajánlattevő",
    "ajánlattevőket": "ajánlattevő",
    "ajánlattevőknek": "ajánlattevő",
    "ajánlattevőkre": "ajánlattevő",
    "ajánlattevőnek": "ajánlattevő",
    "ajánlattételre": "ajánlattétel",
    "ajánlatának": "ajánlat",
    "ajánlatát": "ajánlat",
    "ajánlja": "ajánl",
    "ajánlják": "ajánl",
    "ajánlkozott": "ajánlkozik",
    "ajánlok": "ajánl",
    "ajánlott": "ajánl",
    "ajánlotta": "ajánl",
    "ajánlottak": "ajánlott",
    "ajánlották": "ajánl",
    "ajánltak": "ajánl",
    "ajánlásait": "ajánlás",
    "ajánlásból": "ajánlás",
    "ajánlást": "ajánlás",
    "ajánlását": "ajánlás",
    "akadhatott": "akadhat",
    "akadnak": "akad",
    "akadt": "akad",
    "akadtak": "akadt",
    "akadtunk": "akadt",
    "akadálya": "akadály",
    "akadályok": "akadály",
    "akadályokat": "akadály",
    "akadályozni": "akadályoz",
    "akadályozná": "akadályoz",
    "akadályozta": "akadályoz",
    "akadályozza": "akadályoz",
    "akadályozzák": "akadályoz",
    "akadályt": "akadály",
    "akadályának": "akadály",
    "akadékoskodott": "akadékoskodik",
    "akadémikusok": "akadémikus",
    "akadémikusokkal": "akadémikus",
    "akarata": "akarat",
    "akaratlanul": "akaratlan",
    "akaratodat": "akarat",
    "akaratodból": "akarat",
    "akaratodnak": "akarat",
    "akaratuk": "akarat",
    "akaratukból": "akarat",
    "akaratából": "akarat",
    "akaratának": "akarat",
    "akaratát": "akarat",
    "akaratával": "akarat",
    "akarhatnék": "akarhat",
    "akarja": "akar",
    "akarjon": "akar",
    "akarjuk": "akar",
    "akarják": "akar",
    "akarjátok": "akar",
    "akarna": "akar",
    "akarnak": "akar",
    "akarná": "akar",
    "akarnád": "akar",
    "akarnák": "akar",
    "akarnál": "akar",
    "akarnánk": "akar",
    "akarnék": "akar",
    "akarod": "akar",
    "akarok": "akar",
    "akarom": "akar",
    "akarsz": "akar",
    "akart": "akar",
    "akarta": "akar",
    "akartad": "akart",
    "akartak": "akart",
    "akartam": "akart",
    "akartok": "akar",
    "akartuk": "akar",
    "akartunk": "akart",
    "akarták": "akar",
    "akartál": "akar",
    "akarunk": "akar",
    "akasszatok": "akaszt",
    "akasztani": "akaszt",
    "akaszthassanak": "akaszthat",
    "akasztják": "akaszt",
    "akasztást": "akasztás",
    "akasztását": "akasztás",
    "akceptálja": "akceptál",
    "akcióban": "akció",
    "akcióira": "akciói",
    "akciója": "akció",
    "akciójaként": "akció",
    "akciójukat": "akció",
    "akciójukkal": "akció",
    "akcióját": "akció",
    "akciók": "akció",
    "akcióra": "akció",
    "akcióról": "akció",
    "akciót": "akció",
    "akibe": "aki",
    "akiben": "aki",
    "akiből": "aki",
    "akihez": "aki",
    "akik": "aki",
    "akikben": "aki",
    "akiken": "aki",
    "akiket": "aki",
    "akikhez": "aki",
    "akikkel": "aki",
    "akiknek": "aki",
    "akikre": "aki",
    "akikről": "aki",
    "akiktől": "aki",
    "akin": "aki",
    "akinek": "aki",
    "akinél": "aki",
    "akire": "aki",
    "akiről": "aki",
    "akit": "aki",
    "akivel": "aki",
    "akiét": "aki",
    "akkor": "az",
    "akkordot": "akkord",
    "akkoriban": "akkori",
    "akkortól": "akkor",
    "akkorák": "akkora",
    "akkorára": "akkora",
    "akkumulátorok": "akkumulátor",
    "aknamezőket": "aknamező",
    "aknaszakértőnek": "aknaszakértő",
    "aknák": "akna",
    "aknákat": "akna",
    "aknát": "akna",
    "aknával": "akna",
    "akolajtajuk": "akolajtó",
    "akolajtót": "akolajtó",
    "akolból": "akol",
    "aktatáskájából": "aktatáska",
    "aktivistái": "aktivista",
    "aktivistája": "aktivista",
    "aktivitása": "aktivitás",
    "aktivitással": "aktivitás",
    "aktivitást": "aktivitás",
    "aktivizálódott": "aktivizálódik",
    "aktok": "akt",
    "aktualitásokra": "aktualitás",
    "aktualitást": "aktualitás",
    "aktualizálni": "aktualizál",
    "aktust": "aktus",
    "aktusát": "aktus",
    "aktívaké": "aktív",
    "aktívan": "aktív",
    "aktívnak": "aktív",
    "akáccserje": "akáccser",
    "akácfakaptába": "akácfakapta",
    "akácfasorokat": "akácfasor",
    "akácfánál": "akácfa",
    "akárkinek": "akárki",
    "akármennyire": "akármennyi",
    "akármennyit": "akármennyi",
    "akármilyen": "akármily",
    "akármiről": "akármi",
    "akármit": "akármi",
    "alacsonyabb": "alacsony",
    "alacsonyabban": "alacsony",
    "alacsonyra": "alacsony",
    "alagútjain": "alagút",
    "alakba": "alak",
    "alakja": "alak",
    "alakjába": "alak",
    "alakjában": "alak",
    "alakját": "alak",
    "alakok": "alak",
    "alakokat": "alak",
    "alakokká": "alak",
    "alakot": "alak",
    "alakul": "alak",
    "alakulatnak": "alakulat",
    "alakulatok": "alakulat",
    "alakulna": "alakul",
    "alakulnak": "alakul",
    "alakulni": "alakul",
    "alakulnod": "alakul",
    "alakult": "alakul",
    "alakultak": "alakult",
    "alakultunk": "alakult",
    "alakulása": "alakulás",
    "alakulást": "alakulás",
    "alakulását": "alakulás",
    "alakítana": "alakít",
    "alakítanak": "alakít",
    "alakítani": "alakít",
    "alakítania": "alakít",
    "alakítja": "alakít",
    "alakítjuk": "alakít",
    "alakítják": "alakít",
    "alakított": "alakít",
    "alakította": "alakít",
    "alakítottak": "alakított",
    "alakították": "alakít",
    "alakítsa": "alakít",
    "alakítsanak": "alakít",
    "alakításokat": "alakítás",
    "alakításomban": "alakítás",
    "alakításáról": "alakítás",
    "alamizsnálkodást": "alamizsnálkodás",
    "alanyai": "alany",
    "alanyaimat": "alany",
    "alanyiak": "alanyi",
    "alapdíjat": "alapdíj",
    "alapelvei": "alapelv",
    "alapelveinek": "alapelv",
    "alapelveiről": "alapelv",
    "alapelveit": "alapelv",
    "alapelvekben": "alapelv",
    "alapelvekre": "alapelv",
    "alapelvként": "alapelvkén",
    "alaperőműből": "alaperőmű",
    "alapfeladatok": "alapfeladat",
    "alapfeladatának": "alapfeladat",
    "alapfeltétele": "alapfeltétel",
    "alapfizetést": "alapfizetés",
    "alapja": "alap",
    "alapjainak": "alap",
    "alapjutalékot": "alapjutalék",
    "alapjában": "alap",
    "alapján": "alap",
    "alapját": "alap",
    "alapjátékok": "alapjáték",
    "alapjául": "alap",
    "alapkövét": "alapkő",
    "alapon": "alap",
    "alaposabban": "alapos",
    "alaposan": "alapos",
    "alapossággal": "alaposság",
    "alapot": "alap",
    "alapozni": "alapoz",
    "alapozott": "alapoz",
    "alapoztak": "alapoz",
    "alapozták": "alapoz",
    "alapozza": "alapoz",
    "alapozással": "alapozás",
    "alappal": "alap",
    "alappillére": "alappillér",
    "alapproblémáiról": "alapprobléma",
    "alapról": "alap",
    "alapszabály-módosítást": "alapszabály-módosítás",
    "alapszabályai": "alapszabály",
    "alapszerződésről": "alapszerződés",
    "alapszerződést": "alapszerződés",
    "alapterülettel": "alapterület",
    "alapterületét": "alapterület",
    "alaptételein": "alaptétel",
    "alaptőke-csökkentést": "alaptőke-csökkentés",
    "alaptőkéje": "alaptőke",
    "alaptőkéjének": "alaptőke",
    "alaptőkével": "alaptőke",
    "alapul": "alap",
    "alapult": "alapul",
    "alapvetően": "alapvető",
    "alapvetőnek": "alapvető",
    "alapvonásai": "alapvonás",
    "alapértékei": "alapérték",
    "alapítani": "alapít",
    "alapítok": "alapít",
    "alapított": "alapít",
    "alapította": "alapít",
    "alapítottak": "alapított",
    "alapítványának": "alapítvány",
    "alapítással": "alapítás",
    "alapítók": "alapító",
    "alapötletük": "alapötlet",
    "alatta": "alatt",
    "alattiak": "alatti",
    "alattuk": "alatt",
    "alattvalói": "alattvaló",
    "alattvalóik": "alattvaló",
    "alattvalót": "alattvaló",
    "albizottságoknak": "albizottság",
    "albizottságába": "albizottság",
    "albumot": "album",
    "albumát": "album",
    "albumáért": "album",
    "albérletbe": "albérlet",
    "albérletben": "albérlet",
    "alelnöke": "alelnök",
    "alelnökkel": "alelnök",
    "alelnöknek": "alelnök",
    "alelnökök": "alelnök",
    "alelnököt": "alelnök",
    "alibije": "alibi",
    "alja": "alj",
    "aljában": "alja",
    "aljából": "alja",
    "alján": "alja",
    "aljára": "alja",
    "alját": "alja",
    "alkalma": "alkalom",
    "alkalmakkor": "alkalom",
    "alkalmam": "alkalom",
    "alkalmasak": "alkalmas",
    "alkalmasságot": "alkalmasság",
    "alkalmasságukat": "alkalmasság",
    "alkalmasságát": "alkalmasság",
    "alkalmat": "alkalom",
    "alkalmatlanabb": "alkalmatlan",
    "alkalmatlanná": "alkalmatlan",
    "alkalmazkodni": "alkalmazkodik",
    "alkalmazkodnia": "alkalmazkodik",
    "alkalmazkodnom": "alkalmazkodik",
    "alkalmazkodása": "alkalmazkodás",
    "alkalmazkodást": "alkalmazkodás",
    "alkalmazkodásuk": "alkalmazkodás",
    "alkalmazna": "alkalmaz",
    "alkalmaznak": "alkalmaz",
    "alkalmazni": "alkalmaz",
    "alkalmazniuk": "alkalmaz",
    "alkalmazná": "alkalmaz",
    "alkalmazott": "alkalmaz",
    "alkalmazottak": "alkalmazott",
    "alkalmazottakból": "alkalmazott",
    "alkalmazottja": "alkalmazott",
    "alkalmazottjától": "alkalmazott",
    "alkalmaztak": "alkalmaz",
    "alkalmazták": "alkalmaz",
    "alkalmazzák": "alkalmaz",
    "alkalmazása": "alkalmazás",
    "alkalmazásukra": "alkalmazás",
    "alkalmazásának": "alkalmazás",
    "alkalmazására": "alkalmazás",
    "alkalmazásával": "alkalmazás",
    "alkalmából": "alkalom",
    "alkalmával": "alkalom",
    "alkalommal": "alkalom",
    "alkalomra": "alkalom",
    "alkalomszerűen": "alkalomszerű",
    "alkancellár-külügyminiszternek": "alkancellár-külügyminiszter",
    "alkata": "alkat",
    "alkatrészei": "alkatrész",
    "alkatrészekkel": "alkatrész",
    "alkoholtól": "alkohol",
    "alkonyatig": "alkonyat",
    "alkonyattájban": "alkonyattáj",
    "alkonyodott": "alkonyodik",
    "alkonyon": "alkony",
    "alkoss": "alkot",
    "alkosson": "alkot",
    "alkotja": "alkot",
    "alkotják": "alkot",
    "alkotmányból": "alkotmány",
    "alkotmányt": "alkotmány",
    "alkotmányukból": "alkotmány",
    "alkotna": "alkot",
    "alkotnak": "alkot",
    "alkotni": "alkot",
    "alkotott": "alkot",
    "alkottak": "alkot",
    "alkottál": "alkot",
    "alkotásai": "alkotás",
    "alkotások": "alkotás",
    "alkotáson": "alkotás",
    "alkotásának": "alkotás",
    "alkotóelemének": "alkotóelem",
    "alkotóerőt": "alkotóerő",
    "alkotói": "alkotó",
    "alkotójuk": "alkotó",
    "alkotók": "alkotó",
    "alkotómunkáját": "alkotómunka",
    "alkudhassunk": "alkudhat",
    "alkudni": "alkuszik",
    "alkudozni": "alkudozik",
    "alkudoztunk": "alkudozik",
    "alkudozásnak": "alkudozás",
    "alkudozásokat": "alkudozás",
    "alkudozással": "alkudozás",
    "alkuszok": "alkuszik",
    "allokációra": "allokáció",
    "alma": "alom",
    "almafáival": "almafa",
    "almot": "alom",
    "almákkal": "alma",
    "almát": "alom",
    "alsóbb": "alsó",
    "alsóbbrendűnek": "alsóbbrendű",
    "alsóbbrendűségének": "alsóbbrendűség",
    "alsókarja": "alsókar",
    "alsókarjai": "alsókar",
    "alsókarokat": "alsókar",
    "alsóruhája": "alsóruha",
    "alsóruhájának": "alsóruha",
    "alsóruhát": "alsóruha",
    "altatótól": "altató",
    "alternatívája": "alternatíva",
    "alternatívák": "alternatíva",
    "alternatívát": "alternatíva",
    "altisztek": "altiszt",
    "altisztjeihez": "altiszt",
    "altisztnél": "altiszt",
    "altiszttől": "altiszt",
    "altételeként": "altétel",
    "aludjunk": "alszik",
    "aludjék": "alszik",
    "aludni": "alszik",
    "aludnia": "alszik",
    "aludt": "alszik",
    "aludtak": "aludt",
    "aludtam": "aludt",
    "aludtunk": "aludt",
    "aludtál": "alszik",
    "aluliak": "aluli",
    "alulmaradt": "alulmarad",
    "alulmúlja": "alulmúlik",
    "alultámogatott": "alultámogat",
    "alultápláltságban": "alultápláltság",
    "alussza": "alszik",
    "alusznak": "alszik",
    "alvállalkozók": "alvállalkozó",
    "alváshiányt": "alváshiány",
    "alváson": "alvás",
    "alvással": "alvás",
    "alvást": "alvás",
    "alvását": "alvás",
    "alvázára": "alváz",
    "aláaknázni": "aláaknáz",
    "aláaknázza": "aláaknáz",
    "alábbhagyni": "alábbhagy",
    "alábbhagyott": "alábbhagy",
    "alábecsülik": "alábecsül",
    "alábecsülnénk": "alábecsül",
    "aláhúzott": "aláhúz",
    "alája": "alá",
    "alárendelt": "alárendel",
    "alárendeltjétől": "alárendelt",
    "alátámasztja": "alátámaszt",
    "alátámasztott": "alátámaszt",
    "alátámasztották": "alátámaszt",
    "alávetik": "alávet",
    "alávetni": "alávet",
    "alázatosabb": "alázatos",
    "alázatosan": "alázatos",
    "alázatosságból": "alázatosság",
    "alázkodnod": "alázkodik",
    "aláznak": "aláz",
    "alázni": "aláz",
    "aláírja": "aláír",
    "aláírják": "aláír",
    "aláírni": "aláír",
    "aláírom": "aláír",
    "aláírt": "aláír",
    "aláírta": "aláír",
    "aláírtunk": "aláírt",
    "aláírták": "aláír",
    "aláírásgyűjtést": "aláírásgyűjtés",
    "aláírások": "aláírás",
    "aláírásra": "aláírás",
    "aláírással": "aláírás",
    "aláírásának": "aláírás",
    "aláírására": "aláírás",
    "aláírásával": "aláírás",
    "aláírói": "aláíró",
    "aláírók": "aláíró",
    "aláírókat": "aláíró",
    "amazok": "amaz",
    "ambícióim": "ambíció",
    "ambícióm": "ambíció",
    "amekkorák": "amekkora",
    "amekkorára": "amekkora",
    "amellyel": "amely",
    "amelybe": "amely",
    "amelyben": "amely",
    "amelyből": "amely",
    "amelyek": "amely",
    "amelyekben": "amely",
    "amelyekből": "amely",
    "amelyeken": "amely",
    "amelyeket": "amely",
    "amelyekhez": "amely",
    "amelyekkel": "amely",
    "amelyeknek": "amely",
    "amelyekre": "amely",
    "amelyekről": "amely",
    "amelyekért": "amely",
    "amelyen": "amely",
    "amelyet": "amely",
    "amelyhez": "amely",
    "amelyikben": "amelyik",
    "amelyiken": "amelyik",
    "amelyikkel": "amelyik",
    "amelyiknek": "amelyik",
    "amelyikről": "amelyik",
    "amelyikért": "amelyik",
    "amelynek": "amely",
    "amelynél": "amely",
    "amelyre": "amely",
    "amelyről": "amely",
    "amelytől": "amely",
    "amelyért": "amely",
    "amennyibe": "amennyi",
    "amennyiben": "amennyi",
    "amennyije": "amennyi",
    "amennyire": "amennyi",
    "amennyit": "amennyi",
    "amennyivel": "amennyi",
    "amerikaiak": "amerikai",
    "amerikaiaknak": "amerikai",
    "ametisztért": "ametiszt",
    "amibe": "ami",
    "amiben": "ami",
    "amiből": "ami",
    "amihez": "ami",
    "amik": "ami",
    "amiket": "ami",
    "amikor": "ami",
    "amiként": "ami",
    "amilyen": "amily",
    "amilyenbe": "amilyen",
    "amilyenben": "amilyen",
    "amilyenek": "amilyen",
    "amilyeneket": "amilyen",
    "amilyennek": "amilyen",
    "amilyennel": "amilyen",
    "amilyenné": "amilyen",
    "amilyenre": "amilyen",
    "amilyent": "amilyen",
    "amilyet": "amily",
    "amin": "ami",
    "aminek": "ami",
    "amire": "ami",
    "amiről": "ami",
    "amit": "ami",
    "amitől": "ami",
    "amivel": "ami",
    "amiért": "ami",
    "ammóniakristályok": "ammóniakristály",
    "amnesztiája": "amnesztia",
    "ampullát": "ampulla",
    "amputált": "amputál",
    "amputáltatunk": "amputáltat",
    "analízisek": "analízis",
    "analízisét": "analízis",
    "analógiákat": "analógia",
    "anekdotáiban": "anekdota",
    "anekdotája": "anekdota",
    "anekdotákon": "anekdota",
    "angolaiak": "angolai",
    "angoljával": "angol",
    "angolok": "angol",
    "angoloknak": "angol",
    "angolra": "angol",
    "angolt": "angol",
    "angolul": "angol",
    "angolórán": "angolóra",
    "angyalok": "angyal",
    "annak": "az",
    "annyiban": "annyi",
    "annyiból": "annyi",
    "annyira": "annyi",
    "annyit": "annyi",
    "annyival": "annyi",
    "annál": "az",
    "anomáliát": "anomália",
    "antagonisztikusak": "antagonisztikus",
    "antimonitot": "antimonit",
    "antiszemitizmusról": "antiszemitizmus",
    "anyaga": "anyag",
    "anyagból": "anyag",
    "anyaggal": "anyag",
    "anyaghoz": "anyag",
    "anyagiak": "anyagi",
    "anyagiakat": "anyagi",
    "anyagismeretére": "anyagismeret",
    "anyagnak": "anyag",
    "anyagok": "anyag",
    "anyagokat": "anyag",
    "anyagokból": "anyag",
    "anyagokkal": "anyag",
    "anyagot": "anyag",
    "anyagtól": "anyag",
    "anyaguk": "anyag",
    "anyagának": "anyag",
    "anyanyelvén": "anyanyelv",
    "anyaszondához": "anyaszonda",
    "anyaszondáról": "anyaszonda",
    "anyaállat": "anyaáll",
    "anyja": "anya",
    "anyjuk": "anya",
    "anyjukat": "anya",
    "anyjuktól": "anya",
    "anyján": "anya",
    "anyjának": "anya",
    "anyjánál": "anya",
    "anyjára": "anya",
    "anyjáról": "anya",
    "anyját": "anya",
    "anyjától": "anya",
    "anyjával": "anya",
    "anyukámat": "anyuka",
    "anyukának": "anyuka",
    "anyukát": "anyuka",
    "anyukával": "anyuka",
    "anyád": "anya",
    "anyáink": "anya",
    "anyák": "anya",
    "anyákat": "anya",
    "anyámat": "anya",
    "anyámmal": "anya",
    "anyásra": "anyás",
    "anyátok": "anya",
    "anyósa": "anyós",
    "anyóst": "anyós",
    "anyósát": "anyós",
    "apadt": "apad",
    "apadásával": "apadás",
    "apagyilkosnak": "apagyilkos",
    "apja": "apa",
    "apjuk": "apa",
    "apjuknak": "apa",
    "apjának": "apa",
    "apjára": "apa",
    "apját": "apa",
    "apjával": "apa",
    "apológiáját": "apológia",
    "apparátust": "apparátus",
    "apparátusát": "apparátus",
    "apraját": "apraja",
    "aprítanak": "aprít",
    "aprítaná": "aprít",
    "apróbb": "apró",
    "aprók": "apró",
    "aprólékosan": "aprólékos",
    "aprólékossággal": "aprólékosság",
    "aprópénzem": "aprópénz",
    "aprópénzemmel": "aprópénz",
    "apróságtól": "apróság",
    "apukának": "apuka",
    "apunak": "apu",
    "apácásan": "apácás",
    "apád": "apa",
    "apáról": "apa",
    "apát": "apa",
    "apósa": "após",
    "arabok": "arab",
    "arabot": "arab",
    "aranyat": "arany",
    "aranyfényben": "aranyfény",
    "aranyhalak": "aranyhal",
    "aranyozott": "aranyoz",
    "aranyozásától": "aranyozás",
    "aranytócsákba": "aranytócsa",
    "arasznyira": "arasznyi",
    "araszolt": "araszol",
    "aratnak": "arat",
    "aratni": "arat",
    "aratott": "arat",
    "arattak": "arat",
    "arattam": "arat",
    "aratásba": "aratás",
    "aratásból": "aratás",
    "aratáshoz": "aratás",
    "aratáskor": "aratás",
    "aratásnak": "aratás",
    "aratásnál": "aratás",
    "aratáson": "aratás",
    "aratásra": "aratás",
    "aratással": "aratás",
    "aratást": "aratás",
    "aratócsapatot": "aratócsapat",
    "aratócsoportokat": "aratócsoport",
    "aratógazdák": "aratógazda",
    "aratógazdára": "aratógazda",
    "aratógazdával": "aratógazda",
    "aratógazdáé": "aratógazda",
    "aratógépek": "aratógép",
    "aratója": "arató",
    "aratók": "arató",
    "aratókat": "arató",
    "aratókhoz": "arató",
    "aratóknak": "arató",
    "aratólányok": "aratólány",
    "aratónak": "arató",
    "aratópálinkából": "aratópálinka",
    "aratórészből": "aratórész",
    "aratórészt": "aratórész",
    "aratórészét": "aratórész",
    "arca": "arc",
    "arcba": "arc",
    "arcból": "arc",
    "arcbőrén": "arcbőr",
    "arcbűn-nek": "arcbűn",
    "arccal": "arc",
    "arccsontjain": "arccsont",
    "arccsontjairól": "arccsont",
    "arccsontjait": "arccsont",
    "arccsontokkal": "arccsont",
    "archívumában": "archívum",
    "arcjátéka": "arcjáték",
    "arckifejezése": "arckifejezés",
    "arckifejezések": "arckifejezés",
    "arckifejezéssel": "arckifejezés",
    "arckifejezésére": "arckifejezés",
    "arckifejezését": "arckifejezés",
    "arckifejezésüket": "arckifejezés",
    "arcképe": "arckép",
    "arcképek": "arckép",
    "arcképeket": "arckép",
    "arcképnek": "arckép",
    "arcképét": "arckép",
    "arcnak": "arc",
    "arcod": "arc",
    "arcodba": "arc",
    "arcodról": "arc",
    "arcok": "arc",
    "arcokat": "arc",
    "arcokról": "arc",
    "arcom": "arc",
    "arcomra": "arc",
    "arcon": "arc",
    "arcot": "arc",
    "arcra": "arc",
    "arcról": "arc",
    "arctól": "arc",
    "arcuk": "arc",
    "arcukat": "arc",
    "arcukon": "arc",
    "arcukról": "arc",
    "arculata": "arculat",
    "arculatát": "arculat",
    "arcunk": "arc",
    "arcvonása": "arcvonás",
    "arcvonásain": "arcvonás",
    "arcvonásait": "arcvonás",
    "arcvonások": "arcvonás",
    "arcába": "arc",
    "arcában": "arc",
    "arcához": "arc",
    "arcán": "arc",
    "arcának": "arc",
    "arcára": "arc",
    "arcáról": "arc",
    "arcát": "arc",
    "arcától": "arc",
    "arcával": "arc",
    "argumentumoknál": "argumentum",
    "arisztokraták": "arisztokrata",
    "arisztokráciafélét": "arisztokráciaféle",
    "arisztokráciák": "arisztokrácia",
    "arra": "az",
    "arra-erre": "arez",
    "arról": "az",
    "arzént": "arzén",
    "aránya": "arány",
    "arányban": "arány",
    "arányhoz": "arány",
    "arányok": "arány",
    "arányokat": "arány",
    "arányokhoz": "arány",
    "arányosan": "arányos",
    "arányt": "arány",
    "aránytalanságokat": "aránytalanság",
    "aránytalanul": "aránytalan",
    "aránytól": "arány",
    "arányában": "arány",
    "arányát": "arány",
    "arénáiban": "aréna",
    "aspektusaiba": "aspektus",
    "asszimilálnia": "asszimilál",
    "asszimilálódni": "asszimilálódik",
    "asszisztenciájával": "asszisztencia",
    "asszisztensének": "asszisztens",
    "asszisztált": "asszisztál",
    "asszociációk": "asszociáció",
    "asszonnyal": "asszony",
    "asszonya": "asszony",
    "asszonyai": "asszony",
    "asszonyairól": "asszony",
    "asszonybolondok": "asszonybolond",
    "asszonyból": "asszony",
    "asszonyhoz": "asszony",
    "asszonykám": "asszonyka",
    "asszonynak": "asszony",
    "asszonyok": "asszony",
    "asszonyokat": "asszony",
    "asszonyokban": "asszony",
    "asszonyokból": "asszony",
    "asszonyokkal": "asszony",
    "asszonyoknak": "asszony",
    "asszonyoknál": "asszony",
    "asszonyokra": "asszony",
    "asszonyom": "asszony",
    "asszonyra": "asszony",
    "asszonysereget": "asszonysereg",
    "asszonyságok": "asszonyság",
    "asszonyt": "asszony",
    "asszonytól": "asszony",
    "aszfaltra": "aszfalt",
    "aszfaltút": "aszfaltú",
    "aszondom": "azt_mond",
    "aszongya": "azt_mond",
    "asztagai": "asztag",
    "asztagban": "asztag",
    "asztala": "asztal",
    "asztalfiókból": "asztalfiók",
    "asztalhoz": "asztal",
    "asztaliteniszezett": "asztaliteniszez",
    "asztaliteniszt": "asztalitenisz",
    "asztalkához": "asztalka",
    "asztalkán": "asztalka",
    "asztallal": "asztal",
    "asztallapokra": "asztallap",
    "asztallámpák": "asztallámpa",
    "asztalnál": "asztal",
    "asztalok": "asztal",
    "asztaloknál": "asztal",
    "asztalokon": "asztal",
    "asztalon": "asztal",
    "asztalosmesterként": "asztalosmesterkén",
    "asztalosról": "asztalos",
    "asztalra": "asztal",
    "asztalról": "asztal",
    "asztalt": "asztal",
    "asztaltól": "asztal",
    "asztalukhoz": "asztal",
    "asztalához": "asztal",
    "asztalán": "asztal",
    "asztalánál": "asztal",
    "asztalára": "asztal",
    "asztalát": "asztal",
    "atlanti-szigeteket": "atlanti-sziget",
    "atlaszt": "atlasz",
    "atlétákkal": "atléta",
    "atmoszférája": "atmoszféra",
    "atmoszférájába": "atmoszféra",
    "atmoszférájával": "atmoszféra",
    "atmoszférán": "atmoszféra",
    "atmoszférára": "atmoszféra",
    "atmoszférát": "atmoszféra",
    "atombombák": "atombomba",
    "atombombákkal": "atombomba",
    "atomerőműben": "atomerőmű",
    "atomerőműveiben": "atomerőmű",
    "atomerőművek": "atomerőmű",
    "atomerőműveket": "atomerőmű",
    "atomfegyverek": "atomfegyver",
    "atomháborújának": "atomháború",
    "atomizáltsága": "atomizáltság",
    "atomjaira": "atom",
    "atomkísérletek": "atomkísérlet",
    "atomkísérleteket": "atomkísérlet",
    "atomtemetőben": "atomtemető",
    "atrocitásairól": "atrocitás",
    "atropint": "atropin",
    "attitűdje": "attitűd",
    "attól": "az",
    "atyaian": "atyai",
    "atyja": "atya",
    "atyjától": "atya",
    "atyának": "atya",
    "atyáról": "atya",
    "atyáskodására": "atyáskodás",
    "augusztusban": "augusztus",
    "augusztusában": "augusztus",
    "aukcióján": "aukció",
    "automatikusan": "automatikus",
    "automatikusnak": "automatikus",
    "autonómiaterületek": "autonómiaterület",
    "autonómiájuknak": "autonómia",
    "autonómiáját": "autonómia",
    "autonómiát": "autonómia",
    "autonómmá": "autonóm",
    "autóban": "autó",
    "autóbusz-megállónál": "autóbusz-megálló",
    "autóbuszok": "autóbusz",
    "autóbuszon": "autóbusz",
    "autóbuszra": "autóbusz",
    "autóbuszról": "autóbusz",
    "autóbuszt": "autóbusz",
    "autók": "autó",
    "autókat": "autó",
    "autón": "autó",
    "autóparkjának": "autópark",
    "autópiacokon": "autópiac",
    "autópiacon": "autópiac",
    "autópályákat": "autópálya",
    "autópályának": "autópálya",
    "autósokra": "autós",
    "autót": "autó",
    "autóval": "autó",
    "autóvásárlásra": "autóvásárlás",
    "autóztak": "autózik",
    "avatnak": "avat",
    "avulnia": "avul",
    "avult": "avul",
    "avval": "az",
    "azbesztet": "azbeszt",
    "azbeszthulladékra": "azbeszthulladék",
    "azbesztlelőhelyet": "azbesztlelőhely",
    "azbeszttel": "azbeszt",
    "azbeszttől": "azbeszt",
    "azerbajdzsánban": "azerbajdzsán",
    "azok": "az",
    "azokat": "az",
    "azokban": "az",
    "azokból": "az",
    "azokkal": "az",
    "azoknak": "az",
    "azoknál": "az",
    "azokon": "az",
    "azokra": "az",
    "azokról": "az",
    "azoktól": "az",
    "azoké": "az",
    "azon": "az",
    "azonosak": "azonos",
    "azonossága": "azonosság",
    "azonosulni": "azonosul",
    "azonosította": "azonosít",
    "azonosították": "azonosít",
    "azonosítást": "azonosítás",
    "azonosításában": "azonosítás",
    "azonosításához": "azonosítás",
    "azt": "az",
    "azzal": "az",
    "azzá": "az",
    "azé": "az",
    "azéban": "az",
    "azért": "az",
    "azét": "az",
    "babakomódok": "babakomód",
    "babfőzelékhez": "babfőzelék",
    "bablevest": "bableves",
    "babnak": "bab",
    "babot": "bab",
    "babrálni": "babrál",
    "babrált": "babrál",
    "babszemek": "babszem",
    "babák": "baba",
    "babérkoszorúit": "babérkoszorúi",
    "badarságok": "badarság",
    "bagóra": "bagó",
    "baja": "baj",
    "bajai": "baj",
    "bajairól": "bajai",
    "bajba": "baj",
    "bajban": "baj",
    "bajlódni": "bajlódik",
    "bajlódott": "bajlódik",
    "bajnokok": "bajnok",
    "bajnokságon": "bajnokság",
    "bajnokságába": "bajnokság",
    "bajnokságán": "bajnokság",
    "bajnokának": "bajnok",
    "bajok": "baj",
    "bajokat": "baj",
    "bajokért": "baj",
    "bajom": "baj",
    "bajorjainak": "bajor",
    "bajorok": "bajor",
    "bajorokat": "bajor",
    "bajosan": "bajos",
    "bajszuk": "bajusz",
    "bajt": "baj",
    "bajtársaktól": "bajtárs",
    "bajtársiasságban": "bajtársiasság",
    "bajuk": "baj",
    "bajunk": "baj",
    "bajusza": "bajusz",
    "bajuszuk": "bajusz",
    "bajuszával": "bajusz",
    "baján": "baj",
    "bakancsaiban": "bakancs",
    "bakancsainak": "bakancs",
    "bakancsaival": "bakancs",
    "bakancsba": "bakancs",
    "bakancsból": "bakancs",
    "bakancsok": "bakancs",
    "bakancsot": "bakancs",
    "bakancsunkat": "bakancs",
    "baktattunk": "baktat",
    "bakterházaknál": "bakterház",
    "balesetek": "baleset",
    "baleseteket": "baleset",
    "balesetet": "baleset",
    "balesetről": "baleset",
    "balesetveszélyesek": "balesetveszélyes",
    "balettet": "balett",
    "balettozunk": "balettoz",
    "balja": "bal",
    "baljósnak": "baljós",
    "ballagjunk": "ballag",
    "ballagott": "ballag",
    "ballagtak": "ballag",
    "balogot": "balog",
    "balra": "bal",
    "balról": "bal",
    "balsejtelmeik": "balsejtelem",
    "balszerencséjére": "balszerencse",
    "balti-tenger": "baltitenger",
    "balul": "bal",
    "bandagazdák": "bandagazda",
    "bandagazdának": "bandagazda",
    "bandagazdát": "bandagazda",
    "bandagazdával": "bandagazda",
    "banditákról": "bandita",
    "bandukoltam": "bandukolt",
    "bandukoltunk": "bandukolt",
    "bandái": "banda",
    "bandákban": "banda",
    "bandát": "banda",
    "bank-egyesülés": "bankegyesülés",
    "bankban": "bank",
    "bankjegyet": "bankjegy",
    "bankjuk": "bank",
    "bankkal": "bank",
    "banknak": "bank",
    "bankok": "bank",
    "bankokhoz": "bank",
    "bankokkal": "bank",
    "bankoktól": "bank",
    "bankot": "bank",
    "bankszámláinkon": "bankszámla",
    "bankszámlájába": "bankszámla",
    "banánköztársaságban": "banánköztársaság",
    "barackot": "barack",
    "barackért": "barack",
    "barakkokig": "barakk",
    "barakktelepre": "barakktelep",
    "barbakánok": "barbakán",
    "barikádokon": "barikád",
    "barikádokról": "barikád",
    "barikádon": "barikád",
    "barlangja": "barlang",
    "barlangjának": "barlang",
    "barlangok": "barlang",
    "barlangokba": "barlang",
    "barlangokban": "barlang",
    "barlangomba": "barlang",
    "barlangot": "barlang",
    "barmok": "barom",
    "barmokat": "barom",
    "barnasága": "barnaság",
    "barnult": "barnul",
    "barnák": "barna",
    "baromfitenyésztésnek": "baromfitenyésztés",
    "baromfiért": "baromfi",
    "barátai": "barát",
    "barátaikkal": "barát",
    "barátaim": "barát",
    "barátainak": "barát",
    "barátainkat": "barát",
    "barátait": "barát",
    "barátban": "barát",
    "barátja": "barát",
    "barátjuk": "barát",
    "barátjával": "barát",
    "barátkozni": "barátkozik",
    "barátkozott": "barátkozik",
    "barátkozást": "barátkozás",
    "barátnőhöz": "barátnő",
    "barátnőivel": "barátnői",
    "barátnője": "barátnő",
    "barátoddal": "barát",
    "barátok": "barát",
    "barátokat": "barát",
    "barátom": "barát",
    "barátságból": "barátság",
    "barátságnak": "barátság",
    "barátságok": "barátság",
    "barátságosabb": "barátságos",
    "barátságosabban": "barátságos",
    "barátságosabbnak": "barátságos",
    "barátságosan": "barátságos",
    "barátságra": "barátság",
    "barátságára": "barátság",
    "barátságát": "barátság",
    "barátunk": "barát",
    "barázdák": "barázda",
    "bazáraiban": "bazár",
    "beadni": "bead",
    "beadta": "bead",
    "beadtam": "bead",
    "beadtuk": "bead",
    "bearanyozták": "bearanyoz",
    "beavatkozzék": "beavatkozik",
    "beavatkozása": "beavatkozás",
    "beavatkozáshoz": "beavatkozás",
    "beavatott": "beavat",
    "beavatottak": "beavatott",
    "beavatottjaként": "beavatott",
    "bebeszélted": "bebeszélt",
    "bebizonyosodik": "bebizonyosod",
    "bebizonyítani": "bebizonyít",
    "bebizonyítja": "bebizonyít",
    "bebizonyította": "bebizonyít",
    "bebizonyítsa": "bebizonyít",
    "bebizonyítsam": "bebizonyít",
    "bebocsátott": "bebocsát",
    "bebocsátása": "bebocsátás",
    "beborítják": "beborít",
    "beborították": "beborít",
    "beburkolja": "beburkol",
    "beburkolta": "beburkol",
    "bebörtönzések": "bebörtönzés",
    "becsaltalak": "becsal",
    "becsapnak": "becsap",
    "becsapni": "becsap",
    "becsapod": "becsap",
    "becsapott": "becsap",
    "becsapta": "becsap",
    "becsaptak": "becsap",
    "becsapták": "becsap",
    "becsapódása": "becsapódás",
    "becsapódások": "becsapódás",
    "becsavarta": "becsavar",
    "becsavartam": "becsavart",
    "becsengessen": "becsenget",
    "becslése": "becslés",
    "becslései": "becslés",
    "becslések": "becslés",
    "becslőnek": "becslő",
    "becsukja": "becsuk",
    "becsukta": "becsuk",
    "becsukták": "becsuk",
    "becsukódott": "becsukódik",
    "becsurgott": "becsurog",
    "becsúsztatta": "becsúsztat",
    "becsül": "becs",
    "becsületből": "becsület",
    "becsülete": "becsület",
    "becsületemre": "becsület",
    "becsületesen": "becsületes",
    "becsületességre": "becsületesség",
    "becsületét": "becsület",
    "becsüli": "becsül",
    "becsülik": "becsül",
    "becsülni": "becsül",
    "becsült": "becsül",
    "becsülte": "becsül",
    "becsültek": "becsül",
    "becsültem": "becsül",
    "becsülöd": "becsül",
    "becsülök": "becsül",
    "becézik": "becéz",
    "becézték": "becéz",
    "bedagadt": "bedagad",
    "bedagasztott": "bedagaszt",
    "bedeszkázták": "bedeszkáz",
    "bediktált": "bediktál",
    "bedobja": "bedob",
    "bedobta": "bedob",
    "bedobták": "bedob",
    "bedugaszolom": "bedugaszol",
    "bedugaszolta": "bedugaszol",
    "beejtette": "beejt",
    "beemeljék": "beemel",
    "beengedik": "beenged",
    "beengedte": "beenged",
    "beeresztettek": "beeresztett",
    "befagyassza": "befagyaszt",
    "befalt": "befal",
    "befalta": "befal",
    "befedi": "befed",
    "befedte": "befed",
    "befejezett": "befejez",
    "befejezetten": "befejezett",
    "befejezettnek": "befejezett",
    "befejezi": "befejez",
    "befejezni": "befejez",
    "befejezte": "befejez",
    "befejezték": "befejez",
    "befejeztük": "befejez",
    "befejezése": "befejezés",
    "befejezéseként": "befejezés",
    "befejezéséhez": "befejezés",
    "befejezéséig": "befejezés",
    "befejezésére": "befejezés",
    "befejezését": "befejezés",
    "befejezésül": "befejezés",
    "befejeződhetnek": "befejeződhet",
    "befejeződnie": "befejeződ",
    "befejeződött": "befejeződik",
    "befektetni": "befektet",
    "befektetések": "befektetés",
    "befektetéseket": "befektetés",
    "befektetéseknek": "befektetés",
    "befektetésnek": "befektetés",
    "befektetést": "befektetés",
    "befektetők": "befektető",
    "befektetőket": "befektető",
    "befektetőknek": "befektető",
    "befizessék": "befizet",
    "befizetett": "befizet",
    "befizetéseket": "befizetés",
    "befizetésekkel": "befizetés",
    "befizetésre": "befizetés",
    "befizetésről": "befizetés",
    "befizetésének": "befizetés",
    "befizetői": "befizető",
    "befizetők": "befizető",
    "befizetőknek": "befizető",
    "befogadott": "befogad",
    "befogadását": "befogadás",
    "befogadóképességét": "befogadóképesség",
    "befogta": "befog",
    "befoltozott": "befoltoz",
    "befolyt": "befolyik",
    "befolyása": "befolyás",
    "befolyásolhatja": "befolyásolhat",
    "befolyásolhatják": "befolyásolhat",
    "befolyásolhatná": "befolyásolhat",
    "befolyásolja": "befolyásol",
    "befolyásolják": "befolyásol",
    "befolyásolni": "befolyásol",
    "befolyásolták": "befolyásol",
    "befolyásolását": "befolyásolás",
    "befolyással": "befolyás",
    "befolyásától": "befolyás",
    "befordult": "befordul",
    "befordultak": "befordult",
    "befordultunk": "befordult",
    "befutnia": "befut",
    "beférjen": "befér",
    "befészkelte": "befészkel",
    "befészkelődnek": "befészkelődik",
    "befűtött": "befűt",
    "begyepesedem": "begyepesedik",
    "begyulladni": "begyullad",
    "begyulladt": "begyullad",
    "begyét": "begy",
    "begyöpösödött": "begyöpösödik",
    "begyújtott": "begyújt",
    "begyűrni": "begyűr",
    "behajlott": "behajlik",
    "behajtja": "behajt",
    "behajtottam": "behajtott",
    "behajtása": "behajtás",
    "behaladnának": "behalad",
    "behaladt": "behalad",
    "behallatszott": "behallatszik",
    "beharangozott": "beharangozik",
    "behatolt": "behatol",
    "behatolásra": "behatolás",
    "behatárolt": "behatárol",
    "behatárolását": "behatárolás",
    "behatóan": "beható",
    "behelyezi": "behelyez",
    "behintik": "behint",
    "behordani": "behord",
    "behordják": "behord",
    "behordták": "behord",
    "behozhatja": "behozhat",
    "behozott": "behoz",
    "behozta": "behoz",
    "behoztak": "behoz",
    "behozták": "behoz",
    "behozzák": "behoz",
    "behunyt": "behuny",
    "behunyta": "behuny",
    "behívjuk": "behív",
    "behívnak": "behív",
    "behívott": "behív",
    "behódolni": "behódol",
    "behódolt": "behódol",
    "behódolásra": "behódolás",
    "behúzni": "behúz",
    "beidegződésének": "beidegződés",
    "beidézettnek": "beidézett",
    "beigazolódott": "beigazolódik",
    "beiktatjuk": "beiktat",
    "beiktatott": "beiktat",
    "beiktatták": "beiktat",
    "beiktatásáról": "beiktatás",
    "beiktatásával": "beiktatás",
    "beillesztése": "beillesztés",
    "beindult": "beindul",
    "beindított": "beindít",
    "beirányítsák": "beirányít",
    "beiskolázások": "beiskolázás",
    "beismerik": "beismer",
    "beismernivalótok": "beismernivaló",
    "beismertem": "beismert",
    "beismerték": "beismer",
    "beismerése": "beismerés",
    "beismerésre": "beismerés",
    "beismerést": "beismerés",
    "beismerünk": "beismer",
    "bejegyeznek": "bejegyez",
    "bejegyzett": "bejegyez",
    "bejelent": "bejelenik",
    "bejelentett": "bejelent",
    "bejelentette": "bejelent",
    "bejelentették": "bejelentet",
    "bejelenti": "bejelent",
    "bejelentik": "bejelent",
    "bejelentse": "bejelent",
    "bejelentése": "bejelentés",
    "bejelentések": "bejelentés",
    "bejelentésemet": "bejelentés",
    "bejelentést": "bejelentés",
    "bejelentésére": "bejelentés",
    "bejelentését": "bejelentés",
    "bejuthasson": "bejuthat",
    "bejutni": "bejut",
    "bejutottam": "bejutott",
    "bejutottunk": "bejutott",
    "bejárat": "bejár",
    "bejárata": "bejárat",
    "bejáratot": "bejárat",
    "bejáratának": "bejárat",
    "bejáratát": "bejárat",
    "bejárhatjuk": "bejárhat",
    "bejártak": "bejárt",
    "bejáráskor": "bejárás",
    "bejárását": "bejárás",
    "bejárókat": "bejáró",
    "bejönne": "bejön",
    "bejönnöm": "bejön",
    "bejött": "bejön",
    "bejöttem": "bejön",
    "bejövetelében": "bejövetel",
    "bekanyarogják": "bekanyarog",
    "bekapcsolása": "bekapcsolás",
    "bekapcsolódjon": "bekapcsolódik",
    "bekapcsolódni": "bekapcsolódik",
    "bekapálhatják": "bekapálhat",
    "bekasszírozni": "bekasszíroz",
    "bekazlazni": "bekazlaz",
    "bekeretezett": "bekeretez",
    "bekergették": "bekerget",
    "bekerített": "bekerít",
    "bekerült": "bekerül",
    "bekerültek": "bekerül",
    "bekiabáljuk": "bekiabál",
    "bekukkantott": "bekukkant",
    "bekérették": "bekéret",
    "bekísért": "bekísér",
    "bekísérte": "bekísér",
    "bekísértek": "bekísért",
    "bekísértették": "bekísértet",
    "beköltöznek": "beköltözik",
    "beköszönt": "beköszön",
    "bekötnek": "beköt",
    "bekövetkezett": "bekövetkezik",
    "bekövetkeztek": "bekövetkezik",
    "bekövetkeztéig": "bekövetkezte",
    "beküldik": "beküld",
    "beküldték": "beküld",
    "belapult": "belapul",
    "bele": "bél",
    "belebonyolítani": "belebonyolít",
    "belebámult": "belebámul",
    "belecsikordultak": "belecsikordult",
    "beledobni": "beledob",
    "beledobta": "beledob",
    "beledugta": "beledug",
    "beleegyezett": "beleegyez",
    "beleegyezik": "beleegyez",
    "beleegyezni": "beleegyez",
    "beleegyeztek": "beleegyez",
    "beleegyezésén": "beleegyezés",
    "beleegyezését": "beleegyezés",
    "beleegyezően": "beleegyező",
    "beleesett": "beleesik",
    "beleevődött": "beleevődik",
    "belefeküdtünk": "belefeküdt",
    "belefogtunk": "belefog",
    "belefojtani": "belefojt",
    "belefulladtak": "belefulladt",
    "belefáradt": "belefárad",
    "belefúródott": "belefúródik",
    "belegondolunk": "belegondol",
    "belehajszolt": "belehajszol",
    "belehajszolták": "belehajszol",
    "belehalna": "belehal",
    "belehalt": "belehal",
    "beleharapott": "beleharap",
    "belei": "bél",
    "beleibe": "bél",
    "beleiben": "bél",
    "beleillett": "beleillik",
    "beleit": "bél",
    "beleizzadt": "beleizzad",
    "belejött": "belejön",
    "belekapcsolódást": "belekapcsolódás",
    "belekapjanak": "belekap",
    "belekeveredtek": "belekeveredik",
    "belekeverni": "belekever",
    "belekezdtek": "belekezd",
    "belekábult": "belekábul",
    "belekóstolt": "belekóstol",
    "belemarkolt": "belemarkol",
    "belemarnak": "belemar",
    "belemarni": "belemar",
    "belemegyünk": "belemegy",
    "belementem": "belement",
    "belementünk": "belement",
    "belemerült": "belemerül",
    "belemámorosodott": "belemámorosod",
    "belenyugodtak": "belenyugszik",
    "belenyugszanak": "belenyugszik",
    "belenyúltak": "belenyúlt",
    "belenézek": "belenéz",
    "belenézett": "belenéz",
    "belenézni": "belenéz",
    "beleolvadt": "beleolvad",
    "beleragadt": "beleragad",
    "beleroppantam": "beleroppant",
    "belerázott": "beleráz",
    "belerögződött": "belerögződik",
    "belerúgott": "belerúg",
    "belesodródottak": "belesodródott",
    "beleszagolhatnak": "beleszagolhat",
    "beleszagolt": "beleszagol",
    "beleszoknak": "beleszokik",
    "beleszoktunk": "beleszokik",
    "beleszokunk": "beleszokik",
    "beleszorult": "beleszorul",
    "beleszólhassanak": "beleszólhat",
    "beleszólt": "beleszól",
    "beleszúrtak": "beleszúrt",
    "belesápadt": "belesápad",
    "belesütött": "belesüt",
    "beletelhetik": "beletelhet",
    "beletelik": "beletel",
    "beletette": "beletesz",
    "beletettük": "beletett",
    "beletörődtek": "beletörődik",
    "beletörődéssel": "beletörődés",
    "beletörődött": "beletörődik",
    "beleugrott": "beleugrik",
    "beleverte": "belever",
    "beleveszett": "beleveszik",
    "belevetette": "belevet",
    "belevinni": "belevisz",
    "belevonta": "belevon",
    "belevágott": "belevág",
    "belezavarodnának": "belezavarodik",
    "belezavarodunk": "belezavarodik",
    "beleírta": "beleír",
    "beleömlött": "beleömlik",
    "beleülnek": "beleül",
    "beleütköztem": "beleütközik",
    "beleütközött": "beleütközik",
    "belföldre": "belföld",
    "belopóztam": "belopóz",
    "belseje": "belső",
    "belsejébe": "belső",
    "belsejében": "belső",
    "belsején": "belső",
    "belsejét": "belső",
    "belterületén": "belterület",
    "belvárosban": "belváros",
    "belvárosának": "belváros",
    "beláthatatlanok": "beláthatatlan",
    "belátja": "belát",
    "belátod": "belát",
    "belátszott": "belátszik",
    "beláttad": "belát",
    "beláttam": "belát",
    "beláttuk": "belát",
    "belátása": "belátás",
    "belátásra": "belátás",
    "belátásuk": "belátás",
    "belé": "ő",
    "belébotlottam": "belébotlott",
    "beléhullottak": "beléhullott",
    "beléje": "ő",
    "beléjük": "ők",
    "belékapott": "belékap",
    "belém": "én",
    "beléndeket": "beléndek",
    "belépett": "belép",
    "belépni": "belép",
    "belépnie": "belép",
    "beléptekor": "belépt",
    "belépése": "belépés",
    "belépéskor": "belépés",
    "belépést": "belépés",
    "belépésükkor": "belépés",
    "belépődíjat": "belépődíj",
    "belépőjegyet": "belépőjegy",
    "belökte": "belök",
    "belökték": "belök",
    "belügye": "belügy",
    "belügyminisztere": "belügyminiszter",
    "belügyminisztert": "belügyminiszter",
    "belőle": "belől",
    "belőled": "belől",
    "belőlem": "belől",
    "belőlük": "belől",
    "belőlünk": "belől",
    "bemegyek": "bemegy",
    "bemehessenek": "bemehet",
    "bemenjen": "bemegy",
    "bemenni": "bemegy",
    "bemenniük": "bemegy",
    "bement": "bemegy",
    "bementek": "bement",
    "bementem": "bement",
    "bementünk": "bement",
    "bemocskolni": "bemocskol",
    "bemocskolódjunk": "bemocskolódik",
    "bemondani": "bemond",
    "bemondja": "bemond",
    "bemondója": "bemondó",
    "bemutassa": "bemutat",
    "bemutatja": "bemutat",
    "bemutatják": "bemutat",
    "bemutatkoztam": "bemutatkozik",
    "bemutatkozást": "bemutatkozás",
    "bemutatni": "bemutat",
    "bemutatom": "bemutat",
    "bemutatott": "bemutat",
    "bemutatta": "bemutat",
    "bemutattak": "bemutat",
    "bemutatták": "bemutat",
    "bemutatása": "bemutatás",
    "bemutatóhelyen": "bemutatóhely",
    "bemutatón": "bemutató",
    "bemutatót": "bemutató",
    "bemártotta": "bemárt",
    "bemásolt": "bemásol",
    "bemázolták": "bemázol",
    "bemérték": "bemér",
    "bendőit": "bendői",
    "benne": "ő",
    "benned": "te",
    "bennem": "én",
    "bennetek": "ti",
    "benneteket": "ti",
    "bennfentesebb": "bennfentes",
    "bennlakást": "bennlakás",
    "bennszülöttektől": "bennszülött",
    "bennük": "ők",
    "bennünk": "mi",
    "bennünket": "ti",
    "benseje": "benső",
    "bensőjükben": "benső",
    "bensőnkben": "benső",
    "benyomathatom": "benyomathat",
    "benyomjuk": "benyom",
    "benyomása": "benyomás",
    "benyomásból": "benyomás",
    "benyomásokat": "benyomás",
    "benyomással": "benyomás",
    "benyomást": "benyomás",
    "benyomását": "benyomás",
    "benyílóban": "benyíló",
    "benyílót": "benyíló",
    "benyújtja": "benyújt",
    "benyújtják": "benyújt",
    "benyújtott": "benyújt",
    "benyújtották": "benyújt",
    "benyújtása": "benyújtás",
    "benyújtását": "benyújtás",
    "benyúlt": "benyúlik",
    "benzin-ügylete": "benzin-ügylet",
    "benzinkerete": "benzinkeret",
    "benzinnel": "benzin",
    "benzint": "benzin",
    "benépesíteni": "benépesít",
    "benéztem": "benéz",
    "benőtt": "benő",
    "beoltani": "beolt",
    "beoltották": "beolt",
    "beolvassák": "beolvas",
    "beolvasztották": "beolvaszt",
    "beolvasztásáról": "beolvasztás",
    "beosonok": "beoson",
    "beosont": "beoson",
    "beosztani": "beoszt",
    "beosztja": "beoszt",
    "beosztása": "beosztás",
    "beosztásban": "beosztás",
    "beosztásában": "beosztás",
    "beperelik": "beperel",
    "bepácolják": "bepácol",
    "bepácolták": "bepácol",
    "beragasztani": "beragaszt",
    "beragasztott": "beragaszt",
    "beragasztotta": "beragaszt",
    "beraktak": "berak",
    "beregszásziak": "beregszászi",
    "berendezett": "berendez",
    "berendezkedett": "berendezkedik",
    "berendezkedésünket": "berendezkedés",
    "berendezése": "berendezés",
    "berendezéseinek": "berendezés",
    "berendezések": "berendezés",
    "berendezésnél": "berendezés",
    "berendezést": "berendezés",
    "berendezését": "berendezés",
    "berobogott": "berobog",
    "beronthatnak": "beronthat",
    "berontottak": "berontott",
    "berregésére": "berregés",
    "beruházni": "beruház",
    "beruházása": "beruházás",
    "beruházásba": "beruházás",
    "beruházáskor": "beruházás",
    "beruházások": "beruházás",
    "beruházásokat": "beruházás",
    "beruházásokba": "beruházás",
    "beruházásokhoz": "beruházás",
    "beruházásokkal": "beruházás",
    "beruházásoknak": "beruházás",
    "beruházásokra": "beruházás",
    "beruházásokról": "beruházás",
    "beruházásra": "beruházás",
    "beruházással": "beruházás",
    "beruházást": "beruházás",
    "beruházását": "beruházás",
    "beruházói": "beruházó",
    "beruházók": "beruházó",
    "beröpültem": "beröpül",
    "berúgta": "berúg",
    "berúgtak": "berúg",
    "besavanyodott": "besavanyodik",
    "besettenkedtek": "besettenkedik",
    "beskatulyázni": "beskatulyáz",
    "besorozott": "besoroz",
    "bestiává": "bestia",
    "besurranhattak": "besurranhat",
    "besurranni": "besurran",
    "besurrant": "besurran",
    "beszakadt": "beszakad",
    "beszakadások": "beszakadás",
    "beszakították": "beszakít",
    "beszaladt": "beszalad",
    "beszedett": "beszed",
    "beszedni": "beszed",
    "beszedniük": "beszed",
    "beszedte": "beszed",
    "beszedtünk": "beszed",
    "beszedésére": "beszedés",
    "beszedésétől": "beszedés",
    "beszedésével": "beszedés",
    "beszemtelenkedtünk": "beszemtelenkedik",
    "beszerezni": "beszerez",
    "beszerzése": "beszerzés",
    "beszerzésében": "beszerzés",
    "beszerzésére": "beszerzés",
    "beszerződtek": "beszerződik",
    "beszolgáltatását": "beszolgáltatás",
    "beszorulnak": "beszorul",
    "beszorítják": "beszorít",
    "beszállított": "beszállít",
    "beszállították": "beszállít",
    "beszállítói": "beszállító",
    "beszállítók": "beszállító",
    "beszállítóként": "beszállító",
    "beszámolni": "beszámol",
    "beszámolt": "beszámol",
    "beszámoltunk": "beszámolt",
    "beszámolásra": "beszámolás",
    "beszámolója": "beszámoló",
    "beszámolójában": "beszámoló",
    "beszámolókból": "beszámoló",
    "beszámolót": "beszámoló",
    "beszámítja": "beszámít",
    "beszámítják": "beszámít",
    "beszédbe": "beszéd",
    "beszédben": "beszéd",
    "beszédből": "beszéd",
    "beszéddel": "beszéd",
    "beszéde": "beszéd",
    "beszédekben": "beszéd",
    "beszédekkel": "beszéd",
    "beszédessé": "beszédes",
    "beszédet": "beszéd",
    "beszédhez": "beszéd",
    "beszédjében": "beszéd",
    "beszédjét": "beszéd",
    "beszédjéért": "beszéd",
    "beszédmódra": "beszédmód",
    "beszédstílusban": "beszédstílus",
    "beszédtárgyat": "beszédtárgy",
    "beszédtárgyban": "beszédtárgy",
    "beszédében": "beszéd",
    "beszédének": "beszéd",
    "beszédére": "beszéd",
    "beszédét": "beszéd",
    "beszédétől": "beszéd",
    "beszédével": "beszéd",
    "beszégyenkeztem": "beszégyenkezik",
    "beszélek": "beszél",
    "beszélgessünk": "beszélget",
    "beszélgetek": "beszélget",
    "beszélgetett": "beszélget",
    "beszélgethetnek": "beszélgethet",
    "beszélgetni": "beszélget",
    "beszélgetniük": "beszélget",
    "beszélgettek": "beszélget",
    "beszélgettünk": "beszélget",
    "beszélgetésbe": "beszélgetés",
    "beszélgetései": "beszélgetés",
    "beszélgetéseikben": "beszélgetés",
    "beszélgetéseiről": "beszélgetés",
    "beszélgetések": "beszélgetés",
    "beszélgetésekre": "beszélgetés",
    "beszélgetésen": "beszélgetés",
    "beszélgetésfoszlányok": "beszélgetésfoszlány",
    "beszélgetésnek": "beszélgetés",
    "beszélgetésre": "beszélgetés",
    "beszélgetésről": "beszélgetés",
    "beszélgetéssel": "beszélgetés",
    "beszélgetést": "beszélgetés",
    "beszélgetését": "beszélgetés",
    "beszélgetésük": "beszélgetés",
    "beszélgetésükből": "beszélgetés",
    "beszélgetésünk": "beszélgetés",
    "beszélhessek": "beszélhet",
    "beszélhetek": "beszélhet",
    "beszélhetne": "beszélhet",
    "beszélj": "beszél",
    "beszéljen": "beszél",
    "beszéljünk": "beszél",
    "beszélne": "beszél",
    "beszélnek": "beszél",
    "beszélni": "beszél",
    "beszélnie": "beszél",
    "beszélnénk": "beszél",
    "beszélnünk": "beszél",
    "beszélsz": "beszél",
    "beszélt": "beszél",
    "beszéltek": "beszélt",
    "beszéltem": "beszélt",
    "beszéltünk": "beszélt",
    "beszélírba": "beszélír",
    "beszélírja": "beszélír",
    "beszélírokba": "beszélír",
    "beszélírral": "beszélír",
    "beszélírt": "beszélír",
    "beszélírtól": "beszélír",
    "beszélünk": "beszél",
    "beszélőképességét": "beszélőképesség",
    "beszíjazták": "beszíjaz",
    "beszólhatott": "beszólhat",
    "beszólított": "beszólít",
    "beszórt": "beszór",
    "beszórtak": "beszórt",
    "beszöknének": "beszökik",
    "beszünteti": "beszüntet",
    "besározott": "besároz",
    "besúgások": "besúgás",
    "besúgókkal": "besúgó",
    "besúgóktól": "besúgó",
    "besütött": "besüt",
    "betakarta": "betakar",
    "betanítást": "betanítás",
    "betartani": "betart",
    "betartja": "betart",
    "betartjuk": "betart",
    "betartottam": "betartott",
    "betartották": "betart",
    "betartásának": "betartás",
    "betartását": "betartás",
    "betegei": "beteg",
    "betegeid": "beteg",
    "betegek": "beteg",
    "betegeket": "beteg",
    "betegeskedett": "betegeskedik",
    "beteget": "beteg",
    "beteggel": "beteg",
    "betegnek": "beteg",
    "betegségben": "betegség",
    "betegségcsoportok": "betegségcsoport",
    "betegsége": "betegség",
    "betegségedhez": "betegség",
    "betegségek": "betegség",
    "betegségeket": "betegség",
    "betegségekről": "betegség",
    "betegségemmel": "betegség",
    "betegséget": "betegség",
    "betegségében": "betegség",
    "betegségére": "betegség",
    "betegségéről": "betegség",
    "betegségét": "betegség",
    "betegségünktől": "betegség",
    "betegyen": "betesz",
    "betegágyától": "betegágy",
    "betegét": "beteg",
    "betegül": "beteg",
    "beteljesedtek": "beteljesedik",
    "betemetik": "betemet",
    "betemettetni": "betemettet",
    "betereltek": "beterelt",
    "betette": "betesz",
    "betettek": "betett",
    "betetőzni": "betetőzik",
    "betetőzte": "betetőzik",
    "betiltottak": "betiltott",
    "betiltsanak": "betilt",
    "betiltást": "betiltás",
    "betiltásának": "betiltás",
    "betiltásáról": "betiltás",
    "betoborzott": "betoboroz",
    "betolakodók": "betolakodó",
    "betonba": "beton",
    "betonból": "beton",
    "betonlapok": "betonlap",
    "betonívekkel": "betonív",
    "betonútról": "betonút",
    "betért": "betér",
    "betértek": "betért",
    "betértünk": "betért",
    "betétek": "betét",
    "betétekből": "betét",
    "betételét": "betétel",
    "betétesek": "betétes",
    "betétesnek": "betétes",
    "betétet": "betét",
    "betétkamatot": "betétkamat",
    "betétállománya": "betétállomány",
    "betölteni": "betölt",
    "betöltenie": "betölt",
    "betölthesse": "betölthet",
    "betölti": "betölt",
    "betöltéséről": "betöltés",
    "betöltött": "betölt",
    "betöltötte": "betölt",
    "betömöm": "betöm",
    "betört": "betörik",
    "betörték": "betörik",
    "betöréssorozatot": "betöréssorozat",
    "betörők": "betörő",
    "betörőt": "betörő",
    "betűi": "betű",
    "betűig": "betű",
    "betűk": "betű",
    "betűkből": "betű",
    "betűkkel": "betű",
    "betűszedést": "betűszedés",
    "betűvel": "betű",
    "beugrott": "beugrik",
    "beugrottak": "beugrott",
    "beugróban": "beugró",
    "beutaztatásból": "beutaztatás",
    "beutazásra": "beutazás",
    "bevagdalt": "bevagdal",
    "bevallani": "bevall",
    "bevallja": "bevall",
    "bevallják": "bevall",
    "bevallom": "bevall",
    "bevallott": "bevall",
    "bevallotta": "bevall",
    "bevallottad": "bevallott",
    "bevallottak": "bevallott",
    "bevallották": "bevall",
    "bevallása": "bevallás",
    "bevallására": "bevallás",
    "bevarrt": "bevarr",
    "bevasalnánk": "bevasal",
    "beverem": "bever",
    "beverhetné": "beverhet",
    "beveszik": "bevesz",
    "bevesznek": "beveszik",
    "bevetette": "bevet",
    "bevett": "bevesz",
    "bevette": "bevesz",
    "bevették": "bevesz",
    "bevezetett": "bevezet",
    "bevezetik": "bevezet",
    "bevezetni": "bevezet",
    "bevezetné": "bevezet",
    "bevezetnék": "bevezet",
    "bevezette": "bevezet",
    "bevezették": "bevezet",
    "bevezetése": "bevezetés",
    "bevezetéséig": "bevezetés",
    "bevezetésének": "bevezetés",
    "bevezetésénél": "bevezetés",
    "bevezetésére": "bevezetés",
    "bevezetéséről": "bevezetés",
    "bevezetését": "bevezetés",
    "bevezetésével": "bevezetés",
    "bevezetésül": "bevezetés",
    "bevigyenek": "bevisz",
    "bevilágítsa": "bevilágít",
    "beviszik": "bevisz",
    "bevisznek": "bevisz",
    "bevitte": "bevisz",
    "bevittek": "bevitt",
    "bevonjuk": "bevon",
    "bevonják": "bevon",
    "bevonni": "bevon",
    "bevonszolta": "bevonszol",
    "bevont": "bevon",
    "bevonta": "bevon",
    "bevonták": "bevon",
    "bevonult": "bevonul",
    "bevonulását": "bevonulás",
    "bevonása": "bevonás",
    "bevonásával": "bevonás",
    "bevádolt": "bevádol",
    "bevágatott": "bevágat",
    "bevágja": "bevág",
    "beválasztottak": "beválasztott",
    "beválasztották": "beválaszt",
    "bevált": "beválik",
    "beváltani": "bevált",
    "bevándorlóét": "bevándorló",
    "bevándorolni": "bevándorol",
    "bevándoroltak": "bevándorolt",
    "bevásárlásban": "bevásárlás",
    "bevásárlással": "bevásárlás",
    "bevásárlóközpontok": "bevásárlóközpont",
    "bevégzik": "bevégez",
    "bevétele": "bevétel",
    "bevételei": "bevétel",
    "bevételeiből": "bevétel",
    "bevételeik": "bevétel",
    "bevételeikből": "bevétel",
    "bevételeiket": "bevétel",
    "bevételeinek": "bevétel",
    "bevételeit": "bevétel",
    "bevételek": "bevétel",
    "bevételekből": "bevétel",
    "bevételekkel": "bevétel",
    "bevételekre": "bevétel",
    "bevételkiesést": "bevételkiesés",
    "bevétellel": "bevétel",
    "bevételre": "bevétel",
    "bevételt": "bevétel",
    "bevételének": "bevétel",
    "bevételük": "bevétel",
    "bevételüket": "bevétel",
    "bezárja": "bezár",
    "bezárnak": "bezár",
    "bezárni": "bezár",
    "bezárt": "bezár",
    "bezárását": "bezárás",
    "bezörgettek": "bezörget",
    "bezörgettünk": "bezörget",
    "beállanánk": "beáll",
    "beállnak": "beáll",
    "beállni": "beáll",
    "beállott": "beáll",
    "beállt": "beáll",
    "beálltak": "beállt",
    "beálltakor": "beállta",
    "beállított": "beállít",
    "beállítottságok": "beállítottság",
    "beáramlása": "beáramlás",
    "beárulná": "beárul",
    "beázott": "beázik",
    "beépített": "beépít",
    "beépítettek": "beépített",
    "beépítése": "beépítés",
    "beépítésre": "beépítés",
    "beépítést": "beépítés",
    "beépítésének": "beépítés",
    "beépítésére": "beépítés",
    "beépítésével": "beépítés",
    "beépítésükre": "beépítés",
    "beérik": "beér",
    "beérkeztek": "beérkezik",
    "beérte": "beérik",
    "beírt": "beír",
    "beírta": "beír",
    "beírtak": "beírt",
    "beöntést": "beöntés",
    "beültünk": "beült",
    "beülök": "beül",
    "beütne": "beüt",
    "bibliát": "biblia",
    "bicepszedet": "bicepsz",
    "biciklijét": "bicikli",
    "bicskával": "bicska",
    "bikája": "bika",
    "billent": "billen",
    "billentyűn": "billentyű",
    "billentyűt": "billentyű",
    "bimbóstól": "bimbós",
    "biológiát": "biológia",
    "biológusok": "biológus",
    "birkabégetéssé": "birkabégetés",
    "birkának": "birka",
    "birkózni": "birkózik",
    "birodalma": "birodalom",
    "birodalmát": "birodalom",
    "birodalomnak": "birodalom",
    "birsággal": "birság",
    "birtoklása": "birtoklás",
    "birtoklásáról": "birtoklás",
    "birtoklásáért": "birtoklás",
    "birtokodban": "birtok",
    "birtokolhatja": "birtokolhat",
    "birtokolja": "birtokol",
    "birtokolják": "birtokol",
    "birtokomban": "birtok",
    "birtokosok": "birtokos",
    "birtokról": "birtok",
    "birtokukban": "birtok",
    "birtokába": "birtok",
    "birtokában": "birtok",
    "birtokán": "birtok",
    "birtokára": "birtok",
    "bitangságra": "bitangság",
    "bizakodással": "bizakodás",
    "bizakodását": "bizakodás",
    "bizakodóan": "bizakodó",
    "bizakodóbban": "bizakodó",
    "bizakodón": "bizakodó",
    "bizalmasai": "bizalmas",
    "bizalmasan": "bizalmas",
    "bizalmasságainál": "bizalmasság",
    "bizalmat": "bizalom",
    "bizalmatlanságot": "bizalmatlanság",
    "bizalmatlanul": "bizalmatlan",
    "bizalmának": "bizalom",
    "bizalommal": "bizalom",
    "bizalomra": "bizalom",
    "bizonnyal": "bizony",
    "bizonygathattunk": "bizonygathat",
    "bizonygatják": "bizonygat",
    "bizonygatta": "bizonygat",
    "bizonylatot": "bizonylat",
    "bizonyosabb": "bizonyos",
    "bizonyosan": "bizonyos",
    "bizonyosodhatnék": "bizonyosodhat",
    "bizonyosodott": "bizonyosodik",
    "bizonyosra": "bizonyos",
    "bizonyossá": "bizonyos",
    "bizonyosságban": "bizonyosság",
    "bizonyossággal": "bizonyosság",
    "bizonyosságot": "bizonyosság",
    "bizonysága": "bizonyság",
    "bizonyságot": "bizonyság",
    "bizonytalankodott": "bizonytalankodik",
    "bizonytalanná": "bizonytalan",
    "bizonytalanok": "bizonytalan",
    "bizonytalansága": "bizonytalanság",
    "bizonytalanságban": "bizonytalanság",
    "bizonytalanságot": "bizonytalanság",
    "bizonytalanságra": "bizonytalanság",
    "bizonytalanságtól": "bizonytalanság",
    "bizonytalanságával": "bizonytalanság",
    "bizonytalantól": "bizonytalan",
    "bizonytalanul": "bizonytalan",
    "bizonyul": "bizony",
    "bizonyulhatnak": "bizonyulhat",
    "bizonyult": "bizonyul",
    "bizonyultak": "bizonyult",
    "bizonyára": "bizony",
    "bizonyítanak": "bizonyít",
    "bizonyítani": "bizonyít",
    "bizonyítaniuk": "bizonyít",
    "bizonyíthassa": "bizonyíthat",
    "bizonyítja": "bizonyít",
    "bizonyítják": "bizonyít",
    "bizonyított": "bizonyít",
    "bizonyította": "bizonyít",
    "bizonyítottam": "bizonyított",
    "bizonyították": "bizonyít",
    "bizonyítványra": "bizonyítvány",
    "bizonyítványt": "bizonyítvány",
    "bizonyításaként": "bizonyítás",
    "bizonyítások": "bizonyítás",
    "bizonyításra": "bizonyítás",
    "bizonyításul": "bizonyítás",
    "bizonyítéka": "bizonyíték",
    "bizonyítékaik": "bizonyíték",
    "bizonyítékaként": "bizonyíték",
    "bizonyítékkal": "bizonyíték",
    "bizonyítékok": "bizonyíték",
    "bizonyítékokat": "bizonyíték",
    "bizonyítékom": "bizonyíték",
    "bizonyítékot": "bizonyíték",
    "bizottsága": "bizottság",
    "bizottságban": "bizottság",
    "bizottsághoz": "bizottság",
    "bizottságnak": "bizottság",
    "bizottságoknak": "bizottság",
    "bizottságot": "bizottság",
    "bizottságra": "bizottság",
    "bizottságába": "bizottság",
    "bizottságának": "bizottság",
    "bizottságát": "bizottság",
    "bizsergést": "bizsergés",
    "biztatnak": "biztat",
    "biztatta": "biztat",
    "biztattak": "biztat",
    "biztatással": "biztatás",
    "biztatására": "biztatás",
    "biztatóan": "biztató",
    "biztatón": "biztató",
    "biztatónak": "biztató",
    "biztonsága": "biztonság",
    "biztonságban": "biztonság",
    "biztonsággal": "biztonság",
    "biztonságnak": "biztonság",
    "biztonságosabb": "biztonságos",
    "biztonságosan": "biztonságos",
    "biztonságosnak": "biztonságos",
    "biztonságot": "biztonság",
    "biztonságra": "biztonság",
    "biztonságról": "biztonság",
    "biztonságukra": "biztonság",
    "biztonságára": "biztonság",
    "biztonságát": "biztonság",
    "biztonságét": "biztonság",
    "biztosabb": "biztos",
    "biztosabbak": "biztos",
    "biztosak": "biztos",
    "biztosan": "biztos",
    "biztosra": "biztos",
    "biztost": "biztos",
    "biztosítanak": "biztosít",
    "biztosítani": "biztosít",
    "biztosítanák": "biztosít",
    "biztosíthatnák": "biztosíthat",
    "biztosíthatom": "biztosíthat",
    "biztosítja": "biztosít",
    "biztosítják": "biztosít",
    "biztosított": "biztosít",
    "biztosította": "biztosít",
    "biztosítottak": "biztosított",
    "biztosítottnak": "biztosított",
    "biztosították": "biztosít",
    "biztosítsa": "biztosít",
    "biztosítsanak": "biztosít",
    "biztosítása": "biztosítás",
    "biztosításonként": "biztosítás",
    "biztosításról": "biztosítás",
    "biztosítást": "biztosítás",
    "biztosításában": "biztosítás",
    "biztosításához": "biztosítás",
    "biztosítására": "biztosítás",
    "biztosítéka": "biztosíték",
    "biztosítékot": "biztosíték",
    "biztosítója": "biztosító",
    "biztosítók": "biztosító",
    "biztosítókat": "biztosító",
    "biztosítóknál": "biztosító",
    "biztosítónak": "biztosító",
    "biztosítót": "biztosító",
    "biztosítótársaságok": "biztosítótársaság",
    "biztosítótűt": "biztosítótű",
    "blokkban": "blokk",
    "blokkjait": "blokk",
    "blokkjában": "blokk",
    "blokkolni": "blokkol",
    "blöffje": "blöff",
    "blúza": "blúz",
    "blúzban": "blúz",
    "blúzodban": "blúz",
    "blúzokat": "blúz",
    "blúzt": "blúz",
    "blúzát": "blúz",
    "bocskor": "bocs",
    "bocskorban": "bocskor",
    "bocskorok": "bocskor",
    "bocskorokat": "bocskor",
    "bocskort": "bocskor",
    "bocsánatkérést": "bocsánatkérés",
    "bocsánatkérően": "bocsánatkérő",
    "bocsánatkérőn": "bocsánatkérő",
    "bocsánatot": "bocsánat",
    "bocsássák": "bocsát",
    "bocsátanak": "bocsát",
    "bocsátani": "bocsát",
    "bocsátják": "bocsát",
    "bocsátkozni": "bocsátkozik",
    "bocsátkozott": "bocsátkozik",
    "bocsátkozzanak": "bocsátkozik",
    "bocsátotta": "bocsát",
    "bocsátották": "bocsát",
    "bocsátásuk": "bocsátás",
    "bocsátását": "bocsátás",
    "bocsátásával": "bocsátás",
    "bogarat": "bogár",
    "boglyázni": "boglyáz",
    "bogozza": "bogoz",
    "bogozódni": "bogozódik",
    "bográcsba": "bogrács",
    "bográcsban": "bogrács",
    "bográcscsörgetéssel": "bográcscsörgetés",
    "bográcsot": "bogrács",
    "bohémvilága": "bohémvilág",
    "bohóckodásból": "bohóckodás",
    "bohózatban": "bohózat",
    "bojkottjára": "bojkott",
    "bojkottot": "bojkott",
    "bojárnak": "bojár",
    "bokasérülést": "bokasérülés",
    "bokrok": "bokor",
    "bokrokat": "bokor",
    "bokron": "bokor",
    "bokrosé": "bokros",
    "bokrot": "bokor",
    "bokszkesztyűk": "bokszkesztyű",
    "bokáig": "boka",
    "bokája": "boka",
    "bokájukat": "boka",
    "bokájába": "boka",
    "bokáját": "boka",
    "boldogabbak": "boldog",
    "boldogan": "boldog",
    "boldognak": "boldog",
    "boldogok": "boldog",
    "boldogságból": "boldogság",
    "boldogsággal": "boldogság",
    "boldogságot": "boldogság",
    "boldogságra": "boldogság",
    "boldogságtól": "boldogság",
    "boldogságához": "boldogság",
    "boldogságát": "boldogság",
    "boldogtalanná": "boldogtalan",
    "boldogtalanságba": "boldogtalanság",
    "boldogtalanságra": "boldogtalanság",
    "boldogulnak": "boldogul",
    "boldogulnék": "boldogul",
    "boldogult": "boldogul",
    "boldogultak": "boldogult",
    "boldogulásunknak": "boldogulás",
    "boldogítására": "boldogítás",
    "bolgárkertészekhez": "bolgárkertész",
    "bolgárokkal": "bolgár",
    "bolhák": "bolha",
    "bolondnak": "bolond",
    "bolondokat": "bolond",
    "bolondoknak": "bolond",
    "bolondot": "bolond",
    "bolondságaikkal": "bolondság",
    "bolondságokkal": "bolondság",
    "bolondériáikat": "bolondéria",
    "boltajtó-formát": "boltajtó-forma",
    "boltba": "bolt",
    "boltban": "bolt",
    "boltja": "bolt",
    "boltjaiban": "bolt",
    "boltokat": "bolt",
    "boltokba": "bolt",
    "bolton": "bolt",
    "boltosban": "boltos",
    "boltosnak": "boltos",
    "boltosnál": "boltos",
    "boltosok": "boltos",
    "boltosokkal": "boltos",
    "boltot": "bolt",
    "boltozata": "boltozat",
    "boltívek": "boltív",
    "bolygatta": "bolygat",
    "bolygónak": "bolygó",
    "bolyongana": "bolyong",
    "bombariadóját": "bombariadó",
    "bombariadón": "bombariadó",
    "bombatámadások": "bombatámadás",
    "bombák": "bomba",
    "bombáktól": "bomba",
    "bombát": "bomba",
    "bombáznak": "bombáz",
    "bombázni": "bombáz",
    "bombáztak": "bombáz",
    "bombázógépeket": "bombázógép",
    "bomlasztja": "bomlaszt",
    "bomlott": "bomlik",
    "boncolgatja": "boncolgat",
    "boncolást": "boncolás",
    "bongja": "bong",
    "bontakozott": "bontakozik",
    "bontanak": "bont",
    "bontani": "bont",
    "bontja": "bont",
    "bontogatja": "bontogat",
    "bontott": "bont",
    "bontsunk": "bont",
    "bonyodalmat": "bonyodalom",
    "bonyolultabb": "bonyolult",
    "bonyolultnak": "bonyolult",
    "bonyolulttá": "bonyolult",
    "bonyolítani": "bonyolít",
    "bonyolítja": "bonyolít",
    "bonyolítják": "bonyolít",
    "bonyolított": "bonyolít",
    "bonyolította": "bonyolít",
    "bonyolítottak": "bonyolított",
    "bonyolódott": "bonyolódik",
    "borbélyra": "borbély",
    "bordái": "borda",
    "bordáiba": "borda",
    "bordélyháza": "bordélyház",
    "borjával": "borjú",
    "borként": "borkén",
    "bornak": "bor",
    "bornyújából": "bornyú",
    "borok": "bor",
    "borotvapengéd": "borotvapenge",
    "borotvapengék": "borotvapenge",
    "borotvapengére": "borotvapenge",
    "borotvapengét": "borotvapenge",
    "borotválkozhatott": "borotválkozhat",
    "borra": "bor",
    "borral": "bor",
    "borsod": "bors",
    "borsodban": "bors",
    "borssal": "bors",
    "borszaga": "borszag",
    "borsódzott": "borsódzik",
    "bort": "bor",
    "borul": "bor",
    "borult": "borul",
    "borzadt": "borzad",
    "borzadállyal": "borzadály",
    "borzadályt": "borzadály",
    "borzalmasabbá": "borzalmas",
    "borzalommal": "borzalom",
    "borzasztóan": "borzasztó",
    "borzasztóbb": "borzasztó",
    "borzolódott": "borzolódik",
    "borzra": "borz",
    "borítja": "borít",
    "borított": "borít",
    "borította": "borít",
    "borították": "borít",
    "borítást": "borítás",
    "borítékban": "boríték",
    "borítékokat": "boríték",
    "borítékon": "boríték",
    "borítékot": "boríték",
    "borúlátónkat": "borúlátó",
    "bosnyákok": "bosnyák",
    "bosszankodást": "bosszankodás",
    "bosszantotta": "bosszant",
    "bosszulta": "bosszul",
    "bosszúsan": "bosszús",
    "bosszúsággal": "bosszúság",
    "bosszúságnak": "bosszúság",
    "bosszúságot": "bosszúság",
    "bosszúságtól": "bosszúság",
    "bosszúságára": "bosszúság",
    "botja": "bot",
    "botjuk": "bot",
    "botjára": "bot",
    "botlása": "botlás",
    "botlásra": "botlás",
    "botokkal": "bot",
    "botorkált": "botorkál",
    "botorkáltak": "botorkált",
    "botrányairól": "botrány",
    "botrányba": "botrány",
    "botrányoddal": "botrány",
    "botrányok": "botrány",
    "botrányokat": "botrány",
    "botrányokkal": "botrány",
    "botrányt": "botrány",
    "bottól": "bot",
    "botvégre": "botvég",
    "bozótot": "bozót",
    "bravúrgyőzelemhez": "bravúrgyőzelem",
    "bravúrosan": "bravúros",
    "bravúrral": "bravúr",
    "bricsesznadrágot": "bricsesznadrág",
    "brigádok": "brigád",
    "brigádot": "brigád",
    "briliánsa": "briliáns",
    "briliánsokat": "briliáns",
    "bronzba": "bronz",
    "brosúrákból": "brosúra",
    "brácsázássá": "brácsázás",
    "brókerek": "bróker",
    "budapestinél": "budapesti",
    "bugyorban": "bugyor",
    "bujasággal": "bujaság",
    "bujdostam": "bujdosik",
    "bujkálnak": "bujkál",
    "bujkálni": "bujkál",
    "bujkálok": "bujkál",
    "bujkált": "bujkál",
    "bujkálást": "bujkálás",
    "bujkálástól": "bujkálás",
    "buján": "buja",
    "bukdácsolnak": "bukdácsol",
    "bukdácsoltak": "bukdácsolt",
    "bukfence": "bukfenc",
    "bukkannak": "bukkan",
    "bukkant": "bukkan",
    "bukkantak": "bukkant",
    "bukkantam": "bukkant",
    "buknak": "bukik",
    "bukott": "bukik",
    "bukszáját": "buksza",
    "buktak": "bukik",
    "buktatta": "buktat",
    "buktatóin": "buktató",
    "buktáit": "bukta",
    "bukása": "bukás",
    "bukásra": "bukás",
    "bukásából": "bukás",
    "bukását": "bukás",
    "bulik": "buli",
    "bundanadrágokra": "bundanadrág",
    "bundájába": "bunda",
    "bundájáért": "bunda",
    "bunyók": "bunyó",
    "burkolatban": "burkolat",
    "burkolatáról": "burkolat",
    "burkolt": "burkol",
    "burkoltan": "burkolt",
    "burnótszelencéjét": "burnótszelence",
    "burája": "bura",
    "burát": "bura",
    "buszmegállótól": "buszmegálló",
    "buszokat": "busz",
    "buszokra": "busz",
    "butaságot": "butaság",
    "bután": "buta",
    "buzdításokkal": "buzdítás",
    "buzgalommal": "buzgalom",
    "bábiskolán": "bábiskola",
    "bábjaival": "báb",
    "bábjátékot": "bábjáték",
    "bábjátékának": "bábjáték",
    "bábufejek": "bábufej",
    "bábui": "bábu",
    "bábujává": "bábu",
    "bábuk": "bábu",
    "bábukat": "bábu",
    "bábukban": "bábu",
    "bábukkal": "bábu",
    "bábukká": "bábu",
    "bábukként": "bábu",
    "bábukra": "bábu",
    "bábura": "bábúr",
    "bábut": "bábu",
    "bábuval": "bábu",
    "bábuábrázolását": "bábuábrázolás",
    "bábáskodott": "bábáskodik",
    "bábút": "bábú",
    "bácsiból": "bácsi",
    "bádoglemezzel": "bádoglemez",
    "bádogszagánál": "bádogszag",
    "bágyadt": "bágyad",
    "bágyadtak": "bágyadt",
    "bágyadtsággal": "bágyadtság",
    "bája": "báj",
    "báját": "báj",
    "bájával": "báj",
    "bálban": "bál",
    "bálványai": "bálvány",
    "bámulja": "bámul",
    "bámulsz": "bámul",
    "bámult": "bámul",
    "bámulta": "bámul",
    "bámultak": "bámult",
    "bámulása": "bámulás",
    "bámészkodni": "bámészkodik",
    "bámészkodókkal": "bámészkodó",
    "bánatost": "bánatos",
    "bánatában": "bánat",
    "bánja": "bánik",
    "bánják": "bánik",
    "bánna": "bánik",
    "bánnak": "bánik",
    "bánni": "bánik",
    "bánniuk": "bánik",
    "bánom": "bánik",
    "bánta": "bánik",
    "bántak": "bánt",
    "bántalmazta": "bántalmaz",
    "bántatok": "bántat",
    "bántja": "bánt",
    "bántott": "bánt",
    "bántottak": "bántott",
    "bántottam": "bántott",
    "bántunk": "bánt",
    "bánták": "bánik",
    "bántóbb": "bántó",
    "bányavidéken": "bányavidék",
    "bányákat": "bánya",
    "bányánál": "bánya",
    "bányászköszöntést": "bányászköszöntés",
    "bányászszerszámok": "bányászszerszám",
    "bánásmódban": "bánásmód",
    "bánásmódok": "bánásmód",
    "bánásmódot": "bánásmód",
    "bárcalemezeket": "bárcalemez",
    "bárkihez": "bárki",
    "bárkinek": "bárki",
    "bárkivel": "bárki",
    "bármelyikkel": "bármelyik",
    "bármennyire": "bármennyi",
    "bármibe": "bármi",
    "bármikor": "bármi",
    "bármiként": "bármi",
    "bármilyen": "bármily",
    "bármin": "bármi",
    "bármiről": "bármi",
    "bármit": "bármi",
    "bárok": "bár",
    "bárokat": "bár",
    "bársonyon": "bársony",
    "bársonyossá": "bársonyos",
    "bársonyujjast": "bársonyujjas",
    "bárt": "bár",
    "bástyá-nak": "bástya",
    "bástyák": "bástya",
    "bátorsága": "bátorság",
    "bátorsággal": "bátorság",
    "bátorságom": "bátorság",
    "bátorságon": "bátorság",
    "bátorságot": "bátorság",
    "bátorságra": "bátorság",
    "bátorságuk": "bátorság",
    "bátorságunk": "bátorság",
    "bátortalanabbul": "bátortalan",
    "bátortalanul": "bátortalan",
    "bátorítani": "bátorít",
    "bátorítják": "bátorít",
    "bátorította": "bátorít",
    "bátorítson": "bátorít",
    "bátorításban": "bátorítás",
    "bátorításért": "bátorítás",
    "bátorítóan": "bátorító",
    "bátorítón": "bátorító",
    "bátrabb": "bátor",
    "bátran": "bátor",
    "bátyja": "bátya",
    "bátyám": "bátya",
    "bátyámra": "bátya",
    "bátyánk": "bátya",
    "bázisgyűrűre": "bázisgyűrű",
    "bázison": "bázis",
    "bázisponttal": "bázispont",
    "bázisról": "bázis",
    "bázisuk": "bázis",
    "bázisára": "bázis",
    "bázisát": "bázis",
    "bázisától": "bázis",
    "bécsiek": "bécsi",
    "békalencsét": "békalencse",
    "békeegyezményben": "békeegyezmény",
    "békeerők": "békeerő",
    "békefolyamatban": "békefolyamat",
    "békefolyamatot": "békefolyamat",
    "békekötést": "békekötés",
    "békeszerződések": "békeszerződés",
    "béketárgyalások": "béketárgyalás",
    "béketárgyalásokon": "béketárgyalás",
    "béketárgyaláson": "béketárgyalás",
    "békát": "béka",
    "békében": "béke",
    "békéje": "béke",
    "békéjében": "béke",
    "békén": "béke",
    "békésebben": "békés",
    "békésen": "békés",
    "békét": "béke",
    "békültünk": "békült",
    "bélférgek": "bélféreg",
    "bélit": "béli",
    "bélyegekről": "bélyeg",
    "bélyegre": "bélyeg",
    "bélyegzett": "bélyegez",
    "bélyegzőjén": "bélyegző",
    "bélyegzőjét": "bélyegző",
    "bélyegzőn": "bélyegző",
    "bélyegzővel": "bélyegző",
    "bélésalját": "bélésalj",
    "bénaságba": "bénaság",
    "bénultan": "bénult",
    "bénítja": "bénít",
    "bénítsák": "bénít",
    "bérbe": "bér",
    "bérbeadása": "bérbeadás",
    "bérbeadásából": "bérbeadás",
    "bérbeadására": "bérbeadás",
    "bérbeadók": "bérbeadó",
    "bérbeadót": "bérbeadó",
    "bére": "bér",
    "béregyezséget": "béregyezség",
    "bérek": "bér",
    "béreket": "bér",
    "béreli": "bérel",
    "béreljenek": "bérel",
    "bérelnie": "bérel",
    "béremelésben": "béremelés",
    "béremelésből": "béremelés",
    "béresek": "béres",
    "béresekkel": "béres",
    "béresgazdát": "béresgazda",
    "béreslegények": "béreslegény",
    "bérest": "béres",
    "bérfejlesztésből": "bérfejlesztés",
    "bérfejlesztéssel": "bérfejlesztés",
    "bérfejlesztést": "bérfejlesztés",
    "bérgyilkost": "bérgyilkos",
    "bérházé": "bérház",
    "bérkifizetések": "bérkifizetés",
    "bérlakások": "bérlakás",
    "bérlakásokban": "bérlakás",
    "bérlakásokból": "bérlakás",
    "bérleményüket": "bérlemény",
    "bérletére": "bérlet",
    "bérlik": "bérel",
    "bérlőhöz": "bérlő",
    "bérlői": "bérlő",
    "bérlőinek": "bérlői",
    "bérlője": "bérlő",
    "bérlők": "bérlő",
    "bérlőket": "bérlő",
    "bérlőkhöz": "bérlő",
    "bérlőkkel": "bérlő",
    "bérlőknél": "bérlő",
    "bérlőnek": "bérlő",
    "bérlőt": "bérlő",
    "bérlőtől": "bérlő",
    "bérlővel": "bérlő",
    "bérmegállapodáshoz": "bérmegállapodás",
    "bérmegállapodást": "bérmegállapodás",
    "bérmentesen": "bérmentes",
    "bérmunkaigényeit": "bérmunkaigény",
    "bérmunkát": "bérmunka",
    "bérre": "bér",
    "bért": "bér",
    "bértámogatással": "bértámogatás",
    "bértársaságok": "bértársaság",
    "bérért": "bér",
    "béréről": "bér",
    "bérét": "bér",
    "béréért": "bér",
    "bérük": "bér",
    "bérüket": "bér",
    "bérünk": "bér",
    "bérünkből": "bér",
    "bérünket": "bér",
    "bérünkön": "bér",
    "bíborvörösek": "bíborvörös",
    "bírja": "bír",
    "bírjuk": "bír",
    "bírják": "bír",
    "bírna": "bír",
    "bírnak": "bír",
    "bírná": "bír",
    "bírnák": "bír",
    "bírod": "bír",
    "bírom": "bír",
    "bírságok": "bírság",
    "bírságot": "bírság",
    "bírságra": "bírság",
    "bírságából": "bírság",
    "bírt": "bír",
    "bírta": "bír",
    "bírtak": "bírt",
    "bírtuk": "bír",
    "bírtunk": "bírt",
    "bírták": "bír",
    "bírunk": "bír",
    "bírák": "bíró",
    "bírákról": "bíró",
    "bírálata": "bírálat",
    "bírálatok": "bírálat",
    "bírálatokat": "bírálat",
    "bírálatában": "bírálat",
    "bírálja": "bírál",
    "bírálják": "bírál",
    "bírálni": "bírál",
    "bírált": "bírál",
    "bírálta": "bírál",
    "bírálták": "bírál",
    "bírálók": "bíráló",
    "bíróból": "bíró",
    "bírói": "bíró",
    "bírók": "bíró",
    "bírópárost": "bírópáros",
    "bírósággal": "bíróság",
    "bírósághoz": "bíróság",
    "bíróságok": "bíróság",
    "bíróságoknak": "bíróság",
    "bíróságon": "bíróság",
    "bíróságot": "bíróság",
    "bízhattak": "bízhat",
    "bízhatták": "bízhat",
    "bízhatunk": "bízhat",
    "bíznak": "bízik",
    "bízni": "bízik",
    "bízniuk": "bízik",
    "bíznunk": "bízik",
    "bízom": "bízik",
    "bízott": "bízik",
    "bízta": "bízik",
    "bíztak": "bízik",
    "bíztam": "bízik",
    "bíztatott": "bíztat",
    "bíztattuk": "bíztat",
    "bíztatóan": "bíztató",
    "bíztunk": "bízik",
    "bízták": "bízik",
    "bízzanak": "bízik",
    "bízzák": "bízik",
    "bóbiskolt": "bóbiskol",
    "bódultan": "bódult",
    "bódultjai": "bódult",
    "bódéban": "bódé",
    "bódéi": "bódé",
    "bódék": "bódé",
    "bólintott": "bólint",
    "bólintásaik": "bólintás",
    "bólintására": "bólintás",
    "bólogatásaik": "bólogatás",
    "böffent": "böffen",
    "böfögött": "böfög",
    "bökdöste": "bökdös",
    "bökte": "bök",
    "bökést": "bökés",
    "bökött": "bök",
    "bölcselőnek": "bölcselő",
    "bölcsessége": "bölcsesség",
    "bölcsességet": "bölcsesség",
    "bölcsességét": "bölcsesség",
    "bölcsőhöz": "bölcső",
    "bölcsője": "bölcső",
    "bölcsőt": "bölcső",
    "bölcsővel": "bölcső",
    "bömbölték": "bömböl",
    "börtönbe": "börtön",
    "börtönben": "börtön",
    "börtönbüntetéssel": "börtönbüntetés",
    "börtönből": "börtön",
    "börtönre": "börtön",
    "börtönt": "börtön",
    "börtönök": "börtön",
    "búcsúban": "búcsú",
    "búcsút": "búcsú",
    "búcsúzhattak": "búcsúzhat",
    "búcsúzott": "búcsúzik",
    "búcsúztak": "búcsúzik",
    "búcsúztatják": "búcsúztat",
    "búcsúztunk": "búcsúzik",
    "búcsúzásnál": "búcsúzás",
    "bújni": "bújik",
    "bújnom": "bújik",
    "bújok": "bújik",
    "bújt": "bújik",
    "bújtatott": "bújtat",
    "bújuk": "bú",
    "bútordarabját": "bútordarab",
    "bútorok": "bútor",
    "bútorokat": "bútor",
    "bútorokról": "bútorok",
    "búvárt": "búvár",
    "búvóhelyeiről": "búvóhely",
    "búvóhelyük": "búvóhely",
    "búzakenyeret": "búzakenyér",
    "búzamezők": "búzamező",
    "búzaszalmában": "búzaszalma",
    "búzaszemek": "búzaszem",
    "búzatarlóra": "búzatarló",
    "búzatáblán": "búzatábla",
    "búzaárak": "búzaár",
    "búzába": "búza",
    "búzában": "búza",
    "búzából": "búza",
    "búzája": "búza",
    "búzát": "búza",
    "búzával": "búza",
    "büdösebb": "büdös",
    "büntetlenül": "büntetlen",
    "büntetnek": "büntet",
    "büntetni": "büntet",
    "büntetné": "büntet",
    "büntetések": "büntetés",
    "büntetéseket": "büntetés",
    "büntetésként": "büntetés",
    "büntetésnek": "büntetés",
    "büntetést": "büntetés",
    "büntetésének": "büntetés",
    "büntetését": "büntetés",
    "büntetésüket": "büntetés",
    "büntetésünket": "büntetés",
    "büntetőből": "büntető",
    "büntetőket": "büntető",
    "büntetőt": "büntető",
    "büszkeségből": "büszkeség",
    "büszkesége": "büszkeség",
    "büszkeségei": "büszkeség",
    "büszkeséggel": "büszkeség",
    "büszkeségének": "büszkeség",
    "büszkeségük": "büszkeség",
    "büszkébb": "büszke",
    "büszkén": "büszke",
    "bőgése": "bőgés",
    "bőkezűen": "bőkezű",
    "bőkezűsége": "bőkezűség",
    "bőrdarabokat": "bőrdarab",
    "bőre": "bőr",
    "bőrfoszlányok": "bőrfoszlány",
    "bőrgyárakba": "bőrgyár",
    "bőrit": "bőri",
    "bőrkeményedésekkel": "bőrkeményedés",
    "bőrrel": "bőr",
    "bőrt": "bőr",
    "bőrtáskát": "bőrtáska",
    "bőréből": "bőr",
    "bőrén": "bőr",
    "bőrének": "bőr",
    "bőrét": "bőr",
    "bőréért": "bőr",
    "bőrömmel": "bőr",
    "bőrük": "bőr",
    "bőség-minisztériumnak": "bőség-minisztérium",
    "bőségesen": "bőséges",
    "bővebb": "bő",
    "bővebbet": "bő",
    "bőven": "bő",
    "bővíteni": "bővít",
    "bővítése": "bővítés",
    "bővítésre": "bővítés",
    "bővítésről": "bővítés",
    "bővülne": "bővül",
    "bővültek": "bővül",
    "bővülése": "bővülés",
    "bővülésére": "bővülés",
    "bővülését": "bővülés",
    "bűn": "bű",
    "bűnbánatban": "bűnbánat",
    "bűncselekményeiről": "bűncselekmény",
    "bűncselekményeket": "bűncselekmény",
    "bűncselekményekkel": "bűncselekmény",
    "bűncselekményeknek": "bűncselekmény",
    "bűncselekményhez": "bűncselekmény",
    "bűncselekményén": "bűncselekmény",
    "bűne": "bűn",
    "bűneiket": "bűn",
    "bűneit": "bűn",
    "bűngondol-ban": "bűngondol",
    "bűnperében": "bűnper",
    "bűnstop-ban": "bűnstop",
    "bűnstop-nak": "bűnstop",
    "bűnt": "bűn",
    "bűntette": "bűntett",
    "bűntettének": "bűntett",
    "bűntudatosabban": "bűntudatos",
    "bűntudatosan": "bűntudatos",
    "bűntudatosnak": "bűntudatos",
    "bűntudattal": "bűntudat",
    "bűnét": "bűn",
    "bűnök": "bűn",
    "bűnöket": "bűn",
    "bűnökkel": "bűn",
    "bűnöknek": "bűn",
    "bűnökért": "bűn",
    "bűnösként": "bűnös",
    "bűnösnek": "bűnös",
    "bűnösségére": "bűnösség",
    "bűnösségüket": "bűnösség",
    "bűnöst": "bűnös",
    "bűnösök": "bűnös",
    "bűnösöket": "bűnös",
    "bűnözők": "bűnöző",
    "bűnözőket": "bűnöző",
    "bűnözőkkel": "bűnöző",
    "bűnözőről": "bűnöző",
    "bűnügyek": "bűnügy",
    "bűnügyeken": "bűnügy",
    "bűnügyekkel": "bűnügy",
    "bűnüket": "bűn",
    "bűvkörébe": "bűvkör",
    "bűvészkedéshez": "bűvészkedés",
    "bűzben": "bűz",
    "bűzlött": "bűzlik",
    "bűzét": "bűz",
    "caflatnak": "caflat",
    "cefetül": "cefet",
    "cellapadlón": "cellapadló",
    "cellába": "cella",
    "cellában": "cella",
    "celláiba": "cella",
    "celláiban": "cella",
    "celláira": "cella",
    "cellája": "cella",
    "cellájába": "cella",
    "cellák": "cella",
    "cellákban": "cella",
    "cellán": "cella",
    "cellára": "cella",
    "cellától": "cella",
    "cementpadlóján": "cementpadló",
    "centerig": "center",
    "centerpályán": "centerpálya",
    "centert": "center",
    "centest": "centes",
    "centet": "cent",
    "centiméternyire": "centiméternyi",
    "centiméterre": "centiméter",
    "centiméterrel": "centiméter",
    "centruma": "centrum",
    "centrumaként": "centrum",
    "centrumban": "centrum",
    "centrumból": "centrum",
    "centrumot": "centrum",
    "centrumában": "centrum",
    "centért": "cent",
    "ceremónián": "ceremónia",
    "ceruzái": "ceruza",
    "ceruzát": "ceruza",
    "ceruzával": "ceruza",
    "chartájának": "charta",
    "cibálnak": "cibál",
    "cifraságot": "cifraság",
    "cigarettacsomagok": "cigarettacsomag",
    "cigarettaraktár-fosztogatásokban": "cigarettaraktár-fosztogatás",
    "cigarettavégekkel": "cigarettavég",
    "cigarettavéget": "cigarettavég",
    "cigarettáiból": "cigaretta",
    "cigarettája": "cigaretta",
    "cigarettájából": "cigaretta",
    "cigarettájáról": "cigaretta",
    "cigarettáját": "cigaretta",
    "cigarettájával": "cigaretta",
    "cigaretták": "cigaretta",
    "cigarettákat": "cigaretta",
    "cigarettára": "cigaretta",
    "cigarettát": "cigaretta",
    "cigarettával": "cigaretta",
    "cigányok": "cigány",
    "cigányoztak": "cigányoz",
    "cikcakkban": "cikcakk",
    "cikkben": "cikk",
    "cikke": "cikk",
    "cikkedben": "cikk",
    "cikkedet": "cikk",
    "cikkei": "cikk",
    "cikkek": "cikk",
    "cikkekből": "cikk",
    "cikkeket": "cikk",
    "cikkekkel": "cikk",
    "cikkekre": "cikk",
    "cikkel": "cikk",
    "cikkelyéről": "cikkely",
    "cikkemben": "cikk",
    "cikket": "cikk",
    "cikkében": "cikk",
    "cikkének": "cikk",
    "ciklusban": "ciklus",
    "cilindereikhez": "cilinder",
    "cilinderesek": "cilinderes",
    "cilindernek": "cilinder",
    "cilindert": "cilinder",
    "cimborái": "cimbora",
    "cimborám": "cimbora",
    "cimborámnak": "cimbora",
    "cimborától": "cimbora",
    "cinikusan": "cinikus",
    "cinizmusnak": "cinizmus",
    "cinkancsók": "cinkancsó",
    "cinkből": "cink",
    "cinkosságot": "cinkosság",
    "cinkosságtól": "cinkosság",
    "cinkosságával": "cinkosság",
    "cinkéknek": "cinkék",
    "cipelnek": "cipel",
    "cipelni": "cipel",
    "cipelt": "cipel",
    "cipelte": "cipel",
    "cipzárat": "cipzár",
    "cipzárját": "cipzár",
    "cipőfűzőt": "cipőfűző",
    "cipőinek": "cipői",
    "cipőjét": "cipő",
    "cipőjüket": "cipő",
    "cipők": "cipő",
    "cipőkben": "cipő",
    "cipőkopogása": "cipőkopogás",
    "cipőt": "cipő",
    "cipőtermelést": "cipőtermelés",
    "cipőért": "cipő",
    "cirkuszba": "cirkusz",
    "cirkuszt": "cirkusz",
    "cirkáltak": "cirkált",
    "cirokseprűt": "cirokseprű",
    "cirógatta": "cirógat",
    "citromra": "citrom",
    "citálhatott": "citálhat",
    "citálására": "citálás",
    "civakodásra": "civakodás",
    "civilek": "civil",
    "civileknek": "civil",
    "civilizációk": "civilizáció",
    "civilizáción": "civilizáció",
    "civilizációnkban": "civilizáció",
    "civilizációt": "civilizáció",
    "civilizált": "civilizál",
    "civilkontrollt": "civilkontroll",
    "civiltársadalmat": "civiltársadalom",
    "civilujjast": "civilujjas",
    "colstokját": "colstok",
    "combcsontja": "combcsont",
    "combja": "comb",
    "combjai": "comb",
    "combjaira": "comb",
    "combjában": "comb",
    "combjának": "comb",
    "condráinkban": "condra",
    "csacsogásával": "csacsogás",
    "csalhatatlanságába": "csalhatatlanság",
    "csalhatatlanságát": "csalhatatlanság",
    "csalhatatlanul": "csalhatatlan",
    "csalnak": "csal",
    "csalni": "csal",
    "csalta": "csal",
    "csaltak": "csalt",
    "csaltalak": "csal",
    "családban": "család",
    "családdal": "család",
    "családfakutatásokat": "családfakutatás",
    "családhoz": "család",
    "családja": "család",
    "családjához": "család",
    "családjának": "család",
    "családjáról": "család",
    "családját": "család",
    "családjával": "család",
    "családnak": "család",
    "családok": "család",
    "családokon": "család",
    "családom": "család",
    "családommal": "család",
    "családomnak": "család",
    "családorvosával": "családorvos",
    "családot": "család",
    "családpolitikát": "családpolitika",
    "családszeretetéből": "családszeretet",
    "családtagjaikat": "családtag",
    "családtagként": "családtag",
    "családtagok": "családtag",
    "családtagokként": "családtag",
    "családunk": "család",
    "családunkhoz": "család",
    "csalárdul": "csalárd",
    "csalások": "csalás",
    "csalást": "csalás",
    "csaléteknek": "csalétek",
    "csalódott": "csalódik",
    "csalódottak": "csalódott",
    "csalódottan": "csalódott",
    "csalódottságának": "csalódottság",
    "csalódtak": "csalódik",
    "csalódást": "csalódás",
    "csalók": "csaló",
    "csalóssága": "csalósság",
    "csapata": "csapat",
    "csapataiban": "csapat",
    "csapataik": "csapat",
    "csapataikat": "csapat",
    "csapatait": "csapat",
    "csapatba": "csapat",
    "csapatban": "csapat",
    "csapatból": "csapat",
    "csapatja": "csapat",
    "csapatkupán": "csapatkupa",
    "csapatnak": "csapat",
    "csapatok": "csapat",
    "csapatokat": "csapat",
    "csapatokkal": "csapatok",
    "csapatoktól": "csapatok",
    "csapaton": "csapat",
    "csapatosan": "csapatos",
    "csapatot": "csapat",
    "csapatra": "csapat",
    "csapattól": "csapat",
    "csapatuk": "csapat",
    "csapatunk": "csapat",
    "csapatunkhoz": "csapat",
    "csapatába": "csapat",
    "csapatából": "csapat",
    "csapatának": "csapat",
    "csapatát": "csapat",
    "csapatátcsoportosítások": "csapatátcsoportosítás",
    "csapatával": "csapat",
    "csapatösszeállítást": "csapatösszeállítás",
    "csapból": "csap",
    "csapd": "csap",
    "csapdákat": "csapda",
    "csapdát": "csapda",
    "csapjon": "csap",
    "csapják": "csap",
    "csapkodott": "csapkod",
    "csapkodta": "csapkod",
    "csapni": "csap",
    "csapniuk": "csap",
    "csapok": "csap",
    "csapongani": "csapong",
    "csaposnak": "csapos",
    "csapossal": "csapos",
    "csapot": "csap",
    "csapott": "csap",
    "csapta": "csap",
    "csaptak": "csap",
    "csaptál": "csap",
    "csapzott": "csapzik",
    "csapágyakat": "csapágy",
    "csapások": "csapás",
    "csapásokat": "csapás",
    "csapáson": "csapás",
    "csapásra": "csapás",
    "csapást": "csapás",
    "csapóajtóikon": "csapóajtó",
    "csapóajtót": "csapóajtó",
    "csapódott": "csapódik",
    "csapódtak": "csapódik",
    "csapókat": "csapó",
    "csapóra": "csapó",
    "csarnokot": "csarnok",
    "csarnokra": "csarnok",
    "csatahajókat": "csatahajó",
    "csatangolni": "csatangol",
    "csatasorban": "csatasor",
    "csatatéren": "csatatér",
    "csatlakozik": "csatlakoz",
    "csatlakozni": "csatlakozik",
    "csatlakoznának": "csatlakozik",
    "csatlakozott": "csatlakozik",
    "csatlakoztak": "csatlakozik",
    "csatlakozunk": "csatlakozik",
    "csatlakozzanak": "csatlakozik",
    "csatlakozásra": "csatlakozás",
    "csatlakozásról": "csatlakozás",
    "csatlósai": "csatlós",
    "csatolni": "csatol",
    "csatornahajlatban": "csatornahajlat",
    "csatornavonalat": "csatornavonal",
    "csatornába": "csatorna",
    "csatornáin": "csatorna",
    "csatornáját": "csatorna",
    "csatornák": "csatorna",
    "csatornákban": "csatorna",
    "csatornán": "csatorna",
    "csatornát": "csatorna",
    "csatornázást": "csatornázás",
    "csattanással": "csattanás",
    "csattanója": "csattanó",
    "csattanóját": "csattanó",
    "csattogásokra": "csattogás",
    "csattogástól": "csattogás",
    "csatában": "csata",
    "csatái": "csata",
    "csatája": "csata",
    "csaták": "csata",
    "csatát": "csata",
    "csavargatta": "csavargat",
    "csavargott": "csavarog",
    "csavargunk": "csavarog",
    "csavargásból": "csavargás",
    "csavargásnak": "csavargás",
    "csavargástól": "csavargás",
    "csavargójának": "csavargó",
    "csavargók": "csavargó",
    "csavargókkal": "csavargó",
    "csavargónak": "csavargó",
    "csavargóssá": "csavargós",
    "csavarhatják": "csavarhat",
    "csavarhúzót": "csavarhúzó",
    "csavarják": "csavar",
    "csavarjával": "csavar",
    "csavarkulcsot": "csavarkulcs",
    "csavarkulcsotok": "csavarkulcs",
    "csavarkulcsunk": "csavarkulcs",
    "csavarodott": "csavarodik",
    "csavarogjunk": "csavarog",
    "csavarogni": "csavarog",
    "csavarogtam": "csavarog",
    "csavarogtunk": "csavarog",
    "csavarok": "csavar",
    "csavart": "csavar",
    "csavarta": "csavar",
    "csavartak": "csavart",
    "csavarták": "csavar",
    "csecsebecsék": "csecsebecse",
    "csecsemőig": "csecsemő",
    "csecsemőiket": "csecsemő",
    "csecsemőjüket": "csecsemő",
    "csecsemőpelenkák": "csecsemőpelenka",
    "csecsemőre": "csecsemő",
    "csecsen": "csecs",
    "csehek": "cseh",
    "csekken": "csekk",
    "csekket": "csekk",
    "csekélyebb": "csekély",
    "cselekedetben": "cselekedet",
    "cselekedete": "cselekedet",
    "cselekedetedben": "cselekedet",
    "cselekedetei": "cselekedet",
    "cselekedeteidről": "cselekedet",
    "cselekedeteit": "cselekedet",
    "cselekedeteiteken": "cselekedet",
    "cselekedetek": "cselekedet",
    "cselekedeteket": "cselekedet",
    "cselekedetekkel": "cselekedet",
    "cselekedetekre": "cselekedet",
    "cselekedetet": "cselekedet",
    "cselekedett": "cselekedik",
    "cselekedettel": "cselekedett",
    "cselekedetük": "cselekedet",
    "cselekedhettem": "cselekedhet",
    "cselekedjék": "cselekedik",
    "cselekedni": "cselekedik",
    "cselekednie": "cselekedik",
    "cselekednék": "cselekedik",
    "cselekednünk": "cselekedik",
    "cselekedte": "cselekedik",
    "cselekedtek": "cselekedik",
    "cselekedtél": "cselekedik",
    "cselekményét": "cselekmény",
    "cselekszel": "cselekszik",
    "cselekszem": "cselekszik",
    "cselekszenek": "cselekszik",
    "cselekszünk": "cselekszik",
    "cselekvése": "cselekvés",
    "cselekvésekre": "cselekvés",
    "cselekvésre": "cselekvés",
    "cselekvésről": "cselekvés",
    "cselekvőképességét": "cselekvőképesség",
    "cselnek": "csel",
    "cseléddel": "cseléd",
    "cselédek": "cseléd",
    "cselédeket": "cseléd",
    "cselédekkel": "cseléd",
    "cselédektől": "cseléd",
    "cselédeké": "cseléd",
    "cselédet": "cseléd",
    "cselédje": "cseléd",
    "cselédjei": "cseléd",
    "cselédjének": "cseléd",
    "cselédjük": "cseléd",
    "cselédkönyveink": "cselédkönyv",
    "cselédkönyveinkkel": "cselédkönyv",
    "cselédkönyvet": "cselédkönyv",
    "cselédkönyvvel": "cselédkönyv",
    "cselédkönyvünk": "cselédkönyv",
    "cselédkönyvünkben": "cselédkönyv",
    "cselédlányok": "cselédlány",
    "cselédnek": "cseléd",
    "cselédre": "cseléd",
    "csemegéje": "csemege",
    "csemegével": "csemege",
    "csemperagyogással": "csemperagyogás",
    "csempészek": "csempész",
    "csempészi": "csempész",
    "csempészni": "csempész",
    "csempészvezetőkkel": "csempészvezető",
    "csempészáruhoz": "csempészáru",
    "csempészéssel": "csempészés",
    "csend": "csen",
    "csendben": "csend",
    "csendesen": "csendes",
    "csendesnek": "csendes",
    "csendje": "csend",
    "csendnek": "csend",
    "csendéletnek": "csendélet",
    "csendül": "csend",
    "csendültek": "csendül",
    "csendőrhöz": "csendőr",
    "csendőrlaktanyán": "csendőrlaktanya",
    "csendőrnek": "csendőr",
    "csendőrségen": "csendőrség",
    "csendőrt": "csendőr",
    "csendőrtől": "csendőr",
    "csendőrök": "csendőr",
    "csendőröket": "csendőr",
    "csendőrökkel": "csendőr",
    "csendőröknek": "csendőr",
    "csendőröktől": "csendőr",
    "csengetett": "csenget",
    "csengetni": "csenget",
    "csengőt": "csengő",
    "csennek": "csen",
    "cseppeket": "csepp",
    "cseppent": "cseppen",
    "cseppet": "csepp",
    "cseppfolyóssá": "cseppfolyós",
    "cseppig": "csepp",
    "cserben": "cser",
    "cserbenhagyták": "cserbenhagy",
    "cserearányáról": "cserearány",
    "cseregondjait": "cseregond",
    "cseresznyéje": "cseresznye",
    "cseresznyéjükbe": "cseresznye",
    "cseresznyét": "cseresznye",
    "csereügyek": "csereügy",
    "cserjéi": "cserje",
    "cserkészcsapatban": "cserkészcsapat",
    "cserkészcsapatnak": "cserkészcsapat",
    "cserkészcsapatot": "cserkészcsapat",
    "cserkészcsapattal": "cserkészcsapat",
    "cserkészei": "cserkész",
    "cserkészein": "cserkész",
    "cserkészek": "cserkészik",
    "cserkészetet": "cserkészet",
    "cserkészetről": "cserkészet",
    "cserkészgyűlésen": "cserkészgyűlés",
    "cserkésztáborból": "cserkésztábor",
    "cserzett": "cserz",
    "cserébe": "csere",
    "cserében": "csere",
    "cseréhez": "csere",
    "cseréje": "cseréj",
    "cseréjére": "cseréj",
    "cserélgettek": "cserélget",
    "cserélhetnek": "cserélhet",
    "cseréljen": "cserél",
    "cseréljék": "cserél",
    "cserélnek": "cserél",
    "cserélni": "cserél",
    "cserélt": "cserél",
    "cserélte": "cserél",
    "cseréltek": "cserélt",
    "cseréltem": "cserélt",
    "cserélődnek": "cserélődik",
    "cserépből": "cserép",
    "cseréppel": "cserép",
    "csettintett": "csettint",
    "csibék": "csibe",
    "csibét": "csibe",
    "csigaformákba": "csigaformá",
    "csigolyatörésbe": "csigolyatörés",
    "csiholni": "csihol",
    "csikarjunk": "csikar",
    "csikarják": "csikar",
    "csikarni": "csikar",
    "csikartak": "csikart",
    "csiklandozhassák": "csiklandozhat",
    "csikorogtak": "csikorog",
    "csilingeljetek": "csilingel",
    "csilingelték": "csilingel",
    "csilingelése": "csilingelés",
    "csilingelését": "csilingelés",
    "csilingelőbb": "csilingelő",
    "csillaga": "csillag",
    "csillagbörtönből": "csillagbörtön",
    "csillaggal": "csillag",
    "csillagok": "csillag",
    "csillagokra": "csillag",
    "csillagra": "csillag",
    "csillagászok": "csillagász",
    "csillanjon": "csillan",
    "csillantak": "csillant",
    "csillapodjál": "csillapodik",
    "csillapodnia": "csillapodik",
    "csillapodott": "csillapodik",
    "csillapodtak": "csillapodik",
    "csillapítóan": "csillapító",
    "csillapítószert": "csillapítószer",
    "csillognak": "csillog",
    "csillogott": "csillog",
    "csimpaszkodással": "csimpaszkodás",
    "csinosabbá": "csinos",
    "csinosaktól": "csinos",
    "csinálhasson": "csinálhat",
    "csinálhatjátok": "csinálhat",
    "csinálhatnak": "csinálhat",
    "csinálhatok": "csinálhat",
    "csinálhatott": "csinálhat",
    "csinálhattak": "csinálhat",
    "csinálja": "csinál",
    "csináljak": "csinál",
    "csináljanak": "csinál",
    "csináljatok": "csinál",
    "csináljon": "csinál",
    "csináljuk": "csinál",
    "csináljunk": "csinál",
    "csinálják": "csinál",
    "csináljátok": "csinál",
    "csinálnak": "csinál",
    "csinálni": "csinál",
    "csinálnia": "csinál",
    "csinálnunk": "csinál",
    "csinálnátok": "csinál",
    "csinálok": "csinál",
    "csinált": "csinál",
    "csinálta": "csinál",
    "csináltad": "csinált",
    "csináltak": "csinált",
    "csináltam": "csinált",
    "csináltatni": "csináltat",
    "csináltatok": "csináltat",
    "csináltok": "csinál",
    "csináltunk": "csinált",
    "csinálták": "csinál",
    "csinálunk": "csinál",
    "csipegetett": "csipeget",
    "csipkedjem": "csipked",
    "csipkelődést": "csipkelődés",
    "csipkerózsához": "csipkerózsa",
    "csipkéből": "csipke",
    "csipát": "csipa",
    "csirkefogók": "csirkefogó",
    "csirkefogóságért": "csirkefogóság",
    "csirkeólakhoz": "csirkeól",
    "csirkéi": "csirke",
    "csirkéim": "csirke",
    "csirkék": "csirke",
    "csirkékről": "csirke",
    "csirkét": "csirke",
    "csirkével": "csirke",
    "csitult": "csitul",
    "csizmában": "csizma",
    "csizmái": "csizma",
    "csizmája": "csizma",
    "csizmák": "csizma",
    "csizmákat": "csizma",
    "csizmát": "csizma",
    "csizmával": "csizma",
    "csobogna": "csobog",
    "csodabogárságába": "csodabogárság",
    "csodagyerekként": "csodagyerek",
    "csodaállat": "csodaáll",
    "csodája": "csoda",
    "csodák": "csoda",
    "csodálatnak": "csodálat",
    "csodálatosan": "csodálatos",
    "csodálatosképpen": "csodálatos",
    "csodálatosnak": "csodálatos",
    "csodálatot": "csodálat",
    "csodálkozna": "csodálkozik",
    "csodálkozni": "csodálkozik",
    "csodálkoznia": "csodálkozik",
    "csodálkozott": "csodálkozik",
    "csodálkoztak": "csodálkozik",
    "csodálkoztam": "csodálkozik",
    "csodálkozása": "csodálkozás",
    "csodálkozásnak": "csodálkozás",
    "csodálkozásában": "csodálkozás",
    "csodálkozására": "csodálkozás",
    "csodálom": "csodál",
    "csodált": "csodál",
    "csodálta": "csodál",
    "csodáltuk": "csodál",
    "csodálói": "csodáló",
    "csodát": "csoda",
    "csodával": "csoda",
    "csokoládé-fejadagot": "csokoládé-fejadag",
    "csokoládéadagot": "csokoládéadag",
    "csokoládédarabot": "csokoládédarab",
    "csokoládédarabra": "csokoládédarab",
    "csokoládéja": "csokoládé",
    "csokoládéját": "csokoládé",
    "csokoládét": "csokoládé",
    "csokoládéval": "csokoládé",
    "csokorra": "csokor",
    "csokrot": "csokor",
    "csokrát": "csokor",
    "csomagba": "csomag",
    "csomagban": "csomag",
    "csomagból": "csomag",
    "csomagja": "csomag",
    "csomagjaiknak": "csomag",
    "csomagküldésre": "csomagküldés",
    "csomagnak": "csomag",
    "csomagokban": "csomag",
    "csomagolt": "csomagol",
    "csomagolta": "csomagol",
    "csomagoltak": "csomagolt",
    "csomagolták": "csomagol",
    "csomagolásra": "csomagolás",
    "csomagolópapírra": "csomagolópapír",
    "csomagot": "csomag",
    "csomagtervnek": "csomagterv",
    "csomói": "csomó",
    "csomópontjain": "csomópont",
    "csomópontjánál": "csomópont",
    "csomópontokat": "csomópont",
    "csomót": "csomó",
    "csonkult": "csonkul",
    "csonthalmazként": "csonthalmaz",
    "csontig": "csont",
    "csontja": "csont",
    "csontjaiban": "csont",
    "csontjaiig": "csont",
    "csontjain": "csont",
    "csontjait": "csont",
    "csontjaival": "csont",
    "csontjáig": "csont",
    "csontok": "csont",
    "csontokat": "csont",
    "csontvázzal": "csontváz",
    "csontvázé": "csontváz",
    "csoportban": "csoport",
    "csoporthoz": "csoport",
    "csoportja": "csoport",
    "csoportjai": "csoport",
    "csoportjaihoz": "csoport",
    "csoportjait": "csoport",
    "csoportjaitól": "csoport",
    "csoportjára": "csoport",
    "csoportját": "csoport",
    "csoportlétszámok": "csoportlétszám",
    "csoportmérkőzések": "csoportmérkőzés",
    "csoportnak": "csoport",
    "csoportok": "csoport",
    "csoportokat": "csoport",
    "csoportokban": "csoport",
    "csoportokból": "csoport",
    "csoportokkal": "csoport",
    "csoportoknak": "csoport",
    "csoportokra": "csoport",
    "csoportomat": "csoport",
    "csoportosan": "csoportos",
    "csoportosul": "csoportos",
    "csoportosult": "csoportosul",
    "csoportosultak": "csoportosult",
    "csoportosulással": "csoportosulás",
    "csoportot": "csoport",
    "csoportozatában": "csoportozat",
    "csoportra": "csoport",
    "csoporttal": "csoport",
    "csoportérdekeken": "csoportérdek",
    "csorbulna": "csorbul",
    "csorbát": "csorba",
    "csordakúton": "csordakút",
    "csordultig": "csordult",
    "csorgott": "csorog",
    "csorogjanak": "csorog",
    "csorogtak": "csorog",
    "csoszogott": "csoszog",
    "csoszogása": "csoszogás",
    "csucsorította": "csucsorít",
    "csudafát": "csudafa",
    "csudát": "csuda",
    "csuklóit": "csuklói",
    "csuklója": "csukló",
    "csuklóján": "csukló",
    "csuklómat": "csukló",
    "csuklóvastagságúak": "csuklóvastagságú",
    "csukogatta": "csukogat",
    "csukottan": "csukott",
    "csukta": "csuk",
    "csurgatta": "csurgat",
    "csurgott": "csurog",
    "csurogna": "csurog",
    "csurrant": "csurran",
    "csutkaizéket": "csutkaizé",
    "csutkatövet": "csutkatő",
    "csábította": "csábít",
    "csábításnak": "csábítás",
    "csákánnyal": "csákány",
    "csáléztak": "csáléz",
    "csángók": "csángó",
    "csépelve": "csépelv",
    "cséplésbe": "cséplés",
    "csépléshez": "cséplés",
    "csépléskor": "cséplés",
    "cséplésnél": "cséplés",
    "csépléssel": "cséplés",
    "cséplőben": "cséplő",
    "cséplőgéphez": "cséplőgép",
    "cséplőmunkások": "cséplőmunkás",
    "cséplőmunkásoknak": "cséplőmunkás",
    "csészék": "csésze",
    "csészét": "csésze",
    "csészével": "csésze",
    "csíkok": "csík",
    "csíkot": "csík",
    "csíkozással": "csíkozás",
    "csípnie": "csíp",
    "csípte": "csíp",
    "csíptek": "csíp",
    "csíptetőt": "csíptető",
    "csípőből": "csípő",
    "csípője": "csípő",
    "csípőjéhez": "csípő",
    "csípőjére": "csípő",
    "csípőjét": "csípő",
    "csípőre": "csípő",
    "csípőtől": "csípő",
    "csókok": "csók",
    "csókolgatta": "csókolgat",
    "csókolni": "csókol",
    "csókolta": "csókol",
    "csókot": "csók",
    "csónakban": "csónak",
    "csónakot": "csónak",
    "csóvákat": "csóva",
    "csóvázott": "csóváz",
    "csökkenhetnek": "csökkenhet",
    "csökkenjen": "csökken",
    "csökkenne": "csökken",
    "csökkennek": "csökken",
    "csökkennének": "csökken",
    "csökkent": "csökken",
    "csökkentek": "csökkent",
    "csökkenteni": "csökkent",
    "csökkentené": "csökkent",
    "csökkentett": "csökkent",
    "csökkentette": "csökkent",
    "csökkentették": "csökkentet",
    "csökkentettük": "csökkentett",
    "csökkenthessék": "csökkenthet",
    "csökkentheti": "csökkenthet",
    "csökkenti": "csökkent",
    "csökkentik": "csökkent",
    "csökkentsék": "csökkent",
    "csökkentése": "csökkentés",
    "csökkentésekre": "csökkentés",
    "csökkentésére": "csökkentés",
    "csökkentését": "csökkentés",
    "csökkentésével": "csökkentés",
    "csökkenése": "csökkenés",
    "csökkenést": "csökkenés",
    "csökkenésére": "csökkenés",
    "csökkenésével": "csökkenés",
    "csöndbe": "csönd",
    "csöndben": "csönd",
    "csöndesen": "csöndes",
    "csöndet": "csönd",
    "csöngetésre": "csöngetés",
    "csöngetését": "csöngetés",
    "csöppentem": "csöppent",
    "csörgedezett": "csörgedezik",
    "csörgése": "csörgés",
    "csörögnek": "csörög",
    "csörömpölése": "csörömpölés",
    "csövesebb": "csöves",
    "csövet": "cső",
    "csövének": "cső",
    "csúcshoz": "csúcs",
    "csúcsidőben": "csúcsidő",
    "csúcsidőszakában": "csúcsidőszak",
    "csúcsjelenetek": "csúcsjelenet",
    "csúcsot": "csúcs",
    "csúcspontja": "csúcspont",
    "csúcspontján": "csúcspont",
    "csúcsra": "csúcs",
    "csúcsán": "csúcs",
    "csúcsát": "csúcs",
    "csúffá": "csúf",
    "csúfolta": "csúfol",
    "csúfoltuk": "csúfol",
    "csúfolták": "csúfol",
    "csúfosan": "csúfos",
    "csúfot": "csúf",
    "csúnyaságuk": "csúnyaság",
    "csúnyákat": "csúnya",
    "csúnyán": "csúnya",
    "csúnyának": "csúnya",
    "csúszkáláson": "csúszkálás",
    "csúszott": "csúszik",
    "csúsztak": "csúszik",
    "csúsztatott": "csúsztat",
    "csúsztatta": "csúsztat",
    "csúszómászókéval": "csúszómászó",
    "csúszósak": "csúszós",
    "csúzlit": "csúzli",
    "csücskében": "csücsök",
    "csüggedt": "csügged",
    "csüggedten": "csüggedt",
    "csüggött": "csügg",
    "csüngtek": "csüng",
    "csürhére": "csürhe",
    "csütörtöktől": "csütörtök",
    "csütörtökön": "csütörtök",
    "csütörtökönként": "csütörtök",
    "csőd": "cső",
    "csődbe": "csőd",
    "csődeljárásról": "csődeljárás",
    "csődhelyzetet": "csődhelyzet",
    "csődhöz": "csőd",
    "csődök": "csőd",
    "csődöt": "csőd",
    "csődületből": "csődület",
    "csőpostakészülékből": "csőpostakészülék",
    "csőpostába": "csőposta",
    "csőpostából": "csőposta",
    "csőposták": "csőposta",
    "csűrjük-csavarjuk": "csűr-csavar",
    "csűrni-csavarni": "csűr-csavar",
    "cukorbaját": "cukorbaj",
    "cukorból": "cukor",
    "cukorral": "cukor",
    "cukorrépán": "cukorrépa",
    "cukorrépánál": "cukorrépa",
    "cukorrépával": "cukorrépa",
    "cáfolataival": "cáfolat",
    "cáfolatot": "cáfolat",
    "cáfolja": "cáfol",
    "cáfolják": "cáfol",
    "cáfolt": "cáfol",
    "cécót": "cécó",
    "cédulánkat": "cédula",
    "cédulára": "cédula",
    "cédulát": "cédula",
    "cégbíróságra": "cégbíróság",
    "cége": "cég",
    "cégek": "cég",
    "cégeket": "cég",
    "cégeknek": "cég",
    "cégeknél": "cég",
    "cégekre": "cég",
    "cégen": "cég",
    "céget": "cég",
    "cégfúziókat": "cégfúzió",
    "céggel": "cég",
    "cégként": "cég",
    "cégvezetőket": "cégvezető",
    "célba": "cél",
    "célból": "cél",
    "célegyenesében": "célegyenes",
    "célja": "cél",
    "céljai": "cél",
    "céljaikat": "cél",
    "céljain": "cél",
    "céljainak": "cél",
    "céljaink": "cél",
    "céljaira": "cél",
    "céljairól": "cél",
    "céljait": "cél",
    "céljaival": "cél",
    "céljuk": "cél",
    "céljukat": "cél",
    "céljából": "cél",
    "céljához": "cél",
    "céljára": "cél",
    "célját": "cél",
    "célkitűzése": "célkitűzés",
    "célkitűzésként": "célkitűzés",
    "célkitűzését": "célkitűzés",
    "célként": "cél",
    "céllal": "cél",
    "célnak": "cél",
    "célok": "cél",
    "célokat": "cél",
    "céloknak": "cél",
    "célokra": "cél",
    "célokért": "cél",
    "célozhatott": "célozhat",
    "célozna": "céloz",
    "célozni": "céloz",
    "célozta": "céloz",
    "célozták": "céloz",
    "célozzák": "céloz",
    "célpontja": "célpont",
    "célra": "cél",
    "célt": "cél",
    "céltalannak": "céltalan",
    "céltalansága": "céltalanság",
    "céltalanságára": "céltalanság",
    "céltalanul": "céltalan",
    "céltudatosan": "céltudatos",
    "céltáblája": "céltábla",
    "céltáblára": "céltábla",
    "céltábláról": "céltábla",
    "céltámogatására": "céltámogatás",
    "célul": "cél",
    "célunk": "cél",
    "célzatot": "célzat",
    "célzott": "céloz",
    "célzásra": "célzás",
    "célzást": "célzás",
    "célállomáson": "célállomás",
    "cérnát": "cérna",
    "cézárok": "cézár",
    "címe": "cím",
    "címemet": "cím",
    "címen": "cím",
    "címet": "cím",
    "címkeragasztások": "címkeragasztás",
    "címlapon": "címlap",
    "címmel": "cím",
    "címre": "cím",
    "címzett": "címez",
    "címzést": "címzés",
    "címébe": "cím",
    "címén": "cím",
    "címét": "cím",
    "cókmókjukat": "cókmók",
    "cölibátusban": "cölibátus",
    "cölibátust": "cölibátus",
    "dacoltak": "dacolt",
    "dacára": "dac",
    "dadogott": "dadog",
    "dagadt": "dagad",
    "dalait": "dal",
    "dalba": "dal",
    "dalban": "dal",
    "dallal": "dal",
    "dallamba": "dallam",
    "dallamnak": "dallam",
    "dallamosan": "dallamos",
    "dallamosnak": "dallamos",
    "dallamra": "dallam",
    "dallá": "dal",
    "dalok": "dal",
    "dalokat": "dal",
    "dalokkal": "dal",
    "daloljanak": "dalol",
    "dalolt": "dalol",
    "dalra": "dal",
    "dalt": "dal",
    "dalát": "dal",
    "dandárját": "dandár",
    "darabbal": "darab",
    "darabban": "darab",
    "darabig": "darab",
    "darabja": "darab",
    "darabjai": "darab",
    "darabjaira": "darab",
    "darabjait": "darab",
    "darabjában": "darab",
    "darabját": "darab",
    "darabkája": "darabka",
    "darabkák": "darabka",
    "darabok": "darab",
    "darabokat": "darab",
    "darabokban": "darab",
    "darabokból": "darab",
    "darabokra": "darabokor",
    "darabot": "darab",
    "darálta": "darál",
    "daráltatni": "daráltat",
    "darócot": "daróc",
    "decemberben": "december",
    "decembere": "december",
    "decemberig": "december",
    "decemberihez": "decemberi",
    "decemberre": "december",
    "decemberében": "december",
    "decemberéig": "december",
    "decemberére": "december",
    "decemberét": "december",
    "decemberétől": "december",
    "dedikált": "dedikál",
    "deficitről": "deficit",
    "definiálnom": "definiál",
    "dekadenciával": "dekadencia",
    "deklarációk": "deklaráció",
    "deklarált": "deklarál",
    "deklarálta": "deklarál",
    "dekorációt": "dekoráció",
    "dekákból": "deka",
    "dekát": "deka",
    "delegációi": "delegáció",
    "delegációt": "delegáció",
    "delegálja": "delegál",
    "delegáljanak": "delegál",
    "delegált": "delegál",
    "delíriumában": "delírium",
    "demizsonnal": "demizson",
    "demizsont": "demizson",
    "demokratikusabb": "demokratikus",
    "demokratikusan": "demokratikus",
    "demokratizmusán": "demokratizmus",
    "demokratizálódásra": "demokratizálódás",
    "demokraták": "demokrata",
    "demokratákkal": "demokrata",
    "demokráciában": "demokrácia",
    "demokráciát": "demokrácia",
    "demonstrációját": "demonstráció",
    "demonstrálta": "demonstrál",
    "demonstrálása": "demonstrálás",
    "denevérjét": "denevér",
    "deportálták": "deportál",
    "deportálása": "deportálás",
    "deportálások": "deportálás",
    "depressziósok": "depressziós",
    "dereka": "derék",
    "derekukkal": "derék",
    "derekukra": "derék",
    "derekában": "derék",
    "derekán": "derék",
    "derekáról": "derék",
    "derekát": "derék",
    "derekától": "derék",
    "derengtek": "dereng",
    "dermedt": "dermed",
    "dermedtek": "dermedt",
    "derékból": "derék",
    "derékszögben": "derékszög",
    "deríteni": "derít",
    "derített": "derít",
    "derítettük": "derített",
    "derülne": "derül",
    "derült": "derül",
    "derültek": "derült",
    "derűje": "derű",
    "derűlátása": "derűlátás",
    "derűlátásunkkal": "derűlátás",
    "derűvel": "derű",
    "deszantosok": "deszantos",
    "deszkabárkával": "deszkabárka",
    "deszkakerítéseken": "deszkakerítés",
    "deszkakerítésen": "deszkakerítés",
    "deszkakerítéssel": "deszkakerítés",
    "deszkalapján": "deszkalap",
    "deszkalapokkal": "deszkalap",
    "deszkapallót": "deszkapalló",
    "deszkaágyon": "deszkaágy",
    "deszkaágyra": "deszkaágy",
    "deszkáját": "deszka",
    "deszkákon": "deszka",
    "deszkával": "deszka",
    "desztillált": "desztillál",
    "determinizmust": "determinizmus",
    "detonációt": "detonáció",
    "devizahitelek": "devizahitel",
    "devizapiacok": "devizapiac",
    "devizapiacon": "devizapiac",
    "devizaszabályozást": "devizaszabályozás",
    "devizatartalékai": "devizatartalék",
    "devizaügyletekkel": "devizaügylet",
    "devizaügyletekre": "devizaügylet",
    "devizát": "deviza",
    "dezorganizálódott": "dezorganizálódik",
    "diadalmasan": "diadalmas",
    "diadalok": "diadal",
    "diadalra": "diadal",
    "diadalt": "diadal",
    "diadalzászlóként": "diadalzászló",
    "diadalának": "diadal",
    "diagnóziscsoportokba": "diagnóziscsoport",
    "dicsekedett": "dicsekedik",
    "dicsekedhettek": "dicsekedhet",
    "dicsekedni": "dicsekedik",
    "dicsekvéssel": "dicsekvés",
    "dicshimnuszokat": "dicshimnusz",
    "dicshimnuszává": "dicshimnusz",
    "dicsérem": "dicsér",
    "dicséretekre": "dicséret",
    "dicséretet": "dicséret",
    "dicséretét": "dicséret",
    "dicsérhetem": "dicsérhet",
    "dicsérik": "dicsér",
    "dicsérjem": "dicsér",
    "dicsérnem": "dicsér",
    "dicsérni": "dicsér",
    "dicsérte": "dicsér",
    "dicsősége": "dicsőség",
    "dicsőségét": "dicsőség",
    "dicsőítik": "dicsőít",
    "dicsőítésének": "dicsőítés",
    "dideregni": "didereg",
    "dideregtünk": "didereg",
    "didergett": "didereg",
    "differenciált": "differenciál",
    "differenciálásra": "differenciálás",
    "differenciálásával": "differenciálás",
    "diktatúráját": "diktatúra",
    "diktatúrát": "diktatúra",
    "diktálja": "diktál",
    "diktálni": "diktál",
    "dilemmákkal": "dilemma",
    "dinamikusan": "dinamikus",
    "dinnyeevéstől": "dinnyeevés",
    "dinnyén": "dinnye",
    "dinnyét": "dinnye",
    "dinnyével": "dinnye",
    "diplomamunkát": "diplomamunka",
    "diplomataházat": "diplomataház",
    "diplomák": "diploma",
    "diplomát": "diploma",
    "diplomázott": "diplomáz",
    "direktóriumot": "direktórium",
    "diszkontált": "diszkontál",
    "diszkreditálják": "diszkreditál",
    "diszkreditált": "diszkreditál",
    "diszkózhatnak": "diszkózhat",
    "disznóhoz": "disznó",
    "disznóiknak": "disznó",
    "disznók": "disznó",
    "disznókkal": "disznó",
    "disznóknak": "disznó",
    "disznónak": "disznó",
    "disznónyájnak": "disznónyáj",
    "disznót": "disznó",
    "diszponálhatnák": "diszponálhat",
    "divatban": "divat",
    "divatja": "divat",
    "diverzánsakciókkal": "diverzánsakció",
    "dixielandet": "dixieland",
    "diák": "dia",
    "diákhotelek": "diákhotel",
    "diákkorában": "diákkor",
    "diákkorából": "diákkor",
    "diáknak": "diák",
    "diákok": "diák",
    "diákoknak": "diák",
    "diákot": "diák",
    "diáksportot": "diáksport",
    "diófáig": "diófa",
    "diószegről": "diószeg",
    "dobbal": "dob",
    "dobja": "dob",
    "dobják": "dob",
    "dobni": "dob",
    "dobogna": "dobog",
    "dobogni": "dobog",
    "dobogott": "dobog",
    "dobogta": "dobog",
    "dobogtak": "dobog",
    "dobogása": "dobogás",
    "dobogását": "dobogás",
    "dobogásával": "dobogás",
    "dobogókon": "dobogó",
    "dobok": "dob",
    "dobolta": "dobol",
    "dobott": "dob",
    "dobozai": "doboz",
    "dobozba": "doboz",
    "dobozból": "doboz",
    "dobozt": "doboz",
    "dobozukban": "doboz",
    "dobozát": "doboz",
    "dobpergéshez": "dobpergés",
    "dobra": "dob",
    "dobta": "dob",
    "dobtak": "dob",
    "dobták": "dob",
    "dobálják": "dobál",
    "dobálásból": "dobálás",
    "dodekaéderen": "dodekaéder",
    "dogozók": "dogozó",
    "dohánnyal": "dohány",
    "dohányadagból": "dohányadag",
    "dohányszelencék": "dohányszelence",
    "dohányt": "dohány",
    "dohányzott": "dohányzik",
    "dohányzást": "dohányzás",
    "dohányának": "dohány",
    "dokkmunkásként": "dokkmunkás",
    "doktorok": "doktor",
    "doktort": "doktor",
    "doktrínái": "doktrína",
    "dokumentuma": "dokumentum",
    "dokumentumai": "dokumentum",
    "dokumentumba": "dokumentum",
    "dokumentumból": "dokumentum",
    "dokumentummá": "dokumentum",
    "dokumentumok": "dokumentum",
    "dokumentumokat": "dokumentum",
    "dokumentumokról": "dokumentum",
    "dokumentumot": "dokumentum",
    "dolga": "dolog",
    "dolgainak": "dolog",
    "dolgainkat": "dolog",
    "dolgait": "dolog",
    "dolgaival": "dolog",
    "dolgod": "dolog",
    "dolgodban": "dolog",
    "dolgok": "dolog",
    "dolgokat": "dolog",
    "dolgokban": "dolog",
    "dolgokból": "dolog",
    "dolgokhoz": "dolog",
    "dolgokkal": "dolog",
    "dolgokon": "dolog",
    "dolgokra": "dolog",
    "dolgokról": "dolog",
    "dolgokért": "dolog",
    "dolgom": "dolog",
    "dolgon": "dolog",
    "dolgost": "dolgos",
    "dolgot": "dolog",
    "dolgozattal": "dolgozat",
    "dolgozatát": "dolgozat",
    "dolgozhatnak": "dolgozhat",
    "dolgozhatott": "dolgozhat",
    "dolgozhattak": "dolgozhat",
    "dolgozik": "dolgoz",
    "dolgozna": "dolgozik",
    "dolgoznak": "dolgozik",
    "dolgozni": "dolgozik",
    "dolgoznia": "dolgozik",
    "dolgozniuk": "dolgozik",
    "dolgoznának": "dolgozik",
    "dolgozok": "dolgozik",
    "dolgozom": "dolgozik",
    "dolgozott": "dolgozik",
    "dolgozta": "dolgozik",
    "dolgoztak": "dolgozik",
    "dolgoztam": "dolgozik",
    "dolgoztatták": "dolgoztat",
    "dolgoztunk": "dolgozik",
    "dolgozták": "dolgozik",
    "dolgozunk": "dolgozik",
    "dolgozza": "dolgozik",
    "dolgozzanak": "dolgozik",
    "dolgozzon": "dolgozik",
    "dolgozzák": "dolgozik",
    "dolgozzék": "dolgozik",
    "dolgozói": "dolgozó",
    "dolgozóiból": "dolgozói",
    "dolgozóik": "dolgozó",
    "dolgozója": "dolgozó",
    "dolgozójukba": "dolgozó",
    "dolgozójáról": "dolgozó",
    "dolgozójától": "dolgozó",
    "dolgozójával": "dolgozó",
    "dolgozók": "dolgozó",
    "dolgozókat": "dolgozó",
    "dolgozóknak": "dolgozó",
    "dolgozószobába": "dolgozószoba",
    "dolgozószobáiban": "dolgozószoba",
    "dolgozószobája": "dolgozószoba",
    "dolgozószobát": "dolgozószoba",
    "dolgozót": "dolgozó",
    "dolguk": "dolog",
    "dolgukat": "dolog",
    "dolgukban": "dolog",
    "dolgunk": "dolog",
    "dolgunkban": "dolog",
    "dolgában": "dolog",
    "dolgán": "dolog",
    "dolgának": "dolog",
    "dolgára": "dolog",
    "dolgáról": "dolog",
    "dolgát": "dolog",
    "dollárba": "dollár",
    "dollárban": "dollár",
    "dollárjegyzések": "dollárjegyzés",
    "dollárjuk": "dollár",
    "dollárjába": "dollár",
    "dollárkilátások": "dollárkilátás",
    "dollárnak": "dollár",
    "dollárnál": "dollár",
    "dollárra": "dollár",
    "dollárral": "dollár",
    "dollárt": "dollár",
    "dollárért": "dollár",
    "dologba": "dolog",
    "dologban": "dolog",
    "dologgal": "dolog",
    "dologhoz": "dolog",
    "dolognak": "dolog",
    "dologra": "dolog",
    "dologról": "dolog",
    "dologért": "dolog",
    "domborulatát": "domborulat",
    "dongták": "dong",
    "dorgálásban": "dorgálás",
    "dossziék": "dosszié",
    "drapériát": "drapéria",
    "drapériával": "drapéria",
    "drogkartelltől": "drogkartell",
    "drukkolta": "drukkol",
    "drukkoltak": "drukkolt",
    "drágulása": "drágulás",
    "drágulást": "drágulás",
    "drágulásához": "drágulás",
    "drágájának": "drága",
    "drágák": "drága",
    "drágám": "drága",
    "drágán": "drága",
    "drágának": "drága",
    "drágítja": "drágít",
    "drámájával": "dráma",
    "drámát": "dráma",
    "drámával": "dráma",
    "drótból": "drót",
    "dróthálót": "drótháló",
    "dróthálóval": "drótháló",
    "drótkosarakkal": "drótkosár",
    "drótnak": "drót",
    "drótokat": "drót",
    "drótozott": "drótoz",
    "dudlit": "dudli",
    "dudorodott": "dudorodik",
    "dudák": "duda",
    "dugattyúját": "dugattyú",
    "dugni": "dug",
    "dugott": "dug",
    "dugta": "dug",
    "dugtak": "dug",
    "dugták": "dug",
    "duhajságért": "duhajság",
    "duplagondol-ban": "duplagondol",
    "duplagondol-gyakorlatoknak": "duplagondol-gyakorlatok",
    "duplagondol-nak": "duplagondol",
    "duplagondol-on": "duplagondol",
    "duplagondol-ról": "duplagondol",
    "duplagondol-t": "duplagondol",
    "duplagondolról": "duplagondol",
    "duplája": "dupla",
    "durcásan": "durcás",
    "durranást": "durranás",
    "duruzsolása": "duruzsolás",
    "duruzsolását": "duruzsolás",
    "durvasága": "durvaság",
    "durvább": "durva",
    "durván": "durva",
    "durvának": "durva",
    "duzzadt": "duzzad",
    "duzzogott": "duzzog",
    "duzzogásokkal": "duzzogás",
    "dzsesszaláfestéssel": "dzsesszaláfestés",
    "dzsesszt": "dzsessz",
    "dánok": "dán",
    "dátummal": "dátum",
    "dátumok": "dátum",
    "dátumokat": "dátum",
    "dátumot": "dátum",
    "dédapja": "dédapa",
    "dédelgette": "dédelget",
    "dédelgettél": "dédelget",
    "dédelgetést": "dédelgetés",
    "dédelgetését": "dédelgetés",
    "dédmamától": "dédmama",
    "dédnagyapjára": "dédnagyapa",
    "dél-Budapesten": "dél-Budapest",
    "dél-Indiában": "dél-India",
    "dél-Koreával": "dél-Korea",
    "dél-Szlovákiában": "dél-Szlovákia",
    "dél-Tirolt": "dél-Tirol",
    "dél-amerikaiak": "dél-amerikai",
    "délben": "dél",
    "délelőttieknél": "délelőtti",
    "délelőttjén": "délelőtt",
    "délelőttre": "délelőtt",
    "délelőttök": "délelőtt",
    "délelőttön": "délelőtt",
    "délen": "dél",
    "délibábból": "délibáb",
    "délidőben": "délidő",
    "délig": "dél",
    "délnek": "dél",
    "délre": "dél",
    "délutánig": "délután",
    "délutánjai": "délután",
    "délutánjában": "délután",
    "délutánján": "délután",
    "délutánnak": "délután",
    "délutánokat": "délután",
    "délutánokon": "délután",
    "délutánon": "délután",
    "délutánonként": "délután",
    "délutánra": "délután",
    "délutánt": "délután",
    "dézsmáláskor": "dézsmálás",
    "dézsába": "dézsa",
    "dézsából": "dézsa",
    "díja": "díj",
    "díjaikat": "díj",
    "díjait": "díj",
    "díjak": "díj",
    "díjakat": "díj",
    "díjakból": "díj",
    "díjat": "díj",
    "díjbirkózókülseje": "díjbirkózókülső",
    "díjbirkózóra": "díjbirkózó",
    "díjhátralékot": "díjhátralék",
    "díjkalkulációjával": "díjkalkuláció",
    "díjkiosztása": "díjkiosztás",
    "díjon": "díj",
    "díjszabása": "díjszabás",
    "díjátadással": "díjátadás",
    "díjért": "díj",
    "dísze": "dísz",
    "díszeiket": "dísz",
    "díszelegni": "díszeleg",
    "dísznövényeket": "dísznövény",
    "díszterem": "dísztér",
    "dísztermet": "díszterem",
    "dísztermében": "díszterem",
    "díszíteni": "díszít",
    "díszített": "díszít",
    "díszítette": "díszít",
    "díszítését": "díszítés",
    "dívtak": "dívik",
    "döbbeneteket": "döbbenet",
    "döbbenetesnek": "döbbenetes",
    "döbbenetet": "döbbenet",
    "döbbenniük": "döbben",
    "döbbent": "döbben",
    "döccent": "döccen",
    "döcögött": "döcög",
    "döcögőssé": "döcögős",
    "döftek": "döf",
    "döfésként": "döfés",
    "döfött": "döf",
    "döglött": "döglik",
    "döglődésig": "döglődés",
    "dögök": "dög",
    "dögöljenek": "dögöl",
    "dögöljön": "dögöl",
    "döntenek": "dönt",
    "dönteni": "dönt",
    "döntenie": "dönt",
    "dönteniük": "dönt",
    "döntenénk": "dönt",
    "döntetlennek": "döntetlen",
    "döntetlenre": "döntetlen",
    "döntetlent": "döntetlen",
    "dönthetett": "dönthet",
    "dönthetik": "dönthet",
    "dönthetnek": "dönthet",
    "dönti": "dönt",
    "döntsenek": "dönt",
    "döntsön": "dönt",
    "döntése": "döntés",
    "döntéseiről": "döntés",
    "döntések": "döntés",
    "döntéseket": "döntés",
    "döntéseknek": "döntés",
    "döntéshez": "döntés",
    "döntéshozatalának": "döntéshozatal",
    "döntéshozók": "döntéshozó",
    "döntésig": "döntés",
    "döntésképtelensége": "döntésképtelenség",
    "döntésre": "döntés",
    "döntést": "döntés",
    "döntésére": "döntés",
    "döntését": "döntés",
    "döntésétől": "döntés",
    "döntésük": "döntés",
    "döntésüket": "döntés",
    "döntésünk": "döntés",
    "döntésünket": "döntés",
    "döntött": "dönt",
    "döntötte": "dönt",
    "döntöttek": "döntött",
    "döntöttem": "döntött",
    "döntöttél": "dönt",
    "döntöttünk": "döntött",
    "döntünk": "dönt",
    "döntőbe": "döntő",
    "döntőben": "döntő",
    "döntőig": "döntő",
    "döntőjében": "döntő",
    "döntőkkel": "döntő",
    "döntőn": "döntő",
    "döntőnek": "döntő",
    "dörgést": "dörgés",
    "dörgésével": "dörgés",
    "dörgölte": "dörgöl",
    "dörmögik": "dörmög",
    "dörmögnie": "dörmög",
    "dörmögte": "dörmög",
    "dörmögtek": "dörmög",
    "dörmögést": "dörmögés",
    "dörmögött": "dörmög",
    "dörmögőknek": "dörmögő",
    "dörrenéssel": "dörrenés",
    "dörzsöli": "dörzsöl",
    "dörzsölték": "dörzsöl",
    "dörömböltünk": "dörömbölt",
    "dörömbölése": "dörömbölés",
    "dörömböléssel": "dörömbölés",
    "dúdolni": "dúdol",
    "dúdolt": "dúdol",
    "dúdolta": "dúdol",
    "dúlta": "dúl",
    "dúsan": "dús",
    "dúsított": "dúsít",
    "dübörgése": "dübörgés",
    "dübörgésének": "dübörgés",
    "dübörgésével": "dübörgés",
    "dühkiáltások": "dühkiáltás",
    "dühvel": "düh",
    "dühében": "düh",
    "dühét": "düh",
    "dühített": "dühít",
    "dühítette": "dühít",
    "dühödni": "dühödik",
    "dühöngött": "dühöng",
    "dühösen": "dühös",
    "dühöt": "düh",
    "dünnyögött": "dünnyög",
    "dőlnek": "dől",
    "dőlni": "dől",
    "dőlt": "dől",
    "dűlt": "dűl",
    "dűlők": "dűlő",
    "dűlőkön": "dűlő",
    "dűlőn": "dűlő",
    "dűlőre": "dűlő",
    "dűlőről": "dűlő",
    "dűlőutakon": "dűlőút",
    "dűlőútra": "dűlőút",
    "e": "ez",
    "ebbe": "ez",
    "ebben": "ez",
    "ebből": "ez",
    "ebédek": "ebéd",
    "ebédet": "ebéd",
    "ebédhez": "ebéd",
    "ebédidőben": "ebédidő",
    "ebédjét": "ebéd",
    "ebédkor": "ebéd",
    "ebédre": "ebéd",
    "ebédről": "ebéd",
    "ecsetelte": "ecsetel",
    "ecsettel": "ecset",
    "eddig": "ez",
    "eddigiek": "eddigi",
    "eddigiekhez": "eddigi",
    "eddigieknél": "eddigi",
    "eddiginél": "eddigi",
    "edzek": "edz",
    "edzenek": "edz",
    "edzeni": "edz",
    "edzette": "edzet",
    "edzettem": "edzett",
    "edzések": "edzés",
    "edzéseken": "edzés",
    "edzésem": "edzés",
    "edzéslehetőségek": "edzéslehetőség",
    "edzésnapot": "edzésnap",
    "edzésre": "edzés",
    "edzéssel": "edzés",
    "edzésétől": "edzés",
    "edzője": "edző",
    "edzőm": "edző",
    "edzőtáboroznak": "edzőtáboroz",
    "edzőtáboroztunk": "edzőtáboroz",
    "edzőtáborunk": "edzőtábor",
    "edények": "edény",
    "effélét": "efféle",
    "egek": "ég",
    "egerek": "egér",
    "eget": "ég",
    "egetverőnek": "egetverő",
    "eggyel": "egy",
    "egriek": "egri",
    "egybe": "egy",
    "egybeesnek": "egybeesik",
    "egybegyúrása": "egybegyúrás",
    "egybegyűltekkel": "egybegyűltek",
    "egybehangzóan": "egybehangzó",
    "egybekössék": "egybeköt",
    "egybekötheti": "egybeköthet",
    "egybekötött": "egybeköt",
    "egyben": "egy",
    "egye": "eszik",
    "egyebek": "egyéb",
    "egyebeket": "egyéb",
    "egyebekről": "egyéb",
    "egyebet": "egyéb",
    "egyedei": "egyed",
    "egyedszámban": "egyedszám",
    "egyedül": "egyed",
    "egyedülállók": "egyedülálló",
    "egyelőre": "egyelő",
    "egyem": "eszik",
    "egyenebédet": "egyenebéd",
    "egyenek": "eszik",
    "egyenesebb": "egyenes",
    "egyenesen": "egyenes",
    "egyenest": "egyenes",
    "egyenként": "egy",
    "egyenletbe": "egyenlet",
    "egyenlíteni": "egyenlít",
    "egyenlített": "egyenlít",
    "egyenlítettek": "egyenlített",
    "egyenlően": "egyenlő",
    "egyenlők": "egyenlő",
    "egyenlőnek": "egyenlő",
    "egyenlőre": "egyenlő",
    "egyenlőséget": "egyenlőség",
    "egyenlőségről": "egyenlőség",
    "egyenlőségében": "egyenlőség",
    "egyenlőségének": "egyenlőség",
    "egyenlőtlenségek": "egyenlőtlenség",
    "egyenrangúaknak": "egyenrangú",
    "egyenruhaként": "egyenruha",
    "egyenruhába": "egyenruha",
    "egyenruhában": "egyenruha",
    "egyenruhája": "egyenruha",
    "egyenruhájában": "egyenruha",
    "egyenruhájához": "egyenruha",
    "egyenruhákban": "egyenruha",
    "egyensúlya": "egyensúly",
    "egyensúlyban": "egyensúly",
    "egyensúlyozta": "egyensúlyoz",
    "egyensúlyra": "egyensúly",
    "egyensúlyt": "egyensúly",
    "egyensúlyának": "egyensúly",
    "egyensúlyát": "egyensúly",
    "egyesben": "egyes",
    "egyesek": "egyes",
    "egyesekben": "egyes",
    "egyeseket": "egyes",
    "egyesét": "egyes",
    "egyesével": "egyes",
    "egyesíteni": "egyesít",
    "egyesítést": "egyesítés",
    "egyesülete": "egyesület",
    "egyesületek": "egyesület",
    "egyesületekre": "egyesület",
    "egyesületre": "egyesület",
    "egyesülettel": "egyesület",
    "egyesületének": "egyesület",
    "egyesült": "egyesül",
    "egyesülten": "egyesült",
    "egyesülése": "egyesülés",
    "egyesüléshez": "egyesülés",
    "egyesülést": "egyesülés",
    "egyesülésében": "egyesülés",
    "egyet": "egy",
    "egyet-egyet": "egy-egy",
    "egyet-kettőt": "egy-kettő",
    "egyet-mást": "egy-más",
    "egyetemei": "egyetem",
    "egyetemek": "egyetem",
    "egyetemen": "egyetem",
    "egyetemet": "egyetem",
    "egyetemhez": "egyetem",
    "egyetemistákkal": "egyetemista",
    "egyetlenegyszer": "egyetlenegy",
    "egyetértek": "egyetért",
    "egyetértenek": "egyetért",
    "egyetérteni": "egyetért",
    "egyetértett": "egyetért",
    "egyetértettek": "egyetértett",
    "egyetértettünk": "egyetértett",
    "egyetértésből": "egyetértés",
    "egyezett": "egyez",
    "egyezik": "egyez",
    "egyezkedett": "egyezkedik",
    "egyezkedni": "egyezkedik",
    "egyezmények": "egyezmény",
    "egyezményhez": "egyezmény",
    "egyezményről": "egyezmény",
    "egyezményt": "egyezmény",
    "egyezményét": "egyezmény",
    "egyeznek": "egyez",
    "egyezni": "egyez",
    "egyezséget": "egyezség",
    "egyezséghez": "egyezség",
    "egyeztek": "egyez",
    "egyeztethetők": "egyeztethető",
    "egyezteti": "egyeztet",
    "egyeztetjük": "egyeztet",
    "egyeztetni": "egyeztet",
    "egyeztetnie": "egyeztet",
    "egyeztetéseik": "egyeztetés",
    "egyeztetésen": "egyeztetés",
    "egyeztetést": "egyeztetés",
    "egyeztünk": "egyez",
    "egyformák": "egyformá",
    "egyformán": "egyformá",
    "egyféleképpen": "egyféle",
    "egyharmada": "egyharmad",
    "egyharmadára": "egyharmad",
    "egyháza": "egyház",
    "egyházak": "egyház",
    "egyházakat": "egyház",
    "egyházakban": "egyház",
    "egyházakkal": "egyház",
    "egyházaknak": "egyház",
    "egyházat": "egyház",
    "egyházhoz": "egyház",
    "egyházközségek": "egyházközség",
    "egyházközségnek": "egyházközség",
    "egyháznak": "egyház",
    "egyházra": "egyház",
    "egyházzal": "egyház",
    "egyházét": "egyház",
    "egyidősnek": "egyidős",
    "egyig": "egy",
    "egyik-másikkal": "egyik-másik",
    "egyikben": "egyik",
    "egyikből": "egyik",
    "egyike": "egyik",
    "egyikeként": "egyik",
    "egyiket": "egyik",
    "egyikkel": "egyik",
    "egyiknek": "egyik",
    "egyikre": "egyik",
    "egyikébe": "egyik",
    "egyikében": "egyik",
    "egyikéből": "egyik",
    "egyikén": "egyik",
    "egyikének": "egyik",
    "egyikét": "egyik",
    "egyikével": "egyik",
    "egyikük": "egyik",
    "egyiküknek": "egyik",
    "egyikükről": "egyik",
    "egyikünk": "egyik",
    "egyiptomiakhoz": "egyiptomi",
    "egykedvűen": "egykedvű",
    "egykor": "egy",
    "egymilliárdot": "egymilliárd",
    "egymilliósnak": "egymilliós",
    "egymásba": "egymás",
    "egymáshoz": "egymás",
    "egymásnak": "egymás",
    "egymásnál": "egymás",
    "egymásra": "egymás",
    "egymásról": "egymás",
    "egymással": "egymás",
    "egymást": "egymás",
    "egymástól": "egymás",
    "egymásutánban": "egymásután",
    "egynegyedét": "egynegyed",
    "egynél": "egy",
    "egyoldalúsága": "egyoldalúság",
    "egyoldalúságában": "egyoldalúság",
    "egypáran": "egypár",
    "egypárat": "egypár",
    "egyre": "egy",
    "egyről": "egy",
    "egyszer": "egy",
    "egyszeriben": "egyszeri",
    "egyszerűbb": "egyszerű",
    "egyszerűbben": "egyszerű",
    "egyszerűbbé": "egyszerű",
    "egyszerűen": "egyszerű",
    "egyszerűnek": "egyszerű",
    "egyszerűséghez": "egyszerűség",
    "egyszerűségében": "egyszerűség",
    "egyszerűsíti": "egyszerűsít",
    "egységben": "egység",
    "egysége": "egység",
    "egységei": "egység",
    "egységek": "egység",
    "egységesen": "egységes",
    "egységessé": "egységes",
    "egységet": "egység",
    "egységként": "egység",
    "egységre": "egység",
    "egységének": "egység",
    "egységéről": "egység",
    "egységét": "egység",
    "egytizede": "egytized",
    "egytizedének": "egytized",
    "egytizedére": "egytized",
    "egytől": "egy",
    "egyvalamit": "egyvalami",
    "egyébbel": "egyéb",
    "egyébkor": "egyéb",
    "egyébként": "egyéb",
    "egyébre": "egyéb",
    "egyék": "eszik",
    "egyén": "egy",
    "egyének": "egyén",
    "egyéneknek": "egyén",
    "egyénenként": "egyén",
    "egyénig": "egyén",
    "egyénisége": "egyéniség",
    "egyéniségek": "egyéniség",
    "egyéniséget": "egyéniség",
    "egyéniségén": "egyéniség",
    "egyéniségét": "egyéniség",
    "egyéniségétől": "egyéniség",
    "egyénnek": "egyén",
    "egyént": "egyén",
    "egyéntől": "egyén",
    "egyértelműek": "egyértelmű",
    "egyértelműen": "egyértelmű",
    "egyéveset": "egyéves",
    "egyöntetűen": "egyöntetű",
    "együgyűségét": "együgyűség",
    "együttesbe": "együttes",
    "együttese": "együttes",
    "együttesen": "együttes",
    "együttest": "együttes",
    "együtteséből": "együttes",
    "együttműködnek": "együttműködik",
    "együttműködni": "együttműködik",
    "együttműködésnek": "együttműködés",
    "együttműködésre": "együttműködés",
    "együttműködést": "együttműködés",
    "együttműködésében": "együttműködés",
    "együttműködésének": "együttműködés",
    "együttműködésért": "együttműködés",
    "együttműködésük": "együttműködés",
    "együttélést": "együttélés",
    "egzaltáltsággal": "egzaltáltság",
    "egzisztenciájuk": "egzisztencia",
    "egészben": "egész",
    "egészen": "egész",
    "egészet": "egész",
    "egészhez": "egész",
    "egésznek": "egész",
    "egészről": "egész",
    "egészségben": "egészség",
    "egészségbiztosításnak": "egészségbiztosítás",
    "egészségbiztosítóban": "egészségbiztosító",
    "egészségedre": "egészség",
    "egészségesebbek": "egészséges",
    "egészségesek": "egészséges",
    "egészségesnek": "egészséges",
    "egészségre": "egészség",
    "egészségét": "egészség",
    "egészségügybe": "egészségügy",
    "egészségügyben": "egészségügy",
    "egészségügyből": "egészségügy",
    "egészségügyet": "egészségügy",
    "egészségügyről": "egészségügy",
    "egészében": "egész",
    "egészének": "egész",
    "egészét": "egész",
    "egészíti": "egészít",
    "egészítik": "egészít",
    "egészítsék": "egészít",
    "egészült": "egészül",
    "ehetetlenül": "ehetetlen",
    "eheti": "ehet",
    "ehetővé": "ehető",
    "ehhez": "ez",
    "ejtenek": "ejt",
    "ejteni": "ejt",
    "ejtenie": "ejt",
    "ejtett": "ejt",
    "ejtette": "ejt",
    "ejtetted": "ejtett",
    "ejtettek": "ejtett",
    "ejtették": "ejtet",
    "ejthetne": "ejthet",
    "ejthette": "ejthet",
    "ejti": "ejt",
    "ejtőernyővel": "ejtőernyő",
    "ekkor": "ez",
    "ekkorára": "ekkora",
    "ekkorát": "ekkora",
    "eksztázisa": "eksztázis",
    "ekvivalenssé": "ekvivalens",
    "ekéjük": "eke",
    "ekével": "eke",
    "el-elbeszélgettünk": "el-elbeszélget",
    "el-elcsennek": "el-elcsen",
    "el-elmaradozott": "el-elmaradozik",
    "eladhatja": "eladhat",
    "eladja": "elad",
    "eladni": "elad",
    "eladott": "elad",
    "eladta": "elad",
    "eladtak": "elad",
    "eladtalak": "elad",
    "eladtam": "elad",
    "eladtuk": "elad",
    "eladtál": "elad",
    "eladása": "eladás",
    "eladásai": "eladás",
    "eladásra": "eladás",
    "eladással": "eladás",
    "eladást": "eladás",
    "eladásából": "eladás",
    "eladását": "eladás",
    "eladásával": "eladás",
    "eladókat": "eladó",
    "eladósodni": "eladósod",
    "eladósodott": "eladósod",
    "eladósodása": "eladósodás",
    "eladósodást": "eladósodás",
    "eladósodásához": "eladósodás",
    "eladósodásának": "eladósodás",
    "elakadna": "elakad",
    "elakadt": "elakad",
    "elakadtunk": "elakadt",
    "elaltassák": "elaltat",
    "elaltatják": "elaltat",
    "elaludni": "elalszik",
    "elaludt": "elalszik",
    "elaludtak": "elaludt",
    "elaludtam": "elaludt",
    "elaludtunk": "elaludt",
    "elalvóban": "elalvó",
    "elamerikázza": "elamerikázik",
    "elapadt": "elapad",
    "elavult": "elavul",
    "elavultan": "elavult",
    "elbarikádozták": "elbarikádoz",
    "elbeszélgetett": "elbeszélget",
    "elbeszélgethetett": "elbeszélgethet",
    "elbeszélgethetnek": "elbeszélgethet",
    "elbeszélgettünk": "elbeszélget",
    "elbeszélte": "elbeszél",
    "elbizakodottá": "elbizakodott",
    "elbizakodástól": "elbizakodás",
    "elbocsátott": "elbocsát",
    "elbocsátották": "elbocsát",
    "elbocsátásával": "elbocsátás",
    "elborzadni": "elborzad",
    "elbájolja": "elbájol",
    "elbánnia": "elbánik",
    "elbátortalanodott": "elbátortalanodik",
    "elbátortalanítania": "elbátortalanít",
    "elbátortalanította": "elbátortalanít",
    "elbíráltatni": "elbíráltat",
    "elbírálásnál": "elbírálás",
    "elbírálást": "elbírálás",
    "elbírálásában": "elbírálás",
    "elbírálásánál": "elbírálás",
    "elbódítania": "elbódít",
    "elbúcsúzhatnak": "elbúcsúzhat",
    "elbúcsúzott": "elbúcsúzik",
    "elbúcsúztak": "elbúcsúzik",
    "elbúcsúztam": "elbúcsúzik",
    "elbúcsúztunk": "elbúcsúzik",
    "elbúsult": "elbúsul",
    "elbűvöli": "elbűvöl",
    "elbűvölte": "elbűvöl",
    "elbűvölésének": "elbűvölés",
    "elcaflatnak": "elcaflat",
    "elcsalta": "elcsal",
    "elcsapják": "elcsap",
    "elcsapta": "elcsap",
    "elcsavarogtuk": "elcsavarog",
    "elcsavart": "elcsavar",
    "elcsendesedett": "elcsendesedik",
    "elcserélni": "elcserél",
    "elcseréltem": "elcserélt",
    "elcseréltük": "elcserél",
    "elcsigázott": "elcsigázik",
    "elcsituljon": "elcsitul",
    "elcsitult": "elcsitul",
    "elcsitítsa": "elcsitít",
    "elcsomagolta": "elcsomagol",
    "elcsépelik": "elcsépel",
    "elcsépelni": "elcsépel",
    "elcsépelt": "elcsépel",
    "elcsépelték": "elcsépel",
    "elcsípi": "elcsíp",
    "elcsúsztatott": "elcsúsztat",
    "elcsüggedt": "elcsügged",
    "eldobhatja": "eldobhat",
    "eldobja": "eldob",
    "eldobni": "eldob",
    "eldobott": "eldob",
    "eldobtam": "eldob",
    "eldobták": "eldob",
    "eldolgozhatnék": "eldolgozhat",
    "eldugaszolják": "eldugaszol",
    "eldugaszolta": "eldugaszol",
    "eldugnia": "eldug",
    "eldugott": "eldug",
    "eldugta": "eldug",
    "eldugult": "eldugul",
    "eldurvult": "eldurvul",
    "eldurvított": "eldurvít",
    "eldönteni": "eldönt",
    "eldöntenie": "eldönt",
    "eldöntéséhez": "eldöntés",
    "eldöntött": "eldönt",
    "eldöntötte": "eldönt",
    "eldőlt": "eldől",
    "eledelen": "eledel",
    "elefántagyarakat": "elefántagyar",
    "elefántokkal": "elefánt",
    "elege": "elég",
    "elegendőnek": "elegendő",
    "eleget": "elég",
    "elegánsak": "elegáns",
    "elejtett": "elejt",
    "elejtette": "elejt",
    "elejéből": "eleje",
    "elején": "eleje",
    "elejének": "eleje",
    "elejére": "eleje",
    "elejét": "eleje",
    "elejétől": "eleje",
    "elektronikával": "elektronika",
    "elektronok": "elektron",
    "elektronokat": "elektron",
    "eleme": "elem",
    "elemei": "elem",
    "elemeit": "elem",
    "elemek": "elem",
    "elemelt": "elemel",
    "elemet": "elem",
    "elemezni": "elemez",
    "elemezte": "elemez",
    "elemeztették": "elemeztet",
    "elemezték": "elemez",
    "elemiig": "elemi",
    "elemnek": "elem",
    "elemzik": "elemez",
    "elemzésben": "elemzés",
    "elemzésből": "elemzés",
    "elemzései": "elemzés",
    "elemzést": "elemzés",
    "elemzéséből": "elemzés",
    "elemzésére": "elemzés",
    "elemződnek": "elemződik",
    "elemzői": "elemző",
    "elemzők": "elemző",
    "elemében": "elem",
    "elengedettséggel": "elengedettség",
    "elengedettségre": "elengedettség",
    "elengedhetetlenné": "elengedhetetlen",
    "elengedhetetlenül": "elengedhetetlen",
    "elengedik": "elenged",
    "elengedni": "elenged",
    "elengedte": "elenged",
    "elengedtek": "elenged",
    "elengedték": "elenged",
    "elengedése": "elengedés",
    "elenyészett": "elenyészik",
    "eleresszenek": "elereszt",
    "elereszteni": "elereszt",
    "eleresztett": "elereszt",
    "eleresztettek": "eleresztett",
    "elestek": "elesik",
    "elevenen": "eleven",
    "eleveníthette": "eleveníthet",
    "eleveníti": "elevenít",
    "elfeketedett": "elfeketedik",
    "elfeledetten": "elfeledett",
    "elfeledkezett": "elfeledkezik",
    "elfeledkezni": "elfeledkezik",
    "elfelejtem": "elfelejt",
    "elfelejtenek": "elfelejt",
    "elfelejteni": "elfelejt",
    "elfelejtett": "elfelejt",
    "elfelejtette": "elfelejt",
    "elfelejtettek": "elfelejtett",
    "elfelejtettem": "elfelejtett",
    "elfelejtettnek": "elfelejtett",
    "elfelejtették": "elfelejtet",
    "elfelejtettél": "elfelejtet",
    "elfelejti": "elfelejt",
    "elfelejtik": "elfelejt",
    "elfelejtkeztek": "elfelejtkezik",
    "elfelejtkeztem": "elfelejtkezik",
    "elfelejtse": "elfelejt",
    "elferdítésével": "elferdítés",
    "elfinomodott": "elfinomodik",
    "elfogadhatatlannak": "elfogadhatatlan",
    "elfogadhatja": "elfogadhat",
    "elfogadhatónak": "elfogadható",
    "elfogadja": "elfogad",
    "elfogadjuk": "elfogad",
    "elfogadják": "elfogad",
    "elfogadna": "elfogad",
    "elfogadni": "elfogad",
    "elfogadott": "elfogad",
    "elfogadta": "elfogad",
    "elfogadtak": "elfogad",
    "elfogadtam": "elfogad",
    "elfogadtatni": "elfogadtat",
    "elfogadtatása": "elfogadtatás",
    "elfogadása": "elfogadás",
    "elfogadásakor": "elfogadás",
    "elfogadásuk": "elfogadás",
    "elfogadásában": "elfogadás",
    "elfogadását": "elfogadás",
    "elfogadásától": "elfogadás",
    "elfogadásával": "elfogadás",
    "elfogatóparancsot": "elfogatóparancs",
    "elfoghatjátok": "elfoghat",
    "elfogja": "elfog",
    "elfogjanak": "elfog",
    "elfogják": "elfog",
    "elfoglalja": "elfoglal",
    "elfoglalt": "elfoglal",
    "elfoglalta": "elfoglal",
    "elfoglaltsággal": "elfoglaltság",
    "elfoglaltságnak": "elfoglaltság",
    "elfoglalták": "elfoglal",
    "elfoglalásánál": "elfoglalás",
    "elfognak": "elfog",
    "elfogni": "elfog",
    "elfogta": "elfog",
    "elfogtak": "elfog",
    "elfogták": "elfog",
    "elfogulatlannak": "elfogulatlan",
    "elfogultak": "elfogult",
    "elfogultságai": "elfogultság",
    "elfogultsággal": "elfogultság",
    "elfogultságok": "elfogultság",
    "elfogyasztása": "elfogyasztás",
    "elfogynak": "elfogy",
    "elfogyni": "elfogy",
    "elfogyott": "elfogy",
    "elfogytak": "elfogy",
    "elfogódottan": "elfogódott",
    "elfojtatják": "elfojtat",
    "elfojtott": "elfojt",
    "elfojtsa": "elfojt",
    "elfordulna": "elfordul",
    "elfordult": "elfordul",
    "elfordítani": "elfordít",
    "elfordított": "elfordít",
    "elfordította": "elfordít",
    "elforrt": "elforr",
    "elfuserált": "elfuserál",
    "elfáradnak": "elfárad",
    "elfáradt": "elfárad",
    "elférnek": "elfér",
    "elfújta": "elfúj",
    "elfüggönyözhetnék": "elfüggönyözhet",
    "elgondolkodni": "elgondolkodik",
    "elgondolkodott": "elgondolkodik",
    "elgondolkozott": "elgondolkozik",
    "elgondolkozón": "elgondolkozó",
    "elgondolni": "elgondol",
    "elgondolása": "elgondolás",
    "elgyengítette": "elgyengít",
    "elgyengült": "elgyengül",
    "elgyávultak": "elgyávult",
    "elgyötört": "elgyötör",
    "elgyötörte": "elgyötör",
    "elgáncsolta": "elgáncsol",
    "elgáncsolták": "elgáncsol",
    "elgörbült": "elgörbül",
    "elgőzösíteni": "elgőzösít",
    "elgőzösítettek": "elgőzösít",
    "elgőzösítették": "elgőzösít",
    "elgőzösítik": "elgőzösít",
    "elgőzösítlek": "elgőzösít",
    "elgőzösíttessen": "elgőzösíttet",
    "elgőzösítések": "elgőzösítés",
    "elhagyatott": "elhagyat",
    "elhagyják": "elhagy",
    "elhagyni": "elhagy",
    "elhagyott": "elhagy",
    "elhagyta": "elhagy",
    "elhagyták": "elhagy",
    "elhajlást": "elhajlás",
    "elhajlásuk": "elhajlás",
    "elhajtott": "elhajt",
    "elhajítjátok": "elhajít",
    "elhaladni": "elhalad",
    "elhaladt": "elhalad",
    "elhaladtak": "elhaladt",
    "elhaladtatok": "elhaladtat",
    "elhaladtunk": "elhaladt",
    "elhalasztott": "elhalaszt",
    "elhalasztását": "elhalasztás",
    "elhallgatnia": "elhallgat",
    "elhallgatott": "elhallgat",
    "elhallgatta": "elhallgat",
    "elhallgattak": "elhallgat",
    "elhallgattassunk": "elhallgattas",
    "elhallgattatta": "elhallgattat",
    "elhallgatták": "elhallgat",
    "elhallgatását": "elhallgatás",
    "elhalmozza": "elhalmoz",
    "elhalnak": "elhal",
    "elhalt": "elhal",
    "elhalványodott": "elhalványodik",
    "elhalása": "elhalás",
    "elhamarkodott": "elhamarkodik",
    "elhangzani": "elhangzik",
    "elhangzott": "elhangzik",
    "elhangzottak": "elhangzott",
    "elhangzottakat": "elhangzott",
    "elhangzása": "elhangzás",
    "elhangzásával": "elhangzás",
    "elhanyagolja": "elhanyagol",
    "elhanyagolt": "elhanyagol",
    "elhanyagoltsága": "elhanyagoltság",
    "elhanyagoltunk": "elhanyagolt",
    "elhanyagolták": "elhanyagol",
    "elhasznált": "elhasznál",
    "elhasználása": "elhasználás",
    "elhasználódjunk": "elhasználódik",
    "elhatalmasodott": "elhatalmasodik",
    "elhatalmasodása": "elhatalmasodás",
    "elhatárolja": "elhatárol",
    "elhatározni": "elhatároz",
    "elhatározott": "elhatároz",
    "elhatározta": "elhatároz",
    "elhatároztam": "elhatároz",
    "elhatároztuk": "elhatároz",
    "elhatározták": "elhatároz",
    "elhatározása": "elhatározás",
    "elhatározáshoz": "elhatározás",
    "elhatározással": "elhatározás",
    "elhatározásában": "elhatározás",
    "elhatározásának": "elhatározás",
    "elhatározásától": "elhatározás",
    "elhelyezett": "elhelyez",
    "elhelyezkedhetem": "elhelyezkedhet",
    "elhelyezkedtek": "elhelyezkedik",
    "elhelyezkedése": "elhelyezkedés",
    "elhelyezkedést": "elhelyezkedés",
    "elhelyezkedőben": "elhelyezkedő",
    "elhelyezni": "elhelyez",
    "elhelyezték": "elhelyez",
    "elhelyezésére": "elhelyezés",
    "elhelyezéséről": "elhelyezés",
    "elhelyezését": "elhelyezés",
    "elhelyezésük": "elhelyezés",
    "elhencegtük": "elhenceg",
    "elherdálták": "elherdál",
    "elhervadnak": "elhervad",
    "elhessegetni": "elhesseget",
    "elhibázott": "elhibázik",
    "elhidegíti": "elhidegít",
    "elhiggye": "elhisz",
    "elhihetné": "elhihet",
    "elhinni": "elhisz",
    "elhintenék": "elhint",
    "elhiszi": "elhisz",
    "elhiszik": "elhisz",
    "elhiteti": "elhitet",
    "elhitte": "elhisz",
    "elhozni": "elhoz",
    "elhozott": "elhoz",
    "elhozzam": "elhoz",
    "elhunyt": "elhuny",
    "elhurcolja": "elhurcol",
    "elhurcolt": "elhurcol",
    "elhurcolták": "elhurcol",
    "elhányt": "elhány",
    "elhápogott": "elhápog",
    "elhárítani": "elhárít",
    "elháríthatja": "elháríthat",
    "elhárított": "elhárít",
    "elhárították": "elhárít",
    "elhárításra": "elhárítás",
    "elhívott": "elhív",
    "elhíznak": "elhízik",
    "elhízott": "elhízik",
    "elhódíthatják": "elhódíthat",
    "elhúzol": "elhúz",
    "elhúzott": "elhúz",
    "elidegenítésére": "elidegenítés",
    "elidegenítésükre": "elidegenítés",
    "elidőzni": "elidőzik",
    "eligazodni": "eligazodik",
    "elillanjon": "elillan",
    "elillanni": "elillan",
    "elillant": "elillan",
    "eliminált": "eliminál",
    "elindulni": "elindul",
    "elindulnánk": "elindul",
    "elindult": "elindul",
    "elindultam": "elindult",
    "elindultunk": "elindult",
    "elindítja": "elindít",
    "elindította": "elindít",
    "elindítása": "elindítás",
    "elindítását": "elindítás",
    "elintézhetnék": "elintézhet",
    "elintézhette": "elintézhet",
    "elintézik": "elintéz",
    "elintézni": "elintéz",
    "elintézték": "elintéz",
    "elintéztük": "elintéz",
    "elintézzék": "elintéz",
    "eliskoláztatja": "eliskoláztat",
    "elismerem": "elismer",
    "elismeri": "elismer",
    "elismerik": "elismer",
    "elismerjük": "elismer",
    "elismerni": "elismer",
    "elismerné": "elismer",
    "elismert": "elismer",
    "elismerte": "elismer",
    "elismertsége": "elismertség",
    "elismertséget": "elismertség",
    "elismertük": "elismer",
    "elismerésben": "elismerés",
    "elismerése": "elismerés",
    "elismerésnek": "elismerés",
    "elismeréssel": "elismerés",
    "elismerést": "elismerés",
    "elismerését": "elismerés",
    "elismeréséül": "elismerés",
    "elismerően": "elismerő",
    "elitből": "elit",
    "elitje": "elit",
    "eljutnak": "eljut",
    "eljutni": "eljut",
    "eljutniuk": "eljut",
    "eljutott": "eljut",
    "eljutottak": "eljutott",
    "eljuttatnám": "eljuttat",
    "eljuttatott": "eljuttat",
    "eljuttatta": "eljuttat",
    "eljuttatása": "eljuttatás",
    "eljárhassanak": "eljárhat",
    "eljárnak": "eljár",
    "eljárni": "eljár",
    "eljárnának": "eljár",
    "eljárt": "eljár",
    "eljárása": "eljárás",
    "eljárásban": "eljárás",
    "eljárásból": "eljárás",
    "eljárásnak": "eljárás",
    "eljárások": "eljárás",
    "eljárásokat": "eljárás",
    "eljárásokban": "eljárás",
    "eljárásokkal": "eljárás",
    "eljárásra": "eljárás",
    "eljárásról": "eljárás",
    "eljárással": "eljárás",
    "eljárást": "eljárás",
    "eljárását": "eljárás",
    "eljöhetnének": "eljöhet",
    "eljöhetünk": "eljöhet",
    "eljönni": "eljön",
    "eljött": "eljön",
    "eljöttek": "eljön",
    "eljöttem": "eljön",
    "eljövendője": "eljövendő",
    "elkalandoztak": "elkalandozik",
    "elkapatják": "elkapat",
    "elkapja": "elkap",
    "elkapni": "elkap",
    "elkapnia": "elkap",
    "elkapott": "elkap",
    "elkapta": "elkap",
    "elkelt": "elkel",
    "elkeresztelt": "elkeresztel",
    "elkerített": "elkerít",
    "elkerítették": "elkerítet",
    "elkerülhetetlenek": "elkerülhetetlen",
    "elkerülhetetlennek": "elkerülhetetlen",
    "elkerülhetetlenné": "elkerülhetetlen",
    "elkerülhetetlenül": "elkerülhetetlen",
    "elkerülheti": "elkerülhet",
    "elkerülhette": "elkerülhet",
    "elkerülhetőek": "elkerülhető",
    "elkerüli": "elkerül",
    "elkerülje": "elkerül",
    "elkerüljék": "elkerül",
    "elkerüljön": "elkerül",
    "elkerülni": "elkerül",
    "elkerülnie": "elkerül",
    "elkerült": "elkerül",
    "elkerülte": "elkerül",
    "elkerülték": "elkerül",
    "elkerülése": "elkerülés",
    "elkeseredett": "elkeseredik",
    "elkezdeni": "elkezd",
    "elkezdenénk": "elkezd",
    "elkezdett": "elkezd",
    "elkezdte": "elkezd",
    "elkezdtek": "elkezd",
    "elkezdtem": "elkezd",
    "elkezdték": "elkezd",
    "elkezdődne": "elkezdődik",
    "elkezdődött": "elkezdődik",
    "elkomorult": "elkomorul",
    "elkábulni": "elkábul",
    "elkárhozott": "elkárhozik",
    "elkárhozástól": "elkárhozás",
    "elkáromkodta": "elkáromkodik",
    "elkényesedett": "elkényesed",
    "elkényeztetett": "elkényeztet",
    "elkényeztetik": "elkényeztet",
    "elképedt": "elképed",
    "elképedésből": "elképedés",
    "elképedést": "elképedés",
    "elképedésére": "elképedés",
    "elképesztően": "elképesztő",
    "elképzelhetetlenek": "elképzelhetetlen",
    "elképzelhetetlennek": "elképzelhetetlen",
    "elképzelhetetlenül": "elképzelhetetlen",
    "elképzelhetőnek": "elképzelhető",
    "elképzeljük": "elképzel",
    "elképzelni": "elképzel",
    "elképzelt": "elképzel",
    "elképzelte": "elképzel",
    "elképzelése": "elképzelés",
    "elképzelései": "elképzelés",
    "elképzeléseik": "elképzelés",
    "elképzeléseinek": "elképzelés",
    "elképzeléseiről": "elképzelés",
    "elképzeléseit": "elképzelés",
    "elképzeléseitől": "elképzelés",
    "elképzeléseivel": "elképzelés",
    "elképzelések": "elképzelés",
    "elképzeléseket": "elképzelés",
    "elképzeléseknek": "elképzelés",
    "elképzelésektől": "elképzelés",
    "elképzelésetek": "elképzelés",
    "elképzeléssel": "elképzelés",
    "elképzelést": "elképzelés",
    "elképzeléséhez": "elképzelés",
    "elképzelésével": "elképzelés",
    "elkészíteni": "elkészít",
    "elkészítette": "elkészít",
    "elkészítése": "elkészítés",
    "elkészítésre": "elkészítés",
    "elkészítéséhez": "elkészítés",
    "elkészítésével": "elkészítés",
    "elkészülhetnek": "elkészülhet",
    "elkészülne": "elkészül",
    "elkészülni": "elkészül",
    "elkészült": "elkészül",
    "elkészülte": "elkészül",
    "elkészültek": "elkészül",
    "elkészültéig": "elkészült",
    "elkíséri": "elkísér",
    "elkísérte": "elkísér",
    "elkívánkoznak": "elkívánkozik",
    "elköltéséről": "elköltés",
    "elkönyvelheti": "elkönyvelhet",
    "elkönyvelte": "elkönyvel",
    "elkönyveltek": "elkönyvelt",
    "elköszöntünk": "elköszönt",
    "elkötelezettje": "elkötelezett",
    "elkötelezettsége": "elkötelezettség",
    "elkötelezettségen": "elkötelezettség",
    "elkötelezettségében": "elkötelezettség",
    "elkötelezni": "elkötelez",
    "elkövetett": "elkövet",
    "elkövetheti": "elkövethet",
    "elkövetni": "elkövet",
    "elkövette": "elkövet",
    "elkövetted": "elkövet",
    "elkövettek": "elkövet",
    "elkövették": "elkövet",
    "elkövettél": "elkövet",
    "elkövetése": "elkövetés",
    "elkövetésébe": "elkövetés",
    "elkövetésére": "elkövetés",
    "elkövetéséért": "elkövetés",
    "elközvetítenének": "elközvetít",
    "elküldeni": "elküld",
    "elküldje": "elküld",
    "elküldte": "elküld",
    "elküldtek": "elküld",
    "elküldték": "elküld",
    "elküldése": "elküldés",
    "elkülönített": "elkülönít",
    "elkülönítették": "elkülönítet",
    "elkülönült": "elkülönül",
    "ellehetetlenítenék": "ellehetetlenít",
    "ellenben": "ellen",
    "ellene": "ellik",
    "ellenem": "ellik",
    "elleneznék": "ellenez",
    "ellenezte": "ellenez",
    "ellenezzük": "ellenez",
    "ellenfele": "ellenfél",
    "ellenfelei": "ellenfél",
    "ellenfeleinek": "ellenfél",
    "ellenfeleié": "ellenfél",
    "ellenfelek": "ellenfél",
    "ellenfelet": "ellenfél",
    "ellenfelét": "ellenfele",
    "ellenforradalmat": "ellenforradalom",
    "ellenforradalmárok": "ellenforradalmár",
    "ellenféllel": "ellenfél",
    "ellenfélnek": "ellenfél",
    "ellenfélre": "ellenfél",
    "ellenféltől": "ellenfél",
    "elleni": "ellik",
    "ellenjelöltet": "ellenjelölt",
    "ellenjelöltre": "ellenjelölt",
    "ellenkezett": "ellenkezik",
    "ellenkezni": "ellenkezik",
    "ellenkezője": "ellenkező",
    "ellenkezőjét": "ellenkező",
    "ellenmondást": "ellenmondás",
    "ellenszegülne": "ellenszegül",
    "ellenszenve": "ellenszenv",
    "ellenszenvemet": "ellenszenv",
    "ellenszenvét": "ellenszenv",
    "ellenszerrel": "ellenszer",
    "ellenszert": "ellenszer",
    "ellenszerét": "ellenszer",
    "ellensége": "ellenség",
    "ellenségei": "ellenség",
    "ellenségeinek": "ellenség",
    "ellenségeinket": "ellenség",
    "ellenségeire": "ellenség",
    "ellenségeit": "ellenség",
    "ellenségek": "ellenség",
    "ellenségen": "ellenség",
    "ellenségesek": "ellenséges",
    "ellenségesen": "ellenséges",
    "ellenséget": "ellenség",
    "ellenséggel": "ellenség",
    "ellenségnek": "ellenség",
    "ellenségének": "ellenség",
    "ellenségük": "ellenség",
    "ellenségünk": "ellenség",
    "ellensúlyozni": "ellensúlyoz",
    "ellenterrorján": "ellenterror",
    "ellentmondanak": "ellentmond",
    "ellentmondhatott": "ellentmondhat",
    "ellentmondott": "ellentmond",
    "ellentmondások": "ellentmondás",
    "ellentmondásokat": "ellentmondás",
    "ellentmondásokban": "ellentmondás",
    "ellentmondásokon": "ellentmondás",
    "ellentmondásosak": "ellentmondásos",
    "ellentmondást": "ellentmondás",
    "ellentámadásra": "ellentámadás",
    "ellentétbe": "ellentét",
    "ellentétben": "ellentét",
    "ellentéte": "ellentét",
    "ellentéteiben": "ellentét",
    "ellentétek": "ellentét",
    "ellentétekben": "ellentét",
    "ellentéteknek": "ellentét",
    "ellentétesek": "ellentétes",
    "ellentétesnek": "ellentétes",
    "ellentétet": "ellentét",
    "ellentétpárt": "ellentétpár",
    "ellentétét": "ellentét",
    "ellenvetésemet": "ellenvetés",
    "ellenvetésre": "ellenvetés",
    "ellenvetéstől": "ellenvetés",
    "ellenvéleményt": "ellenvélemény",
    "ellenzi": "ellenez",
    "ellenzik": "ellenez",
    "ellenzékben": "ellenzék",
    "ellenzéke": "ellenzék",
    "ellenzékiek": "ellenzéki",
    "ellenzékiségről": "ellenzékiség",
    "ellenzéknek": "ellenzék",
    "ellenzékre": "ellenzék",
    "ellenzékétől": "ellenzék",
    "ellenzőivel": "ellenzői",
    "ellenzője": "ellenző",
    "ellenzőknek": "ellenző",
    "ellenzőknél": "ellenző",
    "ellenállhatatlanul": "ellenállhatatlan",
    "ellenállni": "ellenáll",
    "ellenálltak": "ellenállt",
    "ellenálltam": "ellenállt",
    "ellenállása": "ellenállás",
    "ellenállásra": "ellenállás",
    "ellenében": "ellen",
    "ellenére": "ellen",
    "ellenértékének": "ellenérték",
    "ellenértékét": "ellenérték",
    "ellenérveit": "ellenérv",
    "ellenérvként": "ellenérv",
    "ellenérzések": "ellenérzés",
    "ellenérzését": "ellenérzés",
    "ellenük": "ellen",
    "ellenünk": "ellik",
    "ellenőrei": "ellenőr",
    "ellenőrizetlenül": "ellenőrizetlen",
    "ellenőrizhetetlensége": "ellenőrizhetetlenség",
    "ellenőrizhetőbbek": "ellenőrizhető",
    "ellenőrizni": "ellenőriz",
    "ellenőrizte": "ellenőriz",
    "ellenőrizték": "ellenőriz",
    "ellenőrizze": "ellenőriz",
    "ellenőrzi": "ellenőriz",
    "ellenőrzése": "ellenőrzés",
    "ellenőrzések": "ellenőrzés",
    "ellenőrzéseken": "ellenőrzés",
    "ellenőrzésnél": "ellenőrzés",
    "ellenőrzésről": "ellenőrzés",
    "ellenőrzést": "ellenőrzés",
    "ellenőrzésében": "ellenőrzés",
    "ellenőrzésén": "ellenőrzés",
    "ellenőrök": "ellenőr",
    "ellepte": "ellep",
    "ellepték": "ellep",
    "ellopkodta": "ellopkod",
    "ellopni": "ellop",
    "ellopná": "ellop",
    "ellopta": "ellop",
    "elloptad": "ellop",
    "ellopták": "ellop",
    "ellássa": "ellát",
    "ellátják": "ellát",
    "ellátni": "ellát",
    "ellátná": "ellát",
    "ellátott": "ellát",
    "ellátottá": "ellátott",
    "ellátása": "ellátás",
    "ellátásból": "ellátás",
    "ellátáshoz": "ellátás",
    "ellátásra": "ellátás",
    "ellátást": "ellátás",
    "ellátásukat": "ellátás",
    "ellátásában": "ellátás",
    "ellátásához": "ellátás",
    "ellátására": "ellátásár",
    "ellátását": "ellátás",
    "ellátórendszerek": "ellátórendszer",
    "elmagyarázhatja": "elmagyarázhat",
    "elmagyarázom": "elmagyaráz",
    "elmagyarázta": "elmagyaráz",
    "elmagyarázták": "elmagyaráz",
    "elmagyarázzam": "elmagyaráz",
    "elmaradok": "elmarad",
    "elmaradottabb": "elmaradott",
    "elmaradoznak": "elmaradozik",
    "elmaradt": "elmarad",
    "elmaradtak": "elmaradt",
    "elmaradtam": "elmaradt",
    "elmarta": "elmar",
    "elmebajosról": "elmebajos",
    "elmegyek": "elmegy",
    "elmegyógyintézetek": "elmegyógyintézet",
    "elmegyünk": "elmegy",
    "elmehessek": "elmehet",
    "elmehetne": "elmehet",
    "elmehetünk": "elmehét",
    "elmekegte": "elmekeg",
    "elmenekülni": "elmenekül",
    "elmenekülnie": "elmenekül",
    "elmenekült": "elmenekül",
    "elmenjünk": "elmegy",
    "elmennek": "elmegy",
    "elmenni": "elmegy",
    "elmenniük": "elmegy",
    "elment": "elmegy",
    "elmentek": "elment",
    "elmentél": "elmegy",
    "elmentünk": "elment",
    "elmerülnie": "elmerül",
    "elmerült": "elmerül",
    "elmerülten": "elmerült",
    "elmerültséggel": "elmerültség",
    "elmeséli": "elmesél",
    "elmesélik": "elmesél",
    "elmesélte": "elmesél",
    "elmetornáét": "elmetorna",
    "elmeállapotnak": "elmeállapot",
    "elmondani": "elmond",
    "elmondanom": "elmond",
    "elmondaná": "elmond",
    "elmondja": "elmond",
    "elmondok": "elmond",
    "elmondom": "elmond",
    "elmondott": "elmond",
    "elmondottak": "elmondott",
    "elmondta": "elmond",
    "elmondtam": "elmond",
    "elmondtuk": "elmond",
    "elmondták": "elmond",
    "elmondása": "elmondás",
    "elmondásából": "elmondás",
    "elmosolyodott": "elmosolyodik",
    "elmosódott": "elmosódik",
    "elmosódottan": "elmosódott",
    "elmosódtak": "elmosódik",
    "elmozdulnia": "elmozdul",
    "elmozdította": "elmozdít",
    "elmozdítsa": "elmozdít",
    "elmulasztani": "elmulaszt",
    "elmulasztanád": "elmulaszt",
    "elmulasztja": "elmulaszt",
    "elmulasztott": "elmulaszt",
    "elmulasztotta": "elmulaszt",
    "elmulasztása": "elmulasztás",
    "elméd": "elme",
    "elméi": "elme",
    "elméje": "elme",
    "elméjében": "elme",
    "elméjét": "elme",
    "elméjűnek": "elméjű",
    "elméletben": "elmélet",
    "elmélete": "elmélet",
    "elméleteit": "elmélet",
    "elméletek": "elmélet",
    "elméletem": "elmélet",
    "elméletet": "elmélet",
    "elméletnek": "elmélet",
    "elmélettel": "elmélet",
    "elméletében": "elmélet",
    "elméletét": "elmélet",
    "elmélkedett": "elmélkedik",
    "elmélyedni": "elmélyed",
    "elmélyedtek": "elmélyedt",
    "elmélyült": "elmélyül",
    "elmélyülten": "elmélyült",
    "elmémen": "elme",
    "elméregettek": "elméreget",
    "elmérgesedett": "elmérgesedik",
    "elmérje": "elmér",
    "elmúlnak": "elmúlik",
    "elmúlt": "elmúl",
    "elmúltával": "elmúlta",
    "elnevethették": "elnevethet",
    "elnevette": "elnevet",
    "elnevezett": "elnevez",
    "elnevezik": "elnevez",
    "elnevezték": "elnevez",
    "elnevezése": "elnevezés",
    "elnevezést": "elnevezés",
    "elnevezésük": "elnevezés",
    "elnyelhetik": "elnyelhet",
    "elnyelte": "elnyel",
    "elnyeltem": "elnyelt",
    "elnyelték": "elnyel",
    "elnyelése": "elnyelés",
    "elnyomatástól": "elnyomatás",
    "elnyomják": "elnyom",
    "elnyomni": "elnyom",
    "elnyomott": "elnyom",
    "elnyomta": "elnyom",
    "elnyomták": "elnyom",
    "elnyomása": "elnyomás",
    "elnyomóinkkal": "elnyomó",
    "elnyúlt": "elnyúlik",
    "elnyűtt": "elnyű",
    "elnémította": "elnémít",
    "elnézem": "elnéz",
    "elnézi": "elnéz",
    "elnézte": "elnéz",
    "elnézték": "elnéz",
    "elnézéssel": "elnézés",
    "elnézőbbnek": "elnéző",
    "elnöke": "elnök",
    "elnökei": "elnök",
    "elnökeként": "elnök",
    "elnökhelyettese": "elnökhelyettes",
    "elnökjelöltje": "elnökjelölt",
    "elnökjelöltségért": "elnökjelöltség",
    "elnökkel": "elnök",
    "elnökké": "elnök",
    "elnökként": "elnök",
    "elnöklelkészhez": "elnöklelkész",
    "elnöklelkésznek": "elnöklelkész",
    "elnöknek": "elnök",
    "elnökségben": "elnökség",
    "elnöksége": "elnökség",
    "elnökséget": "elnökség",
    "elnökségében": "elnökség",
    "elnökségének": "elnökség",
    "elnökségéről": "elnökség",
    "elnökválasztásig": "elnökválasztás",
    "elnökválasztáson": "elnökválasztás",
    "elnökének": "elnök",
    "elnökénél": "elnök",
    "elnökét": "elnök",
    "elnökétől": "elnök",
    "elnökével": "elnök",
    "elnökévé": "elnökév",
    "elnökök": "elnök",
    "elnökölt": "elnököl",
    "elnököt": "elnök",
    "elnökünk": "elnök",
    "elodázhatatlannak": "elodázhatatlan",
    "elodázni": "elodáz",
    "eloltani": "elolt",
    "elolvadna": "elolvad",
    "elolvadt": "elolvad",
    "elolvashatta": "elolvashat",
    "elolvasni": "elolvas",
    "elolvassa": "elolvas",
    "elolvasta": "elolvas",
    "elolvastátok": "elolvas",
    "elolvasztja": "elolvaszt",
    "elolvasása": "elolvasás",
    "elolvasásuk": "elolvasás",
    "eloszlatja": "eloszlat",
    "eloszlatjuk": "eloszlat",
    "eloszlatni": "eloszlat",
    "elosztotta": "eloszt",
    "elosztásból": "elosztás",
    "elosztásába": "elosztás",
    "elosztását": "elosztás",
    "elosztásáért": "elosztás",
    "elpanaszolhatnám": "elpanaszolhat",
    "elpanaszolja": "elpanaszol",
    "elpatkoljon": "elpatkol",
    "elpattognak": "elpattog",
    "elpazarolni": "elpazarol",
    "elpocsékolásával": "elpocsékolás",
    "elpuhult": "elpuhul",
    "elpusztulni": "elpusztul",
    "elpusztult": "elpusztul",
    "elpusztultak": "elpusztult",
    "elpusztultam": "elpusztult",
    "elpusztítani": "elpusztít",
    "elpusztíthatatlanul": "elpusztíthatatlan",
    "elpusztíthatja": "elpusztíthat",
    "elpusztítjuk": "elpusztít",
    "elpusztított": "elpusztít",
    "elpusztítottak": "elpusztított",
    "elpusztítása": "elpusztítás",
    "elpusztításukat": "elpusztítás",
    "elpusztításának": "elpusztítás",
    "elpusztításával": "elpusztítás",
    "elpárologhatnának": "elpárologhat",
    "elpártolt": "elpártol",
    "elpártolása": "elpártolás",
    "elrablásáról": "elrablás",
    "elrabolt": "elrabol",
    "elrabolták": "elrabol",
    "elragadtatással": "elragadtatás",
    "elragadtatásában": "elragadtatás",
    "elrakja": "elrak",
    "elravaszkodta": "elravaszkodik",
    "elrejtett": "elrejt",
    "elrejteztem": "elrejtezik",
    "elrejthetnék": "elrejthet",
    "elrejtse": "elrejt",
    "elrejtőzhettek": "elrejtőzhet",
    "elrejtőzött": "elrejtőzik",
    "elrendelt": "elrendel",
    "elrendeléséhez": "elrendelés",
    "elrepült": "elrepül",
    "elriasztja": "elriaszt",
    "elriasztottam": "elriasztott",
    "elrohant": "elrohan",
    "elrontani": "elront",
    "elrontják": "elront",
    "elrontott": "elront",
    "elrontották": "elront",
    "elsajátítani": "elsajátít",
    "elsajátított": "elsajátít",
    "elsajátították": "elsajátít",
    "elsatnyulnak": "elsatnyul",
    "elsejéig": "elseje",
    "elsejével": "elseje",
    "elsikkadt": "elsikkad",
    "elsikkasztják": "elsikkaszt",
    "elsimult": "elsimul",
    "elsodorta": "elsodor",
    "elsomfordáltunk": "elsomfordált",
    "elsorolni": "elsorol",
    "elsuhant": "elsuhan",
    "elsuttogott": "elsuttog",
    "elszakadjatok": "elszakad",
    "elszakadni": "elszakad",
    "elszakadt": "elszakad",
    "elszakadtak": "elszakadt",
    "elszakadunk": "elszakad",
    "elszakítja": "elszakít",
    "elszakítják": "elszakít",
    "elszaladni": "elszalad",
    "elszalajtott": "elszalajt",
    "elszaporodott": "elszaporodik",
    "elszaporodtak": "elszaporodik",
    "elszedték": "elszed",
    "elszegényedést": "elszegényedés",
    "elszenesedett": "elszenesedik",
    "elszenvedett": "elszenved",
    "elszigetelt": "elszigetel",
    "elszigeteltsége": "elszigeteltség",
    "elszállnak": "elszáll",
    "elszállt": "elszáll",
    "elszállítják": "elszállít",
    "elszállították": "elszállít",
    "elszállítására": "elszállítás",
    "elszállítását": "elszállítás",
    "elszámolni": "elszámol",
    "elszámolt": "elszámol",
    "elszámították": "elszámít",
    "elszánt": "elszán",
    "elszántabb": "elszánt",
    "elszántak": "elszánt",
    "elszántan": "elszánt",
    "elszántsággal": "elszántság",
    "elszántuk": "elszán",
    "elszármazott": "elszármazik",
    "elszédítse": "elszédít",
    "elszédültem": "elszédül",
    "elszégyellte": "elszégyell",
    "elszíntelenedett": "elszíntelenedik",
    "elszívja": "elszív",
    "elszökellt": "elszökell",
    "elszöknek": "elszökik",
    "elszökni": "elszökik",
    "elszöktek": "elszökik",
    "elszökött": "elszökik",
    "elszökünk": "elszökik",
    "elsápadt": "elsápad",
    "elsétált": "elsétál",
    "elsöpörte": "elsöpör",
    "elsötétedése": "elsötétedés",
    "elsötétült": "elsötétül",
    "elsüllyedt": "elsüllyed",
    "elsült": "elsül",
    "elsőbben": "elsőbb",
    "elsőből": "első",
    "elsődlegesen": "elsődleges",
    "elsők": "első",
    "elsőként": "első",
    "elsőnek": "első",
    "elsőre": "első",
    "elsőségért": "elsőség",
    "elsőségét": "elsőség",
    "elsőt": "első",
    "elsőévesnek": "elsőéves",
    "eltakarja": "eltakar",
    "eltakarni": "eltakar",
    "eltakart": "eltakar",
    "eltakarta": "eltakar",
    "eltaláltad": "eltalált",
    "eltalálták": "eltalál",
    "eltartására": "eltartás",
    "eltartója": "eltartó",
    "eltaszítaná": "eltaszít",
    "eltaszította": "eltaszít",
    "eltelik": "eltel",
    "eltelt": "eltelik",
    "eltelte": "eltelik",
    "elteltek": "eltelt",
    "elteltével": "eltelte",
    "eltemetett": "eltemet",
    "eltemették": "eltemet",
    "eltemetésig": "eltemetés",
    "elterelte": "elterel",
    "elterelése": "elterelés",
    "elterjedni": "elterjed",
    "elterjedt": "elterjed",
    "elterjesztése": "elterjesztés",
    "elterpeszkedni": "elterpeszkedik",
    "elterült": "elterül",
    "eltette": "eltesz",
    "eltettek": "eltett",
    "eltisztogatták": "eltisztogat",
    "eltitkolják": "eltitkol",
    "eltitkolni": "eltitkol",
    "eltitkolása": "eltitkolás",
    "eltitkolására": "eltitkolás",
    "eltitkolását": "eltitkolás",
    "eltorzult": "eltorzul",
    "eltorzítani": "eltorzít",
    "eltulajdonított": "eltulajdonít",
    "eltávolítaná": "eltávolít",
    "eltávolíthatók": "eltávolítható",
    "eltávolítja": "eltávolít",
    "eltávolítják": "eltávolít",
    "eltávolították": "eltávolít",
    "eltávolítsa": "eltávolít",
    "eltávolítása": "eltávolítás",
    "eltávozna": "eltávozik",
    "eltávozott": "eltávozik",
    "eltávozottakat": "eltávozott",
    "eltávozást": "eltávozás",
    "eltérhetnek": "eltérhet",
    "eltért": "eltér",
    "eltérések": "eltérés",
    "eltéréseket": "eltérés",
    "eltérésekre": "eltérés",
    "eltérést": "eltérés",
    "eltéríteni": "eltérít",
    "eltérítette": "eltérít",
    "eltérőek": "eltérő",
    "eltérően": "eltérő",
    "eltévedt": "eltéved",
    "eltévedtek": "eltévedt",
    "eltévelyedett": "eltévelyedik",
    "eltévelyedéseiket": "eltévelyedés",
    "eltévelyedések": "eltévelyedés",
    "eltévelyedéseket": "eltévelyedés",
    "eltévesztette": "eltéveszt",
    "eltökélte": "eltökél",
    "eltölteni": "eltölt",
    "eltölteniük": "eltölt",
    "eltöltik": "eltölt",
    "eltöltse": "eltölt",
    "eltöltött": "eltölt",
    "eltörhetném": "eltörhet",
    "eltörik": "eltör",
    "eltörlik": "eltöröl",
    "eltörlése": "eltörlés",
    "eltörni": "eltörik",
    "eltörpültek": "eltörpül",
    "eltört": "eltörik",
    "eltörte": "eltörik",
    "eltörölje": "eltöröl",
    "eltöröljenek": "eltöröl",
    "eltöröljék": "eltöröl",
    "eltörölni": "eltöröl",
    "eltörölt": "eltöröl",
    "eltörölte": "eltöröl",
    "eltöröltek": "eltöröl",
    "eltörölték": "eltöröl",
    "eltöröltük": "eltöröl",
    "eltörött": "eltörik",
    "eltüntetett": "eltüntet",
    "eltüntetnek": "eltüntet",
    "eltűnnek": "eltűnik",
    "eltűnni": "eltűnik",
    "eltűnnének": "eltűnik",
    "eltűnt": "eltűnik",
    "eltűntek": "eltűnt",
    "eltűntünk": "eltűnt",
    "eltűnése": "eltűnés",
    "eltűnések": "eltűnés",
    "eltűnésnek": "eltűnés",
    "eltűnésének": "eltűnés",
    "eltűnését": "eltűnés",
    "eltűnődött": "eltűnődik",
    "eltűrnie": "eltűr",
    "eltűrték": "eltűr",
    "eludvaroltad": "eludvarolt",
    "elutasítani": "elutasít",
    "elutasítja": "elutasít",
    "elutasítják": "elutasít",
    "elutasította": "elutasít",
    "elutasítására": "elutasítás",
    "elutazni": "elutazik",
    "elutaztak": "elutazik",
    "elvadultan": "elvadult",
    "elvakultságáért": "elvakultság",
    "elvben": "elv",
    "elve": "elv",
    "elvegye": "elvesz",
    "elvegyék": "elvesz",
    "elvei": "elv",
    "elveiben": "elv",
    "elveinek": "elv",
    "elveit": "elv",
    "elveitől": "elv",
    "elveivel": "elv",
    "elvek": "elv",
    "elveken": "elv",
    "elveknek": "elv",
    "elvem": "elv",
    "elverte": "elver",
    "elvesszük": "elveszt",
    "elveszem": "elveszik",
    "elveszett": "elveszik",
    "elveszik": "elvesz",
    "elveszne": "elveszik",
    "elvesznek": "elveszik",
    "elvesztegetnie": "elveszteget",
    "elvesztett": "elveszt",
    "elvesztette": "elveszt",
    "elvesztettek": "elvesztett",
    "elvesztettem": "elvesztett",
    "elvesztették": "elvesztet",
    "elvesztettük": "elvesztett",
    "elveszti": "elveszt",
    "elvesztik": "elveszt",
    "elvesztéséről": "elvesztés",
    "elvesztését": "elvesztés",
    "elvesztésével": "elvesztés",
    "elveszítenek": "elveszít",
    "elveszítenék": "elveszít",
    "elveszítette": "elveszít",
    "elveszítheti": "elveszíthet",
    "elveszíti": "elveszít",
    "elveszítse": "elveszít",
    "elveszítsed": "elveszít",
    "elvet": "elv",
    "elvetették": "elvetet",
    "elvetnéd": "elvet",
    "elvett": "elvesz",
    "elvette": "elvesz",
    "elvettek": "elvett",
    "elvettem": "elvett",
    "elvették": "elvesz",
    "elvettük": "elvett",
    "elvezetett": "elvezet",
    "elvezetniük": "elvezet",
    "elvezette": "elvezet",
    "elvezettek": "elvezett",
    "elvezetésétől": "elvezetés",
    "elvihetnéd": "elvihet",
    "elvihették": "elvihet",
    "elvihetőt": "elvihető",
    "elvinni": "elvisz",
    "elviselhetetlenek": "elviselhetetlen",
    "elviselhetetlennek": "elviselhetetlen",
    "elviselhetetlenségét": "elviselhetetlenség",
    "elviselhetetlenül": "elviselhetetlen",
    "elviselhetőbb": "elviselhető",
    "elviselhetőbbé": "elviselhető",
    "elviselni": "elvisel",
    "elviseltük": "elvisel",
    "elviszi": "elvisz",
    "elviszik": "elvisz",
    "elvitatkoztunk": "elvitatkozik",
    "elvitette": "elvitet",
    "elvitt": "elvisz",
    "elvitte": "elvisz",
    "elvittek": "elvitt",
    "elvitték": "elvisz",
    "elvonja": "elvon",
    "elvont": "elvon",
    "elvontabbá": "elvont",
    "elvontnak": "elvont",
    "elvonult": "elvonul",
    "elvonultok": "elvonul",
    "elvonásokat": "elvonás",
    "elvonásokról": "elvonás",
    "elvtárs-nak": "elvtárs",
    "elvtársai": "elvtárs",
    "elvtársak": "elvtárs",
    "elvtársaknak": "elvtárs",
    "elvtársam": "elvtárs",
    "elvtársat": "elvtárs",
    "elvtársiaskodást": "elvtársiaskodás",
    "elvtársnak": "elvtárs",
    "elvtársról": "elvtárs",
    "elvtársunk": "elvtárs",
    "elvágja": "elvág",
    "elvágni": "elvág",
    "elvágtuk": "elvág",
    "elvágódott": "elvágódik",
    "elválassza": "elválaszt",
    "elválasztani": "elválaszt",
    "elválaszthatatlanul": "elválaszthatatlan",
    "elválasztja": "elválaszt",
    "elválasztják": "elválaszt",
    "elválasztása": "elválasztás",
    "elválasztását": "elválasztás",
    "elváljon": "elválik",
    "elvállalhatunk": "elvállalhat",
    "elvállalni": "elvállal",
    "elvállalná": "elvállal",
    "elvállalok": "elvállal",
    "elvállalta": "elvállal",
    "elvállaltuk": "elvállal",
    "elválna": "elválik",
    "elvált": "elválik",
    "elváltozott": "elváltozik",
    "elváltozást": "elváltozás",
    "elvárják": "elvár",
    "elvárta": "elvár",
    "elvártak": "elvárt",
    "elvárták": "elvár",
    "elvárásainak": "elvárás",
    "elvárásait": "elvárás",
    "elvárást": "elvárás",
    "elvásott": "elvásik",
    "elvégezni": "elvégez",
    "elvégezte": "elvégez",
    "elvégezték": "elvégez",
    "elvégre": "elvég",
    "elvégzett": "elvégez",
    "elvégzi": "elvégez",
    "elvégzik": "elvégez",
    "elvégzése": "elvégzés",
    "elvégzésére": "elvégzés",
    "elvéhez": "elv",
    "elvének": "elv",
    "elvéreztek": "elvérez",
    "elvét": "elv",
    "elzavartam": "elzavart",
    "elzsibbasztotta": "elzsibbaszt",
    "elzárja": "elzár",
    "elzárkózott": "elzárkózik",
    "elzárta": "elzár",
    "elzártak": "elzárt",
    "elzártságukban": "elzártság",
    "elzüllött": "elzüllik",
    "elállt": "eláll",
    "elállítja": "elállít",
    "elállóbbá": "elálló",
    "eláradt": "elárad",
    "elárasztja": "eláraszt",
    "elárulhassa": "elárulhat",
    "elárulhatja": "elárulhat",
    "elárulhatta": "elárulhat",
    "elárulja": "elárul",
    "elárulni": "elárul",
    "elárulnátok": "elárul",
    "elárult": "elárul",
    "elárulta": "elárul",
    "elárultalak": "elárul",
    "elárultuk": "elárul",
    "elárulták": "elárul",
    "elárultál": "elárul",
    "elárusítói": "elárusító",
    "elázott": "elázik",
    "eléd": "elé",
    "elégedetlenek": "elégedetlen",
    "elégedetlenkedjünk": "elégedetlenkedik",
    "elégedetlenkednek": "elégedetlenkedik",
    "elégedetlenkedni": "elégedetlenkedik",
    "elégedetlenkedők": "elégedetlenkedő",
    "elégedetlenséget": "elégedetlenség",
    "elégedetlenségüket": "elégedetlenség",
    "elégedetlenül": "elégedetlen",
    "elégedett": "elégedik",
    "elégedettebbnek": "elégedett",
    "elégedettek": "elégedett",
    "elégedetten": "elégedett",
    "elégedettséggel": "elégedettség",
    "elégedettségre": "elégedettség",
    "elégedettségéből": "elégedettség",
    "elégetik": "eléget",
    "elégette": "eléget",
    "elégették": "eléget",
    "eléggé": "elég",
    "elégiája": "elégia",
    "elégszünk": "elégszik",
    "elégségesnek": "elégséges",
    "elégtelennek": "elégtelen",
    "elégtételre": "elégtétel",
    "elégtételt": "elégtétel",
    "elégtételérzéssel": "elégtételérzés",
    "elégíteni": "elégít",
    "elégítően": "elégítő",
    "eléje": "elé",
    "elérheti": "elérhet",
    "elérhetjük": "elérhet",
    "eléri": "elérik",
    "elérje": "elérik",
    "elérkezettnek": "elérkezett",
    "elérkeztek": "elérkezik",
    "elérni": "elérik",
    "elérnie": "elérik",
    "elért": "elérik",
    "elérte": "elérik",
    "elértek": "elért",
    "elértem": "elért",
    "elértette": "elért",
    "elérték": "elérik",
    "elértünk": "elért",
    "elérzékenyült": "elérzékenyül",
    "eléréséhez": "elérés",
    "elérését": "elérés",
    "elírásokra": "elírás",
    "elítélt": "elítél",
    "elítélte": "elítél",
    "elítélteket": "elítélt",
    "elítélték": "elítél",
    "elöljáróban": "elöljáró",
    "elölni": "elöl",
    "elöntötte": "elönt",
    "elöregedem": "elöregedik",
    "elözönlötték": "elözönlik",
    "elütött": "elüt",
    "elütötte": "elüt",
    "előadnia": "előad",
    "előadott": "előad",
    "előadás-sorozatát": "előadás-sorozat",
    "előadása": "előadás",
    "előadásain": "előadás",
    "előadásba": "előadás",
    "előadásmódja": "előadásmódik",
    "előadások": "előadás",
    "előadásokat": "előadás",
    "előadásra": "előadás",
    "előadásról": "előadás",
    "előadást": "előadás",
    "előadásának": "előadás",
    "előadására": "előadás",
    "előadását": "előadás",
    "előadásával": "előadás",
    "előadóinak": "előadóín",
    "előadók": "előadó",
    "előadóművészeket": "előadóművész",
    "előadót": "előadó",
    "előadóterem": "előadótér",
    "előbbbecslést": "előbbbecslés",
    "előbbiben": "előbbi",
    "előbbiek": "előbbi",
    "előbbiekben": "előbbi",
    "előbbinek": "előbbi",
    "előbbinél": "előbbi",
    "előcsarnokban": "előcsarnok",
    "előcsarnokhoz": "előcsarnok",
    "előcsarnokába": "előcsarnok",
    "előcsarnokával": "előcsarnok",
    "elődei": "előd",
    "elődeitől": "előd",
    "elődje": "előd",
    "elődök": "előd",
    "elődöntőbe": "elődöntő",
    "elődöntőben": "elődöntő",
    "elődöntőjébe": "elődöntő",
    "elődöntőjének": "elődöntő",
    "elődöntőn": "elődöntő",
    "elődöntőse": "elődöntős",
    "előfeltételeként": "előfeltétel",
    "előfelvételit": "előfelvételi",
    "előfizeti": "előfizet",
    "előfizetése": "előfizetés",
    "előfizetőre": "előfizető",
    "előfordulhasson": "előfordulhat",
    "előfordulhatnak": "előfordulhat",
    "előfordulhatott": "előfordulhat",
    "előfordulnia": "előfordul",
    "előfordult": "előfordul",
    "előfordultak": "előfordult",
    "előfordulások": "előfordulás",
    "előhívnia": "előhív",
    "előhúzott": "előhúz",
    "előhúzta": "előhúz",
    "előidézett": "előidéz",
    "előidézni": "előidéz",
    "előidézte": "előidéz",
    "előidézése": "előidézés",
    "előidézésében": "előidézés",
    "előirányzatot": "előirányzat",
    "előirányzatát": "előirányzat",
    "előirányzott": "előirányoz",
    "előjellel": "előjel",
    "előjogai": "előjog",
    "előjogok": "előjog",
    "előjogunk": "előjog",
    "előjátéka": "előjáték",
    "előjött": "előjön",
    "előkalkulált": "előkalkulál",
    "előkapart": "előkapar",
    "előkelőbb": "előkelő",
    "előkelően": "előkelő",
    "előkertje": "előkert",
    "előkertjének": "előkert",
    "előkerítse": "előkerít",
    "előkerült": "előkerül",
    "előkotorni": "előkotor",
    "előkotort": "előkotor",
    "előképzőkkel": "előképző",
    "előképzővel": "előképző",
    "előkészített": "előkészít",
    "előkészítette": "előkészít",
    "előkészítetten": "előkészített",
    "előkészítjük": "előkészít",
    "előkészítése": "előkészítés",
    "előkészítésekor": "előkészítés",
    "előkészítéséhez": "előkészítés",
    "előkészítéséről": "előkészítés",
    "előkészítésével": "előkészítés",
    "előkészületeiről": "előkészület",
    "előkészületeit": "előkészület",
    "előkészületek": "előkészület",
    "előkészületekben": "előkészület",
    "előkészületeket": "előkészület",
    "előkészületekről": "előkészület",
    "előkészületet": "előkészület",
    "előle": "elől",
    "előleget": "előleg",
    "előlegezte": "előlegez",
    "előlegként": "előleg",
    "előléphettünk": "előléphet",
    "előléptetik": "előléptet",
    "előléptetésért": "előléptetés",
    "előlük": "elől",
    "előlünk": "elől",
    "előmozdítani": "előmozdít",
    "előmunkálatok": "előmunkálat",
    "előnevét": "előnév",
    "előnyben": "előny",
    "előnye": "előny",
    "előnyei": "előny",
    "előnyhöz": "előny",
    "előnyről": "előny",
    "előnyt": "előny",
    "előnyét": "előny",
    "előnyök": "előny",
    "előnyösebb": "előnyös",
    "előnyösen": "előnyös",
    "előnyösnek": "előnyös",
    "előrebocsátott": "előrebocsát",
    "előregörbült": "előregörbül",
    "előrehajlott": "előrehajlik",
    "előrehajolt": "előrehajol",
    "előrehaladottabb": "előrehaladott",
    "előrehaladt": "előrehalad",
    "előrehozott": "előrehoz",
    "előrejelzése": "előrejelzés",
    "előrejelzések": "előrejelzés",
    "előrelépésre": "előrelépés",
    "előrenyúlással": "előrenyúlás",
    "előrenéztek": "előrenéz",
    "előreszólt": "előreszól",
    "előretartottam": "előretartott",
    "előretolja": "előretol",
    "előretolt": "előretol",
    "előretörése": "előretörés",
    "előreugrott": "előreugrik",
    "előrevetették": "előrevetet",
    "elősegíteni": "elősegít",
    "elősegítenie": "elősegít",
    "elősegítette": "elősegít",
    "elősegítheti": "elősegíthet",
    "elősegíti": "elősegít",
    "elősegítjük": "elősegít",
    "elősegítése": "elősegítés",
    "elősegítésében": "elősegítés",
    "elősegítésére": "elősegítés",
    "elősegítésével": "elősegítés",
    "előszedtem": "előszed",
    "előszedték": "előszed",
    "előszeleként": "előszél",
    "előszeretettel": "előszeretett",
    "előszobába": "előszoba",
    "előszobában": "előszoba",
    "előszobájukba": "előszoba",
    "előszobájába": "előszoba",
    "előszobáját": "előszoba",
    "előszobát": "előszoba",
    "előteremteni": "előteremt",
    "előteremtenünk": "előteremt",
    "előteremtéséről": "előteremtés",
    "előterjesztést": "előterjesztés",
    "előterjesztésében": "előterjesztés",
    "előterjesztését": "előterjesztés",
    "előterjesztőként": "előterjesztő",
    "előterében": "előtér",
    "előtte": "előtt",
    "előtted": "előtt",
    "előttem": "előtt",
    "előttihez": "előtti",
    "előttük": "előtt",
    "előtérbe": "előtér",
    "előugratta": "előugrat",
    "előveszi": "előveszik",
    "elővett": "elővesz",
    "elővette": "elővesz",
    "elővették": "elővesz",
    "előzetesen": "előzetes",
    "előzi": "előz",
    "előzménye": "előzmény",
    "előzményével": "előzmény",
    "előzte": "előz",
    "előzték": "előz",
    "előzőtől": "előző",
    "előállt": "előáll",
    "előállítani": "előállít",
    "előállításuk": "előállítás",
    "előállításában": "előállítás",
    "előállítására": "előállítás",
    "előállításával": "előállítás",
    "előéletének": "előélet",
    "előérzetét": "előérzet",
    "előírja": "előír",
    "előírt": "előír",
    "előírta": "előír",
    "előírtakkal": "előírt",
    "előírása": "előírás",
    "előírásai": "előírás",
    "előírásaiba": "előírás",
    "előírásain": "előírás",
    "előírásait": "előírás",
    "előírásaival": "előírás",
    "előírásba": "előírás",
    "előírásokat": "előírás",
    "előírásoknak": "előírás",
    "előítéleteken": "előítélet",
    "előítéletéről": "előítélet",
    "elűzni": "elűz",
    "embargót": "embargó",
    "emberalakok": "emberalak",
    "emberben": "ember",
    "emberből": "ember",
    "embercsoportnak": "embercsoport",
    "embercsoportot": "embercsoport",
    "embere": "ember",
    "emberei": "ember",
    "embereiket": "ember",
    "embereim": "ember",
    "embereinek": "ember",
    "embereink": "ember",
    "embereinktől": "ember",
    "emberek": "ember",
    "emberekben": "ember",
    "emberekből": "ember",
    "embereket": "ember",
    "emberekhez": "ember",
    "emberekkel": "ember",
    "embereknek": "ember",
    "emberekre": "ember",
    "emberekről": "ember",
    "emberektől": "ember",
    "emberen": "ember",
    "emberevőkké": "emberevő",
    "emberfogót": "emberfogó",
    "emberhez": "ember",
    "emberhátrányban": "emberhátrány",
    "emberhüvelyek": "emberhüvely",
    "emberiséget": "emberiség",
    "emberiségnek": "emberiség",
    "emberiségre": "emberiség",
    "emberkék": "emberke",
    "emberként": "ember",
    "emberkísérleteiről": "emberkísérlet",
    "emberközelbe": "emberközel",
    "embernek": "ember",
    "embernél": "ember",
    "emberre": "ember",
    "emberrel": "ember",
    "emberré": "ember",
    "emberről": "ember",
    "emberszeretetet": "emberszeretet",
    "emberszeretetről": "emberszeretet",
    "emberszámba": "emberszám",
    "embert": "ember",
    "embertelenséggel": "embertelenség",
    "embertelenül": "embertelen",
    "embertől": "ember",
    "embervásárra": "embervásár",
    "emberáldozatok": "emberáldozat",
    "emberé": "ember",
    "emberének": "ember",
    "emberét": "ember",
    "emberétől": "ember",
    "emberük": "ember",
    "embriókat": "embrió",
    "emelek": "emel",
    "emelem": "emel",
    "emeleten": "emelet",
    "emeletről": "emelet",
    "emeletén": "emelet",
    "emeletének": "emelet",
    "emeli": "emel",
    "emelik": "emel",
    "emeljenek": "emel",
    "emeljék": "emel",
    "emeljünk": "emel",
    "emelkedett": "emelkedik",
    "emelkedettségéből": "emelkedettség",
    "emelkedjen": "emelkedik",
    "emelkedjenek": "emelkedik",
    "emelkednek": "emelkedik",
    "emelkedni": "emelkedik",
    "emelkedtek": "emelkedik",
    "emelkedése": "emelkedés",
    "emelkedéssel": "emelkedés",
    "emelkedést": "emelkedés",
    "emelkedésére": "emelkedés",
    "emelkedését": "emelkedés",
    "emelnek": "emel",
    "emelni": "emel",
    "emelt": "emel",
    "emelte": "emel",
    "emeltek": "emelt",
    "emeltessenek": "emeltes",
    "emeltyűt": "emeltyű",
    "emelték": "emel",
    "emelvényeket": "emelvény",
    "emelvényre": "emelvény",
    "emelvényről": "emelvény",
    "emelésből": "emelés",
    "emelése": "emelés",
    "emeléssel": "emelés",
    "emelést": "emelés",
    "emeléséről": "emelés",
    "emelését": "emelés",
    "emeléséért": "emelés",
    "emigrációból": "emigráció",
    "emigrálni": "emigrál",
    "emigrált": "emigrál",
    "emigránsnak": "emigráns",
    "emigránsok": "emigráns",
    "emlegesse": "emleget",
    "emlegetem": "emleget",
    "emlegetett": "emleget",
    "emlegetik": "emleget",
    "emlegetnek": "emleget",
    "emlegetni": "emleget",
    "emlegette": "emleget",
    "emlegettek": "emleget",
    "emlegették": "emleget",
    "emléke": "emlék",
    "emlékei": "emlék",
    "emlékeihez": "emlék",
    "emlékeinek": "emlék",
    "emlékeink": "emlék",
    "emlékeit": "emlék",
    "emlékek": "emlék",
    "emlékekben": "emlék",
    "emlékeket": "emlék",
    "emlékekről": "emlék",
    "emléket": "emlék",
    "emlékezetben": "emlékezet",
    "emlékezetből": "emlékezet",
    "emlékezetdefektusokban": "emlékezetdefektus",
    "emlékezete": "emlékezet",
    "emlékezetemben": "emlékezet",
    "emlékezetessé": "emlékezetes",
    "emlékezetet": "emlékezet",
    "emlékezetlyukaknak": "emlékezetlyuk",
    "emlékezetlyukba": "emlékezetlyuk",
    "emlékezetlyukhoz": "emlékezetlyuk",
    "emlékezetmutatványokra": "emlékezetmutatvány",
    "emlékezett": "emlékezik",
    "emlékezetébe": "emlékezet",
    "emlékezetében": "emlékezet",
    "emlékezetéből": "emlékezet",
    "emlékezetén": "emlékezet",
    "emlékezetének": "emlékezet",
    "emlékezetét": "emlékezet",
    "emlékezetükben": "emlékezet",
    "emlékezetükből": "emlékezet",
    "emlékezhetett": "emlékezhet",
    "emlékezhetsz": "emlékezhet",
    "emlékezik": "emlékez",
    "emlékeznek": "emlékezik",
    "emlékezni": "emlékezik",
    "emlékeztek": "emlékezik",
    "emlékeztetett": "emlékeztet",
    "emlékeztetnek": "emlékeztet",
    "emlékeztetni": "emlékeztet",
    "emlékeztette": "emlékeztet",
    "emlékeztettek": "emlékeztet",
    "emlékezzenek": "emlékezik",
    "emlékezzünk": "emlékezik",
    "emlékezése": "emlékezés",
    "emlékezést": "emlékezés",
    "emlékezését": "emlékezés",
    "emlékezőtehetsége": "emlékezőtehetség",
    "emlékezőtehetségét": "emlékezőtehetség",
    "emlékirataiban": "emlékirat",
    "emlékiratairól": "emlékirat",
    "emlékké": "emlék",
    "emlékként": "emlék",
    "emlékműnél": "emlékmű",
    "emlékoszlopot": "emlékoszlop",
    "emlékre": "emlék",
    "emlékszel": "emlékszik",
    "emlékszem": "emlékszik",
    "emlékszünk": "emlékszik",
    "emléktáblákat": "emléktábla",
    "emlékének": "emlék",
    "emlékére": "emlék",
    "emlékét": "emlék",
    "emlékével": "emlék",
    "emlékülést": "emlékülés",
    "említed": "említ",
    "említeni": "említ",
    "említett": "említ",
    "említette": "említ",
    "említettek": "említett",
    "említést": "említés",
    "említésénél": "említés",
    "említésére": "említés",
    "empátiával": "empátia",
    "eméssze": "emészt",
    "emésztett": "emészt",
    "energiaár-emelések": "energia-áremelés",
    "energiára": "energia",
    "energiát": "energia",
    "engedd": "enged",
    "engedelmesen": "engedelmes",
    "engedelmeskedett": "engedelmeskedik",
    "engedelmeskedjenek": "engedelmeskedik",
    "engedelmeskedned": "engedelmeskedik",
    "engedelmeskedni": "engedelmeskedik",
    "engedelmeskedtek": "engedelmeskedik",
    "engedelmességgel": "engedelmesség",
    "engedelmességre": "engedelmesség",
    "engedem": "enged",
    "engedetlenséggel": "engedetlenség",
    "engedett": "enged",
    "engedheti": "engedhet",
    "engedhetik": "engedhet",
    "engedhette": "engedhet",
    "engedhetünk": "engedhet",
    "engedi": "enged",
    "engedik": "enged",
    "engedje": "enged",
    "engedjen": "enged",
    "engedjétek": "enged",
    "engedjük": "enged",
    "engedményeket": "engedmény",
    "engedményekhez": "engedmény",
    "engedményt": "engedmény",
    "engednek": "enged",
    "engedni": "enged",
    "engednének": "enged",
    "engedte": "enged",
    "engedtem": "enged",
    "engedték": "enged",
    "engedtünk": "enged",
    "engedékennyé": "engedékeny",
    "engedékenységgel": "engedékenység",
    "engedéllyel": "engedély",
    "engedélye": "engedély",
    "engedélyek": "engedély",
    "engedélyeket": "engedély",
    "engedélyezett": "engedélyez",
    "engedélyezi": "engedélyez",
    "engedélyezné": "engedélyez",
    "engedélyezte": "engedélyez",
    "engedélyezték": "engedélyez",
    "engedélyezze": "engedélyez",
    "engedélyezzék": "engedélyez",
    "engedélyezését": "engedélyezés",
    "engedélyhez": "engedély",
    "engedélyt": "engedély",
    "engem": "én",
    "engemet": "én",
    "ennek": "ez",
    "enni": "eszik",
    "ennie": "eszik",
    "ennivalóból": "ennivaló",
    "ennivalója": "ennivaló",
    "ennivalót": "ennivaló",
    "ennivalóért": "ennivaló",
    "ennyinek": "ennyi",
    "ennyire": "ennyi",
    "ennyit": "ennyi",
    "enné": "eszik",
    "ennél": "ez",
    "ennünk": "eszik",
    "enteriőrsorozatának": "enteriőrsorozat",
    "enteriőrök": "enteriőr",
    "enyhe": "enyh",
    "enyhébb": "enyhe",
    "enyhébben": "enyhe",
    "enyhíteni": "enyhít",
    "enyhítené": "enyhít",
    "enyhített": "enyhít",
    "enyhítették": "enyhítet",
    "enyhíti": "enyhít",
    "enyhítések": "enyhítés",
    "enyhítését": "enyhítés",
    "enyhítéséért": "enyhítés",
    "enyhül": "enyh",
    "enyhült": "enyhül",
    "enyhültebb": "enyhült",
    "enyhülése": "enyhülés",
    "enyémben": "én",
    "enyémek": "én",
    "enyémet": "én",
    "enyémhez": "én",
    "enyészett": "enyészik",
    "epekednek": "epekedik",
    "epizodistáját": "epizodista",
    "epizódjait": "epizód",
    "epizódokat": "epizód",
    "erdei": "erdő",
    "erdélyiek": "erdélyi",
    "erdőbe": "erdő",
    "erdőben": "erdő",
    "erdőbirtokosságok": "erdőbirtokosság",
    "erdőből": "erdő",
    "erdők": "erdő",
    "erdőn": "erdő",
    "erdőnek": "erdő",
    "erdőre": "erdő",
    "erdőségekben": "erdőség",
    "erdőé": "erdő",
    "ere": "ér",
    "eredendően": "eredendő",
    "eredete": "eredet",
    "eredetre": "eredet",
    "eredetűnek": "eredetű",
    "eredménnyel": "eredmény",
    "eredménnyé": "eredmény",
    "eredménye": "eredmény",
    "eredményei": "eredmény",
    "eredményeiről": "eredmény",
    "eredményeit": "eredmény",
    "eredményeivel": "eredmény",
    "eredményeié": "eredmény",
    "eredmények": "eredmény",
    "eredményeket": "eredmény",
    "eredményeknél": "eredmény",
    "eredményeként": "eredmény",
    "eredményeképp": "eredmény",
    "eredményeképpen": "eredmény",
    "eredményekért": "eredmény",
    "eredményesek": "eredményes",
    "eredményesen": "eredményes",
    "eredményesnek": "eredményes",
    "eredményezett": "eredményez",
    "eredményezheti": "eredményezhet",
    "eredménynek": "eredmény",
    "eredményt": "eredmény",
    "eredménytartaléka": "eredménytartalék",
    "eredménytartalékot": "eredménytartalék",
    "eredménytelenül": "eredménytelen",
    "eredményéről": "eredmény",
    "eredményét": "eredmény",
    "eredményével": "eredmény",
    "erednek": "ered",
    "eredt": "ered",
    "eredtem": "eredt",
    "eredtünk": "eredt",
    "erei": "erő",
    "ereit": "erő",
    "ereje": "erő",
    "erejében": "erő",
    "erejéből": "erő",
    "erejéhez": "erő",
    "erejéig": "erő",
    "erején": "erő",
    "erejének": "erő",
    "erejénél": "erő",
    "erejét": "erő",
    "erejük": "erő",
    "erejükben": "erő",
    "erejüket": "erő",
    "erejüknek": "erő",
    "erejűek": "erejű",
    "erek": "ér",
    "erekben": "ér",
    "eresszen": "ereszt",
    "ereszcsatornáját": "ereszcsatorna",
    "eresze": "eresz",
    "ereszkedett": "ereszkedik",
    "ereszkedni": "ereszkedik",
    "ereszkedtek": "ereszkedik",
    "ereszkedünk": "ereszkedik",
    "ereszt": "eresz",
    "ereszteni": "ereszt",
    "eresztett": "ereszt",
    "eresztettek": "eresztett",
    "eresztették": "eresztet",
    "ereszti": "ereszt",
    "eresztik": "ereszt",
    "eresztünk": "ereszt",
    "eretnekek": "eretnek",
    "eretnekeket": "eretnek",
    "eretneket": "eretnek",
    "eretnekkel": "eretnek",
    "eretneksége": "eretnekség",
    "eretnekségei": "eretnekség",
    "eretnekségek": "eretnekség",
    "eretnekségeket": "eretnekség",
    "eretnekségeknek": "eretnekség",
    "eretnekséget": "eretnekség",
    "eretnekségnek": "eretnekség",
    "eretnekségre": "eretnekség",
    "erezett": "erez",
    "erjedt": "erjed",
    "erkélyoszlopai": "erkélyoszlop",
    "erkélyre": "erkély",
    "erkélyt": "erkély",
    "erkélyük": "erkély",
    "erkölcseink": "erkölcs",
    "erkölcsnélkülinek": "erkölcsnélküli",
    "erkölcstanban": "erkölcstan",
    "erkölcstelenségnek": "erkölcstelenség",
    "erkölcsön": "erkölcs",
    "erodálni": "erodál",
    "erotikát": "erotika",
    "erre": "ez",
    "erről": "ez",
    "eréllyel": "erély",
    "erélyesen": "erélyes",
    "erélyével": "erély",
    "erényfalat": "erényfal",
    "erőből": "erő",
    "erőd": "erő",
    "erőddé": "erőd",
    "erődnek": "erőd",
    "erődök": "erőd",
    "erődökkel": "erőd",
    "erődöt": "erőd",
    "erőfeszítésbe": "erőfeszítés",
    "erőfeszítései": "erőfeszítés",
    "erőfeszítéseket": "erőfeszítés",
    "erőfeszítésnek": "erőfeszítés",
    "erőfeszítésre": "erőfeszítés",
    "erőfeszítéssel": "erőfeszítés",
    "erőfeszítést": "erőfeszítés",
    "erőfeszítésébe": "erőfeszítés",
    "erőfeszítéséről": "erőfeszítés",
    "erőforrások": "erőforrás",
    "erői": "erő",
    "erőit": "erő",
    "erők": "erő",
    "erőket": "erő",
    "erőkhöz": "erő",
    "erőknek": "erő",
    "erőként": "erő",
    "erőlködéssel": "erőlködés",
    "erőlködéstől": "erőlködés",
    "erőlködött": "erőlködik",
    "erőltetett": "erőltet",
    "erőltetetten": "erőltetett",
    "erőlteti": "erőltet",
    "erőltetik": "erőltet",
    "erőltetned": "erőltet",
    "erőltetni": "erőltet",
    "erőltetnie": "erőltet",
    "erőltetnünk": "erőltet",
    "erőltette": "erőltet",
    "erőltettek": "erőltet",
    "erőmet": "erő",
    "erőműből": "erőmű",
    "erőműig": "erőmű",
    "erőműnek": "erőmű",
    "erőművei": "erőmű",
    "erőműveink": "erőmű",
    "erőművek": "erőmű",
    "erőművet": "erőmű",
    "erőművésznek": "erőművész",
    "erőnek": "erő",
    "erőre": "erő",
    "erősebb": "erős",
    "erősebbek": "erős",
    "erősebben": "erőseb",
    "erősebbnek": "erős",
    "erősek": "erős",
    "erősen": "erős",
    "erősködni": "erősködik",
    "erősködtek": "erősködik",
    "erősködtünk": "erősködik",
    "erősködött": "erősködik",
    "erősnek": "erős",
    "erőszakhoz": "erőszak",
    "erőszakkal": "erőszak",
    "erőszakolnak": "erőszakol",
    "erőszakoltak": "erőszakolt",
    "erőszakolása": "erőszakolás",
    "erőszakoskodunk": "erőszakoskodik",
    "erőszakot": "erőszak",
    "erőszaktól": "erőszak",
    "erősítené": "erősít",
    "erősített": "erősít",
    "erősítette": "erősít",
    "erősítették": "erősítet",
    "erősíti": "erősít",
    "erősítjük": "erősít",
    "erősítsen": "erősít",
    "erősödnek": "erősödik",
    "erősödtek": "erősödik",
    "erősödtünk": "erősödik",
    "erősödése": "erősödés",
    "erősödött": "erősödik",
    "erőt": "erő",
    "erőteljesebb": "erőteljes",
    "erőteljesek": "erőteljes",
    "erőteljesen": "erőteljes",
    "erőtlenül": "erőtlen",
    "erőtökön": "erőtök",
    "erővel": "erő",
    "erőviszonyok": "erőviszony",
    "eseményei": "esemény",
    "eseményeinek": "esemény",
    "eseményeiről": "esemény",
    "eseményeit": "esemény",
    "események": "esemény",
    "eseményekből": "esemény",
    "eseményeken": "esemény",
    "eseményeket": "esemény",
    "eseményekkel": "esemény",
    "eseményekre": "esemény",
    "eseményre": "esemény",
    "eseményrészletekre": "eseményrészlet",
    "eseményről": "esemény",
    "eseményt": "esemény",
    "esendőségbe": "esendőség",
    "esetben": "eset",
    "esete": "eset",
    "esetedben": "eset",
    "esetek": "eset",
    "esetekben": "eset",
    "eseteket": "eset",
    "esetekre": "eset",
    "esetekről": "eset",
    "esetektől": "eset",
    "esetenként": "eset",
    "esetet": "eset",
    "esethez": "eset",
    "esetlensége": "esetlenség",
    "esetre": "eset",
    "esett": "esik",
    "esettel": "esett",
    "esetében": "eset",
    "esetén": "eset",
    "esetére": "eset",
    "esetét": "eset",
    "esetük": "eset",
    "esetükben": "eset",
    "eshetett": "eshet",
    "eshetőséget": "eshetőség",
    "esküdni": "esküszik",
    "esküdtek": "esküszik",
    "esküvőn": "esküvő",
    "esne": "esik",
    "esnek": "esik",
    "esni": "esik",
    "esnie": "esik",
    "esnének": "esik",
    "essen": "esik",
    "esszéje": "esszé",
    "essék": "esik",
    "estbe": "est",
    "este": "esik",
    "estek": "est",
    "estet": "est",
    "esthajnalon": "esthajnal",
    "esthez": "est",
    "estig": "est",
    "estében": "este",
    "estéi": "este",
    "estéje": "estéj",
    "estéjén": "estéj",
    "estéjét": "estéj",
    "esték": "este",
    "estéket": "esték",
    "estélye": "estély",
    "estén": "este",
    "esténként": "este",
    "estére": "este",
    "estét": "este",
    "estétől": "este",
    "estével": "este",
    "estünk": "est",
    "esze": "ész",
    "eszedbe": "ész",
    "eszelte": "eszel",
    "eszembe": "ész",
    "eszetekbe": "ész",
    "eszi": "eszik",
    "eszkalálódását": "eszkalálódás",
    "eszköze": "eszköz",
    "eszközeinek": "eszköz",
    "eszközeink": "eszköz",
    "eszközeivel": "eszköz",
    "eszközként": "eszköz",
    "eszközt": "eszköz",
    "eszköztárában": "eszköztára",
    "eszközzel": "eszköz",
    "eszközállománya": "eszközállomány",
    "eszközéül": "eszköz",
    "eszközök": "eszköz",
    "eszközöket": "eszköz",
    "eszközökkel": "eszköz",
    "eszközöknek": "eszköz",
    "eszközöktől": "eszköz",
    "eszközökön": "eszköz",
    "eszmecserén": "eszmecsere",
    "eszmefuttatások": "eszmefuttatás",
    "eszmefuttatásának": "eszmefuttatás",
    "eszmekörbe": "eszmekör",
    "eszmeláncban": "eszmelánc",
    "eszmevilága": "eszmevilág",
    "eszméből": "eszme",
    "eszméhez": "eszme",
    "eszméiben": "eszme",
    "eszméivel": "eszme",
    "eszméje": "eszme",
    "eszmék": "eszme",
    "eszméket": "eszme",
    "eszméletlenül": "eszméletlen",
    "eszméletét": "eszmélet",
    "eszmélkedést": "eszmélkedés",
    "eszményképe": "eszménykép",
    "eszményképekkel": "eszménykép",
    "eszményképének": "eszménykép",
    "eszmét": "eszme",
    "esznek": "eszik",
    "eszperantóra": "eszperantó",
    "esztelenségek": "esztelenség",
    "esztendeig": "esztendő",
    "esztendeinek": "esztendő",
    "esztendeivel": "esztendő",
    "esztendeje": "esztendő",
    "esztendőben": "esztendő",
    "esztendőről": "esztendő",
    "esztendőt": "esztendő",
    "eszébe": "ész",
    "eszében": "ész",
    "eszének": "ész",
    "eszük": "ész",
    "eszükbe": "ész",
    "eszüket": "ész",
    "eszükön": "ész",
    "eszünk": "eszik",
    "eszünkbe": "ész",
    "eszünkben": "ész",
    "esélye": "esély",
    "esélyei": "esély",
    "esélyeit": "esély",
    "esélyek": "esély",
    "esélyeket": "esély",
    "esélyesebb": "esélyes",
    "esélyt": "esély",
    "esünk": "esik",
    "esőbe": "eső",
    "esőben": "eső",
    "esőfelhők": "esőfelhő",
    "esőhöz": "eső",
    "esők": "eső",
    "esőnek": "eső",
    "esőt": "eső",
    "esővízből": "esővíz",
    "esővíznek": "esővíz",
    "esőzést": "esőzés",
    "etette": "etet",
    "ette": "eszik",
    "ettek": "eszik",
    "ették": "eszik",
    "ettük": "eszik",
    "ettünk": "eszik",
    "ettől": "ez",
    "eufóriával": "eufória",
    "eurázsiaiak": "eurázsiai",
    "európaiak": "európai",
    "evett": "eszik",
    "evezni": "evez",
    "evidenssé": "evidens",
    "evvel": "ez",
    "evést": "evés",
    "exportbevétele": "exportbevétel",
    "exportját": "export",
    "exportpiacokon": "exportpiac",
    "exportra": "export",
    "exportszubvenciók": "exportszubvenció",
    "exporttámogatások": "exporttámogatás",
    "exportálást": "exportálás",
    "exportálókat": "exportáló",
    "ezek": "ez",
    "ezekben": "ez",
    "ezekből": "ez",
    "ezeken": "ez",
    "ezeket": "ez",
    "ezekhez": "ez",
    "ezekkel": "ez",
    "ezeknek": "ez",
    "ezekre": "ez",
    "ezekről": "ez",
    "ezektől": "ez",
    "ezen": "ez",
    "ezerben": "ezer",
    "ezerhez": "ezer",
    "ezerkilencszáztizenkilencből": "ezerkilencszáztizenkilenc",
    "ezerre": "ezer",
    "ezerrel": "ezer",
    "ezerről": "ezer",
    "ezerszer": "ezer",
    "ezerért": "ezer",
    "ezred": "ezer",
    "ezredeséé": "ezredes",
    "ezredesük": "ezredes",
    "ezredfordulóig": "ezredforduló",
    "ezreinek": "ezer",
    "ezreire": "ezer",
    "ezrek": "ezer",
    "ezren": "ezer",
    "ezret": "ezer",
    "ezrével": "ezer",
    "ezt": "ez",
    "ezzel": "ez",
    "ezzel-azzal": "ez-az",
    "ezért": "ez",
    "ezüstcsengők": "ezüstcsengő",
    "faburkolatba": "faburkolat",
    "faburkolatból": "faburkolat",
    "fabábut": "fabábu",
    "facsarunk": "facsar",
    "facsillárokban": "facsillár",
    "fadarabbal": "fadarab",
    "fagerendákkal": "fagerenda",
    "faggathatná": "faggathat",
    "faggatja": "faggat",
    "faggatni": "faggat",
    "faggattak": "faggat",
    "faggatták": "faggat",
    "fagyasztani": "fagyaszt",
    "fagyott": "fagy",
    "faházakból": "faház",
    "faházában": "faház",
    "fahéjjal": "fahéj",
    "faja": "faj",
    "fajkutyák": "fajkutya",
    "fajnak": "faj",
    "fajokkal": "faj",
    "fajt": "faj",
    "fajtából": "fajta",
    "fajtád": "fajta",
    "fajtától": "fajta",
    "fajul": "faj",
    "fakadt": "fakad",
    "fakadtak": "fakadt",
    "fakockák": "fakocka",
    "fakultásának": "fakultás",
    "fakupában": "fakupa",
    "fakóbb": "fakó",
    "fala": "fal",
    "falai": "fal",
    "falaikkal": "fal",
    "falain": "fal",
    "falainak": "fal",
    "falait": "fal",
    "falak": "fal",
    "falakon": "falak",
    "falakra": "falak",
    "falakról": "falak",
    "falapra": "falap",
    "falat": "fal",
    "falba": "fal",
    "falban": "fal",
    "falburkolatot": "falburkolat",
    "falból": "fal",
    "falevelekkel": "falevél",
    "falevelet": "falevél",
    "falevélként": "falevél",
    "falhoz": "fal",
    "faliszekrényből": "faliszekrény",
    "falitérképet": "falitérkép",
    "faliújságcikket": "faliújságcikk",
    "faliújságja": "faliújság",
    "falják": "fal",
    "fallal": "fal",
    "falnak": "fal",
    "falnál": "fal",
    "falon": "fal",
    "falra": "fal",
    "falról": "fal",
    "faltól": "fal",
    "faluba": "falu",
    "faluban": "falu",
    "faluból": "falu",
    "falucska": "falucsok",
    "faluhoz": "falu",
    "falujában": "falu",
    "faluját": "falu",
    "falukba": "faluk",
    "falukban": "faluk",
    "falukból": "faluk",
    "falukon": "faluk",
    "falum": "falu",
    "falumban": "falu",
    "falun": "falu",
    "falunak": "falu",
    "falunkat": "falu",
    "falunkba": "falu",
    "falunkból": "falu",
    "faluról": "falu",
    "falusiak": "falusi",
    "falusiaknak": "falusi",
    "falut": "falu",
    "faluval": "falu",
    "falvai": "falu",
    "falvaiban": "falu",
    "falvaikból": "falu",
    "falvak": "falu",
    "falvakat": "falu",
    "falvakba": "falvak",
    "falvakban": "falvak",
    "falvakra": "falvak",
    "falában": "fal",
    "falán": "fal",
    "falónak": "faló",
    "fanatikusan": "fanatikus",
    "fanatikusnak": "fanatikus",
    "fanatikusokat": "fanatikus",
    "fanatikusokból": "fanatikus",
    "fanatizmusnak": "fanatizmus",
    "fantasztikusak": "fantasztikus",
    "fantazmákra": "fantazma",
    "fantáziált": "fantáziál",
    "fantáziától": "fantázia",
    "fantáziával": "fantázia",
    "fanyalodtak": "fanyalodik",
    "faraghatják": "faraghat",
    "faragni": "farag",
    "farkasok": "farkas",
    "farkasokat": "farkas",
    "farkasoknak": "farkas",
    "farkast": "farkas",
    "farkasverembe": "farkasverem",
    "farkuk": "fark",
    "farkukat": "fark",
    "farkán": "fark",
    "farkát": "fark",
    "faron": "far",
    "farát": "far",
    "farától": "far",
    "farával": "far",
    "fasorok": "fasor",
    "faszege": "faszég",
    "faszegeket": "faszég",
    "faszeget": "faszég",
    "favágókat": "favágó",
    "fazekaik": "fazék",
    "fazekakban": "fazék",
    "fazekakkal": "fazék",
    "februárban": "február",
    "februárjában": "február",
    "februárra": "február",
    "februártól": "február",
    "fecsegett": "fecseg",
    "fecsegése": "fecsegés",
    "fecskendezni": "fecskendez",
    "fecskendővel": "fecskendő",
    "fecskék": "fecske",
    "fedele": "fedél",
    "fedelében": "fedél",
    "fedelén": "fedél",
    "fedelének": "fedél",
    "fedelére": "fedél",
    "fedeléről": "fedél",
    "fedelét": "fedél",
    "fedett": "fed",
    "fedezetet": "fedezet",
    "fedezett": "fedez",
    "fedezetét": "fedezet",
    "fedezi": "fedez",
    "fedezik": "fedez",
    "fedezni": "fedez",
    "fedezte": "fedez",
    "fedezésére": "fedezés",
    "fedi": "fed",
    "fednék": "fed",
    "fedte": "fed",
    "fegyelme": "fegyelem",
    "fegyelmezett": "fegyelmez",
    "fegyházban": "fegyház",
    "fegyvere": "fegyver",
    "fegyvereiket": "fegyver",
    "fegyvereit": "fegyver",
    "fegyverek": "fegyver",
    "fegyvereket": "fegyver",
    "fegyverekkel": "fegyver",
    "fegyveresek": "fegyveres",
    "fegyveresekkel": "fegyveres",
    "fegyvernek": "fegyver",
    "fegyverneme": "fegyvernem",
    "fegyverraktárak": "fegyverraktár",
    "fegyverraktárakat": "fegyverraktár",
    "fegyverraktárt": "fegyverraktár",
    "fegyverrel": "fegyver",
    "fegyverszállítmányért": "fegyverszállítmány",
    "fegyvert": "fegyver",
    "fegyverzetnél": "fegyverzet",
    "fegyverzetének": "fegyverzet",
    "fegyverzetéről": "fegyverzet",
    "fegyverével": "fegyver",
    "fegyverük": "fegyver",
    "fehéren": "fehér",
    "fehérlett": "fehérlik",
    "fehérlisztből": "fehérliszt",
    "fehérneműje": "fehérnemű",
    "fehérneműt": "fehérnemű",
    "fehérrel": "fehér",
    "fehérrépát": "fehérrépa",
    "fehérváron": "fehérvár",
    "fejadagként": "fejadag",
    "fejadagokra": "fejadag",
    "fejbe": "fej",
    "fejben": "fej",
    "fejbőrben": "fejbőr",
    "fejbőre": "fejbőr",
    "fejbőréhez": "fejbőr",
    "feje": "fej",
    "fejed": "fej",
    "fejedből": "fej",
    "fejedre": "fej",
    "fejek": "fej",
    "fejeket": "fej",
    "fejem": "fej",
    "fejemben": "fej",
    "fejemen": "fej",
    "fejenként": "fej",
    "fejesek": "fejes",
    "fejesekkel": "fejes",
    "fejeseknek": "fejes",
    "fejetlensége": "fejetlenség",
    "fejezete": "fejezet",
    "fejezetet": "fejezet",
    "fejezethez": "fejezet",
    "fejezetnek": "fejezet",
    "fejezetnél": "fejezet",
    "fejezi": "fejez",
    "fejeznek": "fejez",
    "fejezni": "fejez",
    "fejezte": "fejez",
    "fejeztem": "fejez",
    "fejezték": "fejez",
    "fejezzétek": "fejez",
    "fejezzük": "fejez",
    "fejeződött": "fejeződik",
    "fejfájósan": "fejfájós",
    "fejjel": "fej",
    "fejjük": "fej",
    "fejleményei": "fejlemény",
    "fejlesztenek": "fejleszt",
    "fejleszteni": "fejleszt",
    "fejlesztett": "fejleszt",
    "fejlesztette": "fejleszt",
    "fejlesztése": "fejlesztés",
    "fejlesztéseihez": "fejlesztés",
    "fejlesztéseikre": "fejlesztés",
    "fejlesztésre": "fejlesztés",
    "fejlesztéstől": "fejlesztés",
    "fejlesztésében": "fejlesztés",
    "fejlesztésére": "fejlesztés",
    "fejlett": "fejlik",
    "fejlettebb": "fejlett",
    "fejlettsége": "fejlettség",
    "fejlődnek": "fejlődik",
    "fejlődni": "fejlődik",
    "fejlődése": "fejlődés",
    "fejlődésre": "fejlődés",
    "fejlődést": "fejlődés",
    "fejlődéstől": "fejlődés",
    "fejlődésének": "fejlődés",
    "fejlődését": "fejlődés",
    "fejlődésével": "fejlődés",
    "fejlődésükhöz": "fejlődés",
    "fejlődött": "fejlődik",
    "fejmunkát": "fejmunka",
    "fejre": "fej",
    "fejszénk": "fejsze",
    "fejsérüléssel": "fejsérülés",
    "fejtegeti": "fejteget",
    "fejtegette": "fejteget",
    "fejtek": "fejt",
    "fejtette": "fejtet",
    "fejtetőre": "fejtető",
    "fejtágítón": "fejtágító",
    "fejtörést": "fejtörés",
    "fejtől": "fej",
    "fejébe": "fej",
    "fejében": "fej",
    "fejéből": "fej",
    "fejéhez": "fej",
    "fejének": "fej",
    "fejénél": "fej",
    "fejére": "fej",
    "fejét": "fej",
    "fejével": "fej",
    "fejük": "fej",
    "fejüket": "fej",
    "fejükön": "fej",
    "fejünket": "fej",
    "fejűek": "fejű",
    "feketegazdaságban": "feketegazdaság",
    "feketegazdasággal": "feketegazdaság",
    "feketekávéjukat": "feketekávé",
    "feketepiacon": "feketepiac",
    "feketén": "fekete",
    "feketének": "fekete",
    "feketére": "fekete",
    "feketéről": "fekete",
    "feketét": "fekete",
    "feketével": "fekete",
    "feketévé": "fekete",
    "fekhelyek": "fekhely",
    "fekhelyén": "fekhely",
    "fekhettek": "fekhet",
    "fekszel": "fekszik",
    "fekszenek": "fekszik",
    "fektetni": "fektet",
    "fektette": "fektet",
    "fektettek": "fektet",
    "fektették": "fektet",
    "fekvése": "fekvés",
    "fekvésének": "fekvés",
    "fekvőgipszet": "fekvőgipsz",
    "fekvőtámaszt": "fekvőtámasz",
    "fekélye": "fekély",
    "fekélyt": "fekély",
    "fekélyét": "fekély",
    "feküdjünk": "fekszik",
    "feküdni": "fekszik",
    "feküdt": "fekszik",
    "feküdtek": "fekszik",
    "feküdtem": "fekszik",
    "feküdtünk": "feküdt",
    "feladata": "feladat",
    "feladatai": "feladat",
    "feladataik": "feladat",
    "feladataikat": "feladat",
    "feladataira": "feladat",
    "feladatairól": "feladat",
    "feladatait": "feladat",
    "feladataival": "feladat",
    "feladatnak": "feladatik",
    "feladatok": "feladatik",
    "feladatokat": "feladat",
    "feladatokhoz": "feladat",
    "feladatoknak": "feladat",
    "feladatoknál": "feladat",
    "feladatokon": "feladat",
    "feladatokra": "feladat",
    "feladaton": "feladat",
    "feladatot": "feladat",
    "feladatra": "feladat",
    "feladattal": "feladat",
    "feladattá": "feladat",
    "feladatukat": "feladat",
    "feladatunk": "feladatik",
    "feladatának": "feladat",
    "feladatát": "feladat",
    "feladni": "felad",
    "feladta": "felad",
    "feladtam": "felad",
    "feladták": "felad",
    "feladását": "feladás",
    "felajánlani": "felajánl",
    "felajánlja": "felajánl",
    "felajánlott": "felajánl",
    "felajánlotta": "felajánl",
    "felajánlották": "felajánl",
    "felajánlása": "felajánlás",
    "felajánlásból": "felajánlás",
    "felajánlásokra": "felajánlás",
    "felajánlásról": "felajánlás",
    "felajánlást": "felajánlás",
    "felajánlásért": "felajánlás",
    "felakasztanak": "felakaszt",
    "felakasztani": "felakaszt",
    "felakasztotta": "felakaszt",
    "felaranylanak": "felaranylik",
    "felavatta": "felavat",
    "felbolydult": "felbolydul",
    "felbolydítaná": "felbolydít",
    "felbomlott": "felbomlik",
    "felbomlásakor": "felbomlás",
    "felbontják": "felbont",
    "felbontották": "felbont",
    "felbontásának": "felbontás",
    "felborult": "felborul",
    "felborzolódott": "felborzolódik",
    "felbukkant": "felbukkan",
    "felbukkantak": "felbukkant",
    "felbúgjanak": "felbúg",
    "felcihelődtünk": "felcihelődik",
    "felcsavarozott": "felcsavaroz",
    "felcsavartam": "felcsavart",
    "felcserélhetősége": "felcserélhetőség",
    "felcsillant": "felcsillan",
    "felderítetlenek": "felderítetlen",
    "felderült": "felderül",
    "feldolgozott": "feldolgozik",
    "feldolgozása": "feldolgozás",
    "feldolgozást": "feldolgozás",
    "feldúltabbnak": "feldúlt",
    "feldúltságát": "feldúltság",
    "feldúlták": "feldúl",
    "fele": "fél",
    "feledjük": "feled",
    "feledkezett": "feledkezik",
    "feledkezni": "feledkezik",
    "feledni": "feled",
    "feledte": "feled",
    "feledtesse": "feledtes",
    "feledteti": "feledtet",
    "feledtetni": "feledtet",
    "feledésbe": "feledés",
    "feledésből": "feledés",
    "felejtem": "felejt",
    "felejtenek": "felejt",
    "felejteni": "felejt",
    "felejtenie": "felejt",
    "felejtett": "felejt",
    "felejtette": "felejt",
    "felejti": "felejt",
    "felejtik": "felejt",
    "felejtsd": "felejt",
    "felejtsem": "felejt",
    "felek": "fél",
    "feleket": "fél",
    "felekezeten": "felekezet",
    "feleknek": "fél",
    "feleletei": "felelet",
    "feleletek": "felelet",
    "feleleteket": "felelet",
    "feleletet": "felelet",
    "felelhetett": "felelhet",
    "feleli": "felel",
    "feleljek": "felel",
    "feleljetek": "felel",
    "felelne": "felel",
    "felelnek": "felel",
    "felelni": "felel",
    "felelnie": "felel",
    "felelt": "felel",
    "felelte": "felel",
    "feleltek": "felelt",
    "feleltem": "felelt",
    "felelték": "felel",
    "feleltünk": "felelt",
    "felelősek": "felelős",
    "felelősen": "felelős",
    "felelősnek": "felelős",
    "felelőssé": "felelős",
    "felelősséget": "felelősség",
    "felelősségre": "felelősség",
    "felelősségtől": "felelősség",
    "felelősségének": "felelősség",
    "felelősségérzete": "felelősségérzet",
    "felelősségét": "felelősség",
    "felelősöket": "felelős",
    "felelőtlenül": "felelőtlen",
    "felemelhette": "felemelhet",
    "felemeli": "felemel",
    "felemeljenek": "felemel",
    "felemelkedett": "felemelkedik",
    "felemelkedhetnek": "felemelkedhet",
    "felemelkedni": "felemelkedik",
    "felemelkedésnek": "felemelkedés",
    "felemelné": "felemel",
    "felemelnék": "felemel",
    "felemelt": "felemel",
    "felemelte": "felemel",
    "felemeltük": "felemel",
    "felemelése": "felemelés",
    "felemeléséről": "felemelés",
    "felemelését": "felemelés",
    "felemásra": "felemás",
    "felemészti": "felemészt",
    "felerősítette": "felerősít",
    "felerősítsem": "felerősít",
    "felerősödtek": "felerősödik",
    "feleselésekkel": "feleselés",
    "feleselést": "feleselés",
    "feleslegesnek": "felesleges",
    "feleslegessé": "felesleges",
    "feleségben": "feleség",
    "felesége": "feleség",
    "feleségek": "feleség",
    "feleségem": "feleség",
    "feleségemmel": "feleség",
    "feleségemnek": "feleség",
    "feleségéhez": "feleség",
    "feleségének": "feleség",
    "feleségénél": "feleség",
    "feleségére": "feleség",
    "feleségét": "feleség",
    "feleségével": "feleség",
    "feleségük": "feleség",
    "feleségül": "feleség",
    "feleségünk": "feleség",
    "feleségünket": "feleség",
    "felet": "fél",
    "felette": "felett",
    "felettiek": "feletti",
    "felették": "feleszik",
    "felettük": "felett",
    "felfedezem": "felfedez",
    "felfedezett": "felfedez",
    "felfedezik": "felfedez",
    "felfedeznek": "felfedez",
    "felfedezni": "felfedez",
    "felfedeztem": "felfedez",
    "felfedezték": "felfedez",
    "felfedezze": "felfedez",
    "felfedezzék": "felfedez",
    "felfedezése": "felfedezés",
    "felfedezéseket": "felfedezés",
    "felfedezésként": "felfedezés",
    "felfedezésszámba": "felfedezésszám",
    "felfedezést": "felfedezés",
    "felfedezéséről": "felfedezés",
    "felfedezésével": "felfedezés",
    "felfedezésük": "felfedezés",
    "felfedhetnek": "felfedhet",
    "felfedték": "felfed",
    "felfigyeljen": "felfigyel",
    "felfigyelnek": "felfigyel",
    "felfigyelt": "felfigyel",
    "felfigyeltek": "felfigyelt",
    "felfirkantott": "felfirkant",
    "felfogadja": "felfogad",
    "felfogadni": "felfogad",
    "felfoghatja": "felfoghat",
    "felfogja": "felfog",
    "felfogni": "felfog",
    "felfogta": "felfog",
    "felfogásában": "felfogás",
    "felfogásán": "felfogás",
    "felfogását": "felfogás",
    "felfogásával": "felfogás",
    "felfogóképességét": "felfogóképesség",
    "felforgatja": "felforgat",
    "felforralni": "felforral",
    "felforrt": "felforr",
    "felfrissítették": "felfrissítet",
    "felfrissítik": "felfrissít",
    "felfrissítsék": "felfrissít",
    "felfújt": "felfúj",
    "felfújta": "felfúj",
    "felfüggessze": "felfüggeszt",
    "felfüggesztéséről": "felfüggesztés",
    "felfüggesztését": "felfüggesztés",
    "felfüggesztéséért": "felfüggesztés",
    "felfűtötte": "felfűt",
    "felgyorsult": "felgyorsul",
    "felgyújtani": "felgyújt",
    "felgyújtják": "felgyújt",
    "felgöngyölíteni": "felgöngyölít",
    "felhagynak": "felhagy",
    "felhagysz": "felhagy",
    "felhagytak": "felhagy",
    "felhajtott": "felhajt",
    "felhajtásra": "felhajtás",
    "felhallatszott": "felhallatszik",
    "felhalmozott": "felhalmoz",
    "felhalmozása": "felhalmozás",
    "felhalmozását": "felhalmozás",
    "felhalmozódott": "felhalmozódik",
    "felhalmozódása": "felhalmozódás",
    "felhangok": "felhang",
    "felharsant": "felharsan",
    "felhasogatni": "felhasogat",
    "felhasználhassák": "felhasználhat",
    "felhasználni": "felhasznál",
    "felhasználtam": "felhasznált",
    "felhasználása": "felhasználás",
    "felhasználások": "felhasználás",
    "felhasználásuk": "felhasználás",
    "felhasználásának": "felhasználás",
    "felhasználására": "felhasználás",
    "felhasználását": "felhasználás",
    "felhasználásával": "felhasználás",
    "felhasználók": "felhasználó",
    "felhasználóknak": "felhasználó",
    "felhatalmazhatja": "felhatalmazhat",
    "felhatalmaztak": "felhatalmaz",
    "felhatalmazták": "felhatalmaz",
    "felhatalmazása": "felhatalmazás",
    "felhozott": "felhoz",
    "felhozta": "felhoz",
    "felháborodnál": "felháborodik",
    "felháborodott": "felháborodik",
    "felháborodását": "felháborodás",
    "felhánytak": "felhányt",
    "felhívhassák": "felhívhat",
    "felhívják": "felhív",
    "felhívni": "felhív",
    "felhívott": "felhív",
    "felhívta": "felhív",
    "felhívtak": "felhív",
    "felhívásban": "felhívás",
    "felhívásukban": "felhívás",
    "felhívását": "felhívás",
    "felhördülést": "felhördülés",
    "felhúzott": "felhúz",
    "felhői": "felhő",
    "felhők": "felhő",
    "felhőkbe": "felhő",
    "felhőkben": "felhő",
    "felhőket": "felhő",
    "felhőzete": "felhőzet",
    "felibe": "feli",
    "felidézett": "felidéz",
    "felidézettek": "felidézett",
    "felidézi": "felidéz",
    "felidézik": "felidéz",
    "felidézni": "felidéz",
    "feliratnak": "felirat",
    "feliratokat": "felirat",
    "feliratokkal": "felirat",
    "feliratot": "felirat",
    "felirattal": "felirat",
    "felismerem": "felismer",
    "felismerhetetlenné": "felismerhetetlen",
    "felismerhetetlenségig": "felismerhetetlenség",
    "felismerhetők": "felismerhető",
    "felismerik": "felismer",
    "felismerjék": "felismer",
    "felismerjük": "felismer",
    "felismerni": "felismer",
    "felismernie": "felismer",
    "felismerte": "felismer",
    "felismerték": "felismer",
    "feliszapolódások": "feliszapolódás",
    "felitatni": "felitat",
    "felizgatására": "felizgatás",
    "felizgult": "felizgul",
    "felizzott": "felizzik",
    "feljegyezhetne": "feljegyezhet",
    "feljegyeztem": "feljegyez",
    "feljegyezték": "feljegyez",
    "feljegyzett": "feljegyez",
    "feljegyzések": "feljegyzés",
    "feljegyzésekben": "feljegyzés",
    "feljegyzéseket": "feljegyzés",
    "feljegyzést": "feljegyzés",
    "feljelentenek": "feljelent",
    "feljelenteni": "feljelent",
    "feljelenteném": "feljelent",
    "feljelentett": "feljelent",
    "feljelentette": "feljelent",
    "feljelentették": "feljelentet",
    "feljelenthette": "feljelenthet",
    "feljelentik": "feljelent",
    "feljelentsek": "feljelent",
    "feljelentsen": "feljelent",
    "feljelentése": "feljelentés",
    "feljelentést": "feljelentés",
    "feljelentésére": "feljelentés",
    "feljárják": "feljár",
    "feljött": "feljön",
    "feljöttek": "feljön",
    "feljövetelének": "feljövetel",
    "felkapott": "felkap",
    "felkapta": "felkap",
    "felkavarhatja": "felkavarhat",
    "felkavartak": "felkavart",
    "felkelek": "felkel",
    "felkeljen": "felkel",
    "felkeljenek": "felkel",
    "felkelnek": "felkel",
    "felkelni": "felkel",
    "felkelt": "felkel",
    "felkeltem": "felkelt",
    "felkelteni": "felkelt",
    "felkelti": "felkelt",
    "felkeltünk": "felkelt",
    "felkelésről": "felkelés",
    "felkelést": "felkelés",
    "felkelünk": "felkel",
    "felkelők": "felkelő",
    "felkelőket": "felkelő",
    "felkelőkkel": "felkelő",
    "felkelőt": "felkelő",
    "felkerekedtünk": "felkerekedik",
    "felkeresett": "felkeres",
    "felkeresi": "felkeres",
    "felkereste": "felkeres",
    "felkeresték": "felkeres",
    "felkerüljön": "felkerül",
    "felkerülését": "felkerülés",
    "felkiáltójelek": "felkiáltójel",
    "felkukorékolnak": "felkukorékol",
    "felkutatja": "felkutat",
    "felkutatni": "felkutat",
    "felkutatása": "felkutatás",
    "felkutatásakor": "felkutatás",
    "felkutatására": "felkutatás",
    "felkérte": "felkér",
    "felkérést": "felkérés",
    "felkérésének": "felkérés",
    "felkérését": "felkérés",
    "felkészülhessen": "felkészülhet",
    "felkészülnek": "felkészül",
    "felkészült": "felkészül",
    "felkészültebb": "felkészült",
    "felkészültem": "felkészül",
    "felkészülten": "felkészült",
    "felkészültsége": "felkészültség",
    "felkészültséget": "felkészültség",
    "felkészültünk": "felkészült",
    "felkészülésben": "felkészülés",
    "felkészülésről": "felkészülés",
    "felkészülést": "felkészülés",
    "felkínálja": "felkínál",
    "felköszöntsünk": "felköszönt",
    "felkötött": "felköt",
    "fellebbezett": "fellebbez",
    "fellebbezhetnél": "fellebbezhet",
    "fellebbezéssel": "fellebbezés",
    "fellebbezést": "fellebbezés",
    "fellegvára": "fellegvár",
    "fellegvárba": "fellegvár",
    "fellegvárban": "fellegvár",
    "fellegvárból": "fellegvár",
    "fellegzett": "fellegez",
    "fellelhesse": "fellelhet",
    "fellelkesített": "fellelkesít",
    "fellelni": "fellel",
    "fellendítése": "fellendítés",
    "fellendültek": "fellendül",
    "fellendülést": "fellendülés",
    "fellázadjon": "fellázad",
    "fellázadnak": "fellázad",
    "fellázadni": "fellázad",
    "fellélegezhetnek": "fellélegezhet",
    "fellélegzése": "fellélegzés",
    "fellépett": "fellép",
    "fellépnek": "fellép",
    "felléptek": "fellép",
    "fellépése": "fellépés",
    "fellépéssel": "fellépés",
    "fellépést": "fellépés",
    "fellépésért": "fellépés",
    "fellépésével": "fellépés",
    "felmegyünk": "felmegy",
    "felmelegedést": "felmelegedés",
    "felment": "felmegy",
    "felmentek": "felment",
    "felmentette": "felment",
    "felmentése": "felmentés",
    "felmentésért": "felmentés",
    "felmerült": "felmerül",
    "felmerültek": "felmerül",
    "felmondja": "felmond",
    "felmondom": "felmond",
    "felmondta": "felmond",
    "felmondtak": "felmond",
    "felmondtam": "felmond",
    "felmondták": "felmond",
    "felmondunk": "felmond",
    "felmondást": "felmondás",
    "felmondásával": "felmondás",
    "felmutatni": "felmutat",
    "felmutatta": "felmutat",
    "felmászni": "felmászik",
    "felmászott": "felmászik",
    "felmásztak": "felmászik",
    "felmérjék": "felmér",
    "felmérni": "felmér",
    "felmérte": "felmér",
    "felmérték": "felmér",
    "felmérése": "felmérés",
    "felmérései": "felmérés",
    "felmérések": "felmérés",
    "felmérésnek": "felmérés",
    "felmérésében": "felmérés",
    "felmérését": "felmérés",
    "felnevetése": "felnevetés",
    "felnyitott": "felnyit",
    "felnégyeléssel": "felnégyelés",
    "felnézett": "felnéz",
    "felnövi": "felnő",
    "felnőnek": "felnő",
    "felnőtt": "felnő",
    "felnőttek": "felnőtt",
    "felnőtteket": "felnőtt",
    "felnőtteknél": "felnőtt",
    "feloldani": "felold",
    "feloldották": "felold",
    "feloldásában": "feloldás",
    "feloldódott": "feloldódik",
    "felolvassa": "felolvas",
    "felolvastál": "felolvas",
    "felolvasásokat": "felolvasás",
    "felolvasásokon": "felolvasás",
    "felolvasást": "felolvasás",
    "felordított": "felordít",
    "feloszlatott": "feloszlat",
    "feloszlatták": "feloszlat",
    "feloszlott": "feloszlik",
    "felosztja": "feloszt",
    "felosztották": "feloszt",
    "felosztása": "felosztás",
    "felosztására": "felosztás",
    "felpakoltunk": "felpakolt",
    "felpanaszolhatnánk": "felpanaszolhat",
    "felpattant": "felpattan",
    "felpillantott": "felpillant",
    "felpuffadt": "felpuffad",
    "felpénzt": "felpénz",
    "felpörgesse": "felpörget",
    "felpúpozott": "felpúpoz",
    "felragasztott": "felragaszt",
    "felragyogott": "felragyog",
    "felrakják": "felrak",
    "felrakott": "felrak",
    "felriadt": "felriad",
    "felrobbant": "felrobban",
    "felrobbantak": "felrobbant",
    "felrobbantani": "felrobbant",
    "felrobbantott": "felrobbant",
    "felrobbantotta": "felrobbant",
    "felrobbantották": "felrobbant",
    "felrángatnak": "felrángat",
    "felrántotta": "felránt",
    "felsorakozásához": "felsorakozás",
    "felsorakozását": "felsorakozás",
    "felsorolni": "felsorol",
    "felsorolt": "felsorol",
    "felsorolta": "felsorol",
    "felsorolása": "felsorolás",
    "felsorolásban": "felsorolás",
    "felszabadult": "felszabadul",
    "felszabadította": "felszabadít",
    "felszabadítása": "felszabadítás",
    "felszakadt": "felszakad",
    "felszakította": "felszakít",
    "felszedelőzködtünk": "felszedelőzködik",
    "felszedett": "felszed",
    "felszedni": "felszed",
    "felszedésük": "felszedés",
    "felszentelni": "felszentel",
    "felszerelt": "felszerel",
    "felszereltsége": "felszereltség",
    "felszereltségét": "felszereltség",
    "felszerelése": "felszerelés",
    "felszerelésének": "felszerelés",
    "felszolgált": "felszolgál",
    "felszállni": "felszáll",
    "felszállt": "felszáll",
    "felszálltam": "felszállt",
    "felszámolhatja": "felszámolhat",
    "felszámolják": "felszámol",
    "felszámolnák": "felszámol",
    "felszámolta": "felszámol",
    "felszámolásai": "felszámolás",
    "felszámolástól": "felszámolás",
    "felszámolására": "felszámolás",
    "felszámolását": "felszámolás",
    "felszámolásával": "felszámolás",
    "felszámolót": "felszámoló",
    "felszántott": "felszánt",
    "felszínen": "felszín",
    "felszínesen": "felszínes",
    "felszínét": "felszín",
    "felszívódottak": "felszívódott",
    "felszólalni": "felszólal",
    "felszólalt": "felszólal",
    "felszólalásában": "felszólalás",
    "felszólalását": "felszólalás",
    "felszólalók": "felszólaló",
    "felszólítja": "felszólít",
    "felszólítják": "felszólít",
    "felszólított": "felszólít",
    "felszólította": "felszólít",
    "felszólítottak": "felszólított",
    "felszólították": "felszólít",
    "felszólításul": "felszólítás",
    "felszólításának": "felszólítás",
    "felsírt": "felsír",
    "felsöpörte": "felsöpör",
    "felsőbb": "felső",
    "felsőbbrendűnek": "felsőbbrendű",
    "felsőbbségét": "felsőbbség",
    "felsőházban": "felsőház",
    "felsőkabátját": "felsőkabát",
    "felsőkarjára": "felsőkar",
    "felsőt": "felső",
    "felsőtesttel": "felsőtest",
    "felsőtestét": "felsőtest",
    "feltalálnak": "feltalál",
    "feltalálták": "feltalál",
    "feltalálása": "feltalálás",
    "feltalálásának": "feltalálás",
    "feltalálásával": "feltalálás",
    "feltartóztassa": "feltartóztat",
    "feltartóztathatatlanul": "feltartóztathatatlan",
    "feltehetsz": "feltehet",
    "feltehetően": "feltehető",
    "feltekerni": "felteker",
    "feltekert": "felteker",
    "felteszem": "feltesz",
    "feltett": "feltesz",
    "feltette": "feltesz",
    "feltevést": "feltevés",
    "feltolakodtunk": "feltolakodik",
    "feltámadása": "feltámadás",
    "feltápászkodni": "feltápászkodik",
    "feltápászkodott": "feltápászkodik",
    "feltárják": "feltár",
    "feltárni": "feltár",
    "feltárnia": "feltár",
    "feltárása": "feltárás",
    "feltárásnak": "feltárás",
    "feltárásába": "feltárás",
    "feltárásában": "feltárás",
    "feltárásáról": "feltárás",
    "feltárását": "feltárás",
    "feltáróknak": "feltáró",
    "feltérképezni": "feltérképez",
    "feltétele": "feltétel",
    "feltételei": "feltétel",
    "feltételeiket": "feltételeik",
    "feltételeinek": "feltétel",
    "feltételeire": "feltétel",
    "feltételeiről": "feltétel",
    "feltételeit": "feltétel",
    "feltételek": "feltétel",
    "feltételekben": "feltétel",
    "feltételeket": "feltétel",
    "feltételekhez": "feltétel",
    "feltételekkel": "feltétel",
    "feltételeknek": "feltétel",
    "feltételeként": "feltétel",
    "feltételesen": "feltételes",
    "feltételezed": "feltételez",
    "feltételezem": "feltételez",
    "feltételezett": "feltételez",
    "feltételezhetők": "feltételezhető",
    "feltételezi": "feltételez",
    "feltételezik": "feltételez",
    "feltételezni": "feltételez",
    "feltételezte": "feltételez",
    "feltételezték": "feltételez",
    "feltételezést": "feltételezés",
    "feltételezéséhez": "feltételezés",
    "feltétellel": "feltétel",
    "feltételének": "feltétel",
    "feltételéül": "feltétel",
    "feltétlenül": "feltétlen",
    "feltölteni": "feltölt",
    "feltöltse": "feltölt",
    "feltörhetne": "feltörhet",
    "feltörték": "feltörik",
    "feltüntetni": "feltüntet",
    "feltőkésítésére": "feltőkésítés",
    "feltűnne": "feltűnik",
    "feltűnt": "feltűnik",
    "feltűnést": "feltűnés",
    "feltűnőbbé": "feltűnő",
    "feltűnően": "feltűnő",
    "feltűrt": "feltűr",
    "felugrom": "felugrik",
    "felugrott": "felugrik",
    "felugrottak": "felugrott",
    "felugráltak": "felugrált",
    "felvagdaltak": "felvagdalt",
    "felvegye": "felvesz",
    "felvehesse": "felvehet",
    "felvenni": "felvesz",
    "felvert": "felver",
    "felveszem": "felveszik",
    "felveszi": "felveszik",
    "felveszik": "felvesz",
    "felvetette": "felvetet",
    "felvett": "felvesz",
    "felvette": "felvesz",
    "felvették": "felvesz",
    "felvetése": "felvetés",
    "felvetődött": "felvetődik",
    "felvevőgéppel": "felvevőgép",
    "felvezetett": "felvezet",
    "felvezetni": "felvezet",
    "felvezette": "felvezet",
    "felvezettek": "felvezet",
    "felvezetésének": "felvezetés",
    "felvezetői": "felvezető",
    "felvidékről": "felvidék",
    "felvigyázása": "felvigyázás",
    "felvillant": "felvillan",
    "felvillanások": "felvillanás",
    "felvillanásokat": "felvillanás",
    "felvilágosultnak": "felvilágosult",
    "felvilágosított": "felvilágosít",
    "felvilágosítása": "felvilágosítás",
    "felvilágosításokat": "felvilágosítás",
    "felvilágosításokkal": "felvilágosítás",
    "felvilágosítást": "felvilágosítás",
    "felvilágosításért": "felvilágosítás",
    "felvirágoztatásához": "felvirágoztatás",
    "felviszik": "felvisz",
    "felvitele": "felvitel",
    "felvonultunk": "felvonult",
    "felvonulások": "felvonulás",
    "felvonulásokat": "felvonulás",
    "felvonulásokkal": "felvonulás",
    "felvonulásokon": "felvonulás",
    "felvonók": "felvonó",
    "felvonókezelők": "felvonókezelő",
    "felvonóval": "felvonó",
    "felvágni": "felvág",
    "felvállalja": "felvállal",
    "felváltotta": "felvált",
    "felváltsa": "felvált",
    "felvázolt": "felvázol",
    "felvétele": "felvétel",
    "felvételeit": "felvétel",
    "felvételek": "felvétel",
    "felvételekor": "felvétel",
    "felvételen": "felvétel",
    "felvételinek": "felvételi",
    "felvételinél": "felvételi",
    "felvételit": "felvételi",
    "felvételizni": "felvételiz",
    "felvételizők": "felvételiző",
    "felvételén": "felvétel",
    "felvételére": "felvétel",
    "felvételét": "felvétel",
    "felvételével": "felvétel",
    "felvételükkel": "felvétel",
    "felzárkóztatását": "felzárkóztatás",
    "felzárkózást": "felzárkózás",
    "felzörgetni": "felzörget",
    "feláldozni": "feláldozik",
    "feláldozta": "feláldozik",
    "feláldozza": "feláldozik",
    "feláldozzák": "feláldozik",
    "felállt": "feláll",
    "felálltunk": "felállt",
    "felállítani": "felállít",
    "felállított": "felállít",
    "felállította": "felállít",
    "felállították": "felállít",
    "felállítására": "felállítás",
    "felállításával": "felállítás",
    "felé": "fel",
    "felébe": "fele",
    "felében": "fele",
    "felébredt": "felébred",
    "felébredtem": "felébredt",
    "felébredéseiben": "felébredés",
    "felébredését": "felébredés",
    "felébreszthette": "felébreszthet",
    "feléből": "fele",
    "feléje": "fele",
    "feléjük": "felé",
    "feléledt": "feléled",
    "feléledtek": "feléledt",
    "felélénkült": "felélénkül",
    "felén": "fele",
    "felének": "fele",
    "felénk": "felé",
    "felénél": "fele",
    "felépített": "felépít",
    "felépítése": "felépítés",
    "felépítéséhez": "felépítés",
    "felépítésére": "felépítés",
    "felépítésük": "felépítés",
    "felépülni": "felépül",
    "felépültek": "felépül",
    "felére": "fele",
    "felértékelődését": "felértékelődés",
    "felértékelődött": "felértékelődik",
    "feléről": "fele",
    "felét": "fele",
    "felírni": "felír",
    "felírt": "felír",
    "felírtam": "felírt",
    "felírták": "felír",
    "felöleli": "felölel",
    "felölteni": "felölt",
    "felölti": "felölt",
    "felöltözött": "felöltözik",
    "felötlött": "felötlik",
    "felújítani": "felújít",
    "felújított": "felújít",
    "felújították": "felújít",
    "felújítása": "felújítás",
    "felújításra": "felújítás",
    "felújításáról": "felújítás",
    "felújítását": "felújítás",
    "felüdült": "felüdül",
    "felügyeletet": "felügyelet",
    "felügyeletének": "felügyelet",
    "felügyeletére": "felügyelet",
    "felügyeletét": "felügyelet",
    "felügyeli": "felügyel",
    "felügyelni": "felügyel",
    "felügyelője": "felügyelő",
    "felükön": "fél",
    "felül": "fel",
    "felülbélyegzéssel": "felülbélyegzés",
    "felülete": "felület",
    "felületei": "felület",
    "felületesen": "felületes",
    "felülettől": "felület",
    "felületéről": "felület",
    "felüli": "felül",
    "felüliek": "felüli",
    "felülieknek": "felüli",
    "felülmúlja": "felülmúlik",
    "felülnézetből": "felülnézet",
    "felült": "felül",
    "felültünk": "felült",
    "felőle": "felől",
    "felőlük": "felől",
    "felőrli": "felőröl",
    "felőrlik": "felőröl",
    "feneke": "fenék",
    "fenekébe": "fenék",
    "fenekén": "fenék",
    "fenekéről": "fenék",
    "fennakadt": "fennakad",
    "fennakadásokra": "fennakadás",
    "fennhatóságát": "fennhatóság",
    "fennmaradjon": "fennmarad",
    "fennmaradnak": "fennmarad",
    "fennmaradt": "fennmarad",
    "fennmaradtak": "fennmaradt",
    "fennmaradását": "fennmaradás",
    "fennsíkon": "fennsík",
    "fenntartani": "fenntart",
    "fenntartanák": "fenntart",
    "fenntartja": "fenntart",
    "fenntartják": "fenntart",
    "fenntartott": "fenntart",
    "fenntartotta": "fenntart",
    "fenntartottuk": "fenntart",
    "fenntartották": "fenntart",
    "fenntartsa": "fenntart",
    "fenntartsák": "fenntart",
    "fenntartása": "fenntartás",
    "fenntartásai": "fenntartás",
    "fenntartásait": "fenntartás",
    "fenntartásokat": "fenntartás",
    "fenntartásában": "fenntartás",
    "fenntartásához": "fenntartás",
    "fenntartására": "fenntartás",
    "fenntartását": "fenntartás",
    "fenntartói": "fenntartó",
    "fenntartója": "fenntartó",
    "fennállnak": "fennáll",
    "fennállni": "fennáll",
    "fennállt": "fennáll",
    "fennállása": "fennállás",
    "fennállásuk": "fennállás",
    "fennállására": "fennállás",
    "fenségét": "fenség",
    "fent": "fen",
    "fentebb": "fent",
    "fentiekből": "fenti",
    "fentieket": "fenti",
    "fentiekre": "fenti",
    "fenyegetett": "fenyeget",
    "fenyegetettségben": "fenyegetettség",
    "fenyegeti": "fenyeget",
    "fenyegetni": "fenyeget",
    "fenyegette": "fenyeget",
    "fenyegették": "fenyeget",
    "fenyegetéssel": "fenyegetés",
    "fenyegetően": "fenyegető",
    "fenyegetőztek": "fenyegetőz",
    "fenyegetőzött": "fenyegetőz",
    "fenyveseket": "fenyves",
    "fenébe": "fene",
    "fenékre": "fenék",
    "fenén": "fene",
    "fenét": "fene",
    "ferdesége": "ferdeség",
    "ferdén": "ferde",
    "fertőzte": "fertőz",
    "festeni": "fest",
    "festett": "fest",
    "festette": "festet",
    "festettek": "festett",
    "festették": "festet",
    "festik": "fest",
    "festményt": "festmény",
    "festékeit": "festék",
    "festéket": "festék",
    "festékkel": "festék",
    "festészettől": "festészet",
    "festői": "festő",
    "festőiskolásokat": "festőiskolás",
    "festők": "festő",
    "festőkre": "festő",
    "festőktől": "festő",
    "festőnőnek": "festőnő",
    "festőnőt": "festőnő",
    "feszegetésével": "feszegetés",
    "feszesebb": "feszes",
    "feszességét": "feszesség",
    "fesztelenül": "fesztelen",
    "fesztiválján": "fesztivál",
    "fesztiválját": "fesztivál",
    "fesztiválon": "fesztivál",
    "feszítette": "feszít",
    "feszítettek": "feszített",
    "feszíti": "feszít",
    "feszítik": "feszít",
    "feszítését": "feszítés",
    "feszül": "fesz",
    "feszülnek": "feszül",
    "feszülten": "feszült",
    "feszültsége": "feszültség",
    "feszültségek": "feszültség",
    "feszültségen": "feszültség",
    "feszültséget": "feszültség",
    "feszültséggel": "feszültség",
    "feszültségre": "feszültség",
    "feszültségén": "feszültség",
    "feszültté": "feszült",
    "fetrengeni": "fetreng",
    "fetrengett": "fetreng",
    "fetrengtél": "fetreng",
    "fia": "fiú",
    "fiai": "fiú",
    "fiaik": "fiú",
    "fiaimnak": "fiú",
    "fiaink": "fiú",
    "fiaitoknak": "fiú",
    "fiam": "fiú",
    "fiamat": "fiú",
    "fiatalabb": "fiatal",
    "fiatalabbak": "fiatal",
    "fiatalabbaknak": "fiatal",
    "fiatalemberrel": "fiatalember",
    "fiatalembert": "fiatalember",
    "fiatalja": "fiatal",
    "fiatalkora": "fiatalkor",
    "fiatalkoromban": "fiatalkorom",
    "fiatalkorában": "fiatalkor",
    "fiatalkorának": "fiatalkor",
    "fiatalkorúak": "fiatalkorú",
    "fiatalnak": "fiatal",
    "fiatalok": "fiatal",
    "fiatalokból": "fiatal",
    "fiataloknak": "fiatal",
    "fiataloktól": "fiatal",
    "fiatalon": "fiatal",
    "fiatalosan": "fiatalos",
    "fiatalsága": "fiatalság",
    "fiatalságában": "fiatalság",
    "fiatalságából": "fiatalság",
    "fiatalt": "fiatal",
    "fickóba": "fickó",
    "fickók": "fickó",
    "fickónak": "fickó",
    "figurákkal": "figura",
    "figurára": "figura",
    "figurát": "figura",
    "figurával": "figura",
    "figyeld": "figyel",
    "figyelek": "figyel",
    "figyelem": "figyel",
    "figyelembe": "figyelem",
    "figyelembevételével": "figyelembevétel",
    "figyelemmel": "figyelem",
    "figyelemre": "figyelem",
    "figyelemreméltóan": "figyelemreméltó",
    "figyelemreméltóbb": "figyelemreméltó",
    "figyelgetik": "figyelget",
    "figyeli": "figyel",
    "figyelik": "figyel",
    "figyelje": "figyel",
    "figyeljen": "figyel",
    "figyeljenek": "figyel",
    "figyeljetek": "figyel",
    "figyelme": "figyelem",
    "figyelmesen": "figyelmes",
    "figyelmességgel": "figyelmesség",
    "figyelmet": "figyelem",
    "figyelmeztetett": "figyelmeztet",
    "figyelmezteti": "figyelmeztet",
    "figyelmeztetlek": "figyelmeztet",
    "figyelmeztetni": "figyelmeztet",
    "figyelmeztette": "figyelmeztet",
    "figyelmeztettelek": "figyelmeztet",
    "figyelmeztetése": "figyelmeztetés",
    "figyelmeztetéssel": "figyelmeztetés",
    "figyelmeztetésül": "figyelmeztetés",
    "figyelmeztetünk": "figyelmeztet",
    "figyelmébe": "figyelem",
    "figyelmét": "figyelem",
    "figyelmüket": "figyelem",
    "figyelnek": "figyel",
    "figyelni": "figyel",
    "figyelsz": "figyel",
    "figyelt": "figyel",
    "figyelte": "figyel",
    "figyeltek": "figyelt",
    "figyeltem": "figyelt",
    "filharmonikusokat": "filharmonikus",
    "fillérrel": "fillér",
    "fillért": "fillér",
    "fillérükbe": "fillér",
    "filmalkotást": "filmalkotás",
    "filmbemutatókat": "filmbemutató",
    "filmbemutatón": "filmbemutató",
    "filmeken": "film",
    "filmeket": "film",
    "filmekkel": "film",
    "filmet": "film",
    "filmgyárnak": "filmgyár",
    "filmhíradóban": "filmhíradó",
    "filmjét": "film",
    "filmrajongók": "filmrajongó",
    "filmrendezőt": "filmrendező",
    "filmszínházra": "filmszínház",
    "filmvásznon": "filmvászon",
    "filozófiában": "filozófia",
    "filozófiájuk": "filozófia",
    "filozófiájával": "filozófia",
    "filozófusok": "filozófus",
    "finanszírozhatók": "finanszírozható",
    "finanszírozta": "finanszíroz",
    "finanszírozták": "finanszíroz",
    "finanszírozza": "finanszíroz",
    "finanszírozzák": "finanszíroz",
    "finanszírozásban": "finanszírozás",
    "finanszírozásra": "finanszírozás",
    "finanszírozást": "finanszírozás",
    "finanszírozásának": "finanszírozás",
    "finanszírozására": "finanszírozás",
    "finanszírozásáról": "finanszírozás",
    "finanszírozását": "finanszírozás",
    "finanszírozásával": "finanszírozás",
    "finomabban": "finom",
    "finoman": "finom",
    "finomította": "finomít",
    "finomítsd": "finomít",
    "fintorai": "fintor",
    "fintorral": "fintor",
    "fináncnak": "finánc",
    "firkák": "firka",
    "firkálnak": "firkál",
    "firkált": "firkál",
    "firtatják": "firtat",
    "firtatott": "firtat",
    "fittyet": "fitty",
    "fityinggel": "fitying",
    "fityingnek": "fitying",
    "fivérek": "fivér",
    "fizesse": "fizet",
    "fizessen": "fizet",
    "fizessék": "fizet",
    "fizetett": "fizet",
    "fizetheti": "fizethet",
    "fizethetik": "fizethet",
    "fizeti": "fizet",
    "fizetik": "fizet",
    "fizetjük": "fizet",
    "fizetne": "fizet",
    "fizetnek": "fizet",
    "fizetni": "fizet",
    "fizetnie": "fizet",
    "fizetniük": "fizet",
    "fizetné": "fizet",
    "fizetnünk": "fizet",
    "fizette": "fizet",
    "fizettek": "fizet",
    "fizették": "fizet",
    "fizettél": "fizet",
    "fizettünk": "fizet",
    "fizetések": "fizetés",
    "fizetéseknek": "fizetés",
    "fizetésemelésre": "fizetésemelés",
    "fizetésemelést": "fizetésemelés",
    "fizetésképtelenséget": "fizetésképtelenség",
    "fizetést": "fizetés",
    "fizetésére": "fizetés",
    "fizetésünket": "fizetés",
    "fizetünk": "fizet",
    "fizetők": "fizető",
    "fizetőpincérnek": "fizetőpincér",
    "fizetővé": "fizető",
    "fizikainak": "fizikaín",
    "fiában": "fiú",
    "fiából": "fiú",
    "fiának": "fiú",
    "fiára": "fiú",
    "fiát": "fiú",
    "fiókba": "fiók",
    "fiókban": "fiók",
    "fiókból": "fiók",
    "fiókintézménye": "fiókintézmény",
    "fiókintézményeikkel": "fiókintézmény",
    "fiókja": "fiók",
    "fiókjai": "fiók",
    "fiókjaiban": "fiók",
    "fiókjából": "fiók",
    "fiókját": "fiók",
    "fiókot": "fiók",
    "fiúban": "fiú",
    "fiúcskák": "fiúcská",
    "fiúk": "fiú",
    "fiúk-lányok": "fiú-lány",
    "fiúkat": "fiú",
    "fiúkban": "fiú",
    "fiúkból": "fiú",
    "fiúkkal": "fiú",
    "fiúknak": "fiú",
    "fiúkra": "fiú",
    "fiúként": "fiú",
    "fiúnak": "fiú",
    "fiúra": "fiú",
    "fiúsan": "fiús",
    "fiút": "fiú",
    "fiúval": "fiú",
    "flamingók": "flamingó",
    "floppylemezen": "floppylemez",
    "flottát": "flotta",
    "fluktuációban": "fluktuáció",
    "fluktuációt": "fluktuáció",
    "flótáját": "flóta",
    "focistája": "focista",
    "fodrozott": "fodroz",
    "foga": "fog",
    "fogad": "fog",
    "fogadalmat": "fogadalom",
    "fogadat": "fog",
    "fogadhatnak": "fogadhat",
    "fogadhatott": "fogadhat",
    "fogadja": "fogad",
    "fogadják": "fogad",
    "fogadkoztak": "fogadkozik",
    "fogadkozások": "fogadkozás",
    "fogadni": "fogad",
    "fogadnia": "fogad",
    "fogadniuk": "fogad",
    "fogadott": "fogad",
    "fogadta": "fogad",
    "fogadtak": "fogad",
    "fogadtam": "fogad",
    "fogadtatni": "fogadtat",
    "fogadtatásával": "fogadtatás",
    "fogadták": "fogad",
    "fogadásainak": "fogadás",
    "fogadásukra": "fogadás",
    "fogadására": "fogadás",
    "fogadóba": "fogadó",
    "fogadószobába": "fogadószoba",
    "fogadóépülete": "fogadóépület",
    "fogai": "fog",
    "fogaim": "fog",
    "fogait": "fog",
    "fogakon": "fog",
    "fogalma": "fogalom",
    "fogalmai": "fogalom",
    "fogalmaink": "fogalom",
    "fogalmak": "fogalom",
    "fogalmakban": "fogalom",
    "fogalmakkal": "fogalom",
    "fogalmam": "fogalom",
    "fogalmat": "fogalom",
    "fogalmazhatjuk": "fogalmazhat",
    "fogalmazni": "fogalmaz",
    "fogalmazom": "fogalmaz",
    "fogalmazott": "fogalmaz",
    "fogalmazta": "fogalmaz",
    "fogalmaztak": "fogalmaz",
    "fogalmazták": "fogalmaz",
    "fogalmazványomat": "fogalmazvány",
    "fogalmazványt": "fogalmazvány",
    "fogalmazásba": "fogalmazás",
    "fogalmuk": "fogalom",
    "fogalmunknak": "fogalom",
    "fogalmába": "fogalom",
    "fogalmához": "fogalom",
    "fogalmára": "fogalom",
    "fogalmáról": "fogalom",
    "fogalmát": "fogalom",
    "fogalomként": "fogalom",
    "fogalomkörét": "fogalomkör",
    "fogalomvilágából": "fogalomvilág",
    "fogamat": "fog",
    "foganatosíthatnak": "foganatosíthat",
    "fogantyúval": "fogantyú",
    "fogat": "fog",
    "fogatlanná": "fogatlan",
    "fogazatát": "fogazat",
    "foghatja": "foghat",
    "fogházba": "fogház",
    "fogházban": "fogház",
    "fogházbüntetésre": "fogházbüntetés",
    "fogházkapuban": "fogházkapu",
    "fogházudvaron": "fogházudvar",
    "fogházőrök": "fogházőr",
    "fogházőröknek": "fogházőr",
    "fogházőröktől": "fogházőr",
    "foghíjtelkek": "foghíjtelek",
    "fogja": "fog",
    "fogjanak": "fog",
    "fogjon": "fog",
    "fogjuk": "fog",
    "fogjunk": "fog",
    "fogják": "fog",
    "fogjátok": "fog",
    "fogkeféje": "fogkefe",
    "foglak": "fog",
    "foglakozik": "foglakoz",
    "foglalatoskodott": "foglalatoskodik",
    "foglalhatja": "foglalhat",
    "foglalja": "foglal",
    "foglalják": "foglal",
    "foglalkozhatunk": "foglalkozhat",
    "foglalkozna": "foglalkozik",
    "foglalkoznak": "foglalkozik",
    "foglalkozni": "foglalkozik",
    "foglalkoznia": "foglalkozik",
    "foglalkozom": "foglalkozik",
    "foglalkozott": "foglalkozik",
    "foglalkoztak": "foglalkozik",
    "foglalkoztatja": "foglalkoztat",
    "foglalkoztatott": "foglalkoztat",
    "foglalkoztatottak": "foglalkoztatott",
    "foglalkoztatottakhoz": "foglalkoztatott",
    "foglalkoztatta": "foglalkoztat",
    "foglalkoztatták": "foglalkoztat",
    "foglalkoztatása": "foglalkoztatás",
    "foglalkoztatásra": "foglalkoztatás",
    "foglalkoztatásért": "foglalkoztatás",
    "foglalkozunk": "foglalkozik",
    "foglalkozzanak": "foglalkozik",
    "foglalkozzék": "foglalkozik",
    "foglalkozások": "foglalkozás",
    "foglalkozásokon": "foglalkozás",
    "foglalkozásra": "foglalkozás",
    "foglalnak": "foglal",
    "foglalni": "foglal",
    "foglalná": "foglal",
    "foglalt": "foglal",
    "foglalta": "foglal",
    "foglaltak": "foglalt",
    "foglaltakkal": "foglalt",
    "foglaltatott": "foglaltatik",
    "foglalták": "foglal",
    "foglalása": "foglalás",
    "foglyok": "fogoly",
    "foglyokat": "fogoly",
    "foglyokkal": "fogoly",
    "foglyoknak": "fogoly",
    "foglyokról": "fogoly",
    "foglyoktól": "fogoly",
    "foglyon": "fogoly",
    "foglyot": "fogoly",
    "foglyul": "fogoly",
    "fognak": "fog",
    "fogni": "fog",
    "fognia": "fog",
    "fogná": "fog",
    "fogod": "fog",
    "fogok": "fog",
    "fogolycserére": "fogolycsere",
    "fogolykínzások": "fogolykínzás",
    "fogolynak": "fogoly",
    "fogolyra": "fogoly",
    "fogolyról": "fogoly",
    "fogom": "fog",
    "fogott": "fog",
    "fogsort": "fogsor",
    "fogsz": "fog",
    "fogsága": "fogság",
    "fogságba": "fogság",
    "fogságban": "fogság",
    "fogta": "fog",
    "fogtak": "fog",
    "fogtok": "fog",
    "fogták": "fog",
    "fogunk": "fog",
    "fogyasztani": "fogyaszt",
    "fogyasztott": "fogyaszt",
    "fogyasztása": "fogyasztás",
    "fogyasztáscsökkenést": "fogyasztáscsökkenés",
    "fogyasztásra": "fogyasztás",
    "fogyasztói": "fogyasztó",
    "fogyasztókat": "fogyasztó",
    "fogyasztókkal": "fogyasztó",
    "fogyasztónak": "fogyasztó",
    "fogyasztót": "fogyasztó",
    "fogyasztóval": "fogyasztó",
    "fogyatékosokat": "fogyatékos",
    "fogyjanak": "fogy",
    "fogyna": "fogy",
    "fogynak": "fogy",
    "fogyott": "fogy",
    "fogytál": "fogy",
    "fogyását": "fogyás",
    "fogása": "fogás",
    "fogásaiból": "fogás",
    "fogásnak": "fogás",
    "fogászaton": "fogászat",
    "fogászatot": "fogászat",
    "fogászattal": "fogászat",
    "fogát": "fog",
    "fojtanának": "fojt",
    "fojtott": "fojt",
    "fojtotta": "fojt",
    "fojtottak": "fojtott",
    "fojtottam": "fojtott",
    "fojtottan": "fojtott",
    "foka": "fok",
    "fokig": "fok",
    "fokkal": "fok",
    "fokokat": "fok",
    "fokon": "fok",
    "fokot": "fok",
    "fokozatosan": "fokozatos",
    "fokozatát": "fokozat",
    "fokozni": "fokoz",
    "fokozott": "fokoz",
    "fokozottabb": "fokozott",
    "fokozottan": "fokozott",
    "fokozta": "fokoz",
    "fokozza": "fokoz",
    "fokozódott": "fokozódik",
    "fokozódásával": "fokozódás",
    "fokra": "fok",
    "fokról": "fok",
    "fokát": "fok",
    "foltjai": "folt",
    "foltok": "folt",
    "foltokat": "folt",
    "foltokban": "folt",
    "folton": "folt",
    "foltot": "folt",
    "foltozott": "foltoz",
    "folyadékkal": "folyadék",
    "folyadékot": "folyadék",
    "folyamatait": "folyamat",
    "folyamatban": "folyamat",
    "folyamatként": "folyamat",
    "folyamatnak": "folyamat",
    "folyamatok": "folyamat",
    "folyamaton": "folyamat",
    "folyamatosak": "folyamatos",
    "folyamatosan": "folyamatos",
    "folyamatot": "folyamat",
    "folyamatában": "folyamat",
    "folyamatából": "folyamat",
    "folyamatára": "folyamat",
    "folyamatát": "folyamat",
    "folyamodnak": "folyamodik",
    "folyamodtak": "folyamodik",
    "folyamán": "folyam",
    "folyamát": "folyam",
    "folydogált": "folydogál",
    "folyja": "folyik",
    "folynak": "folyik",
    "folyosóin": "folyosó",
    "folyosójában": "folyosó",
    "folyosóján": "folyosó",
    "folyosókat": "folyosó",
    "folyosókon": "folyosó",
    "folyosólabirintusában": "folyosólabirintus",
    "folyosón": "folyosó",
    "folyosóra": "folyosó",
    "folyosót": "folyosó",
    "folyt": "folyik",
    "folytak": "folyt",
    "folytassa": "folytat",
    "folytat": "folyt",
    "folytathatja": "folytathat",
    "folytathatják": "folytathat",
    "folytatja": "folytat",
    "folytatjuk": "folytat",
    "folytatják": "folytat",
    "folytatnak": "folytat",
    "folytatni": "folytat",
    "folytatná": "folytat",
    "folytatod": "folytat",
    "folytatott": "folytat",
    "folytatta": "folytat",
    "folytattak": "folytat",
    "folytatták": "folytat",
    "folytatunk": "folytat",
    "folytatása": "folytatás",
    "folytatáshoz": "folytatás",
    "folytatásának": "folytatás",
    "folytatására": "folytatás",
    "folytatását": "folytatás",
    "folytatódnak": "folytatódik",
    "folytatódni": "folytatódik",
    "folytatódnia": "folytatódik",
    "folytatódott": "folytatódik",
    "folyton": "folyt",
    "folytonosak": "folytonos",
    "folytonosan": "folytonos",
    "folytonossá": "folytonos",
    "folytonosságot": "folytonosság",
    "folytonosságának": "folytonosság",
    "folyékonyan": "folyékony",
    "folyóan": "folyó",
    "folyóiratban": "folyóirat",
    "folyóiratként": "folyóirat",
    "folyóiratnak": "folyóirat",
    "folyóiratok": "folyóirat",
    "folyóiratokban": "folyóirat",
    "folyóiratot": "folyóirat",
    "folyóiratról": "folyóirat",
    "folyóirattá": "folyóirat",
    "folyón": "folyó",
    "folyónapszámnak": "folyónapszám",
    "folyósítja": "folyósít",
    "folyósított": "folyósít",
    "folyósítását": "folyósítás",
    "fonja": "fon",
    "fonnyadt": "fonnyad",
    "font": "fon",
    "fonta": "fon",
    "fontba": "font",
    "fontolgatja": "fontolgat",
    "fontolgatják": "fontolgat",
    "fontolóra": "fontoló",
    "fontosabb": "fontos",
    "fontosabbaké": "fontos",
    "fontosabbnak": "fontos",
    "fontosak": "fontos",
    "fontosnak": "fontos",
    "fontossá": "fontos",
    "fontosságod": "fontosság",
    "fontosságára": "fontosság",
    "fontosságát": "fontosság",
    "fontosságával": "fontosság",
    "fontért": "font",
    "fonódtak": "fonódik",
    "fonókról": "fonó",
    "fordulatok": "fordulat",
    "fordulatot": "fordulat",
    "fordulhatnak": "fordulhat",
    "fordulj": "fordul",
    "forduljon": "fordul",
    "fordulnak": "fordul",
    "fordulni": "fordul",
    "fordulnia": "fordul",
    "fordulok": "fordul",
    "fordult": "fordul",
    "fordultak": "fordult",
    "fordulóban": "forduló",
    "fordulóiban": "fordulói",
    "fordulóig": "forduló",
    "fordulója": "forduló",
    "fordulójában": "forduló",
    "fordulóján": "forduló",
    "fordulójára": "forduló",
    "fordulóját": "forduló",
    "fordulókat": "forduló",
    "fordulókban": "forduló",
    "fordulót": "forduló",
    "fordulóval": "forduló",
    "fordítanak": "fordít",
    "fordítani": "fordít",
    "fordítaniuk": "fordít",
    "fordítanák": "fordít",
    "fordíthatta": "fordíthat",
    "fordíthattunk": "fordíthat",
    "fordítja": "fordít",
    "fordítjuk": "fordít",
    "fordítják": "fordít",
    "fordított": "fordít",
    "fordította": "fordít",
    "fordítottak": "fordított",
    "fordítottam": "fordított",
    "fordították": "fordít",
    "fordítások": "fordítás",
    "fordítását": "fordítás",
    "forgalma": "forgalom",
    "forgalmat": "forgalom",
    "forgalmazott": "forgalmaz",
    "forgalmaztak": "forgalmaz",
    "forgalmazása": "forgalmazás",
    "forgalmazásában": "forgalmazás",
    "forgalmazásával": "forgalmazás",
    "forgalmazói": "forgalmazó",
    "forgalmazóit": "forgalmazói",
    "forgalmazók": "forgalmazó",
    "forgalmát": "forgalom",
    "forgalomba": "forgalom",
    "forgalomban": "forgalom",
    "forgalomból": "forgalom",
    "forgalomnövekedést": "forgalomnövekedés",
    "forgatja": "forgat",
    "forgatnak": "forgat",
    "forgatni": "forgat",
    "forgatnia": "forgat",
    "forgatná": "forgat",
    "forgatta": "forgat",
    "forgattam": "forgat",
    "forgatták": "forgat",
    "forgatunk": "forgat",
    "forgatása": "forgatás",
    "forgatásra": "forgatás",
    "forgatókönyvei": "forgatókönyv",
    "forgatókönyvek": "forgatókönyv",
    "forgatókönyvet": "forgatókönyv",
    "forgatókönyvnek": "forgatókönyv",
    "forgatókönyvének": "forgatókönyv",
    "forgolódott": "forgolódik",
    "forgott": "forog",
    "forintba": "forint",
    "forintból": "forint",
    "forintig": "forint",
    "forintjuk": "forint",
    "forintjába": "forint",
    "forintnyit": "forintnyi",
    "forintnál": "forint",
    "forintocskákat": "forintocská",
    "forinton": "forint",
    "forintosat": "forintos",
    "forintot": "forint",
    "forintra": "forint",
    "forintról": "forint",
    "forinttal": "forint",
    "forintért": "forint",
    "formatervezők": "formatervező",
    "formába": "forma",
    "formában": "forma",
    "formáira": "forma",
    "formája": "forma",
    "formájuk": "forma",
    "formájukat": "forma",
    "formájába": "forma",
    "formájában": "forma",
    "formájából": "forma",
    "formáját": "forma",
    "formájától": "forma",
    "formájával": "forma",
    "formákat": "forma",
    "formákhoz": "forma",
    "formákkal": "forma",
    "formálisan": "formális",
    "formálta": "formál",
    "formán": "forma",
    "formának": "formán",
    "formát": "forma",
    "formátlanságnak": "formátlanság",
    "foroghatott": "foroghat",
    "forogjon": "forog",
    "forognak": "forog",
    "forogtak": "forog",
    "forradalmak": "forradalom",
    "forradalmakat": "forradalom",
    "forradalmat": "forradalom",
    "forradalmiságban": "forradalmiság",
    "forradalmárok": "forradalmár",
    "forradalomban": "forradalom",
    "forradalomnak": "forradalom",
    "forradalomról": "forradalom",
    "forradások": "forradás",
    "forralt": "forral",
    "forrt": "forr",
    "forrása": "forrás",
    "forrásaiknak": "forrás",
    "forrásain": "forrás",
    "forrásait": "forrás",
    "forrásból": "forrás",
    "forráshiányt": "forráshiány",
    "forrásmegosztásra": "forrásmegosztás",
    "források": "forrás",
    "forrásokat": "forrás",
    "forrásokból": "forrás",
    "forrást": "forrás",
    "forrástól": "forrás",
    "forróbban": "forró",
    "forrónyomon": "forrónyom",
    "forróságban": "forróság",
    "forróságtól": "forróság",
    "forróságát": "forróság",
    "fortélyát": "fortély",
    "fosszon": "foszt",
    "foszlányok": "foszlány",
    "foszlányt": "foszlány",
    "fosztani": "foszt",
    "fosztogatások": "fosztogatás",
    "fosztotta": "foszt",
    "fosztották": "foszt",
    "fotókat": "fotó",
    "fotókkal": "fotó",
    "fotót": "fotó",
    "fotóért": "fotó",
    "frakciója": "frakció",
    "frakciójának": "frakció",
    "frakciótanácskozásán": "frakciótanácskozás",
    "franciák": "francia",
    "franciát": "francia",
    "franciául": "francia",
    "franciával": "francia",
    "franciáé": "francia",
    "frankjába": "frank",
    "frazeológiáját": "frazeológia",
    "fregattot": "fregatt",
    "freskóival": "freskói",
    "frissebb": "friss",
    "frissen": "friss",
    "frissességét": "frissesség",
    "frisset": "friss",
    "frissítésre": "frissítés",
    "frissítőket": "frissítő",
    "frontharcosok": "frontharcos",
    "frontján": "front",
    "fronton": "front",
    "frontról": "front",
    "frontvonalak": "frontvonal",
    "frázisa": "frázis",
    "frázisaikban": "frázis",
    "frázisok": "frázis",
    "frázissal": "frázis",
    "frázist": "frázis",
    "fukarkodni": "fukarkodik",
    "fukarnak": "fukar",
    "fukarságból": "fukarság",
    "fukarságon": "fukarság",
    "fukarságot": "fukarság",
    "fuldoklunk": "fuldoklik",
    "fulladt": "fullad",
    "funkciója": "funkció",
    "funkciójában": "funkció",
    "funkcióját": "funkció",
    "funkciók": "funkció",
    "funkciókat": "funkció",
    "funkciókkal": "funkció",
    "funkciót": "funkció",
    "furcsább": "furcsa",
    "furcsábban": "furcsa",
    "furcsállhatta": "furcsállhat",
    "furcsán": "furcsa",
    "furcsának": "furcsa",
    "furfangosan": "furfangos",
    "furgonjában": "furgon",
    "fussatok": "fut",
    "fusson": "fut",
    "futballistákról": "futballista",
    "futballmérkőzések": "futballmérkőzés",
    "futballrajongók": "futballrajongó",
    "futja": "fut",
    "futkostam": "futkos",
    "futkározást": "futkározás",
    "futnak": "fut",
    "futni": "fut",
    "futok": "fut",
    "futott": "fut",
    "futotta": "fut",
    "futottak": "futott",
    "futtatja": "futtat",
    "futtatják": "futtat",
    "futtatni": "futtat",
    "futtában": "futta",
    "futunk": "fut",
    "futással": "futás",
    "fuvarlevélen": "fuvarlevél",
    "fuvarokmányain": "fuvarokmány",
    "fuvarosokkal": "fuvaros",
    "fuzionáljon": "fuzionál",
    "fából": "fa",
    "fához": "fa",
    "fái": "fa",
    "fájdalma": "fájdalom",
    "fájdalmai": "fájdalom",
    "fájdalmak": "fájdalom",
    "fájdalmasan": "fájdalmas",
    "fájdalmat": "fájdalom",
    "fájdalomcsillapítójuk": "fájdalomcsillapító",
    "fájdalomhullám": "fájdalomhulla",
    "fájdalomkiáltást": "fájdalomkiáltás",
    "fájdalommal": "fájdalom",
    "fájdalommentesnek": "fájdalommentes",
    "fájdalomra": "fájdalom",
    "fájdalomtól": "fájdalom",
    "fájni": "fáj",
    "fájt": "fáj",
    "fájtak": "fájt",
    "fák": "fa",
    "fákat": "fa",
    "fákkal": "fa",
    "fának": "fa",
    "fánkot": "fánk",
    "fára": "fa",
    "fáradhatatlanul": "fáradhatatlan",
    "fáradnak": "fárad",
    "fáradozom": "fáradozik",
    "fáradságot": "fáradság",
    "fáradságra": "fáradság",
    "fáradságtól": "fáradság",
    "fáradt": "fárad",
    "fáradtak": "fáradt",
    "fáradtan": "fáradt",
    "fáradtsága": "fáradtság",
    "fáradtságból": "fáradtság",
    "fáradtságtól": "fáradtság",
    "fáradtságával": "fáradtság",
    "fáradunk": "fárad",
    "fárassza": "fáraszt",
    "fárasztóbb": "fárasztó",
    "fárasztónak": "fárasztó",
    "fáraók": "fáraó",
    "fáraóktól": "fáraó",
    "fásult": "fásul",
    "fátyolozza": "fátyoloz",
    "fázik": "fáz",
    "fázisait": "fázis",
    "fázisát": "fázis",
    "fáznak": "fázik",
    "fázott": "fázik",
    "fáztak": "fázik",
    "fékbetétek": "fékbetét",
    "féken": "fék",
    "fékezett": "fékez",
    "fékezhetetlenül": "fékezhetetlen",
    "fékezheti": "fékezhet",
    "fékezni": "fékez",
    "félbe": "fél",
    "félbeszakadt": "félbeszakad",
    "félbeszakítani": "félbeszakít",
    "félbeszakította": "félbeszakít",
    "félbolondot": "félbolond",
    "féldecit": "féldeci",
    "félek": "fél",
    "félelembe": "félelem",
    "félelemhez": "félelem",
    "félelemmel": "félelem",
    "félelemnek": "félelem",
    "félelemre": "félelem",
    "félelemtől": "félelem",
    "félelme": "félelem",
    "félelmeit": "félelem",
    "félelmet": "félelem",
    "félelmetesek": "félelmetes",
    "félelmetesen": "félelmetes",
    "félelmetesnek": "félelmetes",
    "félelmét": "félelem",
    "félelméért": "félelem",
    "félelmünkben": "félelem",
    "félemeletek": "félemelet",
    "félfordulattal": "félfordulat",
    "félgömbön": "félgömb",
    "félhangon": "félhang",
    "félhetett": "félhet",
    "félhivatalosan": "félhivatalos",
    "félhomálya": "félhomály",
    "félhomályban": "félhomály",
    "félhomályt": "félhomály",
    "félidejére": "félidő",
    "félidőben": "félidő",
    "félidőn": "félidő",
    "félidőre": "félidő",
    "félig": "fél",
    "félistennek": "félisten",
    "félj": "fél",
    "félkörében": "félkör",
    "féllel": "fél",
    "féllépésnyire": "féllépésnyi",
    "félmosolyukat": "félmosoly",
    "félnek": "fél",
    "félnem": "fél",
    "félni": "fél",
    "félnie": "fél",
    "félnivalója": "félnivaló",
    "félniük": "fél",
    "félre": "fél",
    "félrebillentett": "félrebillent",
    "félredobta": "félredob",
    "félrefordította": "félrefordít",
    "félreismerhetetlenül": "félreismerhetetlen",
    "félrelökte": "félrelök",
    "félrelökött": "félrelök",
    "félrenézett": "félrenéz",
    "félresikerült": "félresikerül",
    "félretaposott": "félretapos",
    "félretennie": "félretesz",
    "félretett": "félretesz",
    "félretette": "félretesz",
    "félretették": "félretesz",
    "félretettük": "félretett",
    "félretolta": "félretol",
    "félrevezetett": "félrevezet",
    "félrevezette": "félrevezet",
    "félrevezettek": "félrevezet",
    "félreállnak": "félreáll",
    "félreállni": "félreáll",
    "félreállt": "félreáll",
    "félreálltál": "félreáll",
    "félreállított": "félreállít",
    "félreérthetetlenül": "félreérthetetlen",
    "félreértések": "félreértés",
    "félreértéseket": "félreértés",
    "félreértéssel": "félreértés",
    "félreértést": "félreértés",
    "félsz": "fél",
    "félszegen": "félszeg",
    "félszázad": "félszáz",
    "félszélességben": "félszélesség",
    "félt": "fél",
    "féltek": "félt",
    "félteni": "félt",
    "féltett": "félt",
    "féltettem": "féltett",
    "féltették": "féltet",
    "féltsék": "félt",
    "féltékenyen": "féltékeny",
    "féltékenységnek": "féltékenység",
    "féltése": "féltés",
    "féltünk": "félt",
    "félálomban": "félálom",
    "félénken": "félénk",
    "félévben": "félév",
    "féléve": "félév",
    "félévek": "félév",
    "félévvel": "félév",
    "félévét": "félév",
    "félóráig": "félóra",
    "félórájába": "félóra",
    "félóránál": "félóra",
    "félórára": "félóra",
    "félórával": "félóra",
    "félúton": "félút",
    "fémanyagot": "fémanyag",
    "fémasztalok": "fémasztal",
    "fémdarabkákat": "fémdarabka",
    "fémlapocskák": "fémlapocska",
    "fémlemezből": "fémlemez",
    "fémtálcát": "fémtálca",
    "fémtálkában": "fémtálka",
    "fémágyakon": "fémágy",
    "fénnyel": "fény",
    "fénybe": "fény",
    "fényben": "fény",
    "fénye": "fény",
    "fényei": "fény",
    "fényeinek": "fény",
    "fényeit": "fény",
    "fények": "fény",
    "fényekbe": "fény",
    "fényesebbek": "fényes",
    "fényesebbnek": "fényes",
    "fényesre": "fényes",
    "fényességgel": "fényesség",
    "fényességnövekedést": "fényességnövekedés",
    "fényesített": "fényesít",
    "fénykorában": "fénykor",
    "fényképből": "fénykép",
    "fényképei": "fénykép",
    "fényképeken": "fénykép",
    "fényképeket": "fénykép",
    "fényképekről": "fénykép",
    "fényképen": "fénykép",
    "fényképet": "fénykép",
    "fényképezett": "fényképez",
    "fényképfelvételek": "fényképfelvétel",
    "fényképhamisítások": "fényképhamisítás",
    "fényképnek": "fénykép",
    "fényképről": "fénykép",
    "fényképésszel": "fényképész",
    "fényképészeket": "fényképész",
    "fényképét": "fénykép",
    "fénykévéje": "fénykéve",
    "fénykörében": "fénykör",
    "fénypáráját": "fénypára",
    "fényszórói": "fényszóró",
    "fényt": "fény",
    "fényét": "fény",
    "fényűzést": "fényűzés",
    "fényűzéstől": "fényűzés",
    "férfiak": "férfi",
    "férfiakat": "férfi",
    "férfiakkal": "férfi",
    "férfiaknak": "férfi",
    "férfiarcok": "férfiarc",
    "férfiasságot": "férfiasság",
    "férfiból": "férfi",
    "férfiből": "férfi",
    "férfikor": "férfi",
    "férfimentségnek": "férfimentség",
    "férfinak": "férfi",
    "férfira": "férfi",
    "férfit": "férfi",
    "férfival": "férfi",
    "férfiéhoz": "férfi",
    "férfiét": "férfi",
    "férgekké": "féreg",
    "férj": "fér",
    "férje": "férj",
    "férjed": "férj",
    "férjem": "férj",
    "férjemet": "férj",
    "férjemmel": "férj",
    "férjemnek": "férj",
    "férjhez": "férj",
    "férjnek": "férj",
    "férjének": "férj",
    "férjére": "férj",
    "férjéről": "férj",
    "férjét": "férj",
    "férjüknek": "férj",
    "férnek": "fér",
    "fért": "fér",
    "férőhelyek": "férőhely",
    "fészekbe": "fészek",
    "fészekben": "fészek",
    "fészkelt": "fészkel",
    "fészken": "fészek",
    "fészket": "fészek",
    "fésűn": "fésű",
    "fésűt": "fésű",
    "fórumai": "fórum",
    "fórumainak": "fórum",
    "fórumba": "fórum",
    "fórumokkal": "fórum",
    "fórumokon": "fórum",
    "fórumon": "fórum",
    "fórumot": "fórum",
    "fórumától": "fórum",
    "föderáción": "föderáció",
    "föderációra": "föderáció",
    "födémet": "födém",
    "föladta": "fölad",
    "fölajánlott": "fölajánl",
    "fölajánlásaiban": "fölajánlás",
    "fölbátorította": "fölbátorít",
    "fölcitálták": "fölcitál",
    "fölcsapott": "fölcsap",
    "földalatti-állomásig": "földalatti-állomás",
    "földalatti-állomásra": "földalatti-állomás",
    "földalattin": "földalatti",
    "földalattit": "földalatti",
    "földben": "föld",
    "földből": "föld",
    "földdel": "föld",
    "földek": "föld",
    "földeken": "föld",
    "földeket": "föld",
    "földekre": "föld",
    "földekről": "föld",
    "földet": "föld",
    "földgáznak": "földgáz",
    "földhöz": "föld",
    "földhözragadtak": "földhözragadt",
    "földiekkel": "földi",
    "földijével": "földi",
    "földinek": "földin",
    "földje": "föld",
    "földjének": "föld",
    "földjét": "föld",
    "földjével": "föld",
    "földjük": "föld",
    "földjükön": "föld",
    "földméréshez": "földmérés",
    "földművelésben": "földművelés",
    "földolgozni": "földolgozik",
    "földosztást": "földosztás",
    "földrajzból": "földrajz",
    "földre": "föld",
    "földrengések": "földrengés",
    "földrészen": "földrész",
    "földről": "föld",
    "földszinten": "földszint",
    "földterületek": "földterület",
    "földön": "föld",
    "földönti": "földönt",
    "földünket": "föld",
    "földünkre": "föld",
    "fölegyenesedett": "fölegyenesedik",
    "fölemeli": "fölemel",
    "fölemelni": "fölemel",
    "fölemelt": "fölemel",
    "fölemelte": "fölemel",
    "fölemlegeti": "fölemleget",
    "fölengedett": "fölenged",
    "fölfedezett": "fölfedez",
    "fölfedezi": "fölfedez",
    "fölfigyelnének": "fölfigyel",
    "fölhozta": "fölhoz",
    "fölháborodást": "fölháborodás",
    "fölháborított": "fölháborít",
    "fölhívást": "fölhívás",
    "fölhördülhetek": "fölhördülhet",
    "fölhúzott": "fölhúz",
    "fölismerte": "fölismer",
    "fölkelteni": "fölkelt",
    "fölkelti": "fölkelt",
    "fölkészülnie": "fölkészül",
    "fölkínált": "fölkínál",
    "föllátogathatnának": "föllátogathat",
    "fölléptek": "föllépt",
    "föllökte": "föllök",
    "fölment": "fölmegy",
    "fölmerülhetne": "fölmerülhet",
    "fölnevelni": "fölnevel",
    "fölnézett": "fölnéz",
    "fölnéztek": "fölnéz",
    "fölolvasást": "fölolvasás",
    "fölpanaszolja": "fölpanaszol",
    "fölpanaszolta": "fölpanaszol",
    "fölszökött": "fölszökik",
    "fölteszik": "föltesz",
    "föltett": "föltesz",
    "föltisztította": "föltisztít",
    "föltámadt": "föltámad",
    "föltámasztani": "föltámaszt",
    "föltámasztotta": "föltámaszt",
    "föltápászkodott": "föltápászkodik",
    "föltűnt": "föltűnik",
    "fölvillannia": "fölvillan",
    "fölállt": "föláll",
    "fölállítanak": "fölállít",
    "fölé": "föl",
    "fölébe": "föl",
    "fölébredt": "fölébred",
    "föléje": "föléj",
    "föléjük": "föléj",
    "föléledt": "föléled",
    "fölélénkült": "fölélénkül",
    "fölénnyel": "fölény",
    "fölénybe": "fölény",
    "fölényesen": "fölényes",
    "fölénynek": "fölény",
    "fölényével": "fölény",
    "fölért": "fölérik",
    "fölöslegeket": "fölösleg",
    "fölöslegeseket": "fölösleges",
    "fölöslegesen": "fölösleges",
    "fölösleget": "fölösleg",
    "fölöslegét": "fölösleg",
    "fölöslegével": "fölösleg",
    "fölötte": "fölött",
    "fölöttem": "fölött",
    "fölöttük": "fölött",
    "fölöttünk": "fölött",
    "fölülvizsgálatát": "fölülvizsgálat",
    "fölütötte": "fölüt",
    "fönntartani": "fönntart",
    "fönntartását": "fönntartás",
    "föntiekből": "fönti",
    "förmedt": "förmed",
    "förtelmesen": "förtelmes",
    "fúj": "fú",
    "fújja": "fúj",
    "fújják": "fúj",
    "fújni": "fúj",
    "fújt": "fúj",
    "fújta": "fúj",
    "fújták": "fúj",
    "fúrta": "fúr",
    "fúródott": "fúródik",
    "fútt": "fú",
    "fúziója": "fúzió",
    "függelékben": "függelék",
    "függeszti": "függeszt",
    "függetlenek": "független",
    "függetlenségben": "függetlenség",
    "függetlensége": "függetlenség",
    "függetlenséget": "függetlenség",
    "függetlenségre": "függetlenség",
    "függetlenségét": "függetlenség",
    "függetleníteni": "függetlenít",
    "függetlenítheti": "függetleníthet",
    "függetleníthetné": "függetleníthet",
    "függetlenül": "független",
    "függjenek": "függ",
    "függjön": "függ",
    "függnek": "függ",
    "függvénye": "függvény",
    "függönyszárnyak": "függönyszárny",
    "függönyök": "függöny",
    "függönyöket": "függöny",
    "függött": "függ",
    "függően": "függő",
    "függőimet": "függő",
    "függőlegesen": "függőleges",
    "függőségben": "függőség",
    "fülcimpájára": "fülcimpa",
    "füle": "fül",
    "fülei": "fül",
    "fülekre": "fül",
    "fülelnek": "fülel",
    "fülelt": "fülel",
    "fülem": "fül",
    "fület": "fül",
    "fülhallgatót": "fülhallgató",
    "fülkarikáidat": "fülkarika",
    "fülkarikáival": "fülkarika",
    "fülkébe": "fülke",
    "fülkéje": "fülkéj",
    "fülkékben": "fülke",
    "fülledt": "fülled",
    "fülsiketítően": "fülsiketítő",
    "fültanúi": "fültanú",
    "fülébe": "fül",
    "fülében": "fül",
    "füléhez": "fül",
    "fülének": "fül",
    "fülére": "fül",
    "fülét": "fül",
    "fülünk": "fül",
    "fürdött": "fürdik",
    "fürdőben": "fürdő",
    "fürdők": "fürdő",
    "fürdőknek": "fürdő",
    "fürdőkádban": "fürdőkád",
    "fürdőszobába": "fürdőszoba",
    "fürdőszobában": "fürdőszoba",
    "fürdőszobája": "fürdőszoba",
    "fürdőszobájukban": "fürdőszoba",
    "fürdőszobával": "fürdőszoba",
    "fürgeséggel": "fürgeség",
    "fürgén": "fürge",
    "fürkészi": "fürkész",
    "fürkészték": "fürkész",
    "fürtjeit": "fürt",
    "fürödj": "fürödik",
    "fürödni": "fürödik",
    "füstben": "füst",
    "füstje": "füst",
    "füsttel": "füst",
    "füstté": "füst",
    "füstöltek": "füstölt",
    "füvek": "fű",
    "füzetben": "füzet",
    "füzeteiket": "füzet",
    "füzetet": "füzet",
    "füzetét": "füzet",
    "főapát": "főapa",
    "főbb": "fő",
    "főbérletibe": "főbérleti",
    "főbírója": "főbíró",
    "főbűnt": "főbűn",
    "főfelügyelőséggel": "főfelügyelőség",
    "főhetett": "főhet",
    "főigazgató-helyettese": "főigazgató-helyettes",
    "főigazgatója": "főigazgató",
    "főiskolák": "főiskola",
    "főiskolán": "főiskola",
    "főiskolára": "főiskola",
    "főkortese": "főkortes",
    "főként": "fő",
    "főképp": "fő",
    "főmérnökként": "főmérnök",
    "főnevek": "főnév",
    "főnevet": "főnév",
    "főnél": "fő",
    "főnév-igéhez": "főnév-ige",
    "főnévként": "főnév",
    "főnök": "főn",
    "főnökének": "főnök",
    "főnökét": "főnök",
    "főnökével": "főnök",
    "főosztályvezetője": "főosztályvezető",
    "főosztályának": "főosztály",
    "főosztályától": "főosztály",
    "főpolgármesterrel": "főpolgármester",
    "főprofilba": "főprofil",
    "főre": "fő",
    "főről": "fő",
    "főszereplőjét": "főszereplő",
    "főszerkesztője": "főszerkesztő",
    "főszerkesztők": "főszerkesztő",
    "főszólamot": "főszólam",
    "főt": "fő",
    "főtanácsadója": "főtanácsadó",
    "főtanácsosa": "főtanácsos",
    "főtisztek": "főtiszt",
    "főtitkára": "főtitok",
    "főtitkárnak": "főtitkár",
    "főtitkárnál": "főtitkár",
    "főtitkárának": "főtitkár",
    "főtt": "fő",
    "főtáblán": "főtábla",
    "főtábláról": "főtábla",
    "főtávnak": "főtáv",
    "főurakat": "főúr",
    "főutak": "főút",
    "főutakat": "főút",
    "főutcákat": "főutca",
    "főutcákon": "főutca",
    "fővel": "fő",
    "fővonalra": "fővonal",
    "fővállalkozásban": "fővállalkozás",
    "fővállalkozója": "fővállalkozó",
    "fővárosa": "főváros",
    "fővárosba": "főváros",
    "fővárosban": "főváros",
    "fővárosból": "főváros",
    "fővároson": "főváros",
    "fővárosra": "főváros",
    "fővárossal": "főváros",
    "fővárost": "főváros",
    "fővárosának": "főváros",
    "főzelékekről": "főzelék",
    "főzeléket": "főzelék",
    "főzelékünk": "főzelék",
    "főzik": "főz",
    "főzne": "főz",
    "főznek": "főz",
    "főzni": "főz",
    "főzte": "főz",
    "főztek": "főz",
    "főztünk": "főz",
    "főzzek": "főz",
    "főzzön": "főz",
    "főzzünk": "főz",
    "főzésnél": "főzés",
    "főzésre": "főzés",
    "főzést": "főzés",
    "főzök": "főz",
    "főzött": "főz",
    "főzőasszonyt": "főzőasszony",
    "főzőedényekhez": "főzőedény",
    "főzőhelyükre": "főzőhely",
    "főzőt": "főző",
    "főösszeggel": "főösszeg",
    "főútra": "főút",
    "főügyintézői": "főügyintéző",
    "főügyintézőkké": "főügyintéző",
    "fűhöz-fához": "fű-fa",
    "fűre": "fű",
    "fűrészporban": "fűrészpor",
    "fűrészporból": "fűrészpor",
    "fűszerezik": "fűszerez",
    "fűt": "fű",
    "fűtene": "fűt",
    "fűtenek": "fűt",
    "fűti": "fűt",
    "fűtsön": "fűt",
    "fűtésből": "fűtés",
    "fűtésre": "fűtés",
    "fűtéssel": "fűtés",
    "fűtést": "fűtés",
    "fűtésének": "fűtés",
    "fűtésével": "fűtés",
    "fűtésüket": "fűtés",
    "fűtött": "fűt",
    "fűtöttek": "fűtött",
    "fűtőanyagának": "fűtőanyag",
    "fűtőelemek": "fűtőelem",
    "fűtőelemeket": "fűtőelem",
    "fűtőelemnek": "fűtőelem",
    "fűtői": "fűtő",
    "fűtőrendszerről": "fűtőrendszer",
    "fűvel": "fű",
    "fűzfák": "fűzfa",
    "fűzfői": "fűzfő",
    "fűzfőn": "fűzfő",
    "fűzte": "fűz",
    "fűzött": "fűz",
    "fűződött": "fűződik",
    "gabonapiacokkal": "gabonapiac",
    "gabonapiacán": "gabonapiac",
    "gabonaraktáraikat": "gabonaraktár",
    "gabonát": "gabona",
    "gajdolással": "gajdolás",
    "galambfészekből": "galambfészek",
    "gallonban": "gallon",
    "gallyacskát": "gallyacská",
    "gallyakon": "gally",
    "galuskalevesre": "galuskaleves",
    "galuskalevest": "galuskaleves",
    "galériái": "galéria",
    "galériák": "galéria",
    "galériát": "galéria",
    "garanciái": "garancia",
    "garanciák": "garancia",
    "garanciákat": "garancia",
    "garanciát": "garancia",
    "garanciával": "garancia",
    "garantálhatná": "garantálhat",
    "garantálja": "garantál",
    "garantáljon": "garantál",
    "garantálják": "garantál",
    "garantálná": "garantál",
    "garantálom": "garantál",
    "garantált": "garantál",
    "garantáltabb": "garantált",
    "garzontól": "garzon",
    "gavallérosan": "gavalléros",
    "gazdagodnak": "gazdagodik",
    "gazdagodott": "gazdagodik",
    "gazdagok": "gazdag",
    "gazdagokhoz": "gazdag",
    "gazdagságot": "gazdagság",
    "gazdagíthatják": "gazdagíthat",
    "gazdagított": "gazdagít",
    "gazdagítsák": "gazdagít",
    "gazdakörbe": "gazdakör",
    "gazdasszonynak": "gazdasszony",
    "gazdasszonytól": "gazdasszony",
    "gazdasága": "gazdaság",
    "gazdaságba": "gazdaság",
    "gazdaságban": "gazdaság",
    "gazdaságnak": "gazdaság",
    "gazdaságot": "gazdaság",
    "gazdaságpolitikát": "gazdaságpolitika",
    "gazdaságról": "gazdaság",
    "gazdatisztek": "gazdatiszt",
    "gazdái": "gazda",
    "gazdáik": "gazda",
    "gazdáikon": "gazda",
    "gazdája": "gazda",
    "gazdájuk": "gazda",
    "gazdáját": "gazda",
    "gazdájától": "gazda",
    "gazdájával": "gazda",
    "gazdák": "gazda",
    "gazdákat": "gazda",
    "gazdáktól": "gazda",
    "gazdálkodhatnak": "gazdálkodhat",
    "gazdálkodni": "gazdálkodik",
    "gazdálkodott": "gazdálkodik",
    "gazdálkodásban": "gazdálkodás",
    "gazdálkodást": "gazdálkodás",
    "gazdálkodásában": "gazdálkodás",
    "gazdálkodásának": "gazdálkodás",
    "gazdálkodására": "gazdálkodás",
    "gazdálkodását": "gazdálkodás",
    "gazdálkodókkal": "gazdálkodó",
    "gazdálkodót": "gazdálkodó",
    "gazdám": "gazda",
    "gazdának": "gazda",
    "gazdánál": "gazda",
    "gazdára": "gazda",
    "gazdát": "gazda",
    "gazdátlanul": "gazdátlan",
    "gazdától": "gazda",
    "gazemberek": "gazember",
    "gazemberekben": "gazember",
    "gazságok": "gazság",
    "gazt": "gaz",
    "gaztól": "gaz",
    "gazzal": "gaz",
    "gazában": "gaz",
    "gebedésig": "gebedés",
    "gebét": "gebe",
    "generációnak": "generáció",
    "gengszterek": "gengszter",
    "gengszterizmusra": "gengszterizmus",
    "gepárdok": "gepárd",
    "gerince": "gerinc",
    "gerincoszlopa": "gerincoszlop",
    "gerincoszlopod": "gerincoszlop",
    "gerincvelő-sérülésbe": "gerincvelő-sérülés",
    "gerlék": "gerle",
    "gesztenyefák": "gesztenyefa",
    "gesztenyét": "gesztenye",
    "gesztusnak": "gesztus",
    "gesztusokat": "gesztus",
    "gesztussal": "gesztus",
    "gimnasztikázunk": "gimnasztikáz",
    "gimnáziumba": "gimnázium",
    "gimnáziumban": "gimnázium",
    "gimnáziumok": "gimnázium",
    "gimnáziumokban": "gimnázium",
    "gineket": "gin",
    "ginesüveggel": "ginesüveg",
    "ginivásról": "ginivás",
    "ginnel": "gin",
    "ginszaga": "ginszag",
    "gint": "gin",
    "ginért": "gin",
    "gipszbe": "gipsz",
    "gipszet": "gipsz",
    "girhesek": "girhes",
    "giroszkópnak": "giroszkóp",
    "golyóit": "golyói",
    "golyóival": "golyói",
    "golyók": "golyó",
    "golyókat": "golyó",
    "golyóktól": "golyó",
    "golyóra": "golyó",
    "golyósüvöltést": "golyósüvöltés",
    "gombjait": "gomb",
    "gombjára": "gomb",
    "gombostűzték": "gombostűz",
    "gombot": "gomb",
    "gombát": "gomba",
    "gomolyodott": "gomolyodik",
    "gondatlanságból": "gondatlanság",
    "gonddal": "gond",
    "gondja": "gond",
    "gondjai": "gond",
    "gondjaikat": "gond",
    "gondjaimat": "gond",
    "gondjaink": "gond",
    "gondjaira": "gond",
    "gondjait": "gond",
    "gondjuk": "gond",
    "gondját": "gond",
    "gondnak": "gond",
    "gondnoka": "gondnok",
    "gondnokot": "gondnok",
    "gondnoksága": "gondnokság",
    "gondok": "gond",
    "gondokat": "gond",
    "gondokkal": "gond",
    "gondolata": "gondolat",
    "gondolatai": "gondolat",
    "gondolataiban": "gondolat",
    "gondolataiból": "gondolat",
    "gondolataid": "gondolat",
    "gondolataikat": "gondolat",
    "gondolataikba": "gondolat",
    "gondolatainak": "gondolat",
    "gondolatait": "gondolat",
    "gondolatban": "gondolat",
    "gondolatbűnbe": "gondolatbűn",
    "gondolatbűnnek": "gondolatbűn",
    "gondolatbűnt": "gondolatbűn",
    "gondolatbűnözők": "gondolatbűnöző",
    "gondolatbűnözőként": "gondolatbűnöző",
    "gondolatbűnözőt": "gondolatbűnöző",
    "gondolatelferdítést": "gondolatelferdítés",
    "gondolatjelek": "gondolatjel",
    "gondolatmenete": "gondolatmenet",
    "gondolatnak": "gondolat",
    "gondolatok": "gondolat",
    "gondolatokat": "gondolat",
    "gondolatokra": "gondolatok",
    "gondolatoktól": "gondolatok",
    "gondolatot": "gondolat",
    "gondolatra": "gondolat",
    "gondolatrendszereknek": "gondolatrendszer",
    "gondolatrendszert": "gondolatrendszer",
    "gondolatrendőrségen": "gondolatrendőrség",
    "gondolatrendőrséget": "gondolatrendőrség",
    "gondolatrendőrséggel": "gondolatrendőrség",
    "gondolatrendőrségnek": "gondolatrendőrség",
    "gondolatrendőrségnél": "gondolatrendőrség",
    "gondolatrendőrségtől": "gondolatrendőrség",
    "gondolatsorokat": "gondolatsor",
    "gondolatsort": "gondolatsor",
    "gondolatszabadságot": "gondolatszabadság",
    "gondolattal": "gondolat",
    "gondolatuk": "gondolat",
    "gondolatunk": "gondolat",
    "gondolatvilága": "gondolatvilág",
    "gondolatának": "gondolat",
    "gondolatát": "gondolat",
    "gondolhatja": "gondolhat",
    "gondolhatják": "gondolhat",
    "gondolhatod": "gondolhat",
    "gondolja": "gondol",
    "gondoljatok": "gondol",
    "gondoljon": "gondol",
    "gondoljuk": "gondol",
    "gondoljunk": "gondol",
    "gondolják": "gondol",
    "gondoljátok": "gondol",
    "gondolkodhatunk": "gondolkodhat",
    "gondolkodjunk": "gondolkodik",
    "gondolkodni": "gondolkodik",
    "gondolkodnia": "gondolkodik",
    "gondolkodniuk": "gondolkodik",
    "gondolkodnunk": "gondolkodik",
    "gondolkodol": "gondolkodik",
    "gondolkodásmódból": "gondolkodásmód",
    "gondolkodásmódját": "gondolkodásmód",
    "gondolkodásomban": "gondolkodás",
    "gondolkodásra": "gondolkodás",
    "gondolkodással": "gondolkodás",
    "gondolkodást": "gondolkodás",
    "gondolkodását": "gondolkodás",
    "gondolkodásúak": "gondolkodású",
    "gondolkodóé": "gondolkodó",
    "gondolkozhatott": "gondolkozhat",
    "gondolkoznak": "gondolkozik",
    "gondolkozni": "gondolkozik",
    "gondolkozott": "gondolkozik",
    "gondolkoztak": "gondolkozik",
    "gondolkoztam": "gondolkozik",
    "gondolkoztunk": "gondolkozik",
    "gondolkoztál": "gondolkozik",
    "gondolkozzanak": "gondolkozik",
    "gondolnak": "gondol",
    "gondolni": "gondol",
    "gondolnia": "gondol",
    "gondolniuk": "gondol",
    "gondolná": "gondol",
    "gondolnánk": "gondol",
    "gondolod": "gondol",
    "gondolok": "gondol",
    "gondolom": "gondol",
    "gondolsz": "gondol",
    "gondolt": "gondol",
    "gondolta": "gondol",
    "gondoltad": "gondolt",
    "gondoltak": "gondolt",
    "gondoltam": "gondolt",
    "gondoltatok": "gondoltat",
    "gondoltuk": "gondol",
    "gondoltunk": "gondolt",
    "gondolták": "gondol",
    "gondoltál": "gondol",
    "gondolunk": "gondol",
    "gondosan": "gondos",
    "gondoskodjon": "gondoskodik",
    "gondoskodniuk": "gondoskodik",
    "gondoskodtak": "gondoskodik",
    "gondoskodtam": "gondoskodik",
    "gondoskodásában": "gondoskodás",
    "gondoskodását": "gondoskodás",
    "gondoskodónak": "gondoskodó",
    "gondossága": "gondosság",
    "gondosságot": "gondosság",
    "gondot": "gond",
    "gondotok": "gond",
    "gondoznia": "gondoz",
    "gondozta": "gondoz",
    "gondozták": "gondoz",
    "gondozzák": "gondoz",
    "gondozásban": "gondozás",
    "gondozásnak": "gondozás",
    "gondozóiként": "gondozói",
    "gondozója": "gondozó",
    "gondra": "gond",
    "gondterhes": "gondterhet",
    "gondterhesebb": "gondterhes",
    "gondunk": "gond",
    "gondviselésben": "gondviselés",
    "gonoszabb": "gonosz",
    "gonoszak": "gonosz",
    "gonoszságot": "gonoszság",
    "gonosztevők": "gonosztevő",
    "gonoszul": "gonosz",
    "gorombaságokat": "gorombaság",
    "gorombák": "goromba",
    "grafikonok": "grafikon",
    "grafikonokban": "grafikon",
    "grammra": "gramm",
    "grammról": "gramm",
    "gramofonja": "gramofon",
    "gratulálok": "gratulál",
    "grimaszokat": "grimasz",
    "gránittömbhöz": "gránittömb",
    "grémiumainak": "grémium",
    "grémiumnak": "grémium",
    "grófnál": "gróf",
    "grófért": "gróf",
    "gubancainak": "gubanc",
    "gubájában": "guba",
    "gubózzák": "gubóz",
    "gulyatelek": "gulyatél",
    "gulyáshoz": "gulyás",
    "gulyást": "gulyás",
    "gumibotját": "gumibot",
    "gumibotok": "gumibot",
    "gumiboton": "gumibot",
    "gumibotozták": "gumibotoz",
    "gumibottal": "gumibot",
    "gumipuskáját": "gumipuska",
    "gumipuskával": "gumipuska",
    "gumiszagában": "gumiszag",
    "gunyorosak": "gunyoros",
    "gurult": "gurul",
    "gurultak": "gurult",
    "gyakoriak": "gyakori",
    "gyakorisága": "gyakoriság",
    "gyakorlata": "gyakorlat",
    "gyakorlatban": "gyakorlat",
    "gyakorlatiasságával": "gyakorlatiasság",
    "gyakorlatok": "gyakorlat",
    "gyakorlatokkal": "gyakorlat",
    "gyakorlatoknak": "gyakorlat",
    "gyakorlaton": "gyakorlat",
    "gyakorlatot": "gyakorlat",
    "gyakorlattal": "gyakorlat",
    "gyakorlatában": "gyakorlat",
    "gyakorlatát": "gyakorlat",
    "gyakorlott": "gyakorol",
    "gyakorlását": "gyakorlás",
    "gyakorlói": "gyakorló",
    "gyakornoknak": "gyakornok",
    "gyakornokok": "gyakornok",
    "gyakornokokat": "gyakornok",
    "gyakorolhatók": "gyakorolható",
    "gyakorolja": "gyakorol",
    "gyakorolnak": "gyakorol",
    "gyakorolni": "gyakorol",
    "gyakorolt": "gyakorol",
    "gyakorolta": "gyakorol",
    "gyakoroltak": "gyakorolt",
    "gyalogolt": "gyalogol",
    "gyalogot": "gyalog",
    "gyalogutakon": "gyalogút",
    "gyalogút": "gyalogú",
    "gyalázatosságokat": "gyalázatosság",
    "gyalázkodásokat": "gyalázkodás",
    "gyalázta": "gyaláz",
    "gyalázták": "gyaláz",
    "gyalázást": "gyalázás",
    "gyanakodni": "gyanakodik",
    "gyanakodnia": "gyanakodik",
    "gyanakvásait": "gyanakvás",
    "gyanakvásokat": "gyanakvás",
    "gyanakvással": "gyanakvás",
    "gyanakvását": "gyanakvás",
    "gyanakvóan": "gyanakvó",
    "gyanakvón": "gyanakvó",
    "gyanítanak": "gyanít",
    "gyanítani": "gyanít",
    "gyaníthatja": "gyaníthat",
    "gyanítom": "gyanít",
    "gyanította": "gyanít",
    "gyanították": "gyanít",
    "gyanúja": "gyanú",
    "gyanúját": "gyanú",
    "gyanúm": "gyanú",
    "gyanúnak": "gyanú",
    "gyanúsak": "gyanús",
    "gyanúsított": "gyanúsít",
    "gyanúsítottak": "gyanúsított",
    "gyanúsítottakkal": "gyanúsított",
    "gyanúsították": "gyanúsít",
    "gyanúsítással": "gyanúsítás",
    "gyanút": "gyanú",
    "gyanútlanságában": "gyanútlanság",
    "gyanútlanul": "gyanútlan",
    "gyapotmezők": "gyapotmező",
    "gyarapodjék": "gyarapodik",
    "gyarapodott": "gyarapodik",
    "gyarapodása": "gyarapodás",
    "gyarapításával": "gyarapítás",
    "gyengeelméjűeknek": "gyengeelméjű",
    "gyengeségről": "gyengeség",
    "gyengeségében": "gyengeség",
    "gyengébb": "gyenge",
    "gyengébben": "gyenge",
    "gyengéből": "gyenge",
    "gyengéd": "gyenge",
    "gyengéden": "gyengéd",
    "gyengédséget": "gyengédség",
    "gyengéit": "gyenge",
    "gyengéjének": "gyenge",
    "gyengék": "gyenge",
    "gyengéket": "gyenge",
    "gyengélkedése": "gyengélkedés",
    "gyengén": "gyenge",
    "gyengítette": "gyengít",
    "gyengíti": "gyengít",
    "gyengült": "gyengül",
    "gyengülése": "gyengülés",
    "gyengülését": "gyengülés",
    "gyepeken": "gyep",
    "gyepet": "gyep",
    "gyeplőjén": "gyeplő",
    "gyeplőt": "gyeplő",
    "gyere": "jön",
    "gyerekből": "gyerek",
    "gyereke": "gyerek",
    "gyerekecskék": "gyerekecské",
    "gyerekei": "gyerek",
    "gyerekeiből": "gyerek",
    "gyerekeik": "gyerek",
    "gyerekeiket": "gyerek",
    "gyerekeikkel": "gyerek",
    "gyerekeink": "gyerek",
    "gyerekeit": "gyerek",
    "gyerekeivel": "gyerek",
    "gyerekek": "gyerek",
    "gyerekekből": "gyerek",
    "gyerekeket": "gyerek",
    "gyerekekkel": "gyerek",
    "gyerekeknek": "gyerek",
    "gyerekekre": "gyerek",
    "gyerekekről": "gyerek",
    "gyerekem": "gyerek",
    "gyereket": "gyerek",
    "gyerekhez": "gyerek",
    "gyerekig": "gyerek",
    "gyerekkel": "gyerek",
    "gyerekkorom": "gyerekkor",
    "gyerekkoromban": "gyerekkorom",
    "gyerekkorunktól": "gyerekkor",
    "gyerekkorától": "gyerekkor",
    "gyereknél": "gyerek",
    "gyerekporciót": "gyerekporció",
    "gyerekről": "gyerek",
    "gyerekszobát": "gyerekszoba",
    "gyerektől": "gyerek",
    "gyerekének": "gyerek",
    "gyerekét": "gyerek",
    "gyermekben": "gyermek",
    "gyermekből": "gyermek",
    "gyermeke": "gyermek",
    "gyermekedet": "gyermek",
    "gyermekei": "gyermek",
    "gyermekeiket": "gyermek",
    "gyermekeiktől": "gyermek",
    "gyermekeire": "gyermek",
    "gyermekeit": "gyermek",
    "gyermekek": "gyermek",
    "gyermekeket": "gyermek",
    "gyermekeknek": "gyermek",
    "gyermekem": "gyermek",
    "gyermekessé": "gyermekes",
    "gyermeket": "gyermek",
    "gyermekhősként": "gyermekhős",
    "gyermekintézményben": "gyermekintézmény",
    "gyermekintézményekbe": "gyermekintézmény",
    "gyermekjátékok": "gyermekjáték",
    "gyermekkel": "gyermek",
    "gyermekkora": "gyermekkor",
    "gyermekkorom": "gyermekkor",
    "gyermekkorunkban": "gyermekkor",
    "gyermekkorában": "gyermekkor",
    "gyermekkorából": "gyermekkor",
    "gyermekkorán": "gyermekkor",
    "gyermekkorát": "gyermekkor",
    "gyermekkorától": "gyermekkor",
    "gyermekként": "gyermek",
    "gyermeknek": "gyermek",
    "gyermekorvosok": "gyermekorvos",
    "gyermekrészlegbe": "gyermekrészleg",
    "gyermekujjak": "gyermekujj",
    "gyermekábécéktől": "gyermekábécé",
    "gyermeké": "gyermek",
    "gyermekét": "gyermek",
    "gyermekük": "gyermek",
    "gyertyacsonkot": "gyertyacsonk",
    "gyertyatartók": "gyertyatartó",
    "gyertyatartót": "gyertyatartó",
    "gyertyát": "gyertya",
    "gyertyával": "gyertya",
    "gyilkolnak": "gyilkol",
    "gyilkolni": "gyilkol",
    "gyilkolt": "gyilkol",
    "gyilkoltak": "gyilkolt",
    "gyilkolták": "gyilkol",
    "gyilkosa": "gyilkos",
    "gyilkosként": "gyilkos",
    "gyilkosok": "gyilkos",
    "gyilkosoknak": "gyilkos",
    "gyilkossá": "gyilkos",
    "gyilkossággal": "gyilkosság",
    "gyilkosságnál": "gyilkosság",
    "gyilkosságok": "gyilkosság",
    "gyilkosságot": "gyilkosság",
    "gyilkosságról": "gyilkosság",
    "gyomorban": "gyomor",
    "gyomorral": "gyomorr",
    "gyomosan": "gyomos",
    "gyomra": "gyomor",
    "gyomrodban": "gyomor",
    "gyomrom": "gyomor",
    "gyomrukat": "gyomor",
    "gyomrába": "gyomor",
    "gyomrában": "gyomor",
    "gyomrából": "gyomor",
    "gyomrán": "gyomor",
    "gyomrát": "gyomor",
    "gyomtól": "gyom",
    "gyors-at": "gyors",
    "gyorsabb": "gyors",
    "gyorsabban": "gyors",
    "gyorsan": "gyors",
    "gyorsan-t": "gyorsan",
    "gyorsasággal": "gyorsaság",
    "gyorsaságán": "gyorsaság",
    "gyorsjelentését": "gyorsjelentés",
    "gyorskezűnek": "gyorskezű",
    "gyorsra": "gyors",
    "gyorstalpalókon": "gyorstalpaló",
    "gyorsvonatból": "gyorsvonat",
    "gyorsvonathoz": "gyorsvonat",
    "gyorsítaná": "gyorsít",
    "gyorsított": "gyorsít",
    "gyorsítsunk": "gyorsít",
    "gyufaskatulyák": "gyufaskatulya",
    "gyufaszálakká": "gyufaszál",
    "gyufaszálat": "gyufaszál",
    "gyufája": "gyufa",
    "gyufásdobozából": "gyufásdoboz",
    "gyufával": "gyufa",
    "gyulladjon": "gyullad",
    "gyulladt": "gyullad",
    "gyulladásba": "gyulladás",
    "gyulát": "gyula",
    "gyámkodására": "gyámkodás",
    "gyámoltalanul": "gyámoltalan",
    "gyámságát": "gyámság",
    "gyámügyön": "gyámügy",
    "gyáraiban": "gyár",
    "gyárakat": "gyár",
    "gyárakba": "gyár",
    "gyárakból": "gyár",
    "gyárat": "gyár",
    "gyárba": "gyár",
    "gyárban": "gyár",
    "gyártanak": "gyárt",
    "gyártmánya": "gyártmány",
    "gyártottak": "gyártott",
    "gyártson": "gyárt",
    "gyártulajdonosát": "gyártulajdonos",
    "gyártása": "gyártás",
    "gyártásosan": "gyártásos",
    "gyártást": "gyártás",
    "gyártására": "gyártás",
    "gyártását": "gyártás",
    "gyártók": "gyártó",
    "gyártól": "gyár",
    "gyártónak": "gyártó",
    "gyászszertartáson": "gyászszertartás",
    "gyávaságom": "gyávaság",
    "gyávák": "gyáva",
    "gyáván": "gyáva",
    "gyíkocskák": "gyíkocská",
    "gyógymódot": "gyógymód",
    "gyógyszeralapanyagok": "gyógyszeralapanyag",
    "gyógyszeralapanyagokat": "gyógyszeralapanyag",
    "gyógyszereket": "gyógyszer",
    "gyógyszerekre": "gyógyszer",
    "gyógyszerkísérletek": "gyógyszerkísérlet",
    "gyógytornászok": "gyógytornász",
    "gyógyulatlanul": "gyógyulatlan",
    "gyógyuljon": "gyógyul",
    "gyógyulóban": "gyógyuló",
    "gyógyítanak": "gyógyít",
    "gyógyítani": "gyógyít",
    "gyógyítanom": "gyógyít",
    "gyógyított": "gyógyít",
    "gyógyítása": "gyógyítás",
    "gyógyításának": "gyógyítás",
    "gyógyítására": "gyógyítás",
    "gyógyítóinak": "gyógyítói",
    "gyónnia": "gyónik",
    "gyökeresen": "gyökeres",
    "gyökerestül": "gyökér",
    "gyökerezett": "gyökerezik",
    "gyöngyikét": "gyöngyike",
    "gyöngyit": "gyöngyi",
    "gyöngyöztek": "gyöngyözik",
    "gyöngéd": "gyönge",
    "gyöngéim": "gyönge",
    "gyönyöre": "gyönyör",
    "gyönyörködött": "gyönyörködik",
    "gyönyört": "gyönyör",
    "gyönyörűbb": "gyönyörű",
    "gyönyörűséggel": "gyönyörűség",
    "gyönyörűségére": "gyönyörűség",
    "gyötrelemmé": "gyötrelem",
    "gyötörte": "gyötör",
    "gyötörtem": "gyötör",
    "gyötörték": "gyötör",
    "gyújtani": "gyújt",
    "gyújtott": "gyújt",
    "gyújtószerkezetének": "gyújtószerkezet",
    "gyúlt": "gyúl",
    "gyülekezetek": "gyülekezet",
    "gyülekezeteknek": "gyülekezet",
    "gyülekezeti": "gyülekezet",
    "gyülekeznek": "gyülekezik",
    "gyülemlettek": "gyülemlik",
    "gyümölcs-nagykereskedését": "gyümölcs-nagykereskedés",
    "gyümölcshámozást": "gyümölcshámozás",
    "gyümölcsét": "gyümölcs",
    "gyümölcsök": "gyümölcs",
    "gyümölcsöt": "gyümölcs",
    "gyümölcsözővé": "gyümölcsöző",
    "győzelem-cigarettát": "győzelem-cigaretta",
    "győzelem-ginnel": "győzelem-gin",
    "győzelem-gint": "győzelem-gin",
    "győzelem-kávéból": "győzelem-kávé",
    "győzelem-kávét": "győzelem-kávé",
    "győzelem-kávéé": "győzelem-kávé",
    "győzelem-tömbben": "győzelem-tömb",
    "győzelem-tömböt": "győzelem-tömb",
    "győzelemben": "győzelem",
    "győzelemmel": "győzelem",
    "győzelemre": "győzelem",
    "győzelme": "győzelem",
    "győzelmek": "győzelem",
    "győzelmeken": "győzelem",
    "győzelmeknek": "győzelem",
    "győzelmeként": "győzelem",
    "győzelmet": "győzelem",
    "győzelmének": "győzelem",
    "győzelmét": "győzelem",
    "győzelmük": "győzelem",
    "győzhetnek": "győzhet",
    "győzi": "győz",
    "győznek": "győz",
    "győzni": "győz",
    "győznünk": "győz",
    "győzte": "győz",
    "győztesével": "győztes",
    "győzték": "győz",
    "győzött": "győz",
    "győződött": "győződik",
    "gyűjteménye": "gyűjtemény",
    "gyűjtenek": "gyűjt",
    "gyűjteni": "gyűjt",
    "gyűjtik": "gyűjt",
    "gyűjtésben": "gyűjtés",
    "gyűjtésedben": "gyűjtés",
    "gyűjtésére": "gyűjtés",
    "gyűjtésével": "gyűjtés",
    "gyűjtök": "gyűjt",
    "gyűjtött": "gyűjt",
    "gyűjtötte": "gyűjt",
    "gyűjtők": "gyűjtő",
    "gyűlik": "gyűl",
    "gyűlt": "gyűlik",
    "gyűltek": "gyűlik",
    "gyűlése": "gyűlés",
    "gyűlések": "gyűlés",
    "gyűléseken": "gyűlés",
    "gyűléseket": "gyűlés",
    "gyűlésen": "gyűlés",
    "gyűléseznek": "gyűlésezik",
    "gyűlésig": "gyűlés",
    "gyűlésről": "gyűlés",
    "gyűlést": "gyűlés",
    "gyűlését": "gyűlés",
    "gyűlöletbe": "gyűlölet",
    "gyűlöletben": "gyűlölet",
    "gyűlölete": "gyűlölet",
    "gyűlöleten": "gyűlölet",
    "gyűlöletet": "gyűlölet",
    "gyűlöletnek": "gyűlölet",
    "gyűlöletre": "gyűlölet",
    "gyűlöletről": "gyűlölet",
    "gyűlölettel": "gyűlölet",
    "gyűlölettől": "gyűlölet",
    "gyűlöletért": "gyűlölet",
    "gyűlöletét": "gyűlölet",
    "gyűlöli": "gyűlöl",
    "gyűlölködtek": "gyűlölködik",
    "gyűlölködéssel": "gyűlölködés",
    "gyűlöllek": "gyűlöl",
    "gyűlölnek": "gyűlöl",
    "gyűlölni": "gyűlöl",
    "gyűlölséggel": "gyűlölség",
    "gyűlölte": "gyűlöl",
    "gyűlöltek": "gyűlölt",
    "gyűlölték": "gyűlöl",
    "gyűlölöd": "gyűlöl",
    "gyűlölöm": "gyűlöl",
    "gyűrt": "gyűr",
    "gyűrték": "gyűr",
    "gyűrésekkel": "gyűrés",
    "gyűrögeti": "gyűröget",
    "gyűrődéseket": "gyűrődés",
    "gyűrűhöz": "gyűrű",
    "gyűrűje": "gyűrű",
    "gyűrűjében": "gyűrű",
    "gyűrűk": "gyűrű",
    "gyűrűként": "gyűrű",
    "gyűrűnknek": "gyűrű",
    "gyűrűről": "gyűrű",
    "gyűrűt": "gyűrű",
    "gyűrűzik": "gyűrűz",
    "gyűrűzött": "gyűrűzik",
    "gálánsan": "gáláns",
    "gátakat": "gát",
    "gátat": "gát",
    "gátlástalanságuk": "gátlástalanság",
    "gátolta": "gátol",
    "gázai": "gáz",
    "gázkamrák": "gázkamra",
    "gázlángok": "gázláng",
    "gázok": "gáz",
    "gázolnak": "gázol",
    "gázoltak": "gázolt",
    "gázszolgáltatókban": "gázszolgáltató",
    "gáztűzhelyeket": "gáztűzhely",
    "gázvezetékeit": "gázvezeték",
    "gázzal": "gáz",
    "gázzá": "gáz",
    "gének": "gén",
    "gépbe": "gép",
    "gépből": "gép",
    "gépe": "gép",
    "gépek": "gép",
    "gépeket": "gép",
    "gépekkel": "gép",
    "gépekre": "gép",
    "gépelt": "gépel",
    "gépesített": "gépesít",
    "gépesítésre": "gépesítés",
    "gépesítésről": "gépesítés",
    "gépesítéssel": "gépesítés",
    "gépet": "gép",
    "gépezetből": "gépezet",
    "gépezetet": "gépezet",
    "gépezetét": "gépezet",
    "géphez": "gép",
    "gépiesen": "gépies",
    "gépjeivel": "gép",
    "gépjárműadóból": "gépjárműadó",
    "gépjárműfelelősség-biztosítások": "gépjárműfelelősség-biztosítás",
    "gépjárműfelelősség-biztosítását": "gépjárműfelelősség-biztosítás",
    "gépjárműimportőrök": "gépjárműimportőr",
    "gépjárműre": "gépjármű",
    "gépjárművek": "gépjármű",
    "gépjárműveket": "gépjármű",
    "gépkapában": "gépkapa",
    "gépkocsijukkal": "gépkocsi",
    "gépkocsijának": "gépkocsi",
    "gépkocsiját": "gépkocsi",
    "gépkocsik": "gépkocsi",
    "gépkocsin": "gépkocsi",
    "gépkocsit": "gépkocsi",
    "géppel": "gép",
    "géppisztollyal": "géppisztoly",
    "géppisztolyt": "géppisztoly",
    "géppuskafészkek": "géppuskafészek",
    "géppuskairányzékán": "géppuskairányzék",
    "géppuskáját": "géppuska",
    "gépszíj-idegeket": "gépszíj-ideg",
    "gépzenét": "gépzene",
    "gépük": "gép",
    "gócpontja": "gócpont",
    "gólaránnyal": "gólarány",
    "gólja": "gól",
    "góljaival": "gól",
    "gólját": "gól",
    "góljával": "gól",
    "góllal": "gól",
    "gólokat": "gól",
    "gólt": "gól",
    "gólyák": "gólya",
    "gólyát": "gólya",
    "gödröt": "gödör",
    "gödöllőiek": "gödöllői",
    "gödörből": "gödör",
    "gömböcskéi": "gömböcské",
    "gömböket": "gömb",
    "gömbölyödött": "gömbölyödik",
    "gömbölyűre": "gömbölyű",
    "görbék": "görbe",
    "görbített": "görbít",
    "görcsösen": "görcsös",
    "gördült": "gördül",
    "görögtanyán": "görögtanya",
    "görögtanyát": "görögtanya",
    "görögök": "görög",
    "görögökben": "görög",
    "görögöktől": "görög",
    "görögön": "görög",
    "göröngyökkel": "göröngy",
    "gúnnyal": "gúny",
    "gúnydalt": "gúnydal",
    "gúnynevükön": "gúnynév",
    "gúnyolja": "gúnyol",
    "gúnyolni": "gúnyol",
    "gúnyolódásban": "gúnyolódás",
    "gúnyolódásának": "gúnyolódás",
    "gúnyosan": "gúnyos",
    "gúnyosnak": "gúnyos",
    "gúnyt": "gúny",
    "gürcölnek": "gürcöl",
    "gürcöltek": "gürcöl",
    "gőgös-gúnyosan": "gőgös-gúnyos",
    "gőzzel": "gőz",
    "gőzzé": "gőz",
    "gőzösíteni": "gőzösít",
    "habok": "hab",
    "habozott": "habozik",
    "hadart": "hadar",
    "hadarása": "hadarás",
    "haderőink": "haderő",
    "haderők": "haderő",
    "hadifoglyok": "hadifogoly",
    "hadifoglyokat": "hadifogoly",
    "hadifoglyokkal": "hadifogoly",
    "hadifoglyoktól": "hadifogoly",
    "hadifogolyként": "hadifogoly",
    "hadifogolynak": "hadifogoly",
    "hadifogságban": "hadifogság",
    "hadihajóikat": "hadihajó",
    "hadijelentést": "hadijelentés",
    "hadilábon": "hadiláb",
    "hadiszerencsétől": "hadiszerencse",
    "haditechnikának": "haditechnika",
    "haditette": "haditett",
    "haditettet": "haditett",
    "hadjáratok": "hadjárat",
    "hadműveletek": "hadművelet",
    "hadműveleteket": "hadművelet",
    "hadműveletre": "hadművelet",
    "hadonásztak": "hadonászik",
    "hadseregben": "hadsereg",
    "hadsereget": "hadsereg",
    "hadseregéről": "hadsereg",
    "hadseregük": "hadsereg",
    "hadszíntérré": "hadszíntér",
    "hadtestnél": "hadtest",
    "hadtestparancsnoksághoz": "hadtestparancsnokság",
    "hadviseléssel": "hadviselés",
    "hadügyminisztériumba": "hadügyminisztérium",
    "hagyatkozott": "hagyatkozik",
    "hagyd": "hagy",
    "hagyhatják": "hagyhat",
    "hagyhatnak": "hagyhat",
    "hagyhatom": "hagyhat",
    "hagyj": "hagy",
    "hagyja": "hagy",
    "hagyjanak": "hagy",
    "hagyjatok": "hagy",
    "hagyjuk": "hagy",
    "hagyják": "hagy",
    "hagyjátok": "hagy",
    "hagymakupolák": "hagymakupola",
    "hagynak": "hagy",
    "hagyni": "hagy",
    "hagyniuk": "hagy",
    "hagynod": "hagy",
    "hagynom": "hagy",
    "hagynák": "hagy",
    "hagyom": "hagy",
    "hagyománnyal": "hagyomány",
    "hagyománya": "hagyomány",
    "hagyományaikhoz": "hagyomány",
    "hagyományait": "hagyomány",
    "hagyományosan": "hagyományos",
    "hagyományozásával": "hagyományozás",
    "hagyott": "hagy",
    "hagyta": "hagy",
    "hagytad": "hagy",
    "hagytak": "hagy",
    "hagytam": "hagy",
    "hagytuk": "hagy",
    "hagyták": "hagy",
    "hagyunk": "hagy",
    "hagyásával": "hagyás",
    "haja": "haj",
    "hajad": "haj",
    "hajamban": "haj",
    "hajat": "haj",
    "hajcsomókon": "hajcsomó",
    "hajcsomót": "hajcsomó",
    "hajdankoré": "hajdankor",
    "hajdanában": "hajdana",
    "hajdúmegyeiek": "hajdúmegyei",
    "hajfürtje": "hajfürt",
    "hajfürtjei": "hajfürt",
    "hajigálják": "hajigál",
    "hajjal": "haj",
    "hajkoronával": "hajkorona",
    "hajkurászták": "hajkurász",
    "hajlamok": "hajlam",
    "hajlamosak": "hajlamos",
    "hajlamot": "hajlam",
    "hajlamát": "hajlam",
    "hajlandóak": "hajlandó",
    "hajlandók": "hajlandó",
    "hajlandónak": "hajlandó",
    "hajlatban": "hajlat",
    "hajlatába": "hajlat",
    "hajlatából": "hajlat",
    "hajlott": "hajlik",
    "hajlottunk": "hajlott",
    "hajlékonyabb": "hajlékony",
    "hajlított": "hajlít",
    "hajnalban": "hajnal",
    "hajnalig": "hajnal",
    "hajnalodott": "hajnalodik",
    "hajnalokon": "hajnal",
    "hajnalon": "hajnal",
    "hajnalonként": "hajnal",
    "hajnalra": "hajnal",
    "hajnaltól": "hajnal",
    "hajnalán": "hajnal",
    "hajolni": "hajol",
    "hajolnia": "hajol",
    "hajolt": "hajol",
    "hajoltok": "hajol",
    "hajra": "haj",
    "hajrában": "hajrá",
    "hajszolják": "hajszol",
    "hajszolták": "hajszol",
    "hajszálig": "hajszál",
    "hajszálnyit": "hajszálnyi",
    "hajszára": "hajsza",
    "hajszától": "hajsza",
    "hajszínéért": "hajszín",
    "hajsörénnyel": "hajsörény",
    "hajtanak": "hajt",
    "hajtani": "hajt",
    "hajthatatlanok": "hajthatatlan",
    "hajtja": "hajt",
    "hajtják": "hajt",
    "hajtott": "hajt",
    "hajtotta": "hajt",
    "hajtottak": "hajtott",
    "hajtották": "hajt",
    "hajts": "hajt",
    "hajtsam": "hajt",
    "hajtányzörgést": "hajtányzörgés",
    "hajtásra": "hajtás",
    "hajtóerőként": "hajtóerő",
    "hajtók": "hajtó",
    "hajzatot": "hajzat",
    "hajába": "haj",
    "hajában": "haj",
    "hajából": "haj",
    "haján": "haj",
    "hajának": "haj",
    "hajánál": "haj",
    "hajára": "haj",
    "hajáról": "haj",
    "haját": "haj",
    "hajával": "haj",
    "hajította": "hajít",
    "hajóit": "hajói",
    "hajója": "hajó",
    "hajójának": "hajó",
    "hajón": "hajó",
    "hajóról": "hajó",
    "hajósiak": "hajósi",
    "hajóutak": "hajóút",
    "hajózhatóságával": "hajózhatóság",
    "hajózunk": "hajózik",
    "halad": "hal",
    "haladhatja": "haladhat",
    "haladja": "halad",
    "haladjon": "halad",
    "haladnak": "halad",
    "haladni": "halad",
    "haladnod": "halad",
    "haladt": "halad",
    "haladta": "halad",
    "haladtak": "haladt",
    "haladtam": "haladt",
    "haladtok": "halad",
    "haladtunk": "haladt",
    "haladták": "halad",
    "haladunk": "haladu",
    "haladása": "haladás",
    "haladást": "haladás",
    "haladékot": "haladék",
    "haladósabb": "haladós",
    "halainkon": "hal",
    "halak": "hal",
    "halakat": "hal",
    "halakra": "hal",
    "halandók": "halandó",
    "halaszthatatlanná": "halaszthatatlan",
    "halaszthatták": "halaszthat",
    "halasztotta": "halaszt",
    "halasztották": "halaszt",
    "halat": "hal",
    "halcsendéletei": "halcsendélet",
    "haldoklásban": "haldoklás",
    "haldoklásában": "haldoklás",
    "haldoklónak": "haldokló",
    "haleldorádónak": "haleldorádó",
    "halfajtákat": "halfajtá",
    "halfejet": "halfej",
    "halhassanak": "halhat",
    "halhatatlanok": "halhatatlan",
    "halhatna": "halhat",
    "haljanak": "hal",
    "halkabb": "halk",
    "halkabbak": "halk",
    "halkabbra": "halk",
    "halkan": "halk",
    "halkra": "halk",
    "halkítani": "halkít",
    "hallani": "hallik",
    "hallaná": "hallik",
    "hallasz": "hallik",
    "hallatlanul": "hallatlan",
    "hallatott": "hallat",
    "hallatszott": "hallatszik",
    "hallatszottak": "hallatszott",
    "hallatára": "hallata",
    "hallgasd": "hallgat",
    "hallgassanak": "hallgat",
    "hallgatagok": "hallgatag",
    "hallgatagon": "hallgatag",
    "hallgathattam": "hallgathat",
    "hallgatja": "hallgat",
    "hallgatják": "hallgat",
    "hallgatnak": "hallgat",
    "hallgatni": "hallgat",
    "hallgatnia": "hallgat",
    "hallgatott": "hallgat",
    "hallgatta": "hallgat",
    "hallgattak": "hallgat",
    "hallgattuk": "hallgat",
    "hallgattunk": "hallgat",
    "hallgatták": "hallgat",
    "hallgatása": "hallgatás",
    "hallgatásba": "hallgatás",
    "hallgatását": "hallgatás",
    "hallgatói": "hallgató",
    "hallgatók": "hallgató",
    "hallgatólagosan": "hallgatólagos",
    "hallgatónak": "hallgató",
    "hallgatósághoz": "hallgatóság",
    "hallgatóságát": "hallgatóság",
    "hallgatót": "hallgató",
    "hallgatózhassanak": "hallgatózhat",
    "hallgatózott": "hallgatóz",
    "hallhatták": "hallhat",
    "hallja": "hallik",
    "halljak": "hallik",
    "halljon": "hallik",
    "hallják": "hallik",
    "hallod": "hallik",
    "hallok": "hallik",
    "hallom": "hallik",
    "hallott": "hallik",
    "hallotta": "hallik",
    "hallottad": "hallott",
    "hallottak": "hallott",
    "hallottam": "hallott",
    "hallottatok": "hallott",
    "hallottuk": "hallik",
    "hallottunk": "hallott",
    "hallották": "hallik",
    "hallottál": "hallik",
    "hallottátok": "hallik",
    "halltól": "hall",
    "hallásra": "hallás",
    "hallótávolságán": "hallótávolság",
    "halma": "halom",
    "halmai": "halom",
    "halmon": "halom",
    "halmoznak": "halmoz",
    "halmozott": "halmoz",
    "halmoztak": "halmoz",
    "halnak": "hal",
    "halni": "hal",
    "halogatni": "halogat",
    "halogatott": "halogat",
    "halogatásának": "halogatás",
    "halom": "hal",
    "halottak": "halott",
    "halottakkal": "halott",
    "halottaskocsikat": "halottaskocsi",
    "halottfehéren": "halottfehér",
    "halottnak": "halott",
    "halt": "hal",
    "haltak": "halt",
    "halványan": "halvány",
    "halványult": "halványul",
    "halála": "halál",
    "halálba": "halál",
    "halálban": "halál",
    "halálhoz": "halál",
    "halálig": "halál",
    "halálimádatnak": "halálimádat",
    "halállal": "haláll",
    "halálnak": "halál",
    "halálodig": "halál",
    "halálomig": "halálom",
    "halálosabb": "halálos",
    "halálosan": "halálos",
    "halálosinjekció-gépét": "halálosinjekció-gép",
    "halálra": "halál",
    "halálról": "halál",
    "halált": "halál",
    "haláltáborba": "haláltábor",
    "haláltáborból": "haláltábor",
    "haláltánca": "haláltánc",
    "haláltól": "halál",
    "haláluk": "halál",
    "halálukat": "halál",
    "halálukig": "halál",
    "halálához": "halál",
    "haláláig": "halál",
    "halálánál": "halál",
    "halálára": "halál",
    "haláláról": "halál",
    "halálát": "halál",
    "halántékán": "halánték",
    "halántékára": "halánték",
    "halántékát": "halánték",
    "halászbástyától": "halászbástya",
    "halásznak": "halászik",
    "halászok": "halászik",
    "hamarabb": "hamar",
    "hamarjában": "hamar",
    "hamarkodja": "hamarkodik",
    "hamarosan": "hamaros",
    "hamarább": "hamar",
    "hamisak": "hamis",
    "hamisítani": "hamisít",
    "hamisítania": "hamisít",
    "hamisított": "hamisít",
    "hamisítottak": "hamisított",
    "hamisítványok": "hamisítvány",
    "hamisítások": "hamisítás",
    "hamisításokról": "hamisítás",
    "hamisításról": "hamisítás",
    "hamisítást": "hamisítás",
    "hamisítót": "hamisító",
    "hamuja": "hamu",
    "hamuvá": "hamu",
    "hamvaiból": "hamv",
    "hangadóhoz": "hangadó",
    "hangarchívuma": "hangarchívum",
    "hangból": "hang",
    "hangereje": "hangerő",
    "hangfelvételeket": "hangfelvétel",
    "hanghordozásában": "hanghordozás",
    "hanghordozását": "hanghordozás",
    "hangja": "hang",
    "hangjai": "hang",
    "hangjába": "hang",
    "hangjában": "hang",
    "hangjából": "hang",
    "hangján": "hang",
    "hangjának": "hang",
    "hangjára": "hang",
    "hangját": "hang",
    "hangjával": "hang",
    "hanglejtésében": "hanglejtés",
    "hanglemez-nek": "hanglemez",
    "hanglemezeken": "hanglemez",
    "hanglemezeket": "hanglemez",
    "hangmagasságban": "hangmagasság",
    "hangnak": "hang",
    "hangnemben": "hangnem",
    "hangnemet": "hangnem",
    "hangok": "hang",
    "hangokat": "hang",
    "hangolni": "hangol",
    "hangolta": "hangol",
    "hangomat": "hang",
    "hangon": "hang",
    "hangosabban": "hangos",
    "hangosan": "hangos",
    "hangosbemondóval": "hangosbemondó",
    "hangoskodott": "hangoskodik",
    "hangot": "hang",
    "hangotok": "hang",
    "hangozhatott": "hangozhat",
    "hangoztatja": "hangoztat",
    "hangoztatta": "hangoztat",
    "hangra": "hang",
    "hangszalagra": "hangszalag",
    "hangszerek": "hangszer",
    "hangszíngazdagsága": "hangszíngazdagság",
    "hangszínnel": "hangszín",
    "hangszórók": "hangszóró",
    "hangsúlya": "hangsúly",
    "hangsúlyok": "hangsúly",
    "hangsúlyozni": "hangsúlyoz",
    "hangsúlyozottabbá": "hangsúlyozott",
    "hangsúlyozta": "hangsúlyoz",
    "hangsúlyozták": "hangsúlyoz",
    "hangsúlyozzák": "hangsúlyoz",
    "hangsúlyt": "hangsúly",
    "hangtalanul": "hangtalan",
    "hangulatba": "hangulat",
    "hangulatban": "hangulat",
    "hangulatot": "hangulat",
    "hangulattal": "hangulat",
    "hangulatában": "hangulat",
    "hangulatát": "hangulat",
    "hangversenye": "hangverseny",
    "hangversenyeiken": "hangverseny",
    "hangversenytermeiben": "hangversenyterem",
    "hangyabolyhoz": "hangyaboly",
    "hangzanak": "hangzik",
    "hangzavarba": "hangzavar",
    "hangzavarban": "hangzavar",
    "hangzavarból": "hangzavar",
    "hangzavarrá": "hangzavar",
    "hangzott": "hangzik",
    "hangzottak": "hangzott",
    "hangzásuk": "hangzás",
    "hangzóját": "hangzó",
    "hangáradat": "hangár",
    "hangáradatból": "hangáradat",
    "hanyagul": "hanyag",
    "hanyatlott": "hanyatlik",
    "hanyatlóban": "hanyatló",
    "haragban": "harag",
    "haragfelhők": "haragfelhő",
    "haragja": "harag",
    "haragjuk": "harag",
    "haragjukban": "harag",
    "haragjának": "harag",
    "haragját": "harag",
    "haragjától": "harag",
    "haragok": "harag",
    "haragosuk": "haragos",
    "haragot": "harag",
    "haragszanak": "haragszik",
    "haragudni": "haragszik",
    "haragudott": "haragszik",
    "haragudtak": "haragszik",
    "haragudtunk": "haragszik",
    "haragunkat": "harag",
    "haragunkban": "harag",
    "haramiát": "haramia",
    "harangja": "harang",
    "harangjai": "harang",
    "harangjait": "harang",
    "harangok": "harang",
    "harangokat": "harang",
    "harangot": "harang",
    "harangozni": "harangozik",
    "harangszót": "harangszó",
    "harangtornyaiban": "harangtorony",
    "harangtornyában": "harangtorony",
    "harangvirágok": "harangvirág",
    "harangvirágot": "harangvirág",
    "harapni": "harap",
    "harapott": "harap",
    "harapófogója": "harapófogó",
    "harcaira": "harc",
    "harcba": "harc",
    "harcban": "harc",
    "harciasan": "harcias",
    "harckészültségbe": "harckészültség",
    "harcmezőn": "harcmező",
    "harcnak": "harc",
    "harcok": "harc",
    "harcoljunk": "harcol",
    "harcolnak": "harcol",
    "harcolni": "harcol",
    "harcolniuk": "harcol",
    "harcolnának": "harcol",
    "harcolsz": "harcol",
    "harcolt": "harcol",
    "harcoltak": "harcolt",
    "harcoltál": "harcol",
    "harcosainak": "harcos",
    "harcosok": "harcos",
    "harcosokból": "harcos",
    "harcot": "harc",
    "harcra": "harc",
    "harcsabajusza": "harcsabajusz",
    "harctérre": "harctér",
    "harcunk": "harc",
    "harcát": "harc",
    "harisnyavégből": "harisnyavég",
    "harisnyája": "harisnyáj",
    "harisnyákból": "harisnyák",
    "harisnyát": "harisnya",
    "harmada": "harmad",
    "harmadikat": "harmadik",
    "harmadiknak": "harmadik",
    "harmadikról": "harmadik",
    "harmadikára": "harmadika",
    "harmadost": "harmados",
    "harmadszor": "harmad",
    "harmadában": "harmad",
    "harmadát": "harmad",
    "harmattól": "harmat",
    "harmatát": "harmat",
    "harmincan": "harminc",
    "harminckor": "harminc",
    "harmincra": "harminc",
    "harminctól": "harminc",
    "harmincötre": "harmincöt",
    "harsant": "harsan",
    "harsantak": "harsant",
    "harsogni": "harsog",
    "harsogott": "harsog",
    "harsogta": "harsog",
    "harsogása": "harsogás",
    "harsogásával": "harsogás",
    "harsonaszóval": "harsonaszó",
    "hasakban": "has",
    "hasalja": "hasal",
    "hasogatott": "hasogat",
    "hason": "has",
    "hasonlítanak": "hasonlít",
    "hasonlíthatjuk": "hasonlíthat",
    "hasonlítjuk": "hasonlít",
    "hasonlított": "hasonlít",
    "hasonlítottak": "hasonlított",
    "hasonlóan": "hasonló",
    "hasonlók": "hasonló",
    "hasonlókat": "hasonló",
    "hasonlóképpen": "hasonló",
    "hasonulni": "hasonul",
    "hasra": "has",
    "hasuk": "has",
    "hasukat": "has",
    "hasukon": "has",
    "hasunkért": "has",
    "haszna": "haszon",
    "hasznavehetetlenné": "hasznavehetetlen",
    "hasznosabb": "hasznos",
    "hasznosakat": "hasznos",
    "hasznosnak": "hasznos",
    "hasznossá": "hasznos",
    "hasznossággal": "hasznosság",
    "hasznosult": "hasznosul",
    "hasznosítja": "hasznosít",
    "hasznosított": "hasznosít",
    "hasznosítása": "hasznosítás",
    "hasznosítására": "hasznosítás",
    "hasznot": "haszon",
    "hasznuk": "haszon",
    "hasznukat": "haszon",
    "használata": "használat",
    "használatakor": "használat",
    "használatban": "használat",
    "használatlanok": "használatlan",
    "használaton": "használat",
    "használatra": "használat",
    "használatuk": "használat",
    "használatának": "használat",
    "használatára": "használat",
    "használatáról": "használat",
    "használatát": "használat",
    "használatával": "használat",
    "használatáért": "használat",
    "használhatatlanná": "használhatatlan",
    "használhatja": "használhat",
    "használhatják": "használhat",
    "használhatta": "használhat",
    "használhatónak": "használható",
    "használja": "használ",
    "használjon": "használ",
    "használjuk": "használ",
    "használjunk": "használ",
    "használják": "használ",
    "használnak": "használ",
    "használni": "használ",
    "használniuk": "használ",
    "használnom": "használ",
    "használnák": "használ",
    "használom": "használ",
    "használt": "használ",
    "használta": "használ",
    "használtak": "használt",
    "használták": "használ",
    "használunk": "használ",
    "használóira": "használói",
    "használójával": "használó",
    "hasznára": "haszon",
    "hasznát": "haszon",
    "haszonjárművek": "haszonjármű",
    "haszonnal": "haszon",
    "haszonról": "haszon",
    "haszontalanságokat": "haszontalanság",
    "haszontalanságával": "haszontalanság",
    "hasztalanul": "hasztalan",
    "hasábjain": "hasáb",
    "hasábokat": "hasáb",
    "hasábokon": "hasáb",
    "hasát": "has",
    "hasítja": "hasít",
    "hasított": "hasít",
    "hasítottak": "hasított",
    "hatalma": "hatalom",
    "hatalmak": "hatalom",
    "hatalmakkal": "hatalom",
    "hatalmaknak": "hatalom",
    "hatalmamban": "hatalom",
    "hatalmasabb": "hatalmas",
    "hatalmasak": "hatalmas",
    "hatalmasat": "hatalmas",
    "hatalmasok": "hatalmas",
    "hatalmat": "hatalom",
    "hatalmon": "hatalom",
    "hatalmuk": "hatalom",
    "hatalmukat": "hatalom",
    "hatalmukba": "hatalom",
    "hatalmunk": "hatalom",
    "hatalmunkba": "hatalom",
    "hatalmunkban": "hatalom",
    "hatalmába": "hatalom",
    "hatalmában": "hatalom",
    "hatalmának": "hatalom",
    "hatalmát": "hatalom",
    "hatalmával": "hatalom",
    "hatalomba": "hatalom",
    "hatalomból": "hatalom",
    "hatalomhoz": "hatalom",
    "hatalommal": "hatalom",
    "hatalomnak": "hatalom",
    "hatalomra": "hatalom",
    "hatalomról": "hatalom",
    "hatalomtól": "hatalom",
    "hatalomért": "hatalom",
    "hatmillióban": "hatmillió",
    "hatna": "hat",
    "hatnak": "hat",
    "hatni": "hat",
    "hatolni": "hatol",
    "hatolt": "hatol",
    "hatoltak": "hatolt",
    "hatot": "hat",
    "hatott": "hat",
    "hatotta": "hat",
    "hatottak": "hatott",
    "hatszor": "hat",
    "hatszor-hétszer": "hat-hét",
    "hatvanan": "hatvan",
    "hatvanheten": "hatvanhét",
    "hatvanra": "hatvan",
    "hatállyal": "hatály",
    "hatálya": "hatály",
    "hatályba": "hatály",
    "hatálybalépésének": "hatálybalépés",
    "hatályon": "hatály",
    "hatálytalanítsa": "hatálytalanít",
    "hatályát": "hatály",
    "határai": "határ",
    "határain": "határ",
    "határait": "határ",
    "határba": "határ",
    "határban": "határ",
    "határból": "határ",
    "határhoz": "határ",
    "határideje": "határidő",
    "határidejének": "határidő",
    "határidejét": "határidő",
    "határidőhöz": "határidő",
    "határidőig": "határidő",
    "határidők": "határidő",
    "határidőn": "határidő",
    "határidőre": "határidő",
    "határidőt": "határidő",
    "határig": "határ",
    "határköve": "határkő",
    "határnál": "határ",
    "határok": "határ",
    "határokat": "határ",
    "határokhoz": "határ",
    "határokon": "határ",
    "határolni": "határol",
    "határolta": "határol",
    "határon": "határ",
    "határozata": "határozat",
    "határozatban": "határozat",
    "határozatlanná": "határozatlan",
    "határozatlanságban": "határozatlanság",
    "határozatlanságát": "határozatlanság",
    "határozatlanul": "határozatlan",
    "határozatnak": "határozat",
    "határozatot": "határozat",
    "határozatát": "határozat",
    "határozatával": "határozat",
    "határozhatnának": "határozhat",
    "határoznia": "határoz",
    "határozott": "határoz",
    "határozottabb": "határozott",
    "határozottak": "határozott",
    "határozottan": "határozott",
    "határozta": "határoz",
    "határoztak": "határoz",
    "határoztam": "határoz",
    "határoztuk": "határoz",
    "határozták": "határoz",
    "határozza": "határoz",
    "határozzák": "határoz",
    "határozószóink": "határozószó",
    "határozószókat": "határozószó",
    "határozószóként": "határozószó",
    "határra": "határ",
    "határsorompók": "határsorompó",
    "határt": "határ",
    "határtól": "határ",
    "határunkban": "határ",
    "határunkon": "határ",
    "határvidéke": "határvidék",
    "határvonalakat": "határvonal",
    "határában": "határ",
    "határáig": "határ",
    "határállomásokon": "határállomás",
    "határán": "határ",
    "határának": "határ",
    "határára": "határár",
    "határát": "határ",
    "határátkelőinél": "határátkelői",
    "határátkelőkön": "határátkelő",
    "határőrök": "határőr",
    "határőrökhöz": "határőr",
    "hatása": "hatás",
    "hatásairól": "hatás",
    "hatáskörébe": "hatáskör",
    "hatáskörében": "hatáskör",
    "hatásköréről": "hatáskör",
    "hatáskörét": "hatáskör",
    "hatáskörömbe": "hatásköröm",
    "hatáskörükben": "hatáskör",
    "hatáskörükön": "hatáskör",
    "hatáskörünkön": "hatáskör",
    "hatásokat": "hatás",
    "hatásosabb": "hatásos",
    "hatásossá": "hatásos",
    "hatással": "hatás",
    "hatást": "hatás",
    "hatástalannak": "hatástalan",
    "hatástalanok": "hatástalan",
    "hatástalanítására": "hatástalanítás",
    "hatásukat": "hatás",
    "hatására": "hatás",
    "hatását": "hatás",
    "hatásától": "hatás",
    "hatásával": "hatás",
    "hatékonyabb": "hatékony",
    "hatékonyabban": "hatékony",
    "hatékonynak": "hatékony",
    "hatékonysága": "hatékonyság",
    "hatékonysággal": "hatékonyság",
    "hatékonyságnövelést": "hatékonyságnövelés",
    "hatékonyságra": "hatékonyság",
    "hatékonyságára": "hatékonyság",
    "hatékonyságát": "hatékonyság",
    "hatóerőre": "hatóerő",
    "hatóerőt": "hatóerő",
    "hatóerővel": "hatóerő",
    "hatóerőért": "hatóerő",
    "hatókörén": "hatókör",
    "hatóságként": "hatóság",
    "hatóságnak": "hatóság",
    "hatóságok": "hatóság",
    "hatóságoknak": "hatóság",
    "hatóságoknál": "hatóság",
    "hatóságokra": "hatóság",
    "hatóságot": "hatóság",
    "havasabb": "havas",
    "havasak": "havas",
    "havat": "hó",
    "havazások": "havazás",
    "havazással": "havazás",
    "havazást": "havazás",
    "hazacipelni": "hazacipel",
    "hazacsempészi": "hazacsempész",
    "hazacsempészni": "hazacsempész",
    "hazahoznak": "hazahoz",
    "hazahozott": "hazahoz",
    "hazahozza": "hazahoz",
    "hazaiak": "hazai",
    "hazajusson": "hazajut",
    "hazajuthasson": "hazajuthat",
    "hazajutok": "hazajut",
    "hazajuttatni": "hazajuttat",
    "hazajönni": "hazajön",
    "hazajöttek": "hazajön",
    "hazajöttem": "hazajön",
    "hazajöttél": "hazajön",
    "hazajöttünk": "hazajött",
    "hazaküldik": "hazaküld",
    "hazaküldtek": "hazaküld",
    "hazamegyek": "hazamegy",
    "hazamegyünk": "hazamegy",
    "hazamehessünk": "hazamehet",
    "hazamehetnék": "hazamehet",
    "hazamenetelre": "hazamenetel",
    "hazamennek": "hazamegy",
    "hazamennem": "hazamegy",
    "hazamenni": "hazamegy",
    "hazament": "hazamegy",
    "hazamentek": "hazament",
    "hazamenéstől": "hazamenés",
    "hazaszállítanak": "hazaszállít",
    "hazaszállításának": "hazaszállítás",
    "hazaszállításáról": "hazaszállítás",
    "hazaszökni": "hazaszökik",
    "hazatoloncolják": "hazatoloncol",
    "hazatoloncoltatjuk": "hazatoloncoltat",
    "hazatért": "hazatér",
    "hazatérte": "hazatér",
    "hazatérésre": "hazatérés",
    "hazaviszem": "hazavisz",
    "hazaviszik": "hazavisz",
    "hazavitték": "hazavisz",
    "hazavágyott": "hazavágyik",
    "hazazavarnak": "hazazavar",
    "hazaárulásról": "hazaárulás",
    "hazaárulók": "hazaáruló",
    "hazaérkezett": "hazaérkezik",
    "hazaérkeztünk": "hazaérkezik",
    "hazaérkezése": "hazaérkezés",
    "hazaérkezésnek": "hazaérkezés",
    "hazaért": "hazaérik",
    "hazaértem": "hazaért",
    "hazaérve": "hazaérv",
    "hazudj": "hazudik",
    "hazudja": "hazudik",
    "hazudjon": "hazudik",
    "hazudni": "hazudik",
    "hazudok": "hazudik",
    "hazudott": "hazudik",
    "hazudozott": "hazudozik",
    "hazudozunk": "hazudozik",
    "hazudsz": "hazudik",
    "hazudta": "hazudik",
    "hazugságból": "hazugság",
    "hazugságfalak": "hazugságfal",
    "hazugsággal": "hazugság",
    "hazugságok": "hazugság",
    "hazugságokat": "hazugság",
    "hazugságokkal": "hazugság",
    "hazugságot": "hazugság",
    "hazugságra": "hazugság",
    "hazába": "haza",
    "hazáig": "haza",
    "hazája": "haza",
    "hazájában": "haza",
    "hazáját": "haza",
    "hazánk": "haza",
    "hazánkba": "haza",
    "hazánkban": "haza",
    "hazátlanjai": "hazátlan",
    "hazáért": "haza",
    "hecceli": "heccel",
    "hederített": "hederít",
    "hegedűk": "hegedű",
    "hegedűversenye": "hegedűverseny",
    "hegedűversenyének": "hegedűverseny",
    "hegedűversenyét": "hegedűverseny",
    "hegei": "heg",
    "hegyek": "hegy",
    "hegyekbe": "hegy",
    "hegyekben": "hegy",
    "hegyeken": "hegy",
    "hegyesen": "hegyes",
    "hegyesnek": "hegyes",
    "hegyet": "hegy",
    "hegyezni": "hegyez",
    "hegyibe": "hegyi",
    "hegyoldalak": "hegyoldal",
    "hegyre": "hegy",
    "hegytetőt": "hegytető",
    "hegyvidékbe": "hegyvidék",
    "hegyvidéket": "hegyvidék",
    "hegyvidékét": "hegyvidék",
    "hegyén": "hegy",
    "hegyére": "hegy",
    "hegyét": "hegy",
    "hegyével": "hegy",
    "hejehujáznak": "hejehujázik",
    "hektoliterjeit": "hektoliter",
    "helikopterből": "helikopter",
    "helikoptere": "helikopter",
    "helikopterek": "helikopter",
    "helikoptereket": "helikopter",
    "helikopteresek": "helikopteres",
    "helikoptermodellel": "helikoptermodell",
    "helikopterről": "helikopter",
    "helikoptertámadásokról": "helikoptertámadás",
    "hellyel": "hely",
    "hellyé": "hely",
    "helyben": "hely",
    "helye": "hely",
    "helyeit": "hely",
    "helyek": "hely",
    "helyeken": "hely",
    "helyeket": "hely",
    "helyekre": "hely",
    "helyemben": "hely",
    "helyen": "hely",
    "helyenként": "hely",
    "helyesbíteni": "helyesbít",
    "helyesbített": "helyesbít",
    "helyesbíts": "helyesbít",
    "helyesbítse": "helyesbít",
    "helyesbítése": "helyesbítés",
    "helyesbítést": "helyesbítés",
    "helyesbítésének": "helyesbítés",
    "helyesbítésével": "helyesbítés",
    "helyesebb": "helyes",
    "helyeselt": "helyesel",
    "helyeselte": "helyesel",
    "helyesen": "helyes",
    "helyeslem": "helyesel",
    "helyeslésnek": "helyeslés",
    "helyeslésre": "helyeslés",
    "helyeslően": "helyeslő",
    "helyességét": "helyesség",
    "helyet": "hely",
    "helyette": "helyett",
    "helyetteséül": "helyettes",
    "helyettesíteni": "helyettesít",
    "helyettesítené": "helyettesít",
    "helyettesítette": "helyettesítet",
    "helyettesítették": "helyettesítet",
    "helyettesíti": "helyettesít",
    "helyettesítik": "helyettesít",
    "helyettesítse": "helyettesít",
    "helyettesítésére": "helyettesítés",
    "helyettük": "helyett",
    "helyezett": "helyez",
    "helyezettje": "helyezett",
    "helyezi": "helyez",
    "helyezik": "helyez",
    "helyezkedett": "helyezkedik",
    "helyezni": "helyez",
    "helyezte": "helyez",
    "helyeztek": "helyez",
    "helyezték": "helyez",
    "helyeztük": "helyez",
    "helyezzenek": "helyez",
    "helyezése": "helyezés",
    "helyhatóságok": "helyhatóság",
    "helyhiányára": "helyhiány",
    "helyiek": "helyi",
    "helyiségben": "helyiség",
    "helyisége": "helyiség",
    "helyiségei": "helyiség",
    "helyiségek": "helyiség",
    "helyiségekben": "helyiség",
    "helyiségeken": "helyiség",
    "helyiségeket": "helyiség",
    "helyiséget": "helyiség",
    "helyiséggel": "helyiség",
    "helyiségnek": "helyiség",
    "helyiségre": "helyiség",
    "helyiségről": "helyiség",
    "helynek": "hely",
    "helyrajzára": "helyrajz",
    "helyre": "hely",
    "helyreigazítottak": "helyreigazított",
    "helyreállt": "helyreáll",
    "helyreállítani": "helyreállít",
    "helyreállítása": "helyreállítás",
    "helyreállításra": "helyreállítás",
    "helyreállítást": "helyreállítás",
    "helyreállításának": "helyreállítás",
    "helyreállítására": "helyreállítás",
    "helyszínen": "helyszín",
    "helyszínrajzot": "helyszínrajz",
    "helyszínre": "helyszín",
    "helyszínről": "helyszín",
    "helyszínt": "helyszín",
    "helyszínét": "helyszín",
    "helységben": "helység",
    "helységekben": "helység",
    "helyt": "hely",
    "helytelenítette": "helytelenít",
    "helytelenítették": "helytelenítet",
    "helytelenül": "helytelen",
    "helyzetbe": "helyzet",
    "helyzetben": "helyzet",
    "helyzetből": "helyzet",
    "helyzete": "helyzet",
    "helyzeteket": "helyzet",
    "helyzetelemzők": "helyzetelemző",
    "helyzetem": "helyzet",
    "helyzetet": "helyzet",
    "helyzethez": "helyzet",
    "helyzetnek": "helyzet",
    "helyzettel": "helyzet",
    "helyzetében": "helyzet",
    "helyzetéből": "helyzet",
    "helyzetének": "helyzet",
    "helyzetére": "helyzet",
    "helyzetéről": "helyzet",
    "helyzetét": "helyzet",
    "helyzetük": "helyzet",
    "helyzetükbe": "helyzet",
    "helyzetüket": "helyzet",
    "helyzetünknek": "helyzet",
    "helyébe": "hely",
    "helyében": "hely",
    "helyéből": "hely",
    "helyéhez": "hely",
    "helyén": "hely",
    "helyének": "hely",
    "helyére": "hely",
    "helyért": "hely",
    "helyéről": "hely",
    "helyét": "hely",
    "helyéért": "hely",
    "helyük": "hely",
    "helyüket": "hely",
    "helyükről": "hely",
    "helyükön": "hely",
    "hengerelt": "hengerel",
    "hentesek": "hentes",
    "hentesnél": "hentes",
    "hentestől": "hentes",
    "hercegről": "herceg",
    "hergelte": "hergel",
    "hernyótalpainak": "hernyótalp",
    "hervadt": "hervad",
    "hervadtnak": "hervadt",
    "heréjébe": "here",
    "hete": "hét",
    "hetek": "hét",
    "hetekben": "hét",
    "heteken": "hét",
    "hetekig": "hét",
    "hetenként": "hét",
    "hetesre": "hetes",
    "hetet": "hét",
    "hetihez": "heti",
    "hetilappá": "hetilap",
    "hetvenre": "hetven",
    "hetvenötre": "hetvenöt",
    "hetében": "hét",
    "hetének": "hét",
    "hetére": "hét",
    "heveri": "hever",
    "heverni": "hever",
    "hevert": "hever",
    "hevertek": "hevert",
    "heverésztek": "heverészik",
    "heverők": "heverő",
    "heverőn": "heverő",
    "heverőt": "heverő",
    "hevesebben": "heves",
    "hevesen": "heves",
    "hevíti": "hevít",
    "hevületében": "hevület",
    "hezitálásának": "hezitálás",
    "hibái": "hiba",
    "hibáit": "hiba",
    "hibájának": "hiba",
    "hibákat": "hiba",
    "hibám": "hiba",
    "hibásak": "hibás",
    "hibát": "hiba",
    "hibázni": "hibázik",
    "hibázott": "hibázik",
    "hibáztak": "hibázik",
    "hidain": "híd",
    "hideg-et": "hideg",
    "hidegben": "hideg",
    "hidege": "hideg",
    "hidegebb": "hideg",
    "hidegebbek": "hideg",
    "hidegen": "hideg",
    "hidegnek": "hideg",
    "hidegre": "hideg",
    "hidegvérrel": "hidegvér",
    "hidegáramlatokkal": "hidegáramlat",
    "hidegéhez": "hideg",
    "hiedelmek": "hiedelem",
    "hiedelmet": "hiedelem",
    "hierarchiához": "hierarchia",
    "higgadt": "higgad",
    "higgadtan": "higgadt",
    "higgye": "hisz",
    "higgyem": "hisz",
    "higgyék": "hisz",
    "higgyétek": "hisz",
    "hihetetlennek": "hihetetlen",
    "hihetetlenül": "hihetetlen",
    "hihetnénk": "hihet",
    "himnuszból": "himnusz",
    "himnuszunkat": "himnusz",
    "himnuszára": "himnusz",
    "hinne": "hisz",
    "hinni": "hisz",
    "hinnie": "hisz",
    "hintegették": "hinteget",
    "hinteni": "hint",
    "hintóban": "hintó",
    "hintón": "hintó",
    "hirdetett": "hirdet",
    "hirdeti": "hirdet",
    "hirdetni": "hirdet",
    "hirdetnie": "hirdet",
    "hirdette": "hirdet",
    "hirdették": "hirdet",
    "hirdetése": "hirdetés",
    "hirdetőtáblát": "hirdetőtábla",
    "históriának": "história",
    "hiszed": "hisz",
    "hiszek": "hisz",
    "hiszel": "hisz",
    "hiszem": "hisz",
    "hiszi": "hisz",
    "hiszik": "hisz",
    "hisznek": "hisz",
    "hisztérikusan": "hisztérikus",
    "hisztériát": "hisztéria",
    "hiszékenységet": "hiszékenység",
    "hiszékenységét": "hiszékenység",
    "hiszünk": "hisz",
    "hitben": "hit",
    "hite": "hit",
    "hiteget": "hitég",
    "hitehagyottak": "hitehagyott",
    "hitelbe": "hitel",
    "hitelből": "hitel",
    "hitele": "hitel",
    "hitelei": "hitel",
    "hitelek": "hitel",
    "hitelekből": "hitel",
    "hiteleket": "hitel",
    "hitelesek": "hiteles",
    "hitelesen": "hiteles",
    "hitelessé": "hiteles",
    "hitelezett": "hitelez",
    "hiteleztek": "hitelez",
    "hitelezők": "hitelező",
    "hitelezőkkel": "hitelező",
    "hitelezőknek": "hitelező",
    "hitelezőnek": "hitelező",
    "hitelfelvevők": "hitelfelvevő",
    "hitelfelvétellel": "hitelfelvétel",
    "hitelkamatok": "hitelkamat",
    "hitelkeretük": "hitelkeret",
    "hitelkonstrukcióval": "hitelkonstrukció",
    "hitelként": "hitel",
    "hitellehetőséggel": "hitellehetőség",
    "hitellehetőségtől": "hitellehetőség",
    "hitellel": "hitel",
    "hitelnek": "hitel",
    "hitelre": "hitel",
    "hitelt": "hitel",
    "hiteltartozásaitól": "hiteltartozás",
    "hitelvesztéséhez": "hitelvesztés",
    "hitelállománya": "hitelállomány",
    "hitelállományából": "hitelállomány",
    "hitelét": "hitel",
    "hitelük": "hitel",
    "hiten": "hit",
    "hitet": "hit",
    "hitetlenkedve": "hitetlenkedv",
    "hithűsége": "hithűség",
    "hitközségek": "hitközség",
    "hitsorsosoknak": "hitsorsos",
    "hitszegésekkel": "hitszegés",
    "hitszegésnek": "hitszegés",
    "hitt": "hisz",
    "hitte": "hisz",
    "hitted": "hitt",
    "hittek": "hitt",
    "hittem": "hitt",
    "hitték": "hisz",
    "hittél": "hisz",
    "hittételben": "hittétel",
    "hittük": "hitt",
    "hittünk": "hitt",
    "hitében": "hit",
    "hitéhez": "hit",
    "hitét": "hit",
    "hitük": "hit",
    "hitüket": "hit",
    "hivatalba": "hivatal",
    "hivatalban": "hivatal",
    "hivatalból": "hivatal",
    "hivatallal": "hivatal",
    "hivatalnak": "hivatal",
    "hivatalnoka": "hivatalnok",
    "hivatalnokok": "hivatalnok",
    "hivatalnokokból": "hivatalnok",
    "hivatalnoktársa": "hivatalnoktárs",
    "hivatalok": "hivatal",
    "hivatalokból": "hivatal",
    "hivatalosan": "hivatalos",
    "hivatalt": "hivatal",
    "hivatalában": "hivatal",
    "hivatalának": "hivatal",
    "hivatja": "hivat",
    "hivatkozni": "hivatkozik",
    "hivatkozott": "hivatkozik",
    "hivatkoztak": "hivatkozik",
    "hivatkozásai": "hivatkozás",
    "hivatkozását": "hivatkozás",
    "hivatott": "hivat",
    "hivatásost": "hivatásos",
    "hivatást": "hivatás",
    "hivatására": "hivatás",
    "hiábavalónak": "hiábavaló",
    "hiánnyal": "hiány",
    "hiánya": "hiány",
    "hiányként": "hiány",
    "hiányolni": "hiányol",
    "hiányosak": "hiányos",
    "hiányosságainak": "hiányosság",
    "hiányosságot": "hiányosság",
    "hiányozni": "hiányozik",
    "hiányt": "hiány",
    "hiánytalanul": "hiánytalan",
    "hiányzanak": "hiányzik",
    "hiányzott": "hiányzik",
    "hiányában": "hiány",
    "hiányát": "hiány",
    "hiányérzete": "hiányérzet",
    "hiénáknak": "hiéna",
    "hiénának": "hiéna",
    "hodályba": "hodály",
    "hodályban": "hodály",
    "hodályokban": "hodály",
    "hodályokhoz": "hodály",
    "hogyant": "hogyan",
    "hokibotok": "hokibot",
    "hokipályáknak": "hokipálya",
    "holdakat": "hold",
    "holdanként": "hold",
    "holdingot": "holding",
    "holdjától": "hold",
    "holdkórossá": "holdkóros",
    "holdszámra": "holdszám",
    "hollétét": "hollét",
    "hollójaként": "holló",
    "holmik": "holmi",
    "holmim": "holmi",
    "holminkat": "holmi",
    "holmira": "holmi",
    "holmit": "holmi",
    "holnapra": "holnap",
    "holnaptól": "holnap",
    "holtan": "holt",
    "holtszegények": "holtszegény",
    "holttestet": "holttest",
    "holttestét": "holttest",
    "holtvágányai": "holtvágány",
    "homlokkal": "homlok",
    "homlokot": "homlok",
    "homlokra": "homlok",
    "homlokzata": "homlokzat",
    "homlokzatán": "homlokzat",
    "homlokzatára": "homlokzat",
    "homlokzatáról": "homlokzat",
    "homlokához": "homlok",
    "homlokán": "homlok",
    "homlokáról": "homlok",
    "homlokával": "homlok",
    "homokjába": "homok",
    "homokot": "homok",
    "homoszexualitást": "homoszexualitás",
    "homályba": "homály",
    "homályban": "homály",
    "homályból": "homály",
    "homályosabban": "homályos",
    "homályosan": "homályos",
    "homályosságával": "homályosság",
    "honfitársaikat": "honfitárs",
    "honfitársaikra": "honfitárs",
    "honfitársunk": "honfitárs",
    "honfitársát": "honfitárs",
    "honolt": "honol",
    "honorálta": "honorál",
    "honoráriuma": "honorárium",
    "honoráriumokkal": "honorárium",
    "honosítunk": "honosít",
    "honpolgárokat": "honpolgár",
    "honvédek": "honvéd",
    "honvédségnek": "honvédség",
    "honvédségnél": "honvédség",
    "hoppon": "hopp",
    "hordaléktartalommal": "hordaléktartalom",
    "hordani": "hord",
    "hordatta": "hordat",
    "hordhatja": "hordhat",
    "hordhatott": "hordhat",
    "hordja": "hord",
    "hordjuk": "hord",
    "hordják": "hord",
    "hordjátok": "hord",
    "hordott": "hord",
    "hordoztak": "hordoz",
    "hordozóinak": "hordozóín",
    "hordozóitól": "hordozói",
    "hordozókra": "hordozó",
    "hordta": "hord",
    "hordtuk": "hord",
    "hordták": "hord",
    "hordáival": "horda",
    "hordásban": "hordás",
    "hordáshoz": "hordás",
    "hordóba": "hordó",
    "horgonyzott": "horgonyoz",
    "horgászok": "horgászik",
    "horkant": "horkan",
    "horoszkópokon": "horoszkóp",
    "horpadt": "horpad",
    "horvátok": "horvát",
    "hosszabb": "hosszú",
    "hosszabbítja": "hosszabbít",
    "hosszabbítsák": "hosszabbít",
    "hosszadalmasnak": "hosszadalmas",
    "hosszat": "hossz",
    "hosszban": "hossz",
    "hosszában": "hossz",
    "hosszúnak": "hosszú",
    "hosszúságban": "hosszúság",
    "hotelban": "hotel",
    "hovatartozásra": "hovatartozás",
    "hozamot": "hozam",
    "hozassuk": "hozat",
    "hozatala": "hozatal",
    "hozatalát": "hozatal",
    "hozatta": "hozat",
    "hozattam": "hozat",
    "hozatták": "hozat",
    "hozd": "hoz",
    "hozhasson": "hozhat",
    "hozhatna": "hozhat",
    "hozhatná": "hozhat",
    "hozhatták": "hozhat",
    "hozna": "hoz",
    "hoznak": "hoz",
    "hozni": "hoz",
    "hozniuk": "hoz",
    "hozná": "hoz",
    "hozok": "hoz",
    "hozott": "hoz",
    "hozta": "hoz",
    "hoztak": "hoz",
    "hoztam": "hoz",
    "hoztunk": "hoz",
    "hozták": "hoz",
    "hozz": "hoz",
    "hozza": "hoz",
    "hozzanak": "hoz",
    "hozzon": "hoz",
    "hozzuk": "hoz",
    "hozzunk": "hoz",
    "hozzá": "ő",
    "hozzáadott": "hozzáad",
    "hozzácsatolták": "hozzácsatol",
    "hozzád": "te",
    "hozzáfognak": "hozzáfog",
    "hozzáfognánk": "hozzáfog",
    "hozzáfogott": "hozzáfog",
    "hozzáférhetetlenek": "hozzáférhetetlen",
    "hozzáfűzte": "hozzáfűz",
    "hozzáfűztem": "hozzáfűz",
    "hozzáfűzött": "hozzáfűz",
    "hozzájuk": "ők",
    "hozzájuthattak": "hozzájuthat",
    "hozzájutni": "hozzájut",
    "hozzájutott": "hozzájut",
    "hozzájáruljon": "hozzájárul",
    "hozzájárult": "hozzájárul",
    "hozzájárultak": "hozzájárult",
    "hozzájárulása": "hozzájárulás",
    "hozzájárulást": "hozzájárulás",
    "hozzájárulásukat": "hozzájárulás",
    "hozzák": "hoz",
    "hozzákezdeni": "hozzákezd",
    "hozzálátott": "hozzálát",
    "hozzáléptem": "hozzálép",
    "hozzám": "én",
    "hozzánk": "mi",
    "hozzászokott": "hozzászokik",
    "hozzászólni": "hozzászól",
    "hozzátartozói": "hozzátartozó",
    "hozzátartozóikkal": "hozzátartozó",
    "hozzátartozóikról": "hozzátartozó",
    "hozzátartozók": "hozzátartozó",
    "hozzátehetnek": "hozzátehet",
    "hozzáteszem": "hozzátesz",
    "hozzáteszi": "hozzátesz",
    "hozzáteszik": "hozzátesz",
    "hozzátette": "hozzátesz",
    "hozzátételével": "hozzátétel",
    "hozzátűzzük": "hozzátűz",
    "hozzáállása": "hozzáállás",
    "hozzáérett": "hozzáérik",
    "hozzáért": "hozzáérik",
    "hozásában": "hozás",
    "hulladékaként": "hulladék",
    "hulladékkal": "hulladék",
    "hulladéklerakók": "hulladéklerakó",
    "hulladékot": "hulladék",
    "hullania": "hullik",
    "hullhatna": "hullhat",
    "hulljon": "hullik",
    "hulljunk": "hullik",
    "hullott": "hullik",
    "hullottak": "hullott",
    "hullák": "hulla",
    "hullám": "hulla",
    "hulláma": "hullám",
    "hullámai": "hullám",
    "hullámok": "hullám",
    "hullámokba": "hullám",
    "hullámokkal": "hullám",
    "hullámot": "hullám",
    "hullámoztak": "hullámozik",
    "hullámtéren": "hullámtér",
    "hullámzanak": "hullámzik",
    "hullámzása": "hullámzás",
    "hullát": "hulla",
    "hullóban": "hulló",
    "humora": "humor",
    "humorát": "humor",
    "humorérzékében": "humorérzék",
    "huncutul": "huncut",
    "hunt": "hun",
    "hunyd": "huny",
    "hunynunk": "huny",
    "hunyorgott": "hunyorog",
    "hunyt": "huny",
    "hurcolták": "hurcol",
    "hurka": "hurok",
    "huszonegyet": "huszonegy",
    "huszonháromkor": "huszonhárom",
    "huszonnégyből": "huszonnégy",
    "huszárral": "huszár",
    "huzamosabb": "huzamos",
    "huzattal": "huzat",
    "huzigált": "huzigál",
    "háborodjál": "háborodik",
    "háborúba": "háború",
    "háborúban": "háború",
    "háborúból": "háború",
    "háborúiban": "háborúi",
    "háborúja": "háború",
    "háborúk": "háború",
    "háborúkat": "háború",
    "háborúnak": "háború",
    "háborúra": "háború",
    "háborúról": "háború",
    "háborút": "háború",
    "háborúval": "háború",
    "háborúzott": "háborúzik",
    "háborúé": "háború",
    "hágni": "hág",
    "hágott": "hág",
    "hájgyűrűk": "hájgyűrű",
    "hálatüntetéseket": "hálatüntetés",
    "hálhasson": "hálhat",
    "hálhattak": "hálhat",
    "háljunk": "hál",
    "hálnak": "hál",
    "hálok": "hál",
    "hált": "hál",
    "háltam": "hált",
    "háltunk": "hált",
    "hálájukat": "hála",
    "hálálkodott": "hálálkodik",
    "hálásan": "hálás",
    "hálát": "hála",
    "hálóba": "háló",
    "hálójukból": "háló",
    "hálóját": "háló",
    "hálókonténerekből": "hálókonténer",
    "hálószobában": "hálószoba",
    "hálószobája": "hálószoba",
    "hálózata": "hálózat",
    "hálózatokat": "hálózat",
    "hálózatot": "hálózat",
    "hálózatra": "hálózat",
    "hálózatához": "hálózat",
    "hálózatának": "hálózat",
    "hálózsákok": "hálózsák",
    "hámok": "hám",
    "hámozom": "hámoz",
    "hámozta": "hámoz",
    "hámozzák": "hámoz",
    "hányad": "hány",
    "hányada": "hányad",
    "hányaddal": "hányad",
    "hányadot": "hányad",
    "hányadát": "hányad",
    "hányat": "hány",
    "hányatott": "hányat",
    "hánykolódtak": "hánykolódik",
    "hánykor": "hány",
    "hányni": "hány",
    "hányt": "hány",
    "hányta": "hány",
    "hánytak": "hányt",
    "hánytunk": "hányt",
    "hányták": "hány",
    "hányódtak": "hányódik",
    "hápogni": "hápog",
    "hármuk": "három",
    "hármukkal": "három",
    "három-négyszázezerre": "három-négyszázezer",
    "háromméternyire": "háromméternyi",
    "háromnaponta": "háromnap",
    "háromszor": "három",
    "háromszor-négyszer": "három-négy",
    "háromszorosa": "háromszoros",
    "háromszögben": "háromszög",
    "hársfák": "hársfa",
    "hárítani": "hárít",
    "hárította": "hárít",
    "hárították": "hárít",
    "háta": "hát",
    "hátam": "hát",
    "hátat": "hát",
    "hátba": "hát",
    "hátgerince": "hátgerinc",
    "hátgerinced": "hátgerinc",
    "hátgerincéig": "hátgerinc",
    "hátgerincén": "hátgerinc",
    "hátizmoknak": "hátizom",
    "hátizsákjába": "hátizsák",
    "háton": "hát",
    "hátországa": "hátország",
    "hátra": "hát",
    "hátradőlt": "hátradől",
    "hátradőltében": "hátradőlt",
    "hátrahagyott": "hátrahagy",
    "hátrahúzódott": "hátrahúzódik",
    "hátrahőköltek": "hátrahőköl",
    "hátralékban": "hátralék",
    "hátralékának": "hátralék",
    "hátralökte": "hátralök",
    "hátrapillantson": "hátrapillant",
    "hátrapillantások": "hátrapillantás",
    "hátratolt": "hátratol",
    "hátratolta": "hátratol",
    "hátravetette": "hátravet",
    "hátrazuhant": "hátrazuhan",
    "hátránya": "hátrány",
    "hátrányait": "hátrány",
    "hátrányaival": "hátrány",
    "hátrányokból": "hátrány",
    "hátrányosabb": "hátrányos",
    "hátrányt": "hátrány",
    "hátrányát": "hátrány",
    "hátszéllel": "hátszél",
    "háttal": "hát",
    "háttere": "háttér",
    "hátterében": "háttér",
    "hátterének": "háttér",
    "hátterét": "háttér",
    "háttérbe": "háttér",
    "háttérben": "háttér",
    "háttértárolóban": "háttértároló",
    "hátuk": "hát",
    "hátukon": "hát",
    "hátuljából": "hátulja",
    "hátulján": "hátulja",
    "hátuljának": "hátulja",
    "hátunkba": "hát",
    "hátunkra": "hát",
    "hátvédje": "hátvéd",
    "hátában": "hát",
    "hátához": "hát",
    "hátán": "hát",
    "hátára": "hát",
    "hátát": "hát",
    "hátával": "hát",
    "hátérben": "hátér",
    "háza": "ház",
    "házaiban": "ház",
    "házak": "ház",
    "házakat": "ház",
    "házakban": "ház",
    "házakból": "ház",
    "házaspárok": "házaspár",
    "házaspárra": "házaspár",
    "házaspárt": "házaspár",
    "házassága": "házasság",
    "házasságból": "házasság",
    "házasságkötésük": "házasságkötés",
    "házasságokat": "házasság",
    "házasságom": "házasság",
    "házasságomban": "házasság",
    "házasságon": "házasság",
    "házasságot": "házasság",
    "házasságra": "házasság",
    "házasságtörést": "házasságtörés",
    "házasságtörők": "házasságtörő",
    "házasságunknak": "házasság",
    "házasságából": "házasság",
    "házasságának": "házasság",
    "házastársak": "házastárs",
    "házaséletéről": "házasélet",
    "házaséletük": "házasélet",
    "házat": "ház",
    "házba": "ház",
    "házban": "ház",
    "házból": "ház",
    "házfedeleket": "házfedél",
    "házhoz": "ház",
    "háziasszonyod": "háziasszony",
    "háziasszonyok": "háziasszony",
    "házigazdához": "házigazda",
    "házigazdájuknak": "házigazda",
    "házigazdának": "házigazda",
    "házigazdát": "házigazda",
    "házikabátjának": "házikabát",
    "házikónkig": "házikó",
    "házikóra": "házikó",
    "házikót": "házikó",
    "háziszőttesekben": "háziszőttes",
    "házkutatásnál": "házkutatás",
    "házkutatást": "házkutatás",
    "házmesterként": "házmester",
    "háznak": "ház",
    "háznál": "ház",
    "házon": "ház",
    "házra": "ház",
    "házsorok": "házsor",
    "háztartásbelivé": "háztartásbeli",
    "háztartáshoz": "háztartás",
    "háztartásnak": "háztartás",
    "háztartások": "háztartás",
    "háztartást": "háztartás",
    "háztetőkre": "háztető",
    "háztömbök": "háztömb",
    "háztömböt": "háztömb",
    "házunk": "ház",
    "házunkban": "ház",
    "házvezetőnőét": "házvezetőnő",
    "házzal": "ház",
    "házába": "ház",
    "házából": "ház",
    "házához": "ház",
    "házáig": "ház",
    "házánál": "ház",
    "házát": "ház",
    "héja": "héj",
    "héját": "héja",
    "hétben": "hét",
    "héten": "hét",
    "hétfői": "hétfő",
    "hétfőig": "hétfő",
    "hétfőn": "hétfő",
    "hétig": "hét",
    "hétköznapjait": "hétköznap",
    "hétköznapok": "hétköznap",
    "hétnek": "hét",
    "hétnél": "hét",
    "hétre": "hét",
    "hétről": "hét",
    "hétszeresére": "hétszeres",
    "hétszámra": "hétszám",
    "héttel": "hét",
    "héttől": "hét",
    "hétvégeken": "hétvég",
    "hétvégéjének": "hétvége",
    "hétvégén": "hétvége",
    "hétvégére": "hétvége",
    "hétvégét": "hétvége",
    "hétévenként": "hétév",
    "hévízen": "hévíz",
    "hídfőjéről": "hídfő",
    "hídhoz": "híd",
    "hídja": "híd",
    "hídon": "híd",
    "hídról": "híd",
    "híján": "híja",
    "híjával": "híja",
    "híradások": "híradás",
    "híradóban": "híradó",
    "híradójában": "híradó",
    "híradótól": "híradó",
    "híradóval": "híradó",
    "híre": "hír",
    "hírei": "hír",
    "híreink": "hír",
    "hírek": "hír",
    "híreken": "hír",
    "híreket": "hír",
    "hírekre": "hír",
    "hírem": "hír",
    "híremet": "hír",
    "híressé": "híres",
    "híressége": "híresség",
    "hírességek": "híresség",
    "hírhedt": "hírhed",
    "hírlapnak": "hírlap",
    "hírnek": "hír",
    "hírnevének": "hírnév",
    "hírnevével": "hírnév",
    "hírnevüket": "hírnév",
    "hírnevünknek": "hírnév",
    "hírnévtől": "hírnév",
    "hírnökök": "hírnök",
    "hírnököt": "hírnök",
    "hírrészletekre": "hírrészlet",
    "hírsorok": "hírsor",
    "hírszerzésnek": "hírszerzés",
    "hírt": "hír",
    "hírére": "hír",
    "hírét": "hír",
    "hírügynökségek": "hírügynökség",
    "hírül": "hír",
    "hívatja": "hívat",
    "híve": "hív",
    "hívei": "hív",
    "híveinek": "hív",
    "híveire": "hív",
    "híveit": "hív",
    "híven": "hív",
    "hívja": "hív",
    "hívják": "hív",
    "hívnak": "hív",
    "hívni": "hív",
    "hívott": "hív",
    "hívta": "hív",
    "hívtak": "hív",
    "hívtatok": "hívtat",
    "hívtuk": "hív",
    "hívták": "hív",
    "hívásnak": "hívás",
    "hívására": "hívás",
    "hízelegni": "hízeleg",
    "hízelgésnek": "hízelgés",
    "hízelgőbbek": "hízelgő",
    "hízóba": "hízó",
    "hízócskát": "hízócská",
    "hízóiból": "hízói",
    "hízónak": "hízó",
    "hóbortja": "hóbort",
    "hóbortnak": "hóbort",
    "hódolattal": "hódolat",
    "hódolni": "hódol",
    "hódítanak": "hódít",
    "hódíthatja": "hódíthat",
    "hódítjuk": "hódít",
    "hódítottátok": "hódít",
    "hódítsanak": "hódít",
    "hódítása": "hódítás",
    "hódítást": "hódítás",
    "hódítónak": "hódító",
    "hóekét": "hóeke",
    "hófúvásokra": "hófúvás",
    "hóhérok": "hóhér",
    "hókása": "hókás",
    "hólyagom": "hólyag",
    "hólyagomat": "hólyag",
    "hólé": "hól",
    "hóna": "hón",
    "hónapban": "hónap",
    "hónapig": "hónap",
    "hónapja": "hónap",
    "hónapjában": "hónap",
    "hónapjának": "hónap",
    "hónapok": "hónap",
    "hónapokat": "hónap",
    "hónapokban": "hónap",
    "hónapokig": "hónap",
    "hónapokon": "hónap",
    "hónapon": "hónap",
    "hónaposnak": "hónapos",
    "hónaposok": "hónapos",
    "hónapot": "hónap",
    "hónappal": "hónap",
    "hónapra": "hónap",
    "hónaptól": "hónap",
    "hónapunk": "hónapu",
    "hópehelyként": "hópehely",
    "hölggyel": "hölgy",
    "hölgynek": "hölgy",
    "hölgyről": "hölgy",
    "hömpölyögtek": "hömpölyög",
    "hörcsöggel": "hörcsög",
    "hörgésre": "hörgés",
    "húga": "húg",
    "húgodnak": "húg",
    "húgán": "húg",
    "húgának": "húg",
    "húgára": "húg",
    "húgát": "húg",
    "húgával": "húg",
    "húrjának": "húr",
    "húsdarabok": "húsdarab",
    "húsfalat": "húsfal",
    "húsfeldolgozók": "húsfeldolgozó",
    "húsipariak": "húsipari",
    "húslébe": "húslé",
    "hússzal": "húsz",
    "húst": "hús",
    "húsvét-szigeten": "húsvét-sziget",
    "húszat": "húsz",
    "húsznál": "húsz",
    "húsát": "hús",
    "húzattuk": "húzat",
    "húzatták": "húzat",
    "húzd": "húz",
    "húznak": "húz",
    "húzni": "húz",
    "húzniuk": "húz",
    "húzogatott": "húzogat",
    "húzott": "húz",
    "húzta": "húz",
    "húztak": "húz",
    "húztuk": "húz",
    "húztunk": "húz",
    "húzták": "húz",
    "húzzuk": "húz",
    "húzódba": "húzó",
    "húzódnak": "húzódik",
    "húzódni": "húzódik",
    "húzódnunk": "húzódik",
    "húzódott": "húzódik",
    "húzódtak": "húzódik",
    "hülyének": "hülye",
    "hümmögnek": "hümmög",
    "hümmögte": "hümmög",
    "hümmögésben": "hümmögés",
    "hümmögött": "hümmög",
    "hüvelyben": "hüvely",
    "hüvelykujját": "hüvelykujj",
    "hőenergiát": "hőenergia",
    "hőerőműtől": "hőerőmű",
    "hőerőművet": "hőerőmű",
    "hőfokot": "hőfok",
    "hőmérsékletig": "hőmérséklet",
    "hőmérsékletüket": "hőmérséklet",
    "hőnél": "hő",
    "hőse": "hős",
    "hőseit": "hős",
    "hősiesen": "hősies",
    "hősiesnek": "hősies",
    "hősök": "hős",
    "hősöket": "hős",
    "hősökhöz": "hős",
    "hőt": "hő",
    "hűek": "hű",
    "hűlt": "hűl",
    "hűlése": "hűlés",
    "hűsége": "hűség",
    "hűségesek": "hűséges",
    "hűségesen": "hűséges",
    "hűséggel": "hűség",
    "hűségről": "hűség",
    "hűtőházban": "hűtőház",
    "hűvösben": "hűvös",
    "hűvösebb": "hűvös",
    "hűvösséggel": "hűvösség",
    "hűvösön": "hűvös",
    "idealizmusából": "idealizmus",
    "idegei": "ideg",
    "idegeiben": "ideg",
    "idegeim": "ideg",
    "idegeinknek": "ideg",
    "idegek": "ideg",
    "idegeket": "ideg",
    "idegen": "ideg",
    "idegenben": "idegen",
    "idegenebb": "idegen",
    "idegenebbül": "idegen",
    "idegenek": "idegen",
    "idegenen": "idegen",
    "idegenforgalomból": "idegenforgalom",
    "idegenkedett": "idegenkedik",
    "idegenkedve": "idegenkedv",
    "idegenkedése": "idegenkedés",
    "idegenkedésének": "idegenkedés",
    "idegenlégiósukat": "idegenlégiós",
    "idegent": "idegen",
    "idegesen": "ideges",
    "idegességeidben": "idegesség",
    "idegesíti": "idegesít",
    "idegkimerüléstől": "idegkimerülés",
    "idegreakcióit": "idegreakciói",
    "idegrendszered": "idegrendszer",
    "idegrendszereknek": "idegrendszer",
    "idegrendszerünk": "idegrendszer",
    "idegrohamot": "idegroham",
    "idehozatni": "idehozat",
    "idehozták": "idehoz",
    "idehozunk": "idehoz",
    "idei": "idő",
    "ideiekre": "idei",
    "ideig": "idő",
    "ideiglenesen": "ideiglenes",
    "ideiglenességnek": "ideiglenesség",
    "ideinél": "idő",
    "ideje": "idő",
    "idejében": "idő",
    "idején": "idő",
    "idejét": "idő",
    "idejönnek": "idejön",
    "idejönni": "idejön",
    "idejövetelre": "idejövetel",
    "idejük": "idő",
    "idejüket": "idő",
    "idekerült": "idekerül",
    "idekerültek": "idekerül",
    "idekerültél": "idekerül",
    "ideköltöznék": "ideköltözik",
    "identitástudatot": "identitástudat",
    "identitásukkal": "identitás",
    "idenézni": "idenéz",
    "ideológiájába": "ideológia",
    "ideológiájához": "ideológia",
    "ideológiájának": "ideológia",
    "ideológiájával": "ideológia",
    "ideológiák": "ideológia",
    "ideológiát": "ideológia",
    "ideszerződtem": "ideszerződik",
    "idetelepült": "idetelepül",
    "idevezettek": "idevezet",
    "idevezényelt": "idevezényel",
    "idilljéből": "idill",
    "idomai": "idom",
    "idomairól": "idom",
    "idomításának": "idomítás",
    "idényben": "idény",
    "idényének": "idény",
    "idézem": "idéz",
    "idézete": "idézet",
    "idézetekkel": "idézet",
    "idézett": "idéz",
    "idézi": "idéz",
    "idézik": "idéz",
    "idéznek": "idéz",
    "idézni": "idéz",
    "idézte": "idéz",
    "idézték": "idéz",
    "idézzem": "idéz",
    "idézésekre": "idézés",
    "időben": "idő",
    "időd": "idő",
    "időjáráshoz": "időjárás",
    "időjárást": "időjárás",
    "idők": "idő",
    "időkbe": "idő",
    "időkben": "idő",
    "időkből": "idő",
    "időket": "idő",
    "időkhöz": "idő",
    "időknek": "idő",
    "időkre": "idő",
    "időkről": "idő",
    "időközben": "időköz",
    "időközökben": "időköz",
    "időközönként": "időköz",
    "időm": "idő",
    "időmben": "idő",
    "időmértékekkel": "időmérték",
    "időn": "idő",
    "időnek": "idő",
    "időnkben": "idő",
    "időnként": "idő",
    "időpontban": "időpont",
    "időpontja": "időpont",
    "időpontjában": "időpont",
    "időpontjára": "időpont",
    "időpontjáról": "időpont",
    "időpontját": "időpont",
    "időpontot": "időpont",
    "időponttal": "időpont",
    "időre": "idő",
    "időről": "idő",
    "idősebb": "idős",
    "idősebbek": "idős",
    "időskorúak": "időskorú",
    "időszaka": "időszak",
    "időszakban": "időszak",
    "időszakok": "időszak",
    "időszakokban": "időszak",
    "időszakokhoz": "időszak",
    "időszakokon": "időszak",
    "időszakokra": "időszak",
    "időszakonként": "időszak",
    "időszakot": "időszak",
    "időszakra": "időszak",
    "időszakában": "időszaka",
    "időszakából": "időszaka",
    "időszakához": "időszaka",
    "időszakán": "időszaka",
    "időszakát": "időszaka",
    "időszerűségét": "időszerűség",
    "időszerűtlenné": "időszerűtlen",
    "időt": "idő",
    "időtartamra": "időtartam",
    "időtartamáig": "időtartam",
    "idővel": "idő",
    "időznek": "időzik",
    "időzített": "időzít",
    "időzítették": "időzítet",
    "időzítéssel": "időzítés",
    "ifjak": "ifjú",
    "ifjúsága": "ifjúság",
    "ifjúságiak": "ifjúsági",
    "ifjúságot": "ifjúság",
    "ifjúságunk": "ifjúság",
    "ifjúságát": "ifjúság",
    "igaza": "igaz",
    "igazad": "igaz",
    "igazak": "igaz",
    "igazat": "igaz",
    "igazgatóhelyettesétől": "igazgatóhelyettes",
    "igazgatói": "igazgató",
    "igazgatója": "igazgató",
    "igazgatójának": "igazgató",
    "igazgatójától": "igazgató",
    "igazgatók": "igazgató",
    "igazgatósága": "igazgatóság",
    "igazgatóságának": "igazgatóság",
    "igazgatóságát": "igazgatóság",
    "igazgatót": "igazgató",
    "igazgatótanácsa": "igazgatótanács",
    "igazgatótanácsok": "igazgatótanács",
    "igaziak": "igazi",
    "igazibb": "igazi",
    "igazit": "igazi",
    "igazmondást": "igazmondás",
    "igaznak": "igaz",
    "igazodnak": "igazodik",
    "igazodni": "igazodik",
    "igazodtak": "igazodik",
    "igazolatlanul": "igazolatlan",
    "igazolhatta": "igazolhat",
    "igazolja": "igazol",
    "igazolják": "igazol",
    "igazolnak": "igazol",
    "igazolni": "igazol",
    "igazolniuk": "igazol",
    "igazolt": "igazol",
    "igazolta": "igazol",
    "igazoltassanak": "igazoltat",
    "igazolványa": "igazolvány",
    "igazolványainknak": "igazolvány",
    "igazolványait": "igazolvány",
    "igazolványok": "igazolvány",
    "igazolványokat": "igazolvány",
    "igazolványra": "igazolvány",
    "igazolványt": "igazolvány",
    "igazolványuk": "igazolvány",
    "igazolványunk": "igazolvány",
    "igazolványunkkal": "igazolvány",
    "igazolványát": "igazolvány",
    "igazolványért": "igazolvány",
    "igazolásokat": "igazolás",
    "igazolást": "igazolás",
    "igazolását": "igazolás",
    "igazolódott": "igazolódik",
    "igazság-minisztériumba": "igazság-minisztérium",
    "igazság-minisztériumban": "igazság-minisztérium",
    "igazság-minisztériumnak": "igazság-minisztérium",
    "igazsággal": "igazság",
    "igazsággá": "igazság",
    "igazsághoz": "igazság",
    "igazságnak": "igazság",
    "igazságodat": "igazság",
    "igazságokat": "igazság",
    "igazságosan": "igazságos",
    "igazságot": "igazság",
    "igazságra": "igazság",
    "igazságtalannak": "igazságtalan",
    "igazságtalanságok": "igazságtalanság",
    "igazságát": "igazság",
    "igazságért": "igazság",
    "igazságérzete": "igazságérzet",
    "igazuk": "igaz",
    "igazzá": "igaz",
    "igazában": "igaz",
    "igazából": "igaz",
    "igazán": "igaz",
    "igazának": "igaz",
    "igazát": "igaz",
    "igazítani": "igazít",
    "igazítaná": "igazít",
    "igazítja": "igazít",
    "igazított": "igazít",
    "igazította": "igazít",
    "igazították": "igazít",
    "igazítson": "igazít",
    "igeként": "ige",
    "igen-t": "igen",
    "igennel": "igen",
    "igent": "igen",
    "igyekezete": "igyekezet",
    "igyekezett": "igyekezik",
    "igyekezettel": "igyekezett",
    "igyekeznek": "igyekezik",
    "igyekezni": "igyekezik",
    "igyekeztek": "igyekezik",
    "igyekeztem": "igyekezik",
    "igyekeztünk": "igyekezik",
    "igyekezzenek": "igyekezik",
    "igyekezzék": "igyekezik",
    "igyekszel": "igyekszik",
    "igyekszem": "igyekszik",
    "igyekszenek": "igyekszik",
    "igyunk": "iszik",
    "igában": "iga",
    "igája": "iga",
    "igájával": "iga",
    "igáskocsisnál": "igáskocsis",
    "igáskocsisok": "igáskocsis",
    "igéből": "ige",
    "igék": "ige",
    "igének": "ige",
    "igénybe": "igény",
    "igényben": "igény",
    "igénybevételét": "igénybevétel",
    "igényeit": "igény",
    "igények": "igény",
    "igényeket": "igény",
    "igényekhez": "igény",
    "igényekkel": "igény",
    "igényeknek": "igény",
    "igényekre": "igény",
    "igényelhetik": "igényelhet",
    "igényelhetnek": "igényelhet",
    "igényeljen": "igényel",
    "igényelne": "igényel",
    "igényelni": "igényel",
    "igényelné": "igényel",
    "igényelt": "igényel",
    "igényesen": "igényes",
    "igényli": "igényel",
    "igénylik": "igényel",
    "igényt": "igény",
    "igényét": "igény",
    "igényüket": "igény",
    "igét": "ige",
    "igézetfélére": "igézetféle",
    "iharossal": "iharos",
    "ihassanak": "ihat",
    "ihatott": "ihat",
    "ijedelmeit": "ijedelem",
    "ijedelmünkre": "ijedelem",
    "ijedségen": "ijedség",
    "ijedséghullám": "ijedséghulla",
    "ijedt": "ijed",
    "ijedtek": "ijedt",
    "ijedten": "ijedt",
    "ijedtében": "ijedt",
    "ijedtünk": "ijedt",
    "ijesztgették": "ijesztget",
    "ijesztőbb": "ijesztő",
    "ijesztően": "ijesztő",
    "ikonfala": "ikonfal",
    "ikrák": "ikra",
    "iktatták": "iktat",
    "illata": "illat",
    "illatosított": "illatosít",
    "illatot": "illat",
    "illatszereket": "illatszer",
    "illatszert": "illatszer",
    "illatában": "illat",
    "illatát": "illat",
    "illegálisan": "illegális",
    "illem": "illik",
    "illendőségből": "illendőség",
    "illesztették": "illesztet",
    "illeti": "illet",
    "illetménytáblára": "illetménytábla",
    "illett": "illik",
    "illette": "illik",
    "illettek": "illik",
    "illetékese": "illetékes",
    "illetékesei": "illetékes",
    "illetékeseitől": "illetékes",
    "illetékesek": "illetékes",
    "illetékességében": "illetékesség",
    "illetékességükbe": "illetékesség",
    "illetékesétől": "illetékes",
    "illetékről": "illeték",
    "illetően": "illető",
    "illetősége": "illetőség",
    "illetőségnél": "illetőség",
    "illetőt": "illető",
    "illusztrálja": "illusztrál",
    "illúziójuk": "illúzió",
    "illúziót": "illúzió",
    "illőnek": "illő",
    "ilyen": "ily",
    "ilyenben": "ilyen",
    "ilyenek": "ilyen",
    "ilyeneket": "ilyen",
    "ilyenekkel": "ilyen",
    "ilyenekre": "ilyen",
    "ilyenfajtákat": "ilyenfajtá",
    "ilyenformán": "ilyenformá",
    "ilyenféleképpen": "ilyenféle",
    "ilyenkor": "ilyen",
    "ilyenként": "ilyen",
    "ilyennek": "ilyen",
    "ilyennel": "ilyen",
    "ilyenre": "ilyen",
    "ilyesmiben": "ilyesmi",
    "ilyesmihez": "ilyesmi",
    "ilyesmik": "ilyesmi",
    "ilyesmire": "ilyesmi",
    "ilyesmiről": "ilyesmi",
    "ilyesmit": "ilyesmi",
    "ilyesmivel": "ilyesmi",
    "ilyet": "ily",
    "imbolygott": "imbolyog",
    "immúnisak": "immúnis",
    "imponálni": "imponál",
    "importot": "import",
    "importőreként": "importőr",
    "impotenciája": "impotencia",
    "improvizációját": "improvizáció",
    "imád": "ima",
    "imádatig": "imádat",
    "imádattá": "imádat",
    "imádkoznak": "imádkozik",
    "imádkozni": "imádkozik",
    "imádkoztunk": "imádkozik",
    "imádnak": "imád",
    "imádom": "imád",
    "imádott": "imád",
    "imádságfélét": "imádságféle",
    "imádta": "imád",
    "imádták": "imád",
    "imádása": "imádás",
    "inasa": "inas",
    "inasnak": "inas",
    "inasok": "inas",
    "inasomtól": "inas",
    "incidensnek": "incidens",
    "incselkedésre": "incselkedés",
    "indexhez": "index",
    "indiaiak": "indiai",
    "individualizmust": "individualizmus",
    "indoklással": "indoklás",
    "indoklásul": "indoklás",
    "indokok": "indok",
    "indokolja": "indokol",
    "indokolna": "indokol",
    "indokolnak": "indokol",
    "indokolná": "indokol",
    "indokolt": "indokol",
    "indokolta": "indokol",
    "indokoltságról": "indokoltság",
    "indokolták": "indokol",
    "indokot": "indok",
    "indulata": "indulat",
    "indulatok": "indulat",
    "indulatosan": "indulatos",
    "indulatot": "indulat",
    "indulatától": "indulat",
    "indulhatott": "indulhat",
    "induljatok": "indul",
    "induljon": "indul",
    "indulnak": "indul",
    "indulni": "indul",
    "indulnia": "indul",
    "indulnunk": "indul",
    "indult": "indul",
    "indultak": "indult",
    "indulása": "indulás",
    "indulásakor": "indulás",
    "indulásra": "indulás",
    "indulásukat": "indulás",
    "indulók": "induló",
    "indulókat": "induló",
    "indulót": "induló",
    "indákká": "inda",
    "indítanak": "indít",
    "indítani": "indít",
    "indítja": "indít",
    "indítják": "indít",
    "indított": "indít",
    "indította": "indít",
    "indítottak": "indított",
    "indíttatáson": "indíttatás",
    "indítvánnyal": "indítvány",
    "indítványt": "indítvány",
    "indítéka": "indíték",
    "indítékaikat": "indíték",
    "indítékainak": "indíték",
    "indítékait": "indíték",
    "indítékok": "indíték",
    "indítékunk": "indíték",
    "indítékát": "indíték",
    "indítóoka": "indítóok",
    "indóházaiban": "indóház",
    "influenzajárványt": "influenzajárvány",
    "influenzával": "influenza",
    "inflációt": "infláció",
    "inflációval": "infláció",
    "információink": "információ",
    "információk": "információ",
    "információkat": "információ",
    "információkon": "információ",
    "információkéréssel": "információkérés",
    "információnk": "információ",
    "információt": "információ",
    "informálta": "informál",
    "infrastrukturálisan": "infrastrukturális",
    "infrastruktúra-kezdeményezésről": "infrastruktúra-kezdeményezés",
    "infrastruktúrát": "infrastruktúra",
    "ingadozott": "ingadozik",
    "ingatagok": "ingatag",
    "ingatlanadóval": "ingatlanadó",
    "ingatlanjaikat": "ingatlan",
    "ingatlanok": "ingatlan",
    "ingatlanokat": "ingatlan",
    "ingatlanra": "ingatlan",
    "ingatlant": "ingatlan",
    "ingatlanvagyona": "ingatlanvagyon",
    "ingatlanvagyont": "ingatlanvagyon",
    "ingatlanvásárláshoz": "ingatlanvásárlás",
    "ingatlanárak": "ingatlanár",
    "ingatlanát": "ingatlan",
    "ingatlanügyek": "ingatlanügy",
    "ingatlanüzletek": "ingatlanüzlet",
    "ingecskéket": "ingecské",
    "ingeikben": "ing",
    "ingek": "ing",
    "ingekből": "ing",
    "ingeket": "ing",
    "ingere": "inger",
    "ingerelje": "ingerel",
    "ingerelni": "ingerel",
    "ingerelte": "ingerel",
    "ingerli": "ingerel",
    "ingerlőbbé": "ingerlő",
    "ingerülten": "ingerült",
    "ingerültséget": "ingerültség",
    "inget": "ing",
    "ingoványosabb": "ingoványos",
    "ingujját": "ingujj",
    "ingyenesen": "ingyenes",
    "ingyenességből": "ingyenesség",
    "ingyenességről": "ingyenesség",
    "ingában": "inga",
    "ingája": "inga",
    "ingákat": "inga",
    "ingébe": "ing",
    "iniciatívát": "iniciatíva",
    "injekciókat": "injekció",
    "injekciót": "injekció",
    "injekcióval": "injekció",
    "inkorrektségének": "inkorrektség",
    "inkriminált": "inkriminál",
    "inkvizítorai": "inkvizítor",
    "inkvizítornak": "inkvizítor",
    "inkvizítoré": "inkvizítor",
    "inkább": "inka",
    "inni": "iszik",
    "innék": "iszik",
    "instrumentumaikat": "instrumentum",
    "instrumentumra": "instrumentum",
    "integetett": "integet",
    "integethetne": "integethet",
    "integetnek": "integet",
    "integettek": "integet",
    "integetést": "integetés",
    "integritása": "integritás",
    "integrálásodnak": "integrálás",
    "intelemnek": "intelem",
    "intelligenciájuk": "intelligencia",
    "intelligenciájúnak": "intelligenciájú",
    "intelligenciát": "intelligencia",
    "intelligensebb": "intelligens",
    "intelligensnek": "intelligens",
    "intelmeit": "intelem",
    "intenzitása": "intenzitás",
    "interjúban": "interjú",
    "interjújában": "interjú",
    "interjút": "interjú",
    "internacionáléhoz": "internacionálé",
    "internacionálét": "internacionálé",
    "internátus-tervnek": "internátus-terv",
    "internátusa": "internátus",
    "internátusba": "internátus",
    "internátusban": "internátus",
    "internátusnak": "internátus",
    "internátusról": "internátus",
    "internátust": "internátus",
    "interpretálja": "interpretál",
    "intett": "int",
    "intettek": "intett",
    "intették": "intet",
    "inti": "int",
    "intik": "int",
    "intrikáltak": "intrikált",
    "intézetben": "intézet",
    "intézetekben": "intézet",
    "intézetet": "intézet",
    "intézeti": "intézet",
    "intézett": "intéz",
    "intézetében": "intézet",
    "intézi": "intéz",
    "intézkedne": "intézkedik",
    "intézkednek": "intézkedik",
    "intézkedni": "intézkedik",
    "intézkedései": "intézkedés",
    "intézkedések": "intézkedés",
    "intézkedéseket": "intézkedés",
    "intézkedésekkel": "intézkedés",
    "intézkedéseknek": "intézkedés",
    "intézkedésekre": "intézkedés",
    "intézkedésnek": "intézkedés",
    "intézkedéssel": "intézkedés",
    "intézkedést": "intézkedés",
    "intézménybe": "intézmény",
    "intézményben": "intézmény",
    "intézményei": "intézmény",
    "intézményeinek": "intézmény",
    "intézmények": "intézmény",
    "intézményekbe": "intézmény",
    "intézményekben": "intézmény",
    "intézményeket": "intézmény",
    "intézményekhez": "intézmény",
    "intézményeknek": "intézmény",
    "intézményhálózatot": "intézményhálózat",
    "intézményhálózatra": "intézményhálózat",
    "intézménynek": "intézmény",
    "intézményrendszerben": "intézményrendszer",
    "intézményrendszert": "intézményrendszer",
    "intézményt": "intézmény",
    "intézményének": "intézmény",
    "intézményépítését": "intézményépítés",
    "intézni": "intéz",
    "intéznivalóba": "intéznivaló",
    "intézte": "intéz",
    "intéztek": "intéz",
    "intéztük": "intéz",
    "intézőhöz": "intéző",
    "intézőik": "intéző",
    "intézőnek": "intéző",
    "invitálta": "invitál",
    "iparkodott": "iparkodik",
    "iparkodtak": "iparkodik",
    "iparművészek": "iparművész",
    "iparművészeket": "iparművész",
    "iparművészetet": "iparművészet",
    "iparoshoz": "iparos",
    "iparosodott": "iparosodik",
    "iparágak": "iparág",
    "iramban": "iram",
    "iratain": "irat",
    "iratait": "irat",
    "iratkozott": "iratkozik",
    "iratok": "irat",
    "iratokkal": "irat",
    "irattáskájában": "irattáska",
    "irattáskát": "irattáska",
    "iratuk": "irat",
    "iratukat": "irat",
    "irgalmasabb": "irgalmas",
    "irgalmában": "irgalom",
    "irgalomért": "irgalom",
    "irigyellek": "irigyel",
    "irigyelte": "irigyel",
    "irigyen": "irigy",
    "irigykednek": "irigykedik",
    "irigylik": "irigyel",
    "irigylésre": "irigylés",
    "irigységbe": "irigység",
    "irigységet": "irigység",
    "irigységtől": "irigység",
    "irkái": "irka",
    "irkáit": "irka",
    "irkák": "irka",
    "irkáltak": "irkált",
    "irodaháza": "irodaház",
    "irodaházak": "irodaház",
    "irodalma": "irodalom",
    "irodalmak": "irodalom",
    "irodalmat": "irodalom",
    "irodalmából": "irodalom",
    "irodalmának": "irodalom",
    "irodalmára": "irodalom",
    "irodalmárok": "irodalmár",
    "irodalmát": "irodalom",
    "irodalom-érettségit": "irodalom-érettségi",
    "irodalomhoz": "irodalom",
    "irodalommal": "irodalom",
    "irodalomról": "irodalom",
    "irodavezetője": "irodavezető",
    "irodavezetőjének": "irodavezető",
    "irodába": "iroda",
    "irodában": "iroda",
    "irodája": "iroda",
    "irodájának": "iroda",
    "irodáját": "iroda",
    "irodák": "iroda",
    "irodákkal": "iroda",
    "irodáknál": "iroda",
    "irodákon": "iroda",
    "irodának": "iroda",
    "irodát": "iroda",
    "irosz-nak": "irosz",
    "irreálisan": "irreális",
    "irreálisnak": "irreális",
    "irtani": "irt",
    "irtania": "irt",
    "irtottak": "irtott",
    "irtásban": "irtás",
    "irtást": "irtás",
    "irtózatosabban": "irtózatos",
    "irtózatosan": "irtózatos",
    "irtózott": "irtózik",
    "irtóztam": "irtózik",
    "iránta": "iránt",
    "irántuk": "iránt",
    "iránya": "irány",
    "irányba": "irány",
    "irányban": "irány",
    "irányból": "irány",
    "iránymutatást": "iránymutatás",
    "irányról": "irány",
    "irányt": "irány",
    "irányul": "irány",
    "irányult": "irányul",
    "irányultságát": "irányultság",
    "irányába": "irány",
    "irányában": "irány",
    "irányának": "irány",
    "irányárra": "irányár",
    "irányát": "irány",
    "irányítani": "irányít",
    "irányítja": "irányít",
    "irányítjuk": "irányít",
    "irányítják": "irányít",
    "irányított": "irányít",
    "irányította": "irányít",
    "irányítottak": "irányított",
    "irányították": "irányít",
    "irányítsa": "irányít",
    "irányítást": "irányítás",
    "irányításában": "irányítás",
    "irányításával": "irányítás",
    "irányítóit": "irányítói",
    "irányítóját": "irányító",
    "iróniával": "irónia",
    "iskolapadba": "iskolapad",
    "iskolaszékek": "iskolaszék",
    "iskolavándorral": "iskolavándor",
    "iskolába": "iskola",
    "iskolában": "iskola",
    "iskolából": "iskola",
    "iskoládat": "iskola",
    "iskoláikra": "iskola",
    "iskolája": "iskola",
    "iskolájáról": "iskola",
    "iskoláját": "iskola",
    "iskolák": "iskola",
    "iskolákat": "iskola",
    "iskolákból": "iskola",
    "iskoláskorban": "iskoláskor",
    "iskoláskorában": "iskoláskor",
    "iskoláskönyvet": "iskoláskönyv",
    "iskolát": "iskola",
    "iskolává": "iskola",
    "ismered": "ismer",
    "ismerek": "ismer",
    "ismerem": "ismer",
    "ismeretanyagot": "ismeretanyag",
    "ismeretanyagáról": "ismeretanyag",
    "ismerete": "ismeret",
    "ismereteikről": "ismeret",
    "ismereteinek": "ismeret",
    "ismereteit": "ismeret",
    "ismeretek": "ismeret",
    "ismereteket": "ismeretek",
    "ismeretekre": "ismeretek",
    "ismeretet": "ismeret",
    "ismeretségek": "ismeretség",
    "ismeretében": "ismeret",
    "ismerhetett": "ismerhet",
    "ismerhettem": "ismerhet",
    "ismeri": "ismer",
    "ismerik": "ismer",
    "ismerje": "ismer",
    "ismerjük": "ismer",
    "ismerkedett": "ismerkedik",
    "ismerlek": "ismer",
    "ismernek": "ismer",
    "ismerni": "ismer",
    "ismernie": "ismer",
    "ismerné": "ismer",
    "ismernék": "ismer",
    "ismernél": "ismer",
    "ismernünk": "ismer",
    "ismert": "ismer",
    "ismerte": "ismer",
    "ismertek": "ismert",
    "ismertem": "ismert",
    "ismertethette": "ismertethet",
    "ismertetik": "ismertet",
    "ismertetni": "ismertet",
    "ismertette": "ismertet",
    "ismertettük": "ismertet",
    "ismertetése": "ismertetés",
    "ismertsége": "ismertség",
    "ismertté": "ismert",
    "ismerték": "ismer",
    "ismertük": "ismer",
    "ismertünk": "ismert",
    "ismerünk": "ismer",
    "ismerői": "ismerő",
    "ismerősei": "ismerős",
    "ismerőseimhez": "ismerős",
    "ismerőseinek": "ismerős",
    "ismerőseiről": "ismerős",
    "ismerőseit": "ismerős",
    "ismerősnek": "ismerős",
    "ismerősre": "ismerős",
    "ismerőst": "ismerős",
    "ismerősök": "ismerős",
    "ismerősöktől": "ismerős",
    "ismét": "isme",
    "ismételgette": "ismételget",
    "ismételje": "ismétel",
    "ismételjék": "ismétel",
    "ismételnie": "ismétel",
    "ismételnünk": "ismétel",
    "ismételt": "ismétel",
    "ismételte": "ismétel",
    "ismételten": "ismételt",
    "ismételték": "ismétel",
    "ismétled": "ismétel",
    "ismétli": "ismétel",
    "ismétlése": "ismétlés",
    "ismétlődhetnek": "ismétlődhet",
    "ismétlődtek": "ismétlődik",
    "ismétlődése": "ismétlődés",
    "ismétlődött": "ismétlődik",
    "ispánok": "ispán",
    "issza": "iszik",
    "istenben": "isten",
    "isteneket": "isten",
    "istenhez": "isten",
    "istennek": "isten",
    "istennél": "isten",
    "istentiszteleten": "istentisztelet",
    "istentiszteletet": "istentisztelet",
    "istentisztelettel": "istentisztelet",
    "istentől": "isten",
    "istenünk": "isten",
    "istállóba": "istálló",
    "istállóban": "istálló",
    "istállóból": "istálló",
    "istállójuk": "istálló",
    "istállójából": "istálló",
    "istápolását": "istápolás",
    "isznak": "iszik",
    "iszonyattól": "iszonyat",
    "iszonyodott": "iszonyodik",
    "iszonyúan": "iszonyú",
    "iszákját": "iszák",
    "italboltban": "italbolt",
    "italboltok": "italbolt",
    "italközben": "italköz",
    "italmérései": "italmérés",
    "italt": "ital",
    "italuk": "ital",
    "italának": "ital",
    "italát": "ital",
    "itatta": "itat",
    "itta": "iszik",
    "ittak": "iszik",
    "ittam": "iszik",
    "ittasan": "ittas",
    "itteniek": "itteni",
    "ittenihez": "itteni",
    "ittléte": "ittlét",
    "ittunk": "iszik",
    "ivadékok": "ivadék",
    "ivott": "iszik",
    "ivászathoz": "ivászat",
    "ivóban": "ivó",
    "ivódtak": "ivódik",
    "ivóvízellátása": "ivóvízellátás",
    "izegni-mozogni": "izeg-mozog",
    "izgalma": "izgalom",
    "izgalmak": "izgalom",
    "izgalmakkal": "izgalom",
    "izgalmat": "izgalom",
    "izgalmában": "izgalom",
    "izgalmából": "izgalom",
    "izgalmára": "izgalom",
    "izgalmával": "izgalom",
    "izgalomba": "izgalom",
    "izgalommal": "izgalom",
    "izgalomrohamokat": "izgalomroham",
    "izgalomtól": "izgalom",
    "izgatja": "izgat",
    "izgatott": "izgat",
    "izgatottan": "izgatott",
    "izgatottságból": "izgatottság",
    "izgatottságát": "izgatottság",
    "izgatta": "izgat",
    "izgatószerük": "izgatószer",
    "izgett-mozgott": "izeg-mozog",
    "izguljunk": "izgul",
    "izgulnak": "izgul",
    "izgultam": "izgult",
    "izgékonyabb": "izgékony",
    "izmai": "izom",
    "izmaikban": "izom",
    "izmainak": "izom",
    "izmait": "izom",
    "izmok": "izom",
    "izmokból": "izom",
    "izraeliek": "izraeli",
    "izraelieket": "izraeli",
    "izsópról": "izsóp",
    "izzadsággyöngyök": "izzadsággyöngy",
    "izzadságkészlete": "izzadságkészlet",
    "izzadságszaga": "izzadságszag",
    "izzadságszaggal": "izzadságszag",
    "izzadságszagot": "izzadságszag",
    "izzadt": "izzad",
    "izzadóképessége": "izzadóképesség",
    "izzasztja": "izzaszt",
    "izzasztást": "izzasztás",
    "jachtokat": "jacht",
    "jakobinuscédulák": "jakobinuscédula",
    "janicsárokat": "janicsár",
    "januárjában": "január",
    "januárjától": "január",
    "januártól": "január",
    "japánban": "japán",
    "java": "jav",
    "javak": "jav",
    "javakat": "javak",
    "javarészt": "javarész",
    "javaslata": "javaslat",
    "javaslataikat": "javaslat",
    "javaslatban": "javaslat",
    "javaslatok": "javaslat",
    "javaslatokat": "javaslat",
    "javaslatoknak": "javaslat",
    "javaslatot": "javaslat",
    "javaslatra": "javaslat",
    "javaslatról": "javaslat",
    "javaslattal": "javaslat",
    "javaslattételt": "javaslattétel",
    "javaslatuk": "javaslat",
    "javaslatukat": "javaslat",
    "javaslatára": "javaslat",
    "javaslatát": "javaslat",
    "javaslatával": "javaslat",
    "javasolhatja": "javasolhat",
    "javasolja": "javasol",
    "javasolják": "javasol",
    "javasolt": "javasol",
    "javasolta": "javasol",
    "javukra": "jav",
    "javul": "jav",
    "javuljon": "javul",
    "javult": "javul",
    "javulása": "javulás",
    "javulásra": "javulás",
    "javulást": "javulás",
    "javulásához": "javulás",
    "javára": "java",
    "javáért": "java",
    "javítani": "javít",
    "javítják": "javít",
    "javított": "javít",
    "javította": "javít",
    "javítása": "javítás",
    "javításokat": "javítás",
    "javítást": "javítás",
    "javításában": "javítás",
    "javításához": "javítás",
    "javítására": "javítás",
    "javításáról": "javítás",
    "javítóközpontoknak": "javítóközpont",
    "jegenyék": "jegenye",
    "jegesedést": "jegesedés",
    "jegessé": "jeges",
    "jegybevételt": "jegybevétel",
    "jegye": "jegy",
    "jegyei": "jegy",
    "jegyeit": "jegy",
    "jegyek": "jegy",
    "jegyekért": "jegy",
    "jegyemet": "jegy",
    "jegyet": "jegy",
    "jegyezd": "jegyez",
    "jegyezhetik": "jegyezhet",
    "jegyezhettek": "jegyezhet",
    "jegyezhetők": "jegyezhető",
    "jegyezni": "jegyez",
    "jegyeznie": "jegyez",
    "jegyeznünk": "jegyez",
    "jegyezte": "jegyez",
    "jegyeztek": "jegyez",
    "jegyezzen": "jegyez",
    "jegytömegből": "jegytömeg",
    "jegyzeteken": "jegyzet",
    "jegyzeteket": "jegyzet",
    "jegyzetet": "jegyzet",
    "jegyzett": "jegyez",
    "jegyzéket": "jegyzék",
    "jegyzékét": "jegyzék",
    "jegyzésarányosan": "jegyzésarányos",
    "jegyzése": "jegyzés",
    "jegyzései": "jegyzés",
    "jegyzések": "jegyzés",
    "jegyzést": "jegyzés",
    "jegyzője": "jegyző",
    "jegyzőkönyvekkel": "jegyzőkönyv",
    "jegyzőkönyvét": "jegyzőkönyv",
    "jegyében": "jegy",
    "jegyért": "jegy",
    "jeladással": "jeladás",
    "jelcinnek": "jelcin",
    "jele": "jel",
    "jelek": "jel",
    "jelekkel": "jel",
    "jelen": "jel",
    "jelenben": "jelen",
    "jelene": "jelen",
    "jelenetben": "jelenet",
    "jeleneteit": "jelenet",
    "jelenetek": "jelenet",
    "jelenetekre": "jelenet",
    "jelenetet": "jelenet",
    "jelenetnek": "jelenet",
    "jelenhez": "jelen",
    "jelenleginél": "jelenlegi",
    "jelenlevők": "jelenlevő",
    "jelenlevőkre": "jelenlevő",
    "jelenléte": "jelenlét",
    "jelenlétet": "jelenlét",
    "jelenlétében": "jelenlét",
    "jelenlétére": "jelenlét",
    "jelenlétéről": "jelenlét",
    "jelenlétét": "jelenlét",
    "jelenlétével": "jelenlét",
    "jelenlétükkel": "jelenlét",
    "jelennek": "jelenik",
    "jelennék": "jelenik",
    "jelennél": "jelenik",
    "jelenről": "jelen",
    "jelenségek": "jelenség",
    "jelenségeket": "jelenség",
    "jelenséget": "jelenség",
    "jelenségnek": "jelenség",
    "jelent": "jelenik",
    "jelentek": "jelent",
    "jelentene": "jelent",
    "jelentenek": "jelent",
    "jelenteni": "jelent",
    "jelenteniük": "jelent",
    "jelentené": "jelent",
    "jelentett": "jelent",
    "jelentette": "jelent",
    "jelentettek": "jelentett",
    "jelentették": "jelentet",
    "jelenthetett": "jelenthet",
    "jelentheti": "jelenthet",
    "jelenthetik": "jelenthet",
    "jelenthetne": "jelenthet",
    "jelenthette": "jelenthet",
    "jelenthettek": "jelenthet",
    "jelenti": "jelent",
    "jelentik": "jelent",
    "jelentkezem": "jelentkezik",
    "jelentkezett": "jelentkezik",
    "jelentkezhetünk": "jelentkezhet",
    "jelentkezni": "jelentkezik",
    "jelentkeznie": "jelentkezik",
    "jelentkeznék": "jelentkezik",
    "jelentkeztem": "jelentkezik",
    "jelentkezzék": "jelentkezik",
    "jelentkezéseire": "jelentkezés",
    "jelentkezéseket": "jelentkezés",
    "jelentkezésnek": "jelentkezés",
    "jelentkezést": "jelentkezés",
    "jelentkezését": "jelentkezés",
    "jelentkezők": "jelentkező",
    "jelentkezőket": "jelentkező",
    "jelentkezőkkel": "jelentkező",
    "jelentkezőknek": "jelentkező",
    "jelentkezőnek": "jelentkező",
    "jelentse": "jelent",
    "jelentsen": "jelent",
    "jelentsék": "jelent",
    "jelentése": "jelentés",
    "jelentései": "jelentés",
    "jelentéseiktől": "jelentés",
    "jelentéseit": "jelentés",
    "jelentések": "jelentés",
    "jelentésekből": "jelentés",
    "jelentéseket": "jelentés",
    "jelentésekhez": "jelentés",
    "jelentésektől": "jelentés",
    "jelentésnek": "jelentés",
    "jelentésről": "jelentés",
    "jelentéssel": "jelentés",
    "jelentést": "jelentés",
    "jelentéstartalmát": "jelentéstartalom",
    "jelentéstételre": "jelentéstétel",
    "jelentésárnyalatot": "jelentésárnyalat",
    "jelentésében": "jelentés",
    "jelentéséből": "jelentés",
    "jelentésének": "jelentés",
    "jelentéséről": "jelentés",
    "jelentését": "jelentés",
    "jelentésétől": "jelentés",
    "jelentésük": "jelentés",
    "jelentésükből": "jelentés",
    "jelentésüket": "jelentés",
    "jelentésükre": "jelentés",
    "jelentésüktől": "jelentés",
    "jelentünk": "jelent",
    "jelentősebb": "jelentős",
    "jelentősen": "jelentős",
    "jelentőssé": "jelentős",
    "jelentőst": "jelentős",
    "jelentősége": "jelentőség",
    "jelentőséggel": "jelentőség",
    "jelentőségére": "jelentőség",
    "jelentőségéről": "jelentőség",
    "jelentőségét": "jelentőség",
    "jelentőségük": "jelentőség",
    "jelenítettük": "jelenített",
    "jeleníti": "jelenít",
    "jelezni": "jelez",
    "jelezte": "jelez",
    "jelezték": "jelez",
    "jeleztük": "jelez",
    "jelképe": "jelkép",
    "jelképesen": "jelképes",
    "jelképesnek": "jelképes",
    "jelképezi": "jelképez",
    "jelképezte": "jelképez",
    "jelképrendszert": "jelképrendszer",
    "jelképévé": "jelképév",
    "jellege": "jelleg",
    "jelleget": "jelleg",
    "jellegzetesek": "jellegzetes",
    "jellegzetesen": "jellegzetes",
    "jellegét": "jelleg",
    "jellegűek": "jellegű",
    "jelleme": "jellem",
    "jellemet": "jellem",
    "jellemezte": "jellemez",
    "jellemezzük": "jellemez",
    "jellemvonása": "jellemvonás",
    "jellemzi": "jellemez",
    "jellemzik": "jellemez",
    "jellemzője": "jellemző",
    "jellemét": "jellem",
    "jelmezeivé": "jelmez",
    "jelmondata": "jelmondat",
    "jelmondatok": "jelmondat",
    "jelmondatának": "jelmondat",
    "jelmondatát": "jelmondat",
    "jelre": "jel",
    "jelszava": "jelszó",
    "jelszavak": "jelszó",
    "jelszavakat": "jelszó",
    "jelszavakba": "jelszó",
    "jelszavakig": "jelszó",
    "jelszavakkal": "jelszó",
    "jelszavam": "jelszó",
    "jelszavául": "jelszó",
    "jelszót": "jelszó",
    "jelszóval": "jelszó",
    "jelt": "jel",
    "jelvénye": "jelvény",
    "jelvények": "jelvény",
    "jelzett": "jelez",
    "jelzi": "jelez",
    "jelzik": "jelez",
    "jelzések": "jelzés",
    "jelzéseket": "jelzés",
    "jelzéshez": "jelzés",
    "jelzésként": "jelzés",
    "jelzést": "jelzés",
    "jelzőktől": "jelző",
    "jelzőlámpái": "jelzőlámpa",
    "jelét": "jel",
    "jeléül": "jel",
    "jelöli": "jelöl",
    "jelölik": "jelöl",
    "jelölni": "jelöl",
    "jelölné": "jelöl",
    "jelölnöm": "jelöl",
    "jelölt": "jelöl",
    "jelöltből": "jelölt",
    "jelölte": "jelöl",
    "jelölteket": "jelölt",
    "jelöltetni": "jelöltet",
    "jelöltként": "jelölt",
    "jelölték": "jelöl",
    "jelöltünk": "jelölt",
    "jelölése": "jelölés",
    "jelöléskor": "jelölés",
    "jelölést": "jelölés",
    "jelöléstől": "jelölés",
    "jelölésére": "jelölés",
    "jelölését": "jelölés",
    "jelölöd": "jelöl",
    "jelölőlistára": "jelölőlista",
    "jelükké": "jel",
    "jemeniek": "jemeni",
    "jenre": "jen",
    "jobb": "jó",
    "jobbak": "jó",
    "jobban": "jobb",
    "jobbat": "jó",
    "jobbkor": "jobb",
    "jobbnak": "jobb",
    "jobboldalról": "jobboldal",
    "jobboldalt": "jobboldal",
    "jobboldaltól": "jobboldal",
    "jobbra": "jobb",
    "jobbszárnyán": "jobbszárny",
    "joga": "jog",
    "jogai": "jog",
    "jogaimat": "jog",
    "jogainak": "jog",
    "jogait": "jog",
    "jogdíjak": "jogdíj",
    "jogdíjakkal": "jogdíj",
    "jogdíjat": "jogdíj",
    "jogdíjcsúcsot": "jogdíjcsúcs",
    "jogdíjfizetést": "jogdíjfizetés",
    "jogdíjként": "jogdíj",
    "jogdíjának": "jogdíj",
    "jogerősen": "jogerős",
    "jogfolytonosságot": "jogfolytonosság",
    "joggal": "jog",
    "jogintézmények": "jogintézmény",
    "jogkörrel": "jogkör",
    "jogkört": "jogkör",
    "jogkörének": "jogkör",
    "jogok": "jog",
    "jogokat": "jog",
    "jogokban": "jog",
    "jogokkal": "jog",
    "jogoknak": "jog",
    "jogokra": "jog",
    "jogokról": "jog",
    "jogon": "jog",
    "jogosan": "jogos",
    "jogossága": "jogosság",
    "jogosulatlanul": "jogosulatlan",
    "jogosult": "jogosul",
    "jogosultak": "jogosult",
    "jogosítványai": "jogosítvány",
    "jogosítványokat": "jogosítvány",
    "jogot": "jog",
    "jogrendben": "jogrend",
    "jogszabályok": "jogszabály",
    "jogszabályokban": "jogszabály",
    "jogszabálysértést": "jogszabálysértés",
    "jogszabályt": "jogszabály",
    "jogszabályváltozásra": "jogszabályváltozás",
    "jogszerűnek": "jogszerű",
    "jogszerűsége": "jogszerűség",
    "joguk": "jog",
    "jogutód": "jogutó",
    "jogutódait": "jogutód",
    "jogutódjának": "jogutód",
    "jogvitába": "jogvita",
    "jogvitának": "jogvita",
    "jogállamokat": "jogállam",
    "jogán": "jog",
    "jogászai": "jogász",
    "jogászok": "jogász",
    "jogát": "jog",
    "jogától": "jog",
    "jogával": "jog",
    "jubileuma": "jubileum",
    "juhtúrót": "juhtúró",
    "jussanak": "jut",
    "jusson": "jut",
    "jussuk": "jut",
    "justizmord-díjat": "justizmord-díj",
    "jutalmat": "jutalom",
    "jutalmazott": "jutalmaz",
    "jutalmazza": "jutalmaz",
    "jutalomnak": "jutalom",
    "jutalékhoz": "jutalék",
    "jutatta": "jutat",
    "juthatnak": "juthat",
    "juthatnék": "juthat",
    "juthatott": "juthat",
    "juthattak": "juthat",
    "jutna": "jut",
    "jutnak": "jut",
    "jutni": "jut",
    "jutnia": "jut",
    "jutnék": "jut",
    "jutott": "jut",
    "jutottak": "jutott",
    "jutottam": "jutott",
    "jutottunk": "jutott",
    "jutottál": "jut",
    "juttathatja": "juttathat",
    "juttathatná": "juttathat",
    "juttatja": "juttat",
    "juttatni": "juttat",
    "juttatott": "juttat",
    "juttatta": "juttat",
    "juttattad": "juttat",
    "juttattál": "juttat",
    "juttatása": "juttatás",
    "jutunk": "jut",
    "jutányosan": "jutányos",
    "jutáshoz": "jutás",
    "jutásért": "jutás",
    "jutók": "jutó",
    "jámborságában": "jámborság",
    "járadékjogosultságuk": "járadékjogosultság",
    "járadékokat": "járadék",
    "járadékszámítást": "járadékszámítás",
    "járata": "járat",
    "járatban": "járat",
    "járatja": "járat",
    "járatlanok": "járatlan",
    "járatlanért": "járatlan",
    "járdák": "járda",
    "járdákon": "járda",
    "járdán": "járda",
    "járdára": "járda",
    "járdáról": "járda",
    "járdát": "járda",
    "járhatatlanná": "járhatatlan",
    "járhatnak": "járhat",
    "járhatott": "járhat",
    "járhatóak": "járható",
    "járhatók": "járható",
    "járja": "jár",
    "járjon": "jár",
    "járják": "jár",
    "járkálnak": "járkál",
    "járkálni": "járkál",
    "járkált": "járkál",
    "járkáltatják": "járkáltat",
    "járkáltunk": "járkált",
    "járműjavítót": "járműjavító",
    "járműjavítóért": "járműjavító",
    "járműve": "jármű",
    "járműveikben": "jármű",
    "járművek": "jármű",
    "járműveket": "jármű",
    "járművekről": "jármű",
    "járművet": "jármű",
    "járna": "jár",
    "járnak": "jár",
    "járni": "jár",
    "járnának": "jár",
    "járok": "jár",
    "járomba": "járom",
    "járomban": "járom",
    "jársz": "jár",
    "járt": "jár",
    "járt-kelt": "jár-kel",
    "járta": "jár",
    "jártak": "járt",
    "jártam": "járt",
    "jártasak": "jártas",
    "jártassá": "jártas",
    "jártatta": "jártat",
    "jártunk": "járt",
    "járták": "járta",
    "járuljon": "járul",
    "járulniuk": "járul",
    "járult": "járul",
    "járulékai": "járulék",
    "járulékmentesen": "járulékmentes",
    "járulékokról": "járulék",
    "járuléktartozása": "járuléktartozás",
    "járunk": "jár",
    "járványcsírafajták": "járványcsírafajtá",
    "járást": "járás",
    "járőrnél": "járőr",
    "járőrrel": "járőr",
    "járőrt": "járőr",
    "járőrök": "járőr",
    "járőrökön": "járőr",
    "járőrözni": "járőröz",
    "jászkunokkal": "jászkun",
    "jászságban": "jászság",
    "játssza": "játszik",
    "játsszák": "játszik",
    "játszadoztak": "játszadozik",
    "játszanak": "játszik",
    "játszani": "játszik",
    "játszatott": "játszat",
    "játszik": "játszi",
    "játszmában": "játszma",
    "játszmát": "játszma",
    "játszmával": "játszma",
    "játszol": "játszik",
    "játszom": "játszik",
    "játszott": "játszik",
    "játszotta": "játszik",
    "játszottak": "játszott",
    "játszottam": "játszott",
    "játszottunk": "játszott",
    "játszották": "játszik",
    "játszunk": "játszik",
    "játszódtak": "játszódik",
    "játszóknak": "játszó",
    "játszótérnek": "játszótér",
    "játéka": "játék",
    "játékainak": "játék",
    "játékait": "játék",
    "játékba": "játék",
    "játékban": "játék",
    "játékból": "játék",
    "játékengedélye": "játékengedély",
    "játékengedélyek": "játékengedély",
    "játékintelligenciát": "játékintelligencia",
    "játékkal": "játék",
    "játékkészítők": "játékkészítő",
    "játéknak": "játék",
    "játéknapon": "játéknap",
    "játéknál": "játék",
    "játékokat": "játék",
    "játékomra": "játék",
    "játékosa": "játékos",
    "játékosait": "játékos",
    "játékosok": "játékos",
    "játékosokkal": "játékos",
    "játékosoknak": "játékos",
    "játékost": "játékos",
    "játékostól": "játékos",
    "játékosuktól": "játékos",
    "játékosunknak": "játékos",
    "játékosának": "játékos",
    "játékot": "játék",
    "játékra": "játék",
    "játékrészben": "játékrész",
    "játékszabályokat": "játékszabály",
    "játéktere": "játéktér",
    "játékteret": "játéktér",
    "játékvariációt": "játékvariáció",
    "játékvezetői": "játékvezető",
    "játékvezetők": "játékvezető",
    "játékvezetőket": "játékvezető",
    "játékvezetőnek": "játékvezető",
    "játékában": "játék",
    "játékát": "játék",
    "jéggé": "jég",
    "jégre": "jég",
    "jégszekrénnyel": "jégszekrény",
    "jégtömbök": "jégtömb",
    "jércéket": "jérce",
    "jóakarattal": "jóakarat",
    "jóakaratát": "jóakarat",
    "jóba": "jó",
    "jóban": "jó",
    "jócskán": "jócská",
    "jód": "jó",
    "jóemberei": "jóember",
    "jóembereinek": "jóember",
    "jóformán": "jóformá",
    "jógondolosan": "jógondolos",
    "jógondolt": "jógondol",
    "jóhiszeműséged": "jóhiszeműség",
    "jóindulatból": "jóindulat",
    "jóindulatnak": "jóindulat",
    "jóindulatot": "jóindulat",
    "jóindulatára": "jóindulat",
    "jóindulatától": "jóindulat",
    "jóindulatúan": "jóindulatú",
    "jók": "jó",
    "jókat": "jó",
    "jókor": "jó",
    "jókívánságokat": "jókívánság",
    "jólesett": "jólesik",
    "jólesnék": "jólesik",
    "jóllakott": "jóllakik",
    "jóllaktak": "jóllakik",
    "jóltartják": "jóltart",
    "jólétnek": "jólét",
    "jómódúnak": "jómódú",
    "jónak": "jó",
    "jóra": "jó",
    "jórészben": "jórész",
    "jórészt": "jórész",
    "jóslata": "jóslat",
    "jóslatai": "jóslat",
    "jóslatnak": "jóslat",
    "jóslatokat": "jóslat",
    "jósolnak": "jósol",
    "jósolni": "jósol",
    "jósolta": "jósol",
    "jósoltak": "jósolt",
    "jószágai": "jószág",
    "jószággal": "jószág",
    "jószágnak": "jószág",
    "jószágok": "jószág",
    "jószágtól": "jószág",
    "jóságot": "jóság",
    "jót": "jó",
    "jótevőn": "jótevő",
    "jótállója": "jótálló",
    "jótékonyan": "jótékony",
    "jóval": "jó",
    "jóvá": "jó",
    "jóváhagyatására": "jóváhagyatás",
    "jóváhagyja": "jóváhagy",
    "jóváhagyjuk": "jóváhagy",
    "jóváhagyna": "jóváhagy",
    "jóváhagynia": "jóváhagy",
    "jóváhagyniuk": "jóváhagy",
    "jóváhagyott": "jóváhagy",
    "jóváhagyása": "jóváhagyás",
    "jóváhagyásának": "jóváhagyás",
    "jóváhagyását": "jóváhagyás",
    "jóvátenni": "jóvátesz",
    "józanabb": "józan",
    "józannak": "józan",
    "jóérzésére": "jóérzés",
    "jöhetett": "jöhet",
    "jöhettek": "jöhet",
    "jöjj": "jön",
    "jöjjenek": "jön",
    "jöjjön": "jön",
    "jöjjünk": "jön",
    "jönnek": "jön",
    "jönni": "jön",
    "jönnie": "jön",
    "jönnének": "jön",
    "jönnöd": "jön",
    "jönnöm": "jön",
    "jönnünk": "jön",
    "jössz": "jön",
    "jött": "jön",
    "jöttek": "jön",
    "jöttek-mentek": "jön-megy",
    "jöttem": "jön",
    "jöttetek": "jön",
    "jöttél": "jön",
    "jöttök": "jött",
    "jöttünk": "jött",
    "jövedelemadóból": "jövedelemadó",
    "jövedelemadót": "jövedelemadó",
    "jövedelme": "jövedelem",
    "jövedelmeik": "jövedelem",
    "jövedelmezősége": "jövedelmezőség",
    "jövedelmezőségét": "jövedelmezőség",
    "jövedelmének": "jövedelem",
    "jövedelműek": "jövedelmű",
    "jövetele": "jövetel",
    "jövetelével": "jövetel",
    "jövök": "jön",
    "jövünk": "jön",
    "jövőbe": "jövő",
    "jövőben": "jövő",
    "jövőd": "jövő",
    "jövőhöz": "jövő",
    "jövőjének": "jövő",
    "jövőjére": "jövő",
    "jövőjéről": "jövő",
    "jövőjét": "jövő",
    "jövőjéért": "jövő",
    "jövőmet": "jövő",
    "jövőnek": "jövő",
    "jövőnk": "jövő",
    "jövőre": "jövő",
    "jövőt": "jövő",
    "jövővel": "jövő",
    "júliusban": "július",
    "júliusig": "július",
    "júniusa": "június",
    "júniusban": "június",
    "júniusig": "június",
    "júniusra": "június",
    "júniustól": "június",
    "júniusában": "június",
    "kabátot": "kabát",
    "kabátunkra": "kabát",
    "kacagása": "kacagás",
    "kacagását": "kacagás",
    "kacaja": "kacaj",
    "kacsa": "kacs",
    "kacsabeszélő-ről": "kacsabeszélő",
    "kacsamódra": "kacsamód",
    "kacsintottak": "kacsintott",
    "kacsot": "kacs",
    "kacsái": "kacsa",
    "kacsák": "kacsa",
    "kacsákat": "kacsa",
    "kacsának": "kacsa",
    "kacsójába": "kacsó",
    "kaján": "kaja",
    "kajánságnak": "kajánság",
    "kajánul": "kaján",
    "kakasaim": "kakas",
    "kakaskodásainál": "kakaskodás",
    "kakasok": "kakas",
    "kakasszóra": "kakasszó",
    "kakastollaikat": "kakastoll",
    "kalandorok": "kalandor",
    "kalandozni": "kalandozik",
    "kalandoztak": "kalandozik",
    "kalandozunk": "kalandozik",
    "kalapját": "kalap",
    "kalaplerakása": "kalaplerakás",
    "kalapom": "kalap",
    "kalapot": "kalap",
    "kalappal": "kalap",
    "kalapunkat": "kalap",
    "kalapáccsal": "kalapács",
    "kalapácsütések": "kalapácsütés",
    "kalapálnak": "kalapál",
    "kalapálni": "kalapál",
    "kalapált": "kalapál",
    "kalapálással": "kalapálás",
    "kalapálásával": "kalapálás",
    "kalauzolta": "kalauzol",
    "kalauzunk": "kalauz",
    "kaleidoszkópnál": "kaleidoszkóp",
    "kaleidoszkópoknak": "kaleidoszkóp",
    "kalitkában": "kalitka",
    "kalitkát": "kalitka",
    "kalkulációnkban": "kalkuláció",
    "kalkulációt": "kalkuláció",
    "kalkuláltak": "kalkulált",
    "kalodáról": "kaloda",
    "kalácsokból": "kalács",
    "kalácsot": "kalács",
    "kalászok": "kalász",
    "kalászokat": "kalász",
    "kamarapartneréül": "kamarapartner",
    "kamaszgyomrot": "kamaszgyomor",
    "kamaszkorára": "kamaszkor",
    "kamata": "kamat",
    "kamatain": "kamat",
    "kamatait": "kamat",
    "kamatcsökkentése": "kamatcsökkentés",
    "kamatcsökkentésekkel": "kamatcsökkentés",
    "kamatcsökkentéseknél": "kamatcsökkentés",
    "kamatcsökkentést": "kamatcsökkentés",
    "kamatenyhítést": "kamatenyhítés",
    "kamatköltségek": "kamatköltség",
    "kamatnak": "kamat",
    "kamatok": "kamat",
    "kamatokkal": "kamat",
    "kamatokra": "kamat",
    "kamatot": "kamat",
    "kamatoznak": "kamatozik",
    "kamatszinttől": "kamatszint",
    "kamatát": "kamat",
    "kameruniak": "kameruni",
    "kamerái": "kamera",
    "kamerával": "kamera",
    "kampánnyal": "kampány",
    "kampányba": "kampány",
    "kampányban": "kampány",
    "kampányidőszakot": "kampányidőszak",
    "kampánynak": "kampány",
    "kampányt": "kampány",
    "kampányát": "kampány",
    "kamrába": "kamra",
    "kamrában": "kamra",
    "kanadaiak": "kanadai",
    "kanala": "kanál",
    "kanalak": "kanál",
    "kanalakat": "kanál",
    "kanalat": "kanál",
    "kanalazták": "kanalaz",
    "kanalát": "kanál",
    "kancsalítana": "kancsalít",
    "kancsalított": "kancsalít",
    "kancára": "kanca",
    "kandallópárkányon": "kandallópárkány",
    "kandelábert": "kandeláber",
    "kanok": "kan",
    "kanokat": "kan",
    "kanokkal": "kan",
    "kanokéhoz": "kan",
    "kantinba": "kantin",
    "kantinban": "kantin",
    "kantust": "kantus",
    "kanyarban": "kanyar",
    "kanyarintott": "kanyarint",
    "kanyarodnak": "kanyarodik",
    "kanyarodott": "kanyarodik",
    "kanyarodtak": "kanyarodik",
    "kanyarodóban": "kanyarodó",
    "kanyarulatnál": "kanyarulat",
    "kanálban": "kanál",
    "kanállal": "kanáll",
    "kanászok": "kanász",
    "kanászoknak": "kanász",
    "kanászt": "kanász",
    "kanócként": "kanóc",
    "kapacitások": "kapacitás",
    "kapacitásokhoz": "kapacitás",
    "kapacitással": "kapacitás",
    "kapacitásszűkítésben": "kapacitásszűkítés",
    "kapacitást": "kapacitás",
    "kapargatni": "kapargat",
    "kaparnának": "kapar",
    "kapartak": "kapart",
    "kapartam": "kapart",
    "kapartunk": "kapart",
    "kaparást": "kaparás",
    "kaparékot": "kaparék",
    "kapaszkodni": "kapaszkodik",
    "kapaszkodott": "kapaszkodik",
    "kapaszkodásra": "kapaszkodás",
    "kapcsolata": "kapcsolat",
    "kapcsolatai": "kapcsolat",
    "kapcsolataink": "kapcsolat",
    "kapcsolataira": "kapcsolat",
    "kapcsolatait": "kapcsolat",
    "kapcsolatba": "kapcsolat",
    "kapcsolatban": "kapcsolat",
    "kapcsolatok": "kapcsolat",
    "kapcsolatokat": "kapcsolat",
    "kapcsolatokban": "kapcsolat",
    "kapcsolatokra": "kapcsolat",
    "kapcsolatosan": "kapcsolatos",
    "kapcsolatot": "kapcsolat",
    "kapcsolatotok": "kapcsolat",
    "kapcsolatra": "kapcsolat",
    "kapcsolatról": "kapcsolat",
    "kapcsolattartást": "kapcsolattartás",
    "kapcsolatukat": "kapcsolat",
    "kapcsolatát": "kapcsolat",
    "kapcsolni": "kapcsol",
    "kapcsolnom": "kapcsol",
    "kapcsolt": "kapcsol",
    "kapcsolták": "kapcsol",
    "kapcsolódhattak": "kapcsolódhat",
    "kapcsolódni": "kapcsolódik",
    "kapcsolódott": "kapcsolódik",
    "kapcsolódtak": "kapcsolódik",
    "kapcsolót": "kapcsoló",
    "kapcsán": "kapocs",
    "kapcában": "kapca",
    "kapcám": "kapca",
    "kapcának": "kapca",
    "kapcát": "kapca",
    "kaphatja": "kaphat",
    "kaphatnak": "kaphat",
    "kaphattak": "kaphat",
    "kaphatunk": "kaphat",
    "kapitalisták": "kapitalista",
    "kapitalistákkal": "kapitalista",
    "kapitalistáknak": "kapitalista",
    "kapitalistáké": "kapitalista",
    "kapitalistának": "kapitalista",
    "kapitalistát": "kapitalista",
    "kapitalistával": "kapitalista",
    "kapitalizmusban": "kapitalizmus",
    "kapitánya": "kapitány",
    "kapitánysága": "kapitányság",
    "kapitányságok": "kapitányság",
    "kapitányságokon": "kapitányság",
    "kapitányságon": "kapitányság",
    "kapja": "kap",
    "kapjanak": "kap",
    "kapjon": "kap",
    "kapjuk": "kap",
    "kapjunk": "kap",
    "kapják": "kap",
    "kapkodnia": "kapkod",
    "kapkodott": "kapkod",
    "kapkodtak": "kapkod",
    "kapna": "kap",
    "kapnak": "kap",
    "kapni": "kap",
    "kapnia": "kap",
    "kapniuk": "kap",
    "kapná": "kap",
    "kapnának": "kap",
    "kapott": "kap",
    "kapsz": "kap",
    "kapszulája": "kapszula",
    "kapta": "kap",
    "kaptafára": "kaptafa",
    "kaptak": "kap",
    "kaptam": "kap",
    "kaptok": "kap",
    "kaptunk": "kap",
    "kaptája": "kapta",
    "kapták": "kapta",
    "kaptát": "kapta",
    "kapualjba": "kapualj",
    "kapuba": "kapu",
    "kapuban": "kapu",
    "kapuhoz": "kapu",
    "kapuik": "kapu",
    "kapuit": "kapui",
    "kapuja": "kapu",
    "kapujába": "kapu",
    "kapujában": "kapu",
    "kapujához": "kapu",
    "kapuján": "kapu",
    "kapujára": "kapu",
    "kapuját": "kapu",
    "kapuk": "kapu",
    "kapukon": "kapu",
    "kapukulcsot": "kapukulcs",
    "kapukulcsát": "kapukulcs",
    "kapunak": "kapu",
    "kapunk": "kapu",
    "kapunál": "kapu",
    "kapusgondjaik": "kapusgond",
    "kapusukat": "kapus",
    "kaput": "kapu",
    "kapálni": "kapál",
    "kapálta": "kapál",
    "kapáltak": "kapált",
    "kapáltatják": "kapáltat",
    "kapálásban": "kapálás",
    "kapálással": "kapálás",
    "kapálására": "kapálás",
    "kapálását": "kapálás",
    "kapásból": "kapás",
    "kapások": "kapás",
    "kapóra": "kapó",
    "karaktere": "karakter",
    "karaként": "kar",
    "karambolja": "karambol",
    "karavánt": "karaván",
    "karba": "kar",
    "karbantartása": "karbantartás",
    "karbantartásuk": "karbantartás",
    "karcsún": "karcsú",
    "kardjával": "kard",
    "kardokként": "kardokk",
    "kardsuhintások": "kardsuhintás",
    "kardsuhintásokkal": "kardsuhintás",
    "karikatúráját": "karikatúra",
    "karikatúrákon": "karikatúra",
    "karikák": "karika",
    "karikákkal": "karika",
    "karikákra": "karika",
    "karja": "kar",
    "karjai": "kar",
    "karjait": "kar",
    "karjába": "kar",
    "karjában": "kar",
    "karján": "kar",
    "karjánál": "kar",
    "karjára": "kar",
    "karjáról": "kar",
    "karját": "kar",
    "karjával": "kar",
    "karkivágásban": "karkivágás",
    "karmestere": "karmester",
    "karmokat": "karom",
    "karmozdulattal": "karmozdulat",
    "karocskáin": "karocská",
    "karodat": "kar",
    "karokkal": "kar",
    "karom": "kar",
    "karosszékbe": "karosszék",
    "karosszékben": "karosszék",
    "karosszékében": "karosszék",
    "karra": "kar",
    "karral": "kar",
    "karrierjüket": "karrier",
    "karszékben": "karszék",
    "karszékek": "karszék",
    "kart": "kar",
    "kartográfusának": "kartográfus",
    "kartondobozzal": "kartondoboz",
    "kartonok": "karton",
    "kartonra": "karton",
    "kartonruhájukat": "kartonruha",
    "kartont": "karton",
    "kartontáblákon": "kartontábla",
    "kartársnők": "kartársnő",
    "kartávolságnyira": "kartávolságnyi",
    "karzaton": "karzat",
    "karéja": "karéj",
    "karénekében": "karének",
    "karóba": "karó",
    "karórájára": "karórája",
    "kasszasikerben": "kasszasiker",
    "kasszasikerek": "kasszasikér",
    "kasszák": "kassza",
    "kasszákat": "kassza",
    "kasszát": "kassza",
    "kastélyok": "kastély",
    "kasztráltam": "kasztrált",
    "kaszája": "kasza",
    "kaszálni": "kaszál",
    "kaszáláskor": "kaszálás",
    "kaszálóban": "kaszáló",
    "kaszálók": "kaszáló",
    "kaszálókon": "kaszáló",
    "kaszára": "kasza",
    "kaszárnyában": "kaszárnya",
    "kaszása": "kaszás",
    "kaszásnak": "kaszás",
    "kaszások": "kaszás",
    "kaszást": "kaszás",
    "kaszásával": "kaszás",
    "kaszát": "kasza",
    "katalógusát": "katalógus",
    "katasztrófái": "katasztrófa",
    "katasztrófát": "katasztrófa",
    "kategorikusan": "kategorikus",
    "kategóriaként": "kategória",
    "kategóriába": "kategória",
    "kategóriában": "kategória",
    "kategóriáinak": "kategória",
    "kategóriájába": "kategória",
    "kategóriájának": "kategória",
    "katolikusok": "katolikus",
    "katonabakancsa": "katonabakancs",
    "katonablúzok": "katonablúz",
    "katonacsizmák": "katonacsizma",
    "katonaruhában": "katonaruha",
    "katonaruhával": "katonaruha",
    "katonasoron": "katonasor",
    "katonaszökevények": "katonaszökevény",
    "katonaszökevényeket": "katonaszökevény",
    "katonaszökevénynek": "katonaszökevény",
    "katonaságtól": "katonaság",
    "katonatiszt-fiaiknak": "katonatiszt-fiú",
    "katonatisztek": "katonatiszt",
    "katonazenére": "katonazene",
    "katonazenét": "katonazene",
    "katonái": "katona",
    "katonáinak": "katona",
    "katonáira": "katona",
    "katonáit": "katona",
    "katonák": "katona",
    "katonákat": "katona",
    "katonákkal": "katona",
    "katonáknak": "katona",
    "katonáknál": "katona",
    "katonákon": "katona",
    "katonáktól": "katona",
    "katonáké": "katona",
    "katonának": "katona",
    "katonásan": "katonás",
    "katonát": "katona",
    "katonával": "katona",
    "katonáé": "katona",
    "kattant": "kattan",
    "kattanása": "kattanás",
    "kattanást": "kattanás",
    "kavargott": "kavarog",
    "kavarintottam": "kavarintott",
    "kavarodott": "kavarodik",
    "kavarodásban": "kavarodás",
    "kavart": "kavar",
    "kavartak": "kavart",
    "kaviccsal": "kavics",
    "kavicson": "kavics",
    "kavicsot": "kavics",
    "kazincbarcikaiak": "kazincbarcikai",
    "kazánházaival": "kazánház",
    "kebelről": "kebel",
    "keble": "kebel",
    "keblébe": "kebel",
    "kecsesebb": "kecses",
    "kecsesen": "kecses",
    "kecskebékák": "kecskebéka",
    "kecskeszakállal": "kecskeszakáll",
    "kedden": "kedd",
    "keddtől": "kedd",
    "kedve": "kedv",
    "kedved": "kedv",
    "kedvelik": "kedvel",
    "kedvelt": "kedvel",
    "kedvelte": "kedvel",
    "kedvem": "kedv",
    "kedvence": "kedvenc",
    "kedvese": "kedves",
    "kedveset": "kedves",
    "kedveskedést": "kedveskedés",
    "kedvesnek": "kedves",
    "kedvessége": "kedvesség",
    "kedvesének": "kedves",
    "kedvesük": "kedves",
    "kedvet": "kedv",
    "kedvetlenül": "kedvetlen",
    "kedvezményben": "kedvezmény",
    "kedvezmények": "kedvezmény",
    "kedvezményeket": "kedvezmény",
    "kedvezményekkel": "kedvezmény",
    "kedvezőbb": "kedvező",
    "kedvezőbbeknek": "kedvező",
    "kedvezőek": "kedvező",
    "kedvezően": "kedvező",
    "kedvezőtlenebb": "kedvezőtlen",
    "kedvezőtlenül": "kedvezőtlen",
    "kedvében": "kedv",
    "kedvéért": "kedv",
    "kedvükben": "kedv",
    "kedvünk": "kedv",
    "kedélyeket": "kedély",
    "kedélyesen": "kedélyes",
    "kedélyére": "kedély",
    "kegyben": "kegy",
    "kegyed": "kegy",
    "kegyeiből": "kegy",
    "kegyelem": "kegyel",
    "kegyelemért": "kegyelem",
    "kegyeletüket": "kegyelet",
    "kegyelmeznek": "kegyelmez",
    "kegyelmezni": "kegyelmez",
    "kegyetlenebbül": "kegyetlen",
    "kegyetlenek": "kegyetlen",
    "kegyetlenkedéseit": "kegyetlenkedés",
    "kegyetlenkedések": "kegyetlenkedés",
    "kegyetlenkedésekkel": "kegyetlenkedés",
    "kegyetlenkedését": "kegyetlenkedés",
    "kegyetlenkedünk": "kegyetlenkedik",
    "kegyetlennek": "kegyetlen",
    "kegyetlensége": "kegyetlenség",
    "kegyetlenségre": "kegyetlenség",
    "kegyetlenségéről": "kegyetlenség",
    "kegyetlenül": "kegyetlen",
    "kegyvesztettek": "kegyvesztett",
    "kegyüktől": "kegy",
    "kelegetni": "keleget",
    "kelepcébe": "kelepce",
    "kelepcéből": "kelepce",
    "kelet-budapestieké": "kelet-budapesti",
    "kelet-európaiak": "kelet-európai",
    "keleten": "kelet",
    "keletiek": "keleti",
    "keletiekét": "keleti",
    "keletkezett": "keletkezik",
    "keletkeztek": "keletkezik",
    "keletlenül": "keletlen",
    "keletről": "kelet",
    "keletázsiaiak": "keletázsiai",
    "kelj": "kel",
    "kellek": "kell",
    "kellemesebb": "kellemes",
    "kellemesen": "kellemes",
    "kellemességére": "kellemesség",
    "kellemességét": "kellemesség",
    "kellemetlenségben": "kellemetlenség",
    "kellemetlenségei": "kellemetlenség",
    "kellemetlenségeket": "kellemetlenség",
    "kellemetlenséget": "kellemetlenség",
    "kellemetlenül": "kellemetlen",
    "kellene": "kell",
    "kellenek": "kell",
    "kelletlenül": "kelletlen",
    "kellett": "kell",
    "kelleténél": "kellete",
    "kelljen": "kell",
    "kellékdarabjait": "kellékdarab",
    "kellékei": "kellék",
    "kellékeket": "kellék",
    "kellően": "kellő",
    "kellőképp": "kellő",
    "kellőképpen": "kellő",
    "kellőn": "kellő",
    "kelni": "kel",
    "kelniük": "kel",
    "kelt": "kel",
    "keltek": "kelt",
    "kelteni": "kelt",
    "keltetnek": "keltet",
    "keltett": "kelt",
    "keltette": "keltet",
    "keltettek": "keltett",
    "keltették": "keltet",
    "keltheti": "kelthet",
    "kelthetnének": "kelthet",
    "kelthette": "kelthet",
    "kelthettek": "kelthet",
    "kelti": "kelt",
    "keltik": "kelt",
    "keltsem": "kelt",
    "keltsünk": "kelt",
    "kemencébe": "kemence",
    "kemencében": "kemence",
    "kemencék": "kemence",
    "kemencékbe": "kemence",
    "keményebb": "kemény",
    "keményebben": "kemény",
    "keményen": "kemény",
    "keménysége": "keménység",
    "kend": "ken",
    "kenderesen": "kenderes",
    "kendteké": "kendtek",
    "kendőbe": "kendő",
    "kendőre": "kendőr",
    "kendőt": "kendő",
    "kendőt-kötőt": "kendő-kötő",
    "kenik": "ken",
    "kent": "ken",
    "kentben": "kent",
    "kenyere": "kenyér",
    "kenyerek": "kenyér",
    "kenyereket": "kenyér",
    "kenyerekért": "kenyér",
    "kenyeret": "kenyér",
    "kenyeréből": "kenyér",
    "kenyerén": "kenyér",
    "kenyeréről": "kenyér",
    "kenyerét": "kenyér",
    "kenyerével": "kenyér",
    "kenyerük": "kenyér",
    "kenyerünk": "kenyér",
    "kenyerünkre": "kenyér",
    "kenyérbe": "kenyér",
    "kenyérből": "kenyér",
    "kenyérdarabkákat": "kenyérdarabka",
    "kenyérdarabot": "kenyérdarab",
    "kenyéren": "kenyér",
    "kenyérevőket": "kenyérevő",
    "kenyérgyárban": "kenyérgyár",
    "kenyérhéjat": "kenyérhéj",
    "kenyérre": "kenyér",
    "kenyérrel": "kenyér",
    "kenyérről": "kenyér",
    "kenyérszelet": "kenyérszél",
    "kenyérzsákot": "kenyérzsák",
    "kenőccsel": "kenőcs",
    "kenődött": "kenődik",
    "kerekasztal-tárgyalások": "kerekasztal-tárgyalás",
    "kerekedett": "kerekedik",
    "kerekednek": "kerekedik",
    "kerekei": "kerék",
    "kerekek": "kerék",
    "keresek": "keres",
    "keresem": "keres",
    "keresete": "kereset",
    "keresetet": "kereset",
    "keresetről": "kereset",
    "keresett": "keres",
    "keresetten": "keresett",
    "keresetének": "kereset",
    "keresetük": "kereset",
    "keresetünknek": "kereset",
    "kereshetett": "kereshet",
    "keresi": "keres",
    "keresik": "keres",
    "kereskedelembe": "kereskedelem",
    "kereskedelemmel": "kereskedelem",
    "kereskedelme": "kereskedelem",
    "kereskedett": "kereskedik",
    "kereskednek": "kereskedik",
    "kereskedni": "kereskedik",
    "kereskedtek": "kereskedik",
    "kereskedése": "kereskedés",
    "kereskedést": "kereskedés",
    "kereskedésére": "kereskedés",
    "kereskedői": "kereskedő",
    "kereskedőkön": "kereskedő",
    "kereskedőnek": "kereskedő",
    "kereslek": "keres",
    "keresletcsökkentésre": "keresletcsökkentés",
    "keresletet": "kereslet",
    "keresne": "keres",
    "keresnek": "keres",
    "keresni": "keres",
    "keressen": "keres",
    "keressenek": "keres",
    "keressél": "keres",
    "kereste": "keres",
    "kerestek": "keres",
    "kerestem": "keres",
    "keresték": "keres",
    "kerestük": "keres",
    "keresztanyjának": "keresztanya",
    "keresztanyánk": "keresztanya",
    "keresztapja": "keresztapa",
    "keresztbe": "kereszt",
    "keresztben": "kereszt",
    "keresztek": "kereszt",
    "keresztekből": "kereszt",
    "kereszteket": "kereszt",
    "keresztelni": "keresztel",
    "keresztelt": "keresztel",
    "keresztet": "kereszt",
    "keresztezni": "keresztez",
    "keresztezést": "keresztezés",
    "keresztezéséből": "keresztezés",
    "kereszteződésben": "kereszteződés",
    "keresztjeik": "kereszt",
    "keresztjeit": "kereszt",
    "keresztre": "kereszt",
    "kereszténydemokraták": "kereszténydemokrata",
    "kereszténydemokratákat": "kereszténydemokrata",
    "kereszténydemokráciára": "kereszténydemokrácia",
    "keresztül": "kereszt",
    "keresztülbotorkált": "keresztülbotorkál",
    "keresztülhajolt": "keresztülhajol",
    "keresztülhajította": "keresztülhajít",
    "keresztülkötött": "keresztülköt",
    "keresztüllátni": "keresztüllát",
    "keresztüllátok": "keresztüllát",
    "keresztülment": "keresztülmegy",
    "keresztülmentél": "keresztülmegy",
    "keresztülnézett": "keresztülnéz",
    "keresztülszakította": "keresztülszakít",
    "keresztülsétáltak": "keresztülsétált",
    "keresztülsétáltunk": "keresztülsétált",
    "keresztültörtettek": "keresztültörtet",
    "keresztülvillant": "keresztülvillan",
    "keresztülvágott": "keresztülvág",
    "keresztülzuhant": "keresztülzuhan",
    "kereséséről": "keresés",
    "keresünk": "keres",
    "keretben": "keret",
    "keretből": "keret",
    "kerete": "keret",
    "keretei": "keret",
    "kereteit": "keret",
    "keretet": "keret",
    "keretszabályok": "keretszabály",
    "keretében": "keret",
    "kergetni": "kerget",
    "kergetőztek": "kergetőzik",
    "keringtek": "kering",
    "kertbe": "kert",
    "kertek": "kert",
    "kertet": "kert",
    "kertkaput": "kertkapu",
    "kertészkedhetnének": "kertészkedhet",
    "kerékpárgumin": "kerékpárgumi",
    "kerékpárok": "kerékpár",
    "keríteni": "kerít",
    "kerítenék": "kerít",
    "kerítette": "kerít",
    "kerítettek": "kerített",
    "keríthetett": "keríthet",
    "keríthetik": "keríthet",
    "keríthetnél": "keríthet",
    "keríthette": "keríthet",
    "kerítik": "kerít",
    "kerítjük": "kerít",
    "kerítéseikkel": "kerítés",
    "kerítések": "kerítés",
    "kerítésén": "kerítés",
    "kerítésének": "kerítés",
    "kerítője": "kerítő",
    "kerületbe": "kerület",
    "kerületben": "kerület",
    "kerülete": "kerület",
    "kerületek": "kerület",
    "kerületeket": "kerület",
    "kerületeknek": "kerület",
    "kerületiek": "kerületi",
    "kerülgetik": "kerülget",
    "kerülgette": "kerülget",
    "kerülhessek": "kerülhet",
    "kerülhessen": "kerülhet",
    "kerülhetett": "kerülhet",
    "kerülheti": "kerülhet",
    "kerülhetnek": "kerülhet",
    "kerülhettek": "kerülhet",
    "kerüli": "kerül",
    "kerüljön": "kerül",
    "kerülne": "kerül",
    "kerülnek": "kerül",
    "kerülni": "kerül",
    "kerülnie": "kerül",
    "kerülniük": "kerül",
    "kerülnék": "kerül",
    "kerülsz": "kerül",
    "került": "kerül",
    "kerülte": "kerül",
    "kerültek": "kerül",
    "kerültem": "kerül",
    "kerültél": "kerül",
    "kerültünk": "került",
    "kerülését": "kerülés",
    "kerülünk": "kerül",
    "kerülők": "kerülő",
    "kerülőket": "kerülő",
    "kerülőt": "kerülő",
    "keservesen": "keserves",
    "keseríti": "keserít",
    "keserűen": "keserű",
    "keserűségein": "keserűség",
    "keserűségen": "keserűség",
    "keserűséget": "keserűség",
    "keserűséggel": "keserűség",
    "keskenyebb": "keskeny",
    "keszegecskék": "keszegecské",
    "kesztyűbabák": "kesztyűbaba",
    "ketrecekben": "ketrec",
    "ketrecet": "ketrec",
    "ketrecének": "ketrec",
    "kettesben": "kettes",
    "kettétörte": "kettétörik",
    "kettéváljon": "kettéválik",
    "kettőnk": "kettő",
    "kettőnél": "kettő",
    "kettőspontok": "kettőspont",
    "kettősökben": "kettős",
    "kettőt": "kettő",
    "kettőtől": "kettő",
    "kettővel": "kettő",
    "ketyegett": "ketyeg",
    "ketyegése": "ketyegés",
    "ketyegését": "ketyegés",
    "keveredett": "keveredik",
    "keveredni": "keveredik",
    "keveredtek": "keveredik",
    "kevergetik": "keverget",
    "kevernek": "kever",
    "keverte": "kever",
    "kevertek": "kevert",
    "keverték": "kever",
    "keveréke": "keverék",
    "kevesebb": "kevés",
    "kevesebbe": "kevés",
    "kevesebben": "kevés",
    "kevesebbet": "kevés",
    "kevesellte": "kevesell",
    "kevesellték": "kevesell",
    "kevesen": "kevés",
    "keveset": "kevés",
    "kevésnek": "kevés",
    "kevéssé": "kevés",
    "kezded": "kezd",
    "kezdem": "kezd",
    "kezdeményein": "kezdemény",
    "kezdeményezett": "kezdeményez",
    "kezdeményezhetik": "kezdeményezhet",
    "kezdeményezte": "kezdeményez",
    "kezdeményezések": "kezdeményezés",
    "kezdeményezéseket": "kezdeményezés",
    "kezdeményezéseknek": "kezdeményezés",
    "kezdeményezéshez": "kezdeményezés",
    "kezdeményezésnek": "kezdeményezés",
    "kezdeményezésre": "kezdeményezés",
    "kezdeményezést": "kezdeményezés",
    "kezdeményezéséből": "kezdeményezés",
    "kezdeményezésére": "kezdeményezés",
    "kezdeményezését": "kezdeményezés",
    "kezdene": "kezd",
    "kezdenek": "kezd",
    "kezdeni": "kezd",
    "kezdeniük": "kezd",
    "kezdené": "kezd",
    "kezdenék": "kezd",
    "kezdetben": "kezdet",
    "kezdete": "kezdet",
    "kezdeti": "kezdet",
    "kezdetlegesebb": "kezdetleges",
    "kezdett": "kezd",
    "kezdettől": "kezdett",
    "kezdetén": "kezdet",
    "kezdetét": "kezdet",
    "kezdetétől": "kezdet",
    "kezdheti": "kezdhet",
    "kezdi": "kezd",
    "kezdik": "kezd",
    "kezdj": "kezd",
    "kezdje": "kezd",
    "kezdjek": "kezd",
    "kezdjen": "kezd",
    "kezdjük": "kezd",
    "kezdjünk": "kezd",
    "kezdte": "kezd",
    "kezdtek": "kezd",
    "kezdtem": "kezd",
    "kezdtetek": "kezdtet",
    "kezdték": "kezd",
    "kezdtél": "kezd",
    "kezdtük": "kezd",
    "kezdésbe": "kezdés",
    "kezdéshez": "kezdés",
    "kezdést": "kezdés",
    "kezdőbetűje": "kezdőbetű",
    "kezdőbetűk": "kezdőbetű",
    "kezdődhetnek": "kezdődhet",
    "kezdődjék": "kezdődik",
    "kezdődtek": "kezdődik",
    "kezdődött": "kezdődik",
    "kezdődően": "kezdődő",
    "kezdők": "kezdő",
    "kezdőkkel": "kezdő",
    "keze": "kéz",
    "kezedben": "kéz",
    "kezeink": "kéz",
    "kezeit": "kéz",
    "kezeivel": "kéz",
    "kezeket": "kéz",
    "kezekkel": "kéz",
    "kezelhetetlenné": "kezelhetetlen",
    "kezeli": "kezel",
    "kezelik": "kezel",
    "kezelje": "kezel",
    "kezeljék": "kezel",
    "kezelnek": "kezel",
    "kezelni": "kezel",
    "kezelt": "kezel",
    "kezelte": "kezel",
    "kezeltek": "kezelt",
    "kezelések": "kezelés",
    "kezelésnek": "kezelés",
    "kezelést": "kezelés",
    "kezelésében": "kezelés",
    "kezelésének": "kezelés",
    "kezelésére": "kezelés",
    "kezelését": "kezelés",
    "kezelőik": "kezelő",
    "kezelők": "kezelő",
    "kezem": "kéz",
    "kezembe": "kéz",
    "kezemben": "kéz",
    "kezemre": "kéz",
    "kezességet": "kezesség",
    "kezet": "kéz",
    "kezébe": "kéz",
    "kezében": "kéz",
    "kezéből": "kéz",
    "kezéhez": "kéz",
    "kezén": "kéz",
    "kezének": "kéz",
    "kezére": "kéz",
    "kezéről": "kéz",
    "kezét": "kéz",
    "kezével": "kéz",
    "kezéért": "kéz",
    "kezük": "kéz",
    "kezükbe": "kéz",
    "kezükben": "kéz",
    "kezüket": "kéz",
    "kezünk": "kéz",
    "kezünkbe": "kéz",
    "kezünkben": "kéz",
    "kezünket": "kéz",
    "kft-ben": "kft",
    "ki-kifulladt": "ki-kifullad",
    "ki-kimennek": "ki-kimegy",
    "kiabálnak": "kiabál",
    "kiabálni": "kiabál",
    "kiabált": "kiabál",
    "kiabálta": "kiabál",
    "kiabáltak": "kiabált",
    "kiabálását": "kiabálás",
    "kiadatásában": "kiadatás",
    "kiadatását": "kiadatás",
    "kiadhatták": "kiadhat",
    "kiadja": "kiad",
    "kiadni": "kiad",
    "kiadott": "kiad",
    "kiadta": "kiad",
    "kiadtak": "kiad",
    "kiadták": "kiad",
    "kiadtál": "kiad",
    "kiadványt": "kiadvány",
    "kiadása": "kiadás",
    "kiadásait": "kiadás",
    "kiadásban": "kiadás",
    "kiadásként": "kiadás",
    "kiadások": "kiadás",
    "kiadásokra": "kiadás",
    "kiadásokról": "kiadás",
    "kiadást": "kiadás",
    "kiadást-bevételt": "kiadást-bevétel",
    "kiadásában": "kiadás",
    "kiadásán": "kiadás",
    "kiadásának": "kiadás",
    "kiadásánál": "kiadás",
    "kiadását": "kiadás",
    "kiadásáért": "kiadás",
    "kiadói": "kiadó",
    "kiadója": "kiadó",
    "kiadók": "kiadó",
    "kiadónak": "kiadó",
    "kiadóról": "kiadó",
    "kialakult": "kialakul",
    "kialakulása": "kialakulás",
    "kialakulását": "kialakulás",
    "kialakítani": "kialakít",
    "kialakítania": "kialakít",
    "kialakított": "kialakít",
    "kialakították": "kialakít",
    "kialakítása": "kialakítás",
    "kialakítással": "kialakítás",
    "kialakításához": "kialakítás",
    "kialakítására": "kialakítás",
    "kialakítását": "kialakítás",
    "kialakításával": "kialakítás",
    "kialkudni": "kialkuszik",
    "kialkudott": "kialkuszik",
    "kialudják": "kialszik",
    "kialudni": "kialszik",
    "kialudt": "kialszik",
    "kialvatlanságának": "kialvatlanság",
    "kiapadt": "kiapad",
    "kibabrált": "kibabrál",
    "kibeszélte": "kibeszél",
    "kibillent": "kibillen",
    "kibillentik": "kibillent",
    "kibocsátunk": "kibocsát",
    "kibocsátással": "kibocsátás",
    "kibocsátásában": "kibocsátás",
    "kibogozta": "kibogoz",
    "kibomlott": "kibomlik",
    "kibomlottak": "kibomlott",
    "kibontakozni": "kibontakozik",
    "kibontakozott": "kibontakozik",
    "kibontakoztak": "kibontakozik",
    "kibontakozással": "kibontakozás",
    "kibontakozóban": "kibontakozó",
    "kibontott": "kibont",
    "kibontotta": "kibont",
    "kibuggyantak": "kibuggyant",
    "kibukkant": "kibukkan",
    "kibérelhetné": "kibérelhet",
    "kibéreli": "kibérel",
    "kibérelni": "kibérel",
    "kibérelte": "kibérel",
    "kibéreltek": "kibérelt",
    "kibírjuk": "kibír",
    "kibírnak": "kibír",
    "kibírom": "kibír",
    "kibírtam": "kibírt",
    "kiböfögte": "kiböfög",
    "kibújnak": "kibújik",
    "kibújni": "kibújik",
    "kibújtak": "kibújt",
    "kibúvókat": "kibúvó",
    "kibővíteni": "kibővít",
    "kicipelte": "kicipel",
    "kicsalja": "kicsal",
    "kicsapódjanak": "kicsapódik",
    "kicsapódott": "kicsapódik",
    "kicsatolta": "kicsatol",
    "kicsavarni": "kicsavar",
    "kicsavarodott": "kicsavarodik",
    "kicsavarták": "kicsavar",
    "kicsempésznek": "kicsempész",
    "kicserzette": "kicserzet",
    "kicseréled": "kicserél",
    "kicserélheti": "kicserélhet",
    "kicseréli": "kicserél",
    "kicserélik": "kicserél",
    "kicserélni": "kicserél",
    "kicserélték": "kicserél",
    "kicserélésének": "kicserélés",
    "kicsik": "kicsi",
    "kicsikarni": "kicsikar",
    "kicsikartuk": "kicsikar",
    "kicsikarták": "kicsikar",
    "kicsikarására": "kicsikarás",
    "kicsikét": "kicsike",
    "kicsim": "kicsi",
    "kicsinyeskedése": "kicsinyeskedés",
    "kicsire": "kicsi",
    "kicsirázik": "kicsiráz",
    "kicsiről": "kicsi",
    "kicsit": "kicsi",
    "kicsivel": "kicsi",
    "kicsodák": "kicsoda",
    "kicsoszogott": "kicsoszog",
    "kicsíráztak": "kicsírázik",
    "kidagadtak": "kidagadt",
    "kideríteni": "kiderít",
    "kiderítette": "kiderít",
    "kiderítették": "kiderítet",
    "kiderítésére": "kiderítés",
    "kiderülne": "kiderül",
    "kiderült": "kiderül",
    "kidolgozhassanak": "kidolgozhat",
    "kidolgozni": "kidolgozik",
    "kidolgoznia": "kidolgozik",
    "kidolgozott": "kidolgozik",
    "kidolgozták": "kidolgozik",
    "kidolgozása": "kidolgozás",
    "kidolgozásában": "kidolgozás",
    "kidolgozására": "kidolgozás",
    "kidolgozását": "kidolgozás",
    "kidugaszolta": "kidugaszol",
    "kidugta": "kidug",
    "kidülleszti": "kidülleszt",
    "kidőlt": "kidől",
    "kiegyenesedett": "kiegyenesedik",
    "kiegyenesíteni": "kiegyenesít",
    "kiegyenesítette": "kiegyenesít",
    "kiegyenlíteni": "kiegyenlít",
    "kiegyenlítette": "kiegyenlít",
    "kiegyenlítjük": "kiegyenlít",
    "kiegyenlítésében": "kiegyenlítés",
    "kiegyenlítésére": "kiegyenlítés",
    "kiegyensúlyozott": "kiegyensúlyoz",
    "kiegyensúlyozottan": "kiegyensúlyozott",
    "kiegyensúlyozásáról": "kiegyensúlyozás",
    "kiegyezett": "kiegyez",
    "kiegyezésen": "kiegyezés",
    "kiegészíteni": "kiegészít",
    "kiegészített": "kiegészít",
    "kiegészítették": "kiegészítet",
    "kiegészíti": "kiegészít",
    "kiegészítik": "kiegészít",
    "kiegészítse": "kiegészít",
    "kiegészítése": "kiegészítés",
    "kiejtene": "kiejt",
    "kiejthetők": "kiejthető",
    "kiejthetővé": "kiejthető",
    "kiejtse": "kiejt",
    "kiejtése": "kiejtés",
    "kiejtéssel": "kiejtés",
    "kielégíteni": "kielégít",
    "kielégítenie": "kielégít",
    "kielégítette": "kielégít",
    "kielégítettséggel": "kielégítettség",
    "kielégíti": "kielégít",
    "kielégítse": "kielégít",
    "kielégítsük": "kielégít",
    "kielégítése": "kielégítés",
    "kielégítéséhez": "kielégítés",
    "kielégítésére": "kielégítés",
    "kielégítését": "kielégítés",
    "kielégítőek": "kielégítő",
    "kielégítően": "kielégítő",
    "kielégületlenül": "kielégületlen",
    "kiemeli": "kiemel",
    "kiemelik": "kiemel",
    "kiemelje": "kiemel",
    "kiemelkedett": "kiemelkedik",
    "kiemelkedtünk": "kiemelkedik",
    "kiemelt": "kiemel",
    "kiemelte": "kiemel",
    "kiemeltek": "kiemelt",
    "kiemelten": "kiemelt",
    "kiemeltetéstől": "kiemeltetés",
    "kiemelünk": "kiemel",
    "kiengedte": "kienged",
    "kiengedték": "kienged",
    "kiengesztelődésnek": "kiengesztelődés",
    "kierőszakolni": "kierőszakol",
    "kierőszakoltak": "kierőszakolt",
    "kiesdeklik": "kiesdekel",
    "kiesett": "kiesik",
    "kiesnie": "kiesik",
    "kiestek": "kiesik",
    "kieszelni": "kieszel",
    "kiesése": "kiesés",
    "kiette": "kieszik",
    "kifagyásokról": "kifagyás",
    "kifejezetten": "kifejezett",
    "kifejezhetők": "kifejezhető",
    "kifejezi": "kifejez",
    "kifejezni": "kifejez",
    "kifejezné": "kifejez",
    "kifejezte": "kifejez",
    "kifejezték": "kifejez",
    "kifejezzenek": "kifejez",
    "kifejezése": "kifejezés",
    "kifejezéseinek": "kifejezés",
    "kifejezések": "kifejezés",
    "kifejezésekből": "kifejezés",
    "kifejezéseket": "kifejezés",
    "kifejezésekhez": "kifejezés",
    "kifejezésre": "kifejezés",
    "kifejezéssel": "kifejezés",
    "kifejezést": "kifejezés",
    "kifejezéstelenül": "kifejezéstelen",
    "kifejezéstelibb": "kifejezésteli",
    "kifejezésébe": "kifejezés",
    "kifejezésére": "kifejezés",
    "kifejezését": "kifejezés",
    "kifejlődni": "kifejlődik",
    "kifejlődött": "kifejlődik",
    "kifejt": "kifej",
    "kifejtette": "kifejt",
    "kifejtették": "kifejtet",
    "kifejti": "kifejt",
    "kifejtéséhez": "kifejtés",
    "kifestett": "kifest",
    "kifestette": "kifest",
    "kifestésével": "kifestés",
    "kifeszült": "kifeszül",
    "kificamításához": "kificamítás",
    "kifinomultabbá": "kifinomult",
    "kifizesse": "kifizet",
    "kifizetett": "kifizet",
    "kifizeti": "kifizet",
    "kifizetik": "kifizet",
    "kifizetjük": "kifizet",
    "kifizetni": "kifizet",
    "kifizetniük": "kifizet",
    "kifizette": "kifizet",
    "kifizették": "kifizet",
    "kifizetése": "kifizetés",
    "kifizetésnél": "kifizetés",
    "kifizetésére": "kifizetés",
    "kifizetőhellyé": "kifizetőhely",
    "kifogni": "kifog",
    "kifogunk": "kifog",
    "kifogyott": "kifogy",
    "kifogása": "kifogás",
    "kifogásokat": "kifogás",
    "kifogásokkal": "kifogás",
    "kifogásolhatóságán": "kifogásolhatóság",
    "kifogásolja": "kifogásol",
    "kifogásolják": "kifogásol",
    "kifogásolt": "kifogásol",
    "kifogásolta": "kifogásol",
    "kifogásolták": "kifogásol",
    "kifogástalanná": "kifogástalan",
    "kifordulását": "kifordulás",
    "kifordítani": "kifordít",
    "kifordított": "kifordít",
    "kifordították": "kifordít",
    "kiforgathatott": "kiforgathat",
    "kiforgatják": "kiforgat",
    "kiforgattak": "kiforgat",
    "kiformálni": "kiformál",
    "kiforrásának": "kiforrás",
    "kifosztotta": "kifoszt",
    "kifosztottak": "kifosztott",
    "kifosztották": "kifoszt",
    "kifulladnak": "kifullad",
    "kifuthatnak": "kifuthat",
    "kifutásáig": "kifutás",
    "kifáradt": "kifárad",
    "kifélék": "kiféle",
    "kifélék-mifélék": "kiféle-miféle",
    "kifújta": "kifúj",
    "kifürkészhetetlenségét": "kifürkészhetetlenség",
    "kigazdálkodniuk": "kigazdálkodik",
    "kigombostűzött": "kigombostűz",
    "kigondolt": "kigondol",
    "kigyulladt": "kigyullad",
    "kigyönyörködtétek": "kigyönyörködik",
    "kigöngyölített": "kigöngyölít",
    "kigöngyölítette": "kigöngyölít",
    "kigúnyolt": "kigúnyol",
    "kihagyott": "kihagy",
    "kihajtotta": "kihajt",
    "kihajtották": "kihajt",
    "kihajtójára": "kihajtó",
    "kihajítani": "kihajít",
    "kihallatszott": "kihallatszik",
    "kihallgatják": "kihallgat",
    "kihallgatott": "kihallgat",
    "kihallgatáskor": "kihallgatás",
    "kihallgatásnak": "kihallgatás",
    "kihallgatások": "kihallgatás",
    "kihallgatásokkal": "kihallgatás",
    "kihallgatáson": "kihallgatás",
    "kihallgatásra": "kihallgatás",
    "kihallgatást": "kihallgatás",
    "kihallgatásához": "kihallgatás",
    "kihalt": "kihal",
    "kiharcolta": "kiharcol",
    "kiharcolták": "kiharcol",
    "kihasogatott": "kihasogat",
    "kihasogattuk": "kihasogat",
    "kihasználni": "kihasznál",
    "kihasználta": "kihasznál",
    "kihasználtsága": "kihasználtság",
    "kihelyezett": "kihelyez",
    "kiheverni": "kihever",
    "kihevítették": "kihevítet",
    "kihez": "ki",
    "kihirdetett": "kihirdet",
    "kihirdetni": "kihirdet",
    "kihirdette": "kihirdet",
    "kihirdették": "kihirdet",
    "kihirdetést": "kihirdetés",
    "kihirdetésének": "kihirdetés",
    "kihirdetésére": "kihirdetés",
    "kihordták": "kihord",
    "kihozni": "kihoz",
    "kihoztunk": "kihoz",
    "kihozták": "kihoz",
    "kihozzák": "kihoz",
    "kihullott": "kihullik",
    "kihurcolkodott": "kihurcolkodik",
    "kihágást": "kihágás",
    "kihányta": "kihány",
    "kihívhatom": "kihívhat",
    "kihívott": "kihív",
    "kihívták": "kihív",
    "kihívásnak": "kihívás",
    "kihúzatni": "kihúzat",
    "kihúznak": "kihúz",
    "kihúzni": "kihúz",
    "kihúzott": "kihúz",
    "kihúzta": "kihúz",
    "kihúzták": "kihúz",
    "kihúzódtunk": "kihúzódik",
    "kihűlt": "kihűl",
    "kiigazította": "kiigazít",
    "kiigazítása": "kiigazítás",
    "kiigazításának": "kiigazítás",
    "kiiktathassák": "kiiktathat",
    "kiiktatásával": "kiiktatás",
    "kiindulni": "kiindul",
    "kiindulópontig": "kiindulópont",
    "kiindulópontjává": "kiindulópont",
    "kiindulópontul": "kiindulópont",
    "kiirthatatlanul": "kiirthatatlan",
    "kiirthatjuk": "kiirthat",
    "kiirtjuk": "kiirt",
    "kiirtották": "kiirt",
    "kiirtunk": "kiirt",
    "kiirtásának": "kiirtás",
    "kiirtásától": "kiirtás",
    "kiitta": "kiiszik",
    "kijelentem": "kijelent",
    "kijelentette": "kijelent",
    "kijelentettem": "kijelentett",
    "kijelenthetem": "kijelenthet",
    "kijelenthetjük": "kijelenthet",
    "kijelentései": "kijelentés",
    "kijelentések": "kijelentés",
    "kijelentésekre": "kijelentés",
    "kijelentéstől": "kijelentés",
    "kijelentésével": "kijelentés",
    "kijelölhetnénk": "kijelölhet",
    "kijelölt": "kijelöl",
    "kijelölésekor": "kijelölés",
    "kijussanak": "kijut",
    "kijuthatnak": "kijuthat",
    "kijuthattok": "kijuthat",
    "kijutni": "kijut",
    "kijutott": "kijut",
    "kijutottak": "kijutott",
    "kijáratát": "kijárat",
    "kijárna": "kijár",
    "kijátszása": "kijátszás",
    "kijátszására": "kijátszás",
    "kijózanodott": "kijózanodik",
    "kijönni": "kijön",
    "kijönnie": "kijön",
    "kijött": "kijön",
    "kijöttek": "kijön",
    "kik": "ki",
    "kikalapálják": "kikalapál",
    "kikapart": "kikapar",
    "kikapcsolja": "kikapcsol",
    "kikapcsolnak": "kikapcsol",
    "kikapcsolni": "kikapcsol",
    "kikapcsolása": "kikapcsolás",
    "kikapja": "kikap",
    "kikapott": "kikap",
    "kikapta": "kikap",
    "kikaptak": "kikap",
    "kikaptuk": "kikap",
    "kikelne": "kikel",
    "kikelni": "kikel",
    "kikelt": "kikel",
    "kikeresse": "kikeres",
    "kikerestünk": "kikeres",
    "kikerülik": "kikerül",
    "kikerülje": "kikerül",
    "kikerülni": "kikerül",
    "kikerült": "kikerül",
    "kiket": "ki",
    "kikiáltja": "kikiált",
    "kikiáltott": "kikiált",
    "kikkel": "ki",
    "kikocogott": "kikocog",
    "kikopott": "kikopik",
    "kikukucskált": "kikukucskál",
    "kikunyerálni": "kikunyerál",
    "kikupált": "kikupál",
    "kikényszeríteni": "kikényszerít",
    "kikényszeríthetik": "kikényszeríthet",
    "kiképzése": "kiképzés",
    "kiképzést": "kiképzés",
    "kikérdezi": "kikérdez",
    "kikérdezte": "kikérdez",
    "kikérem": "kikér",
    "kikérte": "kikér",
    "kikímélt": "kikímél",
    "kikísértek": "kikísért",
    "kikívánkozott": "kikívánkozik",
    "kiköltöznek": "kiköltözik",
    "kiköltöztek": "kiköltözik",
    "kiköpni": "kiköp",
    "kikövetkeztetheti": "kikövetkeztethet",
    "kikövetkeztetni": "kikövetkeztet",
    "kiközösített": "kiközösít",
    "kiküldte": "kiküld",
    "kiküldött": "kiküld",
    "kiküldöttekről": "kiküldött",
    "kiküszöbölik": "kiküszöböl",
    "kiküszöböljük": "kiküszöböl",
    "kiküszöbölése": "kiküszöbölés",
    "kilencet": "kilenc",
    "kilenckor": "kilenc",
    "kilencszázasok": "kilencszázas",
    "kilencvenezerre": "kilencvenezer",
    "kilencvenre": "kilencven",
    "kilessük": "kiles",
    "kilestünk": "kiles",
    "kilibegett": "kilibeg",
    "kilincseiről": "kilincs",
    "kilincsére": "kilincs",
    "kilométerenként": "kilométer",
    "kilométernyire": "kilométernyi",
    "kilométernél": "kilométer",
    "kilométerre": "kilométer",
    "kilométert": "kilométer",
    "kilyukadni": "kilyukad",
    "kilyukadt": "kilyukad",
    "kilyukadása": "kilyukadás",
    "kilábalni": "kilábal",
    "kilátásba": "kilátás",
    "kilátást": "kilátás",
    "kilépett": "kilép",
    "kilépjen": "kilép",
    "kilépjünk": "kilép",
    "kilépne": "kilép",
    "kilépni": "kilép",
    "kiléptek": "kilép",
    "kiléptem": "kilép",
    "kiléptünk": "kilép",
    "kilétéről": "kilét",
    "kilétét": "kilét",
    "kilójáért": "kiló",
    "kilóra": "kiló",
    "kilót": "kiló",
    "kilóval": "kiló",
    "kilökte": "kilök",
    "kilöttyintett": "kilöttyint",
    "kilötyögtették": "kilötyögtet",
    "kilövik": "kilő",
    "kilőtték": "kilő",
    "kimaradjon": "kimarad",
    "kimaradnak": "kimarad",
    "kimaradt": "kimarad",
    "kimarkoltak": "kimarkolt",
    "kimarták": "kimar",
    "kimegyünk": "kimegy",
    "kimelegedetten": "kimelegedett",
    "kimenekülök": "kimenekül",
    "kimenni": "kimegy",
    "kiment": "kimegy",
    "kimentek": "kiment",
    "kimentem": "kiment",
    "kimentünk": "kiment",
    "kimenőjük": "kimenő",
    "kimerített": "kimerít",
    "kimeríthetetlennek": "kimeríthetetlen",
    "kimerült": "kimerül",
    "kimerültek": "kimerül",
    "kimerülése": "kimerülés",
    "kimondani": "kimond",
    "kimondja": "kimond",
    "kimondott": "kimond",
    "kimondottan": "kimondott",
    "kimondta": "kimond",
    "kimondójuk": "kimondó",
    "kimossa": "kimos",
    "kimostuk": "kimos",
    "kimozdítsák": "kimozdít",
    "kimunkálására": "kimunkálás",
    "kimustrált": "kimustrál",
    "kimutatni": "kimutat",
    "kimutatta": "kimutat",
    "kimutatták": "kimutat",
    "kimutatásokat": "kimutatás",
    "kimutogatta": "kimutogat",
    "kimérette": "kiméret",
    "kimérjük": "kimér",
    "kimérni": "kimér",
    "kimért": "kimér",
    "kimérten": "kimért",
    "kimúlta": "kimúlik",
    "kiművelődnek": "kiművelődik",
    "kincsestárát": "kincsestár",
    "kincstárjegyek": "kincstárjegy",
    "kincstárjegyeknél": "kincstárjegy",
    "kincséért": "kincs",
    "kinek": "ki",
    "kinevetnek": "kinevet",
    "kinevetnének": "kinevet",
    "kinevette": "kinevet",
    "kinevezett": "kinevez",
    "kinevezik": "kinevez",
    "kinevezték": "kinevez",
    "kinevezze": "kinevez",
    "kinevezését": "kinevezés",
    "kinevezésével": "kinevezés",
    "kinyilatkoztatott": "kinyilatkoztat",
    "kinyilatkoztatásnak": "kinyilatkoztatás",
    "kinyilvánítani": "kinyilvánít",
    "kinyilvánítanák": "kinyilvánít",
    "kinyilvánította": "kinyilvánít",
    "kinyit": "kinyi",
    "kinyithassuk": "kinyithat",
    "kinyithatják": "kinyithat",
    "kinyitni": "kinyit",
    "kinyitott": "kinyit",
    "kinyitotta": "kinyit",
    "kinyitása": "kinyitás",
    "kinyomozzon": "kinyomoz",
    "kinyílott": "kinyílik",
    "kinyílt": "kinyílik",
    "kinyújtott": "kinyújt",
    "kinyújtotta": "kinyújt",
    "kinyújtózott": "kinyújtózik",
    "kinyúlt": "kinyúlik",
    "kinél": "ki",
    "kinézett": "kinéz",
    "kinéznének": "kinéz",
    "kinéztek": "kinéz",
    "kinéztünk": "kinéz",
    "kinézésűek": "kinézésű",
    "kiokoskodni": "kiokoskodik",
    "kioldja": "kiold",
    "kioldott": "kiold",
    "kiolthatjuk": "kiolthat",
    "kioltjuk": "kiolt",
    "kioltották": "kiolt",
    "kiolvasni": "kiolvas",
    "kiolvasztják": "kiolvaszt",
    "kiosztani": "kioszt",
    "kiosztják": "kioszt",
    "kiosztott": "kioszt",
    "kiosztotta": "kioszt",
    "kiosztották": "kioszt",
    "kiosztást": "kiosztás",
    "kiosztását": "kiosztás",
    "kipihentem": "kipihent",
    "kipihentük": "kipihen",
    "kipirult": "kipirul",
    "kipislogta": "kipislog",
    "kiporolt": "kiporolik",
    "kipróbálja": "kipróbál",
    "kipróbálta": "kipróbál",
    "kipróbálták": "kipróbál",
    "kipróbálása": "kipróbálás",
    "kipufogója": "kipufogó",
    "kipurgálja": "kipurgál",
    "kipusztult": "kipusztul",
    "kipusztítsák": "kipusztít",
    "kipárolgása": "kipárolgás",
    "kiragadott": "kiragad",
    "kiragasztott": "kiragaszt",
    "kirajzolódtak": "kirajzolódik",
    "kirakatban": "kirakat",
    "kirakathoz": "kirakat",
    "kirakaton": "kirakat",
    "kirakatában": "kirakat",
    "kirakott": "kirak",
    "kirakta": "kirak",
    "kiravaszkodni": "kiravaszkodik",
    "kire": "ki",
    "kirekeszteni": "kirekeszt",
    "kirekesztenék": "kirekeszt",
    "kirekesztetteknek": "kirekesztett",
    "kirekesztették": "kirekesztet",
    "kirekeszthetjük": "kirekeszthet",
    "kirendelt": "kirendel",
    "kirendeltségek": "kirendeltség",
    "kirendeltségen": "kirendeltség",
    "kirendeltséghez": "kirendeltség",
    "kirendeltségnél": "kirendeltség",
    "kirohanjanak": "kirohan",
    "kirohanásokról": "kirohanás",
    "királynak": "király",
    "királynő-nek": "királynő",
    "királynője": "királynő",
    "királyok": "király",
    "királyságánál": "királyság",
    "királyért": "király",
    "kirándult": "kirándul",
    "kirándulások": "kirándulás",
    "kirándulásokat": "kirándulás",
    "kirándulásoknak": "kirándulás",
    "kiránduláson": "kirándulás",
    "kirándulók": "kiránduló",
    "kirántotta": "kiránt",
    "kirótt": "kiró",
    "kirúgni": "kirúg",
    "kirúgtak": "kirúg",
    "kisajátítják": "kisajátít",
    "kisajátították": "kisajátít",
    "kisajátítsanak": "kisajátít",
    "kisarjadtak": "kisarjadt",
    "kisasszonyok": "kisasszony",
    "kisbabát": "kisbaba",
    "kisbefektetők": "kisbefektető",
    "kisbefektetőknek": "kisbefektető",
    "kisdedéhez": "kisded",
    "kisebb": "kis",
    "kisebbek": "kis",
    "kisebbeken": "kis",
    "kisebbeknek": "kis",
    "kisebbre": "kis",
    "kisebbségben": "kisebbség",
    "kisebbségek": "kisebbség",
    "kisebbségeknek": "kisebbség",
    "kisebbséget": "kisebbség",
    "kisebbségnek": "kisebbség",
    "kisegítem": "kisegít",
    "kisegítette": "kisegít",
    "kisemberek": "kisember",
    "kisfia": "kisfiú",
    "kisfiát": "kisfiú",
    "kisfiúkat": "kisfiú",
    "kisfiúkorában": "kisfiúkor",
    "kisfiúval": "kisfiú",
    "kisfiúé": "kisfiú",
    "kisgazda-képviselők": "kisgazda-képviselő",
    "kisgazda-politikusok": "kisgazda-politikus",
    "kisgazdapártba": "kisgazdapárt",
    "kisgazdák": "kisgazda",
    "kisgazdáknál": "kisgazda",
    "kisgyereket": "kisgyerek",
    "kisgyerekkel": "kisgyerek",
    "kisgyerekével": "kisgyerek",
    "kisgyermekek": "kisgyermek",
    "kisgyermeket": "kisgyermek",
    "kisgyermekkoromból": "kisgyermekkorom",
    "kisgyermekkorából": "kisgyermekkor",
    "kisgyermekkorának": "kisgyermekkor",
    "kishivatalnokai": "kishivatalnok",
    "kishivatalnokhoz": "kishivatalnok",
    "kishúga": "kishúg",
    "kishúgomnak": "kishúg",
    "kishúgát": "kishúg",
    "kisimította": "kisimít",
    "kiskaput": "kiskapu",
    "kiskocsmát": "kiskocsma",
    "kiskorában": "kiskor",
    "kisköre": "kiskör",
    "kiskörei": "kiskör",
    "kislánnyal": "kislány",
    "kislánya": "kislány",
    "kislánykoromban": "kislánykorom",
    "kislányom": "kislány",
    "kislányt": "kislány",
    "kislányét": "kislány",
    "kisminkelték": "kisminkel",
    "kispesten": "kispest",
    "kisportolt": "kisportol",
    "kispórolni": "kispórol",
    "kisregénye": "kisregény",
    "kisrészvényesek": "kisrészvényes",
    "kisstadionban": "kisstadion",
    "kissé": "kis",
    "kistelepülések": "kistelepülés",
    "kistelepüléseknek": "kistelepülés",
    "kisugározza": "kisugároz",
    "kisugárzanak": "kisugárzik",
    "kisugárzása": "kisugárzás",
    "kisujja": "kisujj",
    "kisujjamat": "kisujj",
    "kisvárosok": "kisváros",
    "kiszabadult": "kiszabadul",
    "kiszabadítani": "kiszabadít",
    "kiszabott": "kiszab",
    "kiszabását": "kiszabás",
    "kiszaladt": "kiszalad",
    "kiszedett": "kiszed",
    "kiszedi": "kiszed",
    "kiszedik": "kiszed",
    "kiszedte": "kiszed",
    "kiszedték": "kiszed",
    "kiszedünk": "kiszed",
    "kiszellőztethessék": "kiszellőztethet",
    "kiszemelt": "kiszemel",
    "kiszemelték": "kiszemel",
    "kiszerelnék": "kiszerel",
    "kiszivárogtatták": "kiszivárogtat",
    "kiszivárogtatásáért": "kiszivárogtatás",
    "kiszolgáltatott": "kiszolgáltat",
    "kiszolgáltatottabbnak": "kiszolgáltatott",
    "kiszolgáltatottan": "kiszolgáltatott",
    "kiszolgáltatottságába": "kiszolgáltatottság",
    "kiszolgáltatta": "kiszolgáltat",
    "kiszolgálása": "kiszolgálás",
    "kiszoptak": "kiszopik",
    "kiszoruljanak": "kiszorul",
    "kiszorítani": "kiszorít",
    "kiszorítják": "kiszorít",
    "kiszorítása": "kiszorítás",
    "kiszálltam": "kiszállt",
    "kiszálltunk": "kiszállt",
    "kiszállásokat": "kiszállás",
    "kiszállítását": "kiszállítás",
    "kiszámíthatatlanságát": "kiszámíthatatlanság",
    "kiszámíthatóbbak": "kiszámítható",
    "kiszámíthatók": "kiszámítható",
    "kiszámította": "kiszámít",
    "kiszámításhoz": "kiszámítás",
    "kiszáradt": "kiszárad",
    "kiszármazott": "kiszármazik",
    "kiszárította": "kiszárít",
    "kiszélesedett": "kiszélesedik",
    "kiszélesítjük": "kiszélesít",
    "kiszórt": "kiszór",
    "kiszökni": "kiszökik",
    "kiszökéshez": "kiszökés",
    "kiszűri": "kiszűr",
    "kiszűrje": "kiszűr",
    "kiszűrése": "kiszűrés",
    "kiszűrésével": "kiszűrés",
    "kisállomáson": "kisállomás",
    "kisétálnánk": "kisétál",
    "kisült": "kisül",
    "kisütni": "kisüt",
    "kit": "ki",
    "kitakarta": "kitakar",
    "kitakarították": "kitakarít",
    "kitalálja": "kitalál",
    "kitalálnak": "kitalál",
    "kitalálni": "kitalál",
    "kitalált": "kitalál",
    "kitalálta": "kitalál",
    "kitaláltad": "kitalált",
    "kitalálása": "kitalálás",
    "kitalálásával": "kitalálás",
    "kitanultam": "kitanult",
    "kitaníttatja": "kitaníttat",
    "kitaníttatták": "kitaníttat",
    "kitapasztalni": "kitapasztal",
    "kitapasztaltuk": "kitapasztal",
    "kitaposott": "kitapos",
    "kitartja": "kitart",
    "kitartásra": "kitartás",
    "kitartást": "kitartás",
    "kitartóan": "kitartó",
    "kitegyék": "kitesz",
    "kitekerem": "kiteker",
    "kitelepülőknek": "kitelepülő",
    "kitelik": "kitel",
    "kiteljesedése": "kiteljesedés",
    "kitenni": "kitesz",
    "kiteregetett": "kitereget",
    "kiterjedjen": "kiterjed",
    "kiterjedt": "kiterjed",
    "kiterjedése": "kiterjedés",
    "kiterjessze": "kiterjeszt",
    "kiterjeszteni": "kiterjeszt",
    "kiterjesztették": "kiterjesztet",
    "kiterjesztik": "kiterjeszt",
    "kiterjesztése": "kiterjesztés",
    "kitervelt": "kitervel",
    "kitervelte": "kitervel",
    "kiterveltem": "kitervelt",
    "kitervelték": "kitervel",
    "kitervezett": "kitervez",
    "kitervezésén": "kitervezés",
    "kiteríthessék": "kiteríthet",
    "kiteszek": "kitesz",
    "kitett": "kitesz",
    "kitette": "kitesz",
    "kitették": "kitesz",
    "kitisztult": "kitisztul",
    "kitisztítani": "kitisztít",
    "kitisztítottak": "kitisztított",
    "kitisztíttatták": "kitisztíttat",
    "kitombolhassa": "kitombolhat",
    "kitréfálták": "kitréfál",
    "kitágulásokat": "kitágulás",
    "kitárt": "kitár",
    "kitárta": "kitár",
    "kitárult": "kitárul",
    "kitépett": "kitép",
    "kitépi": "kitép",
    "kitépje": "kitép",
    "kitépte": "kitép",
    "kitépték": "kitép",
    "kitérek": "kitér",
    "kitérni": "kitér",
    "kitért": "kitér",
    "kitételt": "kitétel",
    "kitölteni": "kitölt",
    "kitöltését": "kitöltés",
    "kitöltésével": "kitöltés",
    "kitöltött": "kitölt",
    "kitöltötték": "kitölt",
    "kitömött": "kitöm",
    "kitörhetett": "kitörhet",
    "kitörli": "kitöröl",
    "kitörni": "kitörik",
    "kitört": "kitörik",
    "kitörtek": "kitörik",
    "kitörésből": "kitörés",
    "kitörése": "kitörés",
    "kitörésre": "kitörés",
    "kitörést": "kitörés",
    "kitörölhetné": "kitörölhet",
    "kitörölje": "kitöröl",
    "kitörölnek": "kitöröl",
    "kitörölné": "kitöröl",
    "kitüntesse": "kitüntet",
    "kitüntetést": "kitüntetés",
    "kitől": "ki",
    "kitűnt": "kitűnik",
    "kitűnőek": "kitűnő",
    "kitűnően": "kitűnő",
    "kitűzték": "kitűz",
    "kitűzőjével": "kitűző",
    "kiugrott": "kiugrik",
    "kiugrottak": "kiugrott",
    "kiugráltak": "kiugrált",
    "kiugráshoz": "kiugrás",
    "kiugróban": "kiugró",
    "kiutalni": "kiutal",
    "kiutat": "kiút",
    "kiutaztatásból": "kiutaztatás",
    "kivasalni": "kivasal",
    "kivel": "ki",
    "kivenni": "kivesz",
    "kivennék": "kivesz",
    "kivernie": "kiver",
    "kivert": "kiver",
    "kiverte": "kiver",
    "kiveszi": "kiveszik",
    "kiveszik": "kivesz",
    "kiveszünk": "kiveszik",
    "kivetett": "kivet",
    "kivetniük": "kivet",
    "kivett": "kivesz",
    "kivette": "kivesz",
    "kivettek": "kivett",
    "kivettem": "kivett",
    "kivetéséből": "kivetés",
    "kivetésével": "kivetés",
    "kivezetett": "kivezet",
    "kivezették": "kivezet",
    "kivezényelték": "kivezényel",
    "kivihetőbb": "kivihető",
    "kivillant": "kivillan",
    "kivilágított": "kivilágít",
    "kivilágításában": "kivilágítás",
    "kivinni": "kivisz",
    "kivitelezett": "kivitelez",
    "kivitelezhetőnek": "kivitelezhető",
    "kivitelezése": "kivitelezés",
    "kivitelezésre": "kivitelezés",
    "kivitelezést": "kivitelezés",
    "kivitelezésével": "kivitelezés",
    "kivitelezőkkel": "kivitelező",
    "kivitelezőt": "kivitelező",
    "kivitelről": "kivitel",
    "kivitte": "kivisz",
    "kivittek": "kivitt",
    "kivitték": "kivisz",
    "kivonjuk": "kivon",
    "kivonulnak": "kivonul",
    "kivonult": "kivonul",
    "kivonultak": "kivonult",
    "kivonulásakor": "kivonulás",
    "kivonásba": "kivonás",
    "kivágja": "kivág",
    "kivágni": "kivág",
    "kivágott": "kivág",
    "kivágták": "kivág",
    "kivágásokból": "kivágás",
    "kiválasztja": "kiválaszt",
    "kiválasztott": "kiválaszt",
    "kiválasztottaktól": "kiválasztott",
    "kiválasztottnak": "kiválasztott",
    "kiválasztása": "kiválasztás",
    "kiválasztásában": "kiválasztás",
    "kiválasztására": "kiválasztás",
    "kiválni": "kiválik",
    "kiválogatott": "kiválogat",
    "kivált": "kiválik",
    "kiváltak": "kivált",
    "kiváltani": "kivált",
    "kiváltja": "kivált",
    "kiváltotta": "kivált",
    "kiváltságunk": "kiváltság",
    "kiváltására": "kiváltás",
    "kiválások": "kiválás",
    "kiválók": "kiváló",
    "kiválóságainak": "kiválóság",
    "kiválóságaival": "kiválóság",
    "kiválóságok": "kiválóság",
    "kivégeztek": "kivégez",
    "kivégezték": "kivégez",
    "kivégezzék": "kivégez",
    "kivégzése": "kivégzés",
    "kivégzések": "kivégzés",
    "kivégzésekről": "kivégzés",
    "kivégzésre": "kivégzés",
    "kivégzését": "kivégzés",
    "kivételek": "kivétel",
    "kivételeket": "kivétel",
    "kivételeknek": "kivétel",
    "kivételesen": "kivételes",
    "kivételezett": "kivételez",
    "kivételnek": "kivétel",
    "kivételt": "kivétel",
    "kivételtől": "kivétel",
    "kivételét": "kivétel",
    "kivételével": "kivétel",
    "kivörösödötten": "kivörösödött",
    "kizsákmányolt": "kizsákmányol",
    "kizuhant": "kizuhan",
    "kizárhatónak": "kizárható",
    "kizárja": "kizár",
    "kizárnak": "kizár",
    "kizárni": "kizár",
    "kizárt": "kizár",
    "kizárásáig": "kizárás",
    "kizárását": "kizárás",
    "kizáróan": "kizáró",
    "kizökkent": "kizökken",
    "kizöldültek": "kizöldül",
    "kiábrándultsága": "kiábrándultság",
    "kiállott": "kiáll",
    "kiállt": "kiáll",
    "kiállta": "kiáll",
    "kiálltak": "kiállt",
    "kiállítanak": "kiállít",
    "kiállítani": "kiállít",
    "kiállítják": "kiállít",
    "kiállított": "kiállít",
    "kiállították": "kiállít",
    "kiállíttatni": "kiállíttat",
    "kiállításnak": "kiállítás",
    "kiállítások": "kiállítás",
    "kiállításokon": "kiállítás",
    "kiállításokról": "kiállítás",
    "kiállításon": "kiállítás",
    "kiállításra": "kiállítás",
    "kiállítást": "kiállítás",
    "kiállításukra": "kiállítás",
    "kiállításához": "kiállítás",
    "kiállítására": "kiállítás",
    "kiállítását": "kiállítás",
    "kiállítók": "kiállító",
    "kiáltani": "kiált",
    "kiáltanának": "kiált",
    "kiáltott": "kiált",
    "kiáltotta": "kiált",
    "kiáltottak": "kiáltott",
    "kiáltották": "kiált",
    "kiáltozta": "kiáltozik",
    "kiáltozáson": "kiáltozás",
    "kiáltványok": "kiáltvány",
    "kiáltásaira": "kiáltás",
    "kiáltások": "kiáltás",
    "kiáltásokat": "kiáltás",
    "kiáltásokkal": "kiáltás",
    "kiáltással": "kiáltás",
    "kiárusítja": "kiárusít",
    "kiásott": "kiás",
    "kié": "ki",
    "kiégett": "kiég",
    "kiégetünk": "kiéget",
    "kiéhezett": "kiéhezik",
    "kiéheztették": "kiéheztet",
    "kiéleződtek": "kiéleződik",
    "kiélheti": "kiélhet",
    "kiéli": "kiél",
    "kiépítették": "kiépítet",
    "kiépítésére": "kiépítés",
    "kiépítését": "kiépítés",
    "kiépítésével": "kiépítés",
    "kiépültek": "kiépül",
    "kiérdemelték": "kiérdemel",
    "kiérezte": "kiérez",
    "kiérkezett": "kiérkezik",
    "kiértek": "kiért",
    "kiírja": "kiír",
    "kiírni": "kiír",
    "kiírt": "kiír",
    "kiírása": "kiírás",
    "kiírást": "kiírás",
    "kiírásában": "kiírás",
    "kiírására": "kiírás",
    "kiírását": "kiírás",
    "kiöblített": "kiöblít",
    "kiölni": "kiöl",
    "kiöntötte": "kiönt",
    "kiútkeresésről": "kiútkeresés",
    "kiügyeskedte": "kiügyeskedik",
    "kiürített": "kiürít",
    "kiürítették": "kiürítet",
    "kiürítik": "kiürít",
    "kiürítésével": "kiürítés",
    "kiürült": "kiürül",
    "kiürültek": "kiürül",
    "kiütközött": "kiütközik",
    "kiütött": "kiüt",
    "kiűzte": "kiűz",
    "klarinétját": "klarinét",
    "klarinétszínezete": "klarinétszínezet",
    "klasszikusaival": "klasszikus",
    "klasszikusnak": "klasszikus",
    "klasszikusokat": "klasszikus",
    "klubja": "klub",
    "klubjának": "klub",
    "klubkeretben": "klubkeret",
    "klubok": "klub",
    "klubokat": "klub",
    "klubokra": "klub",
    "klubot": "klub",
    "klubé": "klub",
    "klímaberendezéseinek": "klímaberendezés",
    "km-en": "km",
    "km-ig": "km",
    "km-rel": "km",
    "km/óra": "km",
    "km/órára": "km",
    "km/órásakat": "km",
    "koalícióban": "koalíció",
    "koalíciót": "koalíció",
    "koalíciótól": "koalíció",
    "kocadisznója": "kocadisznó",
    "koccanások": "koccanás",
    "kockásdobozt": "kockásdoboz",
    "kockázatnak": "kockázat",
    "kockázatokat": "kockázat",
    "kockázatot": "kockázat",
    "kockázatát": "kockázat",
    "kockázatával": "kockázat",
    "kockáztathatunk": "kockáztathat",
    "kockáztatni": "kockáztat",
    "kockáztatnia": "kockáztat",
    "kockáztattam": "kockáztat",
    "kockáztatásával": "kockáztatás",
    "kocogtak": "kocog",
    "kocsiablakokon": "kocsiablak",
    "kocsiba": "kocsi",
    "kocsiban": "kocsi",
    "kocsijára": "kocsi",
    "kocsik": "kocsi",
    "kocsikat": "kocsi",
    "kocsikba": "kocsi",
    "kocsikban": "kocsi",
    "kocsikkal": "kocsi",
    "kocsikon": "kocsi",
    "kocsikáztak": "kocsikázik",
    "kocsin": "kocsi",
    "kocsinak": "kocsi",
    "kocsioldalakról": "kocsioldal",
    "kocsiparkon": "kocsipark",
    "kocsisaikkal": "kocsis",
    "kocsisnak": "kocsis",
    "kocsisok": "kocsis",
    "kocsissal": "kocsis",
    "kocsit": "kocsi",
    "kocsitetőt": "kocsitető",
    "kocsival": "kocsi",
    "kocsmába": "kocsma",
    "kocsmában": "kocsma",
    "kocsmáikat": "kocsma",
    "kocsmájába": "kocsma",
    "kocsmákban": "kocsma",
    "kocsmárosnak": "kocsmáros",
    "kocsmárosnál": "kocsmáros",
    "kocsmárosokkal": "kocsmáros",
    "kocsonyásan": "kocsonyás",
    "kocsonyával": "kocsonya",
    "kocához": "koca",
    "kocák": "koca",
    "kocákat": "koca",
    "kocákkal": "koca",
    "kofaasszonyok": "kofaasszony",
    "kofák": "kofa",
    "koholói": "koholó",
    "kolbászt": "kolbász",
    "kolbászát": "kolbász",
    "koldulni": "koldul",
    "kollektívan": "kollektív",
    "kollektíven": "kollektív",
    "kollégisták": "kollégista",
    "kollégiuma": "kollégium",
    "kollégiumba": "kollégium",
    "kollégiumban": "kollégium",
    "kollégiumok": "kollégium",
    "kollégiumot": "kollégium",
    "kollégái": "kolléga",
    "kollégáim": "kolléga",
    "kollégáink": "kolléga",
    "kollégája": "kolléga",
    "kollégáját": "kolléga",
    "kollégájával": "kolléga",
    "kollégák": "kolléga",
    "kollégáknak": "kolléga",
    "kollégám": "kolléga",
    "kollégámat": "kolléga",
    "kollégának": "kolléga",
    "kollégánk": "kolléga",
    "kollégánál": "kolléga",
    "kolozsváriak": "kolozsvári",
    "kolumbiai-magyar": "kolumbiaimagyar",
    "kombinációban": "kombináció",
    "kombinációja": "kombináció",
    "komencióból": "komenció",
    "komenciónkat": "komenció",
    "komenciót": "komenció",
    "komencióért": "komenció",
    "komiszságra": "komiszság",
    "kommandósait": "kommandós",
    "kommandósokkal": "kommandós",
    "kommentálta": "kommentál",
    "kommentárt": "kommentár",
    "kommentátora": "kommentátor",
    "kommentátorok": "kommentátor",
    "kommunisták": "kommunista",
    "kommunistának": "kommunista",
    "kommunálishulladék-lerakóban": "kommunális-hulladéklerakó",
    "kommünikét": "kommüniké",
    "kommünről": "kommün",
    "komolyabb": "komoly",
    "komolyan": "komoly",
    "komolynak": "komoly",
    "komorabb": "komor",
    "komoran": "komor",
    "kompenzálták": "kompenzál",
    "kompenzálása": "kompenzálás",
    "kompetenciájából": "kompetencia",
    "komplexumában": "komplexum",
    "komplexusokkal": "komplexus",
    "komponált": "komponál",
    "kompozícióit": "kompozíciói",
    "kompozíciók": "kompozíció",
    "kompromisszumkészséget": "kompromisszumkészség",
    "kompromisszumok": "kompromisszum",
    "kompromittált": "kompromittál",
    "komputerrel": "komputer",
    "komáim": "koma",
    "komám": "koma",
    "komának": "koma",
    "komédiába": "komédia",
    "komédiáztak": "komédiázik",
    "koncentrációt": "koncentráció",
    "koncentrálni": "koncentrál",
    "koncentrálok": "koncentrál",
    "koncentráltabb": "koncentrált",
    "koncentrálásra": "koncentrálás",
    "koncentrálást": "koncentrálás",
    "koncentrálódnak": "koncentrálódik",
    "koncepciója": "koncepció",
    "koncepcióját": "koncepció",
    "koncepciók": "koncepció",
    "koncepciót": "koncepció",
    "koncertek": "koncert",
    "koncertekről": "koncert",
    "koncertet": "koncert",
    "koncertezett": "koncertez",
    "koncertezik": "koncertez",
    "koncesszión": "koncesszió",
    "kondultak": "kondult",
    "kondának": "konda",
    "kondásai": "kondás",
    "kondások": "kondás",
    "kondásokkal": "kondás",
    "kondícióban": "kondíció",
    "kondíciók": "kondíció",
    "konferansziék": "konferanszié",
    "konferenciáján": "konferencia",
    "konferenciákon": "konferencia",
    "konferencián": "konferencia",
    "konfliktusa": "konfliktus",
    "konfliktusok": "konfliktus",
    "konfliktusokhoz": "konfliktus",
    "kongatnak": "kongat",
    "kongatta": "kongat",
    "kongresszusainkra": "kongresszus",
    "kongresszusban": "kongresszus",
    "kongresszushoz": "kongresszus",
    "kongresszusok": "kongresszus",
    "kongresszuson": "kongresszus",
    "kongresszusra": "kongresszus",
    "kongresszust": "kongresszus",
    "kongresszustól": "kongresszus",
    "kongresszusán": "kongresszus",
    "kongresszusát": "kongresszus",
    "konklúzióra": "konklúzió",
    "konkrétan": "konkrét",
    "konkrétumokat": "konkrétum",
    "konkrétumot": "konkrétum",
    "konkurenciáról": "konkurencia",
    "konkurensük": "konkurens",
    "konstrukcióból": "konstrukció",
    "konstrukciókat": "konstrukció",
    "konstrukciót": "konstrukció",
    "konstruktívnak": "konstruktív",
    "kontinensek": "kontinens",
    "kontinensen": "kontinens",
    "kontingenst": "kontingens",
    "kontyon": "konty",
    "kontármunkák": "kontármunka",
    "konténerben": "konténer",
    "konvojok": "konvoj",
    "konyhalányokkal": "konyhalány",
    "konyhába": "konyha",
    "konyhában": "konyha",
    "konyhából": "konyha",
    "konyhájukba": "konyha",
    "konyhájában": "konyha",
    "konyhán": "konyha",
    "konyhára": "konyha",
    "konyhát": "konyha",
    "konzervatívok": "konzervatív",
    "konzervatívoktól": "konzervatív",
    "konzervet": "konzerv",
    "konzorciuma": "konzorcium",
    "konzorciumot": "konzorcium",
    "konzultációk": "konzultáció",
    "konzultációknak": "konzultáció",
    "konzultáción": "konzultáció",
    "konzultációra": "konzultáció",
    "konzultáltak": "konzultált",
    "koordinálnák": "koordinál",
    "koordinált": "koordinál",
    "kopaszra": "kopasz",
    "kopogtak": "kopog",
    "kopogást": "kopogás",
    "koponyában": "koponya",
    "koponyádban": "koponya",
    "koponyáik": "koponya",
    "koponyája": "koponya",
    "koponyájába": "koponya",
    "koponyájában": "koponya",
    "koponyáján": "koponya",
    "koponyájára": "koponya",
    "koporsójában": "koporsó",
    "kopott": "kopik",
    "koppanása": "koppanás",
    "koppanását": "koppanás",
    "koppintani": "koppint",
    "kora": "kor",
    "korai": "kor",
    "korainak": "koraín",
    "korban": "kor",
    "korbáccsal": "korbács",
    "korbácsfélével": "korbácsféle",
    "korbácsoljanak": "korbácsol",
    "korbácsolták": "korbácsol",
    "korbácsot": "korbács",
    "korból": "kor",
    "korcsmában": "korcsma",
    "korcsolyapályáin": "korcsolyapálya",
    "korcsolyázhatok": "korcsolyázhat",
    "korcsolyázni": "korcsolyázik",
    "korcsolyázol": "korcsolyázik",
    "korcsoportba": "korcsoport",
    "kordéról": "kordé",
    "korhadt": "korhad",
    "korhatáron": "korhatár",
    "korig": "kor",
    "korkedvezménnyel": "korkedvezmény",
    "korlátját": "korlát",
    "korlátlanul": "korlátlan",
    "korlátokkal": "korlát",
    "korlátolttá": "korlátolt",
    "korlátozott": "korlátoz",
    "korlátozottabb": "korlátozott",
    "korlátozták": "korlátoz",
    "korlátozza": "korlátoz",
    "korlátozása": "korlátozás",
    "korlátozások": "korlátozás",
    "kormánnyal": "kormány",
    "kormánya": "kormány",
    "kormányai": "kormány",
    "kormányalakítást": "kormányalakítás",
    "kormányalapból": "kormányalap",
    "kormánydöntésre": "kormánydöntés",
    "kormányfői": "kormányfő",
    "kormányfőnek": "kormányfő",
    "kormányfőt": "kormányfő",
    "kormánygaranciát": "kormánygarancia",
    "kormányintézkedései": "kormányintézkedés",
    "kormányintézkedések": "kormányintézkedés",
    "kormánynak": "kormány",
    "kormányok": "kormány",
    "kormányoknak": "kormány",
    "kormányon": "kormány",
    "kormányoznak": "kormányoz",
    "kormányozni": "kormányoz",
    "kormányozottak": "kormányozott",
    "kormányozzanak": "kormányoz",
    "kormányra": "kormány",
    "kormányrúdnál": "kormányrúd",
    "kormányt": "kormány",
    "kormánytagok": "kormánytag",
    "kormánytagokkal": "kormánytag",
    "kormánytisztviselők": "kormánytisztviselő",
    "kormánytól": "kormány",
    "kormányzatokat": "kormányzat",
    "kormányzatot": "kormányzat",
    "kormányzásra": "kormányzás",
    "kormányzást": "kormányzás",
    "kormányában": "kormány",
    "kormányával": "kormány",
    "kornak": "kor",
    "korod": "kor",
    "korodig": "kor",
    "korok": "kor",
    "korokban": "kor",
    "korom": "kor",
    "koromban": "korom",
    "korona-gyógyszertárnak": "koronagyógyszertár",
    "korongja": "korong",
    "korongot": "korong",
    "koronához": "korona",
    "koronákat": "korona",
    "koronára": "korona",
    "koronáról": "korona",
    "koronával": "korona",
    "korpát": "korpa",
    "korra": "kor",
    "korrekciója": "korrekció",
    "korrekcióját": "korrekció",
    "korrigálják": "korrigál",
    "korrigálnák": "korrigál",
    "korrigált": "korrigál",
    "korrigálása": "korrigálás",
    "korról": "kor",
    "korszaka": "korszak",
    "korszakban": "korszak",
    "korszakok": "korszak",
    "korszakokban": "korszak",
    "korszakra": "korszak",
    "korszakról": "korszak",
    "korszakából": "korszaka",
    "korszakáig": "korszaka",
    "korszakán": "korszaka",
    "korszakának": "korszaka",
    "korszerűsítésre": "korszerűsítés",
    "korszerűsítésére": "korszerűsítés",
    "korszerűtlenebb": "korszerűtlen",
    "korsó-korsót": "korsó-korsó",
    "korsóban": "korsó",
    "korsójukat": "korsó",
    "korsóját": "korsó",
    "korsót": "korsó",
    "kort": "kor",
    "kortól": "kor",
    "koruk": "kor",
    "korukban": "kor",
    "korunk": "kor",
    "korunkat": "kor",
    "korunkban": "kor",
    "korában": "kor",
    "korábbiaknak": "korábbi",
    "korábbihoz": "korábbi",
    "korábbinál": "korábbi",
    "korából": "kor",
    "korához": "kor",
    "koráig": "kor",
    "korán": "kor",
    "korának": "kor",
    "korára": "kor",
    "korát": "kor",
    "kosarak": "kosár",
    "kosarakra": "kosár",
    "kosarat": "kosár",
    "kosarából": "kosár",
    "koszorúdombjai": "koszorúdomb",
    "koszorúk": "koszorú",
    "koszorúkkal": "koszorú",
    "koszt": "kosz",
    "kosztban": "koszt",
    "koszthoz": "koszt",
    "kosztján": "koszt",
    "kosztjának": "koszt",
    "kosztolni": "kosztol",
    "koszton": "koszt",
    "kosztot": "koszt",
    "kosztra": "koszt",
    "koszttal": "koszt",
    "kosztunk": "koszt",
    "kosztunkon": "koszt",
    "kosztümje": "kosztüm",
    "kosztümöt": "kosztüm",
    "kosárlabdázója": "kosárlabdázó",
    "kotrásra": "kotrás",
    "kottalapoknál": "kottalap",
    "kottaolvasásra": "kottaolvasás",
    "kottái": "kotta",
    "kottákat": "kotta",
    "kotyvasztott": "kotyvaszt",
    "kovácsmesterek": "kovácsmester",
    "kovácsolni": "kovácsol",
    "kovácsolt": "kovácsol",
    "kozmát": "kozma",
    "krajcárig": "krajcár",
    "krajcárja": "krajcár",
    "krajcárokért": "krajcár",
    "krajcáron": "krajcár",
    "krajcárt": "krajcár",
    "krajcárért": "krajcár",
    "kricsmiben": "kricsmi",
    "kristályrendszerekről": "kristályrendszer",
    "kristálytisztán": "kristálytiszta",
    "kristálytündért": "kristálytündér",
    "krisztustól": "krisztus",
    "kritikusnak": "kritikus",
    "kritikájukat": "kritika",
    "kritikákat": "kritika",
    "kritizálni": "kritizál",
    "kritériumainak": "kritérium",
    "kritériumok": "kritérium",
    "krokodilok": "krokodil",
    "krumpliból": "krumpli",
    "krumplihéjat": "krumplihéj",
    "krumplit": "krumpli",
    "krémesen": "krémes",
    "krémpapírnak": "krémpapír",
    "krétával": "kréta",
    "krétázik": "krétáz",
    "kucorognak": "kucorog",
    "kudarcaként": "kudarc",
    "kudarcba": "kudarc",
    "kudarcok": "kudarc",
    "kudarcot": "kudarc",
    "kudarcunkban": "kudarc",
    "kufárok": "kufár",
    "kukacok": "kukac",
    "kukacokat": "kukac",
    "kukoricát": "kukorica",
    "kukoricával": "kukorica",
    "kukából": "kuka",
    "kulcslyukakon": "kulcslyuk",
    "kulcslyuknál": "kulcslyuk",
    "kulcslyukon": "kulcslyuk",
    "kulcsok": "kulcs",
    "kulcsolta": "kulcsol",
    "kulcsot": "kulcs",
    "kulcsszerepet": "kulcsszerep",
    "kulcsárai": "kulcsár",
    "kulcsárjai": "kulcsár",
    "kulcsárjához": "kulcsár",
    "kulcsárnak": "kulcsár",
    "kulcsárok": "kulcsár",
    "kulcsárokkal": "kulcsár",
    "kulcsárral": "kulcsár",
    "kulcsárt": "kulcsár",
    "kulik": "kuli",
    "kullogott": "kullog",
    "kulturálisan": "kulturális",
    "kultúrháza": "kultúrház",
    "kultúrmunkások": "kultúrmunkás",
    "kultúrpolitikája": "kultúrpolitika",
    "kultúrájára": "kultúra",
    "kultúráját": "kultúra",
    "kultúrákban": "kultúra",
    "kultúrállamokban": "kultúrállam",
    "kultúránk": "kultúra",
    "kultúrára": "kultúra",
    "kultúráról": "kultúra",
    "kultúrát": "kultúra",
    "kultúrával": "kultúra",
    "kuncsaftnak": "kuncsaft",
    "kuncsorgunk": "kuncsorog",
    "kuncsorognak": "kuncsorog",
    "kunyerálni": "kunyerál",
    "kunyerálnom": "kunyerál",
    "kunyerálásba": "kunyerálás",
    "kunyerálást": "kunyerálás",
    "kunyerálásának": "kunyerálás",
    "kunyhóból": "kunyhó",
    "kunyhójára": "kunyhó",
    "kunyhót": "kunyhó",
    "kupagyőzelmének": "kupagyőzelem",
    "kupecek": "kupec",
    "kupecnek": "kupec",
    "kuponokkal": "kupon",
    "kupont": "kupon",
    "kuporogtak": "kuporog",
    "kupában": "kupa",
    "kupájában": "kupa",
    "kuratóriuma": "kuratórium",
    "kuratóriumába": "kuratórium",
    "kuriózumnak": "kuriózum",
    "kurtán": "kurta",
    "kurvától": "kurva",
    "kurzuslapok": "kurzuslap",
    "kurzusnak": "kurzus",
    "kurzusokon": "kurzus",
    "kurzusra": "kurzus",
    "kurzussal": "kurzus",
    "kurátorai": "kurátor",
    "kushadtunk": "kushadt",
    "kussolást": "kussolás",
    "kutakból": "kút",
    "kutat": "kút",
    "kutathatott": "kutathat",
    "kutathattak": "kutathat",
    "kutatjuk": "kutat",
    "kutatnak": "kutat",
    "kutatni": "kutat",
    "kutatott": "kutat",
    "kutatta": "kutat",
    "kutatásaival": "kutatás",
    "kutatások": "kutatás",
    "kutatásokat": "kutatás",
    "kutatásokra": "kutatás",
    "kutatására": "kutatás",
    "kutatók": "kutató",
    "kutatómunkájában": "kutatómunka",
    "kutatón": "kutató",
    "kutyasétáltatást": "kutyasétáltatás",
    "kutyatenyésztésből": "kutyatenyésztés",
    "kutyatáplálékra": "kutyatáplálék",
    "kutyatápszert": "kutyatápszer",
    "kutyaütőit": "kutyaütői",
    "kutyaütők": "kutyaütő",
    "kutyaütőket": "kutyaütő",
    "kutyáikat": "kutya",
    "kutyáival": "kutya",
    "kutyák": "kutya",
    "kutyákat": "kutya",
    "kutyáktól": "kutya",
    "kutyának": "kutya",
    "kutyát": "kutya",
    "kutyául": "kutya",
    "kvalifikált": "kvalifikál",
    "kvartnak": "kvart",
    "kvótáját": "kvóta",
    "kvótán": "kvóta",
    "kábelekéhez": "kábeleke",
    "kábelrendszerek": "kábelrendszer",
    "kábulatba": "kábulat",
    "kábulatban": "kábulat",
    "kábulatában": "kábulat",
    "kábítószer-csempészést": "kábítószer-csempészés",
    "kábítószer-kereskedők": "kábítószer-kereskedő",
    "kábítószer-problémái": "kábítószer-probléma",
    "kábítószerek": "kábítószer",
    "kábítószereket": "kábítószer",
    "kábítószerektől": "kábítószer",
    "kábítószert": "kábítószer",
    "kádban": "kád",
    "kádergyerekek": "kádergyerek",
    "káderjellemzésünk": "káderjellemzés",
    "kálváriája": "kálvária",
    "kálváriának": "kálvária",
    "kályhasarokba": "kályhasarok",
    "kályhába": "kályha",
    "káoszból": "káosz",
    "káplárok": "káplár",
    "káplártípust": "káplártípus",
    "kápolnát": "kápolna",
    "káposztacsutkát": "káposztacsutka",
    "káposztatorzsákat": "káposztatorzsa",
    "káprázott": "káprázik",
    "káptalannál": "káptalan",
    "kárfelmérést": "kárfelmérés",
    "kárhoztatnak": "kárhoztat",
    "kármán": "kárma",
    "károk": "kár",
    "károkat": "kár",
    "károkozással": "károkozás",
    "károkról": "kár",
    "káromkodhattak": "káromkodhat",
    "káromkodnak": "káromkodik",
    "káromkodások": "káromkodás",
    "káromkodásokkal": "káromkodás",
    "károsan": "káros",
    "károsultakat": "károsult",
    "károsultaknak": "károsult",
    "károsítja": "károsít",
    "kárpitozott": "kárpitoz",
    "kárpótlásnál": "kárpótlás",
    "kárpótlásra": "kárpótlás",
    "kárpótlásról": "kárpótlás",
    "kárpótlással": "kárpótlás",
    "kárpótoltak": "kárpótolt",
    "kárt": "kár",
    "kártalanítani": "kártalanít",
    "kártalanítását": "kártalanítás",
    "kártyaüzletágukhoz": "kártyaüzletág",
    "kártyát": "kártya",
    "kártérítéshez": "kártérítés",
    "kártérítésként": "kártérítés",
    "kártérítést": "kártérítés",
    "kárára": "kár",
    "kárát": "kár",
    "kárörömmel": "káröröm",
    "kárörömét": "káröröm",
    "kásánál": "kása",
    "kását": "kása",
    "kásával": "kása",
    "kávéházat": "kávéház",
    "kávéházba": "kávéház",
    "kávéházban": "kávéház",
    "kávéházon": "kávéház",
    "kávéja": "kávé",
    "kávéját": "kávé",
    "kávénak": "kávé",
    "kávéra": "kávé",
    "kávét": "kávé",
    "kéjesen": "kéjes",
    "kéjjel": "kéj",
    "kéjt": "kéj",
    "kékek": "kék",
    "kékfrankostól": "kékfrankos",
    "kéklett": "kéklik",
    "kékre": "kék",
    "kékségét": "kékség",
    "kém-őrse": "kém-őrs",
    "kémek": "kém",
    "kémeket": "kém",
    "kémeknél": "kém",
    "kémeké": "kém",
    "kémje": "kém",
    "kémjeként": "kém",
    "kémkedjenek": "kémkedik",
    "kémkedéssel": "kémkedés",
    "kémlelhetnek": "kémlelhet",
    "kémlelőlyukon": "kémlelőlyuk",
    "kémnek": "kém",
    "kémtevékenységgel": "kémtevékenység",
    "kémények": "kémény",
    "kéményeken": "kémény",
    "kéményre": "kémény",
    "kéne": "kell",
    "kénsavat": "kénsó",
    "ként": "kén",
    "kényednek-kedvednek": "kény-kedv",
    "kényelemben": "kényelem",
    "kényelemnek": "kényelem",
    "kényelmesebb": "kényelmes",
    "kényelmesen": "kényelmes",
    "kényelmeshez": "kényelmes",
    "kényelmetlennek": "kényelmetlen",
    "kényelmetlenséget": "kényelmetlenség",
    "kényelmetlenségtől": "kényelmetlenség",
    "kényelmetlenül": "kényelmetlen",
    "kényesebb": "kényes",
    "kényesek": "kényes",
    "kényesnek": "kényes",
    "kényeztették": "kényeztet",
    "kényszere": "kényszer",
    "kényszeredett": "kényszeredik",
    "kényszeredetten": "kényszeredett",
    "kényszermunkatáborba": "kényszermunkatábor",
    "kényszermunkatáborban": "kényszermunkatábor",
    "kényszermunkatáborokba": "kényszermunkatábor",
    "kényszermunkatáborokban": "kényszermunkatábor",
    "kényszermunkatáborokról": "kényszermunkatábor",
    "kényszerszünetek": "kényszerszünet",
    "kényszert": "kényszer",
    "kényszerállapotából": "kényszerállapot",
    "kényszeríteni": "kényszerít",
    "kényszerítenék": "kényszerít",
    "kényszerítette": "kényszerít",
    "kényszerítették": "kényszerít",
    "kényszeríti": "kényszerít",
    "kényszerítse": "kényszerít",
    "kényszerül": "kényszer",
    "kényszerülnek": "kényszerül",
    "kényszerült": "kényszerül",
    "kényszerültek": "kényszerül",
    "kényszerülünk": "kényszerül",
    "kényszerűen": "kényszerű",
    "kényszerűsége": "kényszerűség",
    "kénytelenek": "kénytelen",
    "kényünk-kedvünk": "kény-kedv",
    "kényünkre-kedvünkre": "kény-kedv",
    "képben": "kép",
    "képe": "kép",
    "képeit": "kép",
    "képek": "kép",
    "képeket": "kép",
    "képeknek": "kép",
    "képen": "kép",
    "képernyőn": "képernyő",
    "képernyőre": "képernyő",
    "képesek": "képes",
    "képeskönyve": "képeskönyv",
    "képesnek": "képes",
    "képessé": "képes",
    "képessége": "képesség",
    "képességei": "képesség",
    "képességeit": "képesség",
    "képességem": "képesség",
    "képességet": "képesség",
    "képességére": "képesség",
    "képességét": "képesség",
    "képességüket": "képesség",
    "képest": "képes",
    "képesítése": "képesítés",
    "képet": "kép",
    "képezett": "képez",
    "képezi": "képez",
    "képeznek": "képez",
    "képeztek": "képez",
    "képezték": "képez",
    "képezzék": "képez",
    "képhez": "kép",
    "képkeretet": "képkeret",
    "képkiállítást": "képkiállítás",
    "képmutatóan": "képmutató",
    "képmutatók": "képmutató",
    "képmására": "képmása",
    "képmását": "képmása",
    "képnek": "kép",
    "képpel": "kép",
    "képtelenebb": "képtelen",
    "képtelenek": "képtelen",
    "képtelenné": "képtelen",
    "képtelenséget": "képtelenség",
    "képtelenséggé": "képtelenség",
    "képtelenül": "képtelen",
    "képviselek": "képvisel",
    "képviseletből": "képviselet",
    "képviselete": "képviselet",
    "képviseletek": "képviselet",
    "képviseletében": "képviselet",
    "képviseli": "képvisel",
    "képviselik": "képvisel",
    "képviselnek": "képvisel",
    "képviselni": "képvisel",
    "képviselt": "képvisel",
    "képviselte": "képvisel",
    "képviseltek": "képviselt",
    "képviselték": "képvisel",
    "képviselő-testületének": "képviselő-testület",
    "képviselőcsoportja": "képviselőcsoport",
    "képviselői": "képviselő",
    "képviselőiből": "képviselői",
    "képviselőiket": "képviselő",
    "képviselőinek": "képviselői",
    "képviselőire": "képviselői",
    "képviselőit": "képviselői",
    "képviselőivel": "képviselői",
    "képviselője": "képviselő",
    "képviselőjével": "képviselő",
    "képviselők": "képviselő",
    "képviselőket": "képviselő",
    "képviselőkhöz": "képviselő",
    "képviselőkkel": "képviselő",
    "képviselőknek": "képviselő",
    "képviselőkre": "képviselő",
    "képviselőkről": "képviselő",
    "képviselőséggel": "képviselőség",
    "képviselőt": "képviselő",
    "képzeld": "képzel",
    "képzeled": "képzel",
    "képzelem": "képzel",
    "képzeletben": "képzelet",
    "képzeletből": "képzelet",
    "képzelete": "képzelet",
    "képzeletemet": "képzelet",
    "képzeletet": "képzelet",
    "képzeletébe": "képzelet",
    "képzeletében": "képzelet",
    "képzeletére": "képzelet",
    "képzeletét": "képzelet",
    "képzelgésekben": "képzelgés",
    "képzelheted": "képzelhet",
    "képzelhették": "képzelhet",
    "képzeli": "képzel",
    "képzelik": "képzel",
    "képzelitek": "képzel",
    "képzelj": "képzel",
    "képzeljünk": "képzel",
    "képzelni": "képzel",
    "képzelné": "képzel",
    "képzelt": "képzel",
    "képzelte": "képzel",
    "képzeltem": "képzelt",
    "képzelték": "képzel",
    "képzelődsz": "képzelődik",
    "képzelődtek": "képzelődik",
    "képzelődést": "képzelődés",
    "képzelőerőre": "képzelőerő",
    "képzett": "képez",
    "képzettséget": "képzettség",
    "képzettségük": "képzettség",
    "képzetét": "képzet",
    "képzetével": "képzet",
    "képzésbe": "képzés",
    "képzésben": "képzés",
    "képzések": "képzés",
    "képzésre": "képzés",
    "képzést": "képzés",
    "képződményei": "képződmény",
    "képzőművészetek": "képzőművészet",
    "képzőnek": "képző",
    "képébe": "kép",
    "képében": "kép",
    "képéhez": "kép",
    "képére": "kép",
    "képéről": "kép",
    "képét": "kép",
    "képétől": "kép",
    "képével": "kép",
    "képünkön": "kép",
    "kérd": "kér",
    "kérdem": "kérd",
    "kérdezd": "kérdez",
    "kérdezett": "kérdez",
    "kérdezhetek": "kérdezhet",
    "kérdezhetné": "kérdezhet",
    "kérdezhettek": "kérdezhet",
    "kérdezik": "kérdez",
    "kérdezni": "kérdez",
    "kérdeznie": "kérdez",
    "kérdezném": "kérdez",
    "kérdeznünk": "kérdez",
    "kérdezte": "kérdez",
    "kérdezted": "kérdez",
    "kérdeztem": "kérdez",
    "kérdezteti": "kérdeztet",
    "kérdezték": "kérdez",
    "kérdeztük": "kérdez",
    "kérdezze": "kérdez",
    "kérdezősködni": "kérdezősködik",
    "kérdezősködtem": "kérdezősködik",
    "kérdezősködött": "kérdezősködik",
    "kérdi": "kérd",
    "kérdésben": "kérdés",
    "kérdése": "kérdés",
    "kérdései": "kérdés",
    "kérdéseire": "kérdés",
    "kérdések": "kérdés",
    "kérdésekbe": "kérdés",
    "kérdésekben": "kérdés",
    "kérdéseket": "kérdés",
    "kérdésekkel": "kérdés",
    "kérdésekre": "kérdés",
    "kérdésekről": "kérdés",
    "kérdésemre": "kérdés",
    "kérdésessé": "kérdéses",
    "kérdésnek": "kérdés",
    "kérdésnél": "kérdés",
    "kérdésre": "kérdés",
    "kérdésről": "kérdés",
    "kérdéssel": "kérdés",
    "kérdést": "kérdés",
    "kérdésében": "kérdés",
    "kérdéséhez": "kérdés",
    "kérdésének": "kérdés",
    "kérdésére": "kérdés",
    "kérdését": "kérdés",
    "kérdésévé": "kérdésév",
    "kérdésük": "kérdés",
    "kérdésünkre": "kérdés",
    "kérdőre": "kérdő",
    "kéredzkedett": "kéredzkedik",
    "kérelmet": "kérelem",
    "kérelmének": "kérelem",
    "kérelmét": "kérelem",
    "kérem": "kér",
    "kérhetnek": "kérhet",
    "kéri": "kér",
    "kérik": "kér",
    "kérje": "kér",
    "kérjenek": "kér",
    "kérjétek": "kér",
    "kérjük": "kér",
    "kérkednek": "kérkedik",
    "kérkedtek": "kérkedik",
    "kérkedését": "kérkedés",
    "kérlek": "kér",
    "kérlelhetetlenségét": "kérlelhetetlenség",
    "kérlelhetetlenül": "kérlelhetetlen",
    "kérlelik": "kérlel",
    "kérlelték": "kérlel",
    "kérnek": "kér",
    "kérnem": "kér",
    "kérni": "kér",
    "kérnie": "kér",
    "kérné": "kér",
    "kérnénk": "kér",
    "kérnünk": "kér",
    "kért": "kér",
    "kérte": "kér",
    "kértek": "kért",
    "kértem": "kért",
    "kérték": "kér",
    "kérvénnyel": "kérvény",
    "kérvényeket": "kérvény",
    "kérése": "kérés",
    "kéréseinek": "kérés",
    "kérésem": "kérés",
    "kérésre": "kérés",
    "kérést": "kérés",
    "kérésének": "kérés",
    "kérésére": "kérés",
    "kéréséről": "kérés",
    "kérését": "kérés",
    "kérésével": "kérés",
    "kérünk": "kér",
    "késedelmesek": "késedelmes",
    "kései": "kés",
    "kések": "késik",
    "késlekedett": "késlekedik",
    "késlekedéséhez": "késlekedés",
    "késleltethetik": "késleltethet",
    "késről": "kés",
    "késsel": "kés",
    "készek": "kész",
    "készen": "kész",
    "készenlétben": "készenlét",
    "készenlétet": "készenlét",
    "készletből": "készlet",
    "készletek": "készlet",
    "készletekben": "készlet",
    "készleten": "készlet",
    "készletét": "készlet",
    "késznek": "kész",
    "készpénzben": "készpénz",
    "készpénzként": "készpénz",
    "készpénznek": "készpénz",
    "készpénzt": "készpénz",
    "készpénzvagyonukat": "készpénzvagyon",
    "készségesen": "készséges",
    "készséget": "készség",
    "készséggel": "készség",
    "késztetni": "késztet",
    "késztette": "késztet",
    "késztettek": "késztett",
    "késztetést": "késztetés",
    "készítenek": "készít",
    "készíteni": "készít",
    "készítenék": "készít",
    "készített": "készít",
    "készítette": "készít",
    "készítettek": "készített",
    "készítettem": "készített",
    "készítették": "készítet",
    "készítettél": "készítet",
    "készítettük": "készített",
    "készíthetik": "készíthet",
    "készíthetnének": "készíthet",
    "készíti": "készít",
    "készítik": "készít",
    "készítjük": "készít",
    "készítményekhez": "készítmény",
    "készítsen": "készít",
    "készíttetett": "készíttet",
    "készítteti": "készíttet",
    "készítése": "készítés",
    "készítését": "készítés",
    "készítésével": "készítés",
    "készülhetett": "készülhet",
    "készüljön": "készül",
    "készülnek": "készül",
    "készülsz": "készül",
    "készült": "készül",
    "készültek": "készült",
    "készültekének": "készülteke",
    "készültem": "készült",
    "készültjavításokat": "készültjavítás",
    "készültségben": "készültség",
    "készültségként": "készültség",
    "készültünk": "készült",
    "készüléke": "készülék",
    "készüléken": "készülék",
    "készüléket": "készülék",
    "készülékébe": "készülék",
    "készülékét": "készülék",
    "készülőben": "készülő",
    "készülődtek": "készülődik",
    "késése": "késés",
    "késései": "késés",
    "késéssel": "késés",
    "késést": "késés",
    "késésért": "késés",
    "kését": "kés",
    "később": "késő",
    "későbbiek": "későbbi",
    "későbbiekben": "későbbi",
    "későbbre": "késő",
    "későn": "késő",
    "későre": "későr",
    "két-háromszor": "két-három",
    "kételkedett": "kételkedik",
    "kételkedhetett": "kételkedhet",
    "kételkedni": "kételkedik",
    "kételkedtek": "kételkedik",
    "kételkedtem": "kételkedik",
    "kételkedtél": "kételkedik",
    "kételkedésre": "kételkedés",
    "kételkedőnek": "kételkedő",
    "kételyek": "kétely",
    "kételyekre": "kétely",
    "kételyt": "kétely",
    "kétezren": "kétezer",
    "kétféleképpen": "kétféle",
    "kétharmadosnál": "kétharmados",
    "kéthavonta": "kéthó",
    "kéthetenként": "kéthét",
    "kétmilliárdot": "kétmilliárd",
    "kétméternyire": "kétméternyi",
    "kétszerese": "kétszeres",
    "kétszeresen": "kétszeres",
    "kétszeresére": "kétszeres",
    "kétszázezerre": "kétszázezer",
    "kétségbe": "kétség",
    "kétségbeesett": "kétségbeesik",
    "kétségbeesetten": "kétségbeesett",
    "kétségbeesése": "kétségbeesés",
    "kétségbeesésén": "kétségbeesés",
    "kétségben": "kétség",
    "kétségbevonhatatlanul": "kétségbevonhatatlan",
    "kétségek": "kétség",
    "kétségeket": "kétség",
    "kétséget": "kétség",
    "kétségtelenül": "kétségtelen",
    "kétértelműek": "kétértelmű",
    "kétértelműséget": "kétértelműség",
    "kétértelművé": "kétértelmű",
    "kévekötésben": "kévekötés",
    "kévéket": "kéve",
    "kévét": "kéve",
    "kézbe": "kéz",
    "kézben": "kéz",
    "kézbesített": "kézbesít",
    "kézcsókra": "kézcsók",
    "kézen": "kéz",
    "kézfogásában": "kézfogás",
    "kézhez": "kéz",
    "kézhezvételével": "kézhezvétel",
    "kézigránátot": "kézigránát",
    "kézikönyvben": "kézikönyv",
    "kézikönyvek": "kézikönyv",
    "kézikönyvekkel": "kézikönyv",
    "kézilabdacsapatától": "kézilabdacsapat",
    "kézilabdakupákban": "kézilabdakupa",
    "kéziratait": "kézirat",
    "kéziratcsomót": "kéziratcsomó",
    "kézmosással": "kézmosás",
    "kézmozdulata": "kézmozdulat",
    "kézmozdulatok": "kézmozdulat",
    "kézmozdulattal": "kézmozdulat",
    "kéznél": "kéz",
    "kézre": "kéz",
    "kézről": "kéz",
    "kézzel": "kéz",
    "kézzé": "kéz",
    "kézírásával": "kézírás",
    "kígyóból": "kígyó",
    "kígyókon": "kígyó",
    "kígyóként": "kígyó",
    "kígyóvonalától": "kígyóvonal",
    "kíméli": "kímél",
    "kímélni": "kímél",
    "kímélnie": "kímél",
    "kímélését": "kímélés",
    "kímélünk": "kímél",
    "kínja": "kín",
    "kínjai": "kín",
    "kínlódón": "kínlódó",
    "kínok": "kín",
    "kínokat": "kín",
    "kínosan": "kínos",
    "kínoznak": "kínoz",
    "kínozni": "kínoz",
    "kínozott": "kínoz",
    "kínozta": "kínoz",
    "kínoztassam": "kínoztas",
    "kínozzák": "kínoz",
    "kínt": "kín",
    "kíntól": "kín",
    "kínzások": "kínzás",
    "kínzásommal": "kínzás",
    "kínzással": "kínzás",
    "kínzását": "kínzás",
    "kínzóan": "kínzó",
    "kínzói": "kínzó",
    "kínzókamrában": "kínzókamra",
    "kínálatként": "kínálat",
    "kínálatot": "kínálat",
    "kínálatra": "kínálat",
    "kínálattal": "kínálat",
    "kínálgatják": "kínálgat",
    "kínálja": "kínál",
    "kínálják": "kínál",
    "kínálnak": "kínál",
    "kínált": "kínál",
    "kínálta": "kínál",
    "kínáltak": "kínált",
    "kínálást": "kínálás",
    "kísérelt": "kísérel",
    "kísérelte": "kísérel",
    "kísérete": "kíséret",
    "kíséretében": "kíséret",
    "kísérhetjük": "kísérhet",
    "kíséri": "kísér",
    "kísérik": "kísér",
    "kísérletbe": "kísérlet",
    "kísérletek": "kísérlet",
    "kísérletet": "kísérlet",
    "kísérletezhessen": "kísérletezhet",
    "kísérletezheti": "kísérletezhet",
    "kísérletezik": "kísérletez",
    "kísérletezni": "kísérletez",
    "kísérletnek": "kísérlet",
    "kísérletről": "kísérlet",
    "kísérlettel": "kísérlett",
    "kísérletét": "kísérlet",
    "kísérli": "kísérel",
    "kísérni": "kísér",
    "kísért": "kísér",
    "kísérte": "kísér",
    "kísértek": "kísért",
    "kísértet": "kísért",
    "kísértetek": "kísértet",
    "kísértetként": "kísértet",
    "kísértett": "kísért",
    "kísértette": "kísértet",
    "kísértésbe": "kísértés",
    "kísértést": "kísértés",
    "kísérőjének": "kísérő",
    "kísérőt": "kísérő",
    "kísérőtől": "kísérő",
    "kívánatosak": "kívánatos",
    "kívánatosnak": "kívánatos",
    "kívánatossá": "kívánatos",
    "kíváncsiak": "kíváncsi",
    "kíváncsian": "kíváncsi",
    "kíváncsisággal": "kíváncsiság",
    "kívánhatja": "kívánhat",
    "kívánja": "kíván",
    "kívánják": "kíván",
    "kívánnak": "kíván",
    "kívánnia": "kíván",
    "kívánná": "kíván",
    "kívánom": "kíván",
    "kívánságod": "kívánság",
    "kívánt": "kíván",
    "kívánta": "kíván",
    "kívántak": "kívánt",
    "kívántam": "kívánt",
    "kívántatta": "kívántatik",
    "kívánták": "kíván",
    "kívüle": "kívül",
    "kóborolhasson": "kóborolhat",
    "kóboroltak": "kóborolt",
    "kódexben": "kódex",
    "kódja": "kód",
    "kódorognia": "kódorog",
    "kódot": "kód",
    "kópiákat": "kópia",
    "kórházai": "kórház",
    "kórházak": "kórház",
    "kórházakat": "kórház",
    "kórházakba": "kórház",
    "kórházakban": "kórház",
    "kórházaknak": "kórház",
    "kórházaknál": "kórház",
    "kórházakon": "kórház",
    "kórházakra": "kórház",
    "kórházba": "kórház",
    "kórházban": "kórház",
    "kórházfolyosón": "kórházfolyosó",
    "kórháznak": "kórház",
    "kórházvezetők": "kórházvezető",
    "kórházát": "kórház",
    "kórházé": "kórház",
    "kórt": "kór",
    "kórtant": "kórtan",
    "kórusokat": "kórus",
    "kórót": "kóró",
    "kóstolták": "kóstol",
    "kótyavetyéjéről": "kótyavetye",
    "kóvályogni": "kóvályog",
    "köbcentiméteren": "köbcentiméter",
    "köbméterre": "köbméter",
    "köbölkútra": "köbölkút",
    "köcsögökkel": "köcsög",
    "ködbe": "köd",
    "ködöt": "köd",
    "köhintett": "köhint",
    "köhécseltek": "köhécselt",
    "köhögésre": "köhögés",
    "köhögésrohamot": "köhögésroham",
    "köhögött": "köhög",
    "kölcsönbe": "kölcsön",
    "kölcsönkérni": "kölcsönkér",
    "kölcsönkért": "kölcsönkér",
    "kölcsönzések": "kölcsönzés",
    "kölcsönért": "kölcsön",
    "kölcsönök": "kölcsön",
    "kölcsönösen": "kölcsönös",
    "kölcsönözni": "kölcsönöz",
    "kölcsönöztem": "kölcsönöz",
    "köleskását": "köleskása",
    "költeményeinek": "költemény",
    "költemények": "költemény",
    "költeményektől": "költemény",
    "költeményre": "költemény",
    "költenek": "költ",
    "költeni": "költ",
    "költi": "költ",
    "költik": "költ",
    "költségarányait": "költségarány",
    "költsége": "költség",
    "költségei": "költség",
    "költségeinek": "költség",
    "költségeinket": "költség",
    "költségeiről": "költség",
    "költségeit": "költség",
    "költségek": "költség",
    "költségeket": "költség",
    "költségeknek": "költség",
    "költségemen": "költség",
    "költségen": "költség",
    "költséget": "költség",
    "költséggel": "költség",
    "költségkihatásai": "költségkihatás",
    "költségnek": "költség",
    "költségtérítést": "költségtérítés",
    "költségvetésben": "költségvetés",
    "költségvetésből": "költségvetés",
    "költségvetése": "költségvetés",
    "költségvetésen": "költségvetés",
    "költségvetésként": "költségvetés",
    "költségvetésnek": "költségvetés",
    "költségvetésre": "költségvetés",
    "költségvetésről": "költségvetés",
    "költségvetését": "költségvetés",
    "költségvetésük": "költségvetés",
    "költségvetésükkel": "költségvetés",
    "költségére": "költség",
    "költségét": "költség",
    "költészetet": "költészet",
    "költött": "költ",
    "költötte": "költ",
    "költöttünk": "költött",
    "költözni": "költözik",
    "költöztek": "költözik",
    "költöztetni": "költöztet",
    "költözött": "költözik",
    "költőben": "költő",
    "költője": "költő",
    "költők": "költő",
    "költőket": "költő",
    "költőpénzből": "költőpénz",
    "költőpénzét": "költőpénz",
    "költőt": "költő",
    "kölyke": "kölyök",
    "kölykök": "kölyök",
    "kölyköm": "kölyök",
    "kölyöktől": "kölyök",
    "könnybe": "könny",
    "könnyebb": "könnyű",
    "könnyebbedett": "könnyebbedik",
    "könnyebben": "könnyű",
    "könnyebbé": "könnyű",
    "könnyebbült": "könnyebbül",
    "könnyebbültem": "könnyebbül",
    "könnyebbülést": "könnyebbülés",
    "könnyed": "könny",
    "könnyedebben": "könnyed",
    "könnyeden": "könnyed",
    "könnyedségre": "könnyedség",
    "könnyedén": "könnyed",
    "könnyei": "könny",
    "könnyek": "könny",
    "könnyekben": "könny",
    "könnyeket": "könny",
    "könnyekkel": "könny",
    "könnyeknek": "könny",
    "könnyel": "könny",
    "könnyelműségből": "könnyelműség",
    "könnyelműségét": "könnyelműség",
    "könnyen": "könny",
    "könnyeteket": "könny",
    "könnynek": "könny",
    "könnyét": "könny",
    "könnyíteni": "könnyít",
    "könnyített": "könnyít",
    "könnyíti": "könnyít",
    "könnyítsen": "könnyít",
    "könnyítések": "könnyítés",
    "könnyítést": "könnyítés",
    "könnyűnek": "könnyű",
    "könnyűszerrel": "könnyűszer",
    "könyvben": "könyv",
    "könyvből": "könyv",
    "könyvcímeiből": "könyvcím",
    "könyve": "könyv",
    "könyvecskéről": "könyvecské",
    "könyvei": "könyv",
    "könyveimet": "könyv",
    "könyveit": "könyv",
    "könyveivel": "könyv",
    "könyvek": "könyv",
    "könyvekben": "könyv",
    "könyveket": "könyv",
    "könyvelésátvezetéssel": "könyvelésátvezetés",
    "könyvelőnek": "könyvelő",
    "könyvelőről": "könyvelő",
    "könyvelőt": "könyvelő",
    "könyvesboltban": "könyvesbolt",
    "könyvespolcok": "könyvespolc",
    "könyvet": "könyv",
    "könyvhöz": "könyv",
    "könyvkiadása": "könyvkiadás",
    "könyvnapon": "könyvnap",
    "könyvről": "könyv",
    "könyvszekrényben": "könyvszekrény",
    "könyvszekrényeket": "könyvszekrény",
    "könyvszekrényre": "könyvszekrény",
    "könyvtárak": "könyvtár",
    "könyvtárakat": "könyvtár",
    "könyvtárakban": "könyvtár",
    "könyvtárat": "könyvtár",
    "könyvtárba": "könyvtár",
    "könyvtárosa": "könyvtáros",
    "könyvtárra": "könyvtár",
    "könyvvel": "könyv",
    "könyvvizsgálót": "könyvvizsgáló",
    "könyvvásárlások": "könyvvásárlás",
    "könyvében": "könyv",
    "könyvéből": "könyv",
    "könyvének": "könyv",
    "könyvészt": "könyvész",
    "könyvét": "könyv",
    "könyvírással": "könyvírás",
    "könyvünket": "könyv",
    "könyökből": "könyök",
    "könyökcsövén": "könyökcső",
    "könyökcsövét": "könyökcső",
    "könyöke": "könyök",
    "könyökhajlatába": "könyökhajlat",
    "könyöktávolságból": "könyöktávolság",
    "könyökéig": "könyök",
    "könyökén": "könyök",
    "könyökének": "könyök",
    "könyökére": "könyök",
    "könyökét": "könyök",
    "könyökével": "könyök",
    "könyörgöm": "könyörög",
    "könyörgött": "könyörög",
    "könyörtelenebb": "könyörtelen",
    "könyörtelensége": "könyörtelenség",
    "könyörtelenül": "könyörtelen",
    "könyörögtek": "könyörög",
    "könyörögtél": "könyörög",
    "könyörületére": "könyörület",
    "köpenyben": "köpeny",
    "köpetként": "köpet",
    "köpködnek": "köpköd",
    "köpködőben": "köpködő",
    "köpni": "köp",
    "körbe": "kör",
    "körbefordult": "körbefordul",
    "körbejárt": "körbejár",
    "körben": "kör",
    "körbenyargalt": "körbenyargal",
    "körbesétált": "körbesétál",
    "körbeverte": "körbever",
    "körbeállítottak": "körbeállított",
    "köre": "kör",
    "köreinél": "kör",
    "körgyűrűnek": "körgyűrű",
    "körme": "köröm",
    "körmeit": "köröm",
    "körmit": "körmi",
    "körmét": "köröm",
    "körmöd": "köröm",
    "körmöket": "köröm",
    "körmönfontan": "körmönfont",
    "környezetbe": "környezet",
    "környezetben": "környezet",
    "környezete": "környezet",
    "környezetre": "környezet",
    "környezetrombolásban": "környezetrombolás",
    "környezetváltozást": "környezetváltozás",
    "környezetvédőinek": "környezetvédői",
    "környezetvédők": "környezetvédő",
    "környezetvédőknek": "környezetvédő",
    "környezetének": "környezet",
    "környezetét": "környezet",
    "környékbeliek": "környékbeli",
    "környéken": "környék",
    "környékén": "környék",
    "környékének": "környék",
    "környékéről": "környék",
    "környékét": "környék",
    "kört": "kör",
    "körtehéjat": "körtehéj",
    "körtét": "körte",
    "körvonalai": "körvonal",
    "körvonalaiban": "körvonal",
    "körvonalait": "körvonal",
    "körvonalak": "körvonal",
    "körzetbe": "körzet",
    "körzetben": "körzet",
    "körzete": "körzet",
    "körzetek": "körzet",
    "körzetet": "körzet",
    "körzetében": "körzet",
    "köré": "kör",
    "körébe": "kör",
    "körében": "kör",
    "köréhez": "kör",
    "köréje": "köréj",
    "körének": "kör",
    "körét": "kör",
    "körítették": "körítet",
    "körök": "kör",
    "körökben": "kör",
    "körömmel": "köröm",
    "körömollóval": "körömolló",
    "körötökből": "kör",
    "körözik": "köröz",
    "körözött": "köröz",
    "körözöttek": "körözött",
    "körútig": "körút",
    "körútjának": "körút",
    "körúton": "körút",
    "körútról": "körút",
    "körükbe": "kör",
    "körül": "kör",
    "körüle": "körül",
    "körülire": "körüli",
    "körüljártatta": "körüljártat",
    "körüljárták": "körüljár",
    "körülményei": "körülmény",
    "körülményeik": "körülmény",
    "körülményeit": "körülmény",
    "körülmények": "körülmény",
    "körülményeket": "körülmény",
    "körülményekhez": "körülmény",
    "körülményeknek": "körülmény",
    "körülményektől": "körülmény",
    "körülménynek": "körülmény",
    "körülnézett": "körülnéz",
    "körülsétált": "körülsétál",
    "körülsétálta": "körülsétál",
    "körültekintett": "körültekint",
    "körültekintéssel": "körültekintés",
    "körülveszi": "körülveszik",
    "körülvett": "körülvesz",
    "körülvette": "körülvesz",
    "körülvették": "körülvesz",
    "körülvettük": "körülvett",
    "körülzárt": "körülzár",
    "körülírást": "körülírás",
    "körülötte": "körülött",
    "körülöttük": "körülött",
    "körülöttünk": "körülött",
    "kösse": "köt",
    "kössenek": "köt",
    "kössön": "köt",
    "kössünk": "köt",
    "köszönetet": "köszönet",
    "köszönettel": "köszönet",
    "köszönhetek": "köszönhet",
    "köszönhetem": "köszönhet",
    "köszönhette": "köszönhet",
    "köszönhetünk": "köszönhet",
    "köszönhetően": "köszönhető",
    "köszönjük": "köszön",
    "köszönjünk": "köszön",
    "köszönni": "köszön",
    "köszönt": "köszön",
    "köszöntené": "köszönt",
    "köszöntsem": "köszönt",
    "köszöntöm": "köszönt",
    "köszöntötte": "köszönt",
    "köszöntünk": "köszönt",
    "köszönésre": "köszönés",
    "köszönöm": "köszön",
    "kötekedésben": "kötekedés",
    "kötelesek": "köteles",
    "kötelessége": "kötelesség",
    "kötelességei": "kötelesség",
    "kötelességeket": "kötelesség",
    "kötelességet": "kötelesség",
    "kötelességgel": "kötelesség",
    "kötelességre": "kötelesség",
    "kötelességszerűen": "kötelességszerű",
    "kötelességteljesítéssel": "kötelességteljesítés",
    "kötelességtudóan": "kötelességtudó",
    "kötelességért": "kötelesség",
    "kötelességük": "kötelesség",
    "kötelességüknek": "kötelesség",
    "kötelességünk": "kötelesség",
    "kötelet": "kötél",
    "kötelezettség-állománya": "kötelezettség-állomány",
    "kötelezettsége": "kötelezettség",
    "kötelezettségei": "kötelezettség",
    "kötelezettségeiket": "kötelezettség",
    "kötelezettségeinek": "kötelezettség",
    "kötelezettségeit": "kötelezettség",
    "kötelezettségeket": "kötelezettség",
    "kötelezettséget": "kötelezettség",
    "kötelezettségtől": "kötelezettség",
    "kötelezettségvállalással": "kötelezettségvállalás",
    "kötelezettségük": "kötelezettség",
    "kötelezheti": "kötelezhet",
    "kötelezi": "kötelez",
    "kötelezte": "kötelez",
    "kötelezően": "kötelező",
    "kötelékei": "kötelék",
    "kötelékek": "kötelék",
    "kötelékeket": "kötelék",
    "kötelékükbe": "kötelék",
    "kötetben": "kötet",
    "kötetei": "kötet",
    "kötetek": "kötet",
    "kötetenként": "kötet",
    "kötetet": "kötet",
    "köthetnek": "köthet",
    "köti": "köt",
    "kötik": "köt",
    "kötnek": "köt",
    "kötni": "köt",
    "kötniük": "köt",
    "kötné": "köt",
    "köttetett": "köttet",
    "kötvénykibocsátásai": "kötvénykibocsátás",
    "kötvénykibocsátásait": "kötvénykibocsátás",
    "kötvénykibocsátások": "kötvénykibocsátás",
    "kötvénykibocsátásához": "kötvénykibocsátás",
    "kötvényt": "kötvény",
    "kötélben": "kötél",
    "kötélből": "kötél",
    "kötélcsinálásban": "kötélcsinálás",
    "kötélkorbácsról": "kötélkorbács",
    "kötélnek": "kötél",
    "kötélre": "kötél",
    "kötélért": "kötél",
    "köténye": "kötény",
    "köténynek": "kötény",
    "kötényébe": "kötény",
    "kötésben": "kötés",
    "kötések": "kötés",
    "kötésnek": "kötés",
    "kötést": "kötés",
    "kötött": "köt",
    "kötötte": "köt",
    "kötöttek": "kötött",
    "kötöttem": "kötött",
    "kötötték": "köt",
    "kötözni": "kötöz",
    "kötözték": "kötöz",
    "kötődne": "kötődik",
    "kötőjükben": "kötő",
    "kötőre": "kötő",
    "köveitől": "kő",
    "kövek": "kő",
    "kövekkel": "kő",
    "kövesse": "követ",
    "követ": "kő",
    "követei": "követ",
    "követek": "követ",
    "követeli": "követel",
    "követelik": "követel",
    "követelménye": "követelmény",
    "követelményeinek": "követelmény",
    "követelmények": "követelmény",
    "követelményeket": "követelmény",
    "követelményekkel": "követelmény",
    "követelményeknek": "követelmény",
    "követelményt": "követelmény",
    "követelni": "követel",
    "követelnie": "követel",
    "követelt": "követel",
    "követelte": "követel",
    "követelték": "követel",
    "követelve": "követelv",
    "követelése": "követelés",
    "követeléseinek": "követelés",
    "követeléseinket": "követelés",
    "követeléseket": "követelés",
    "követelésekkel": "követelés",
    "követelést": "követelés",
    "követelésének": "követelés",
    "követeléséről": "követelés",
    "követelését": "követelés",
    "követelésétől": "követelés",
    "követelünk": "követel",
    "követelőztünk": "követelőzik",
    "követem": "követ",
    "követett": "követ",
    "követhetnének": "követhet",
    "követhették": "követhet",
    "követhetően": "követhető",
    "követi": "követ",
    "követik": "követ",
    "következetesen": "következetes",
    "következetlenül": "következetlen",
    "következett": "következik",
    "következménye": "következmény",
    "következményei": "következmény",
    "következményeik": "következmény",
    "következményeinek": "következmény",
    "következmények": "következmény",
    "következményekkel": "következmény",
    "következményeként": "következmény",
    "következményeképpen": "következmény",
    "következményének": "következmény",
    "következne": "következik",
    "következnek": "következik",
    "következni": "következik",
    "következnie": "következik",
    "következtek": "következik",
    "következtetett": "következtet",
    "következtethetett": "következtethet",
    "következtetni": "következtet",
    "következtetniük": "következtet",
    "következtettem": "következtet",
    "következtetéseit": "következtetés",
    "következtetéseket": "következtetés",
    "következtetésre": "következtetés",
    "következtében": "következte",
    "következésképp": "következés",
    "következésképpen": "következés",
    "következőben": "következő",
    "következőképpen": "következő",
    "következőt": "következő",
    "követne": "követ",
    "követnek": "követ",
    "követni": "követ",
    "követné": "követ",
    "követnék": "követ",
    "követségről": "követség",
    "követte": "követ",
    "követtek": "követ",
    "követtem": "követ",
    "követték": "követ",
    "követésre": "követés",
    "követétől": "követ",
    "követünk": "követ",
    "követően": "követő",
    "követői": "követő",
    "kövezeten": "kövezet",
    "kövezett": "kövez",
    "kövén": "kő",
    "kövérebb": "kövér",
    "közalkalmazottak": "közalkalmazott",
    "közalkalmazottakkal": "közalkalmazott",
    "közalkalmazottaknak": "közalkalmazott",
    "közalkalmazottaknál": "közalkalmazott",
    "közalkalmazottakra": "közalkalmazott",
    "közbe": "köz",
    "közbeléptét": "közbelépte",
    "közben": "köz",
    "közbenjárására": "közbenjárás",
    "közbeszerzést": "közbeszerzés",
    "közbeszóltam": "közbeszólt",
    "közbeszólásaiból": "közbeszólás",
    "közbevetni": "közbevet",
    "közbevágott": "közbevág",
    "köze": "köz",
    "közeget": "közeg",
    "közeledett": "közeledik",
    "közeledtek": "közeledik",
    "közeledése": "közeledés",
    "közeledést": "közeledés",
    "közeledését": "közeledés",
    "közelemben": "közelem",
    "közeljövőben": "közeljövő",
    "közelmúltban": "közelmúlt",
    "közelről": "közel",
    "közelsége": "közelség",
    "közelébe": "közel",
    "közelében": "közel",
    "közeléből": "közel",
    "közelíteni": "közelít",
    "közelítenék": "közelít",
    "közelíteném": "közelít",
    "közelíthettek": "közelíthet",
    "közelíthették": "közelíthet",
    "közelíti": "közelít",
    "közelítjük": "közelít",
    "közelítsen": "közelít",
    "közelükben": "közel",
    "közembersorban": "közembersor",
    "közepe": "közép",
    "közepébe": "közepe",
    "közepében": "közepe",
    "közepéből": "közepe",
    "közepéig": "közepe",
    "közepén": "közepe",
    "közepén-végén": "közepé-végén",
    "közepére": "közepe",
    "közepét": "közepe",
    "közepétől": "közepe",
    "közfalukon": "közfalu",
    "közfelkiáltással": "közfelkiáltás",
    "közgazdák": "közgazda",
    "közgazdásza": "közgazdász",
    "közgazdászok": "közgazdász",
    "közgyűlése": "közgyűlés",
    "közgyűlésen": "közgyűlés",
    "közgyűlésének": "közgyűlés",
    "közhelyet": "közhely",
    "közhelynek": "közhely",
    "közigazgatást": "közigazgatás",
    "közismerten": "közismert",
    "közjátékhoz": "közjáték",
    "közkatonatömegeknek": "közkatonatömeg",
    "közlekedhetnek": "közlekedhet",
    "közlekednek": "közlekedik",
    "közlekedni": "közlekedik",
    "közlekedése": "közlekedés",
    "közleményben": "közlemény",
    "közleménye": "közlemény",
    "közleményre": "közlemény",
    "közleményét": "közlemény",
    "közlemúltban": "közlemúlt",
    "közlendőket": "közlendő",
    "közlik": "közöl",
    "közlésére": "közlés",
    "közlésével": "közlés",
    "közlésünkkel": "közlés",
    "köznyelve": "köznyelv",
    "központba": "központ",
    "központban": "központ",
    "központból": "központ",
    "központja": "központ",
    "központjai": "központ",
    "központjaiban": "központ",
    "központjában": "központ",
    "központjának": "központ",
    "központok": "központ",
    "központokra": "központ",
    "központoktól": "központ",
    "központosítani": "központosít",
    "központosított": "központosít",
    "központot": "központ",
    "központtól": "központ",
    "közpénzeket": "közpénz",
    "közpénzekkel": "közpénz",
    "közre": "köz",
    "közrefogatták": "közrefogat",
    "közrejátszottak": "közrejátszott",
    "közreműködtem": "közreműködik",
    "közreműködése": "közreműködés",
    "közreműködésével": "közreműködés",
    "közreműködéséért": "közreműködés",
    "közreműködője": "közreműködő",
    "közreműködőknek": "közreműködő",
    "közszellemet": "közszellem",
    "közszolgáltatások": "közszolgáltatás",
    "közszájon": "közszáj",
    "községháza": "községház",
    "községházához": "községháza",
    "községházán": "községháza",
    "községnek": "község",
    "községnél": "község",
    "községünk": "község",
    "közt": "köz",
    "közte": "közt",
    "közterületek": "közterület",
    "köztisztaságunk": "köztisztaság",
    "köztiszteletben": "köztisztelet",
    "köztiszteletnek": "köztisztelet",
    "köztudatba": "köztudat",
    "köztudottan": "köztudott",
    "köztulajdonnak": "köztulajdon",
    "köztársaságban": "köztársaság",
    "köztársasággal": "köztársaság",
    "köztársaságként": "köztársaság",
    "köztársaságot": "köztársaság",
    "köztársaságpártiakkal": "köztársaságpárti",
    "köztük": "közt",
    "köztünk": "közt",
    "közvetlenebb": "közvetlen",
    "közvetlenül": "közvetlen",
    "közvetített": "közvetít",
    "közvetítette": "közvetít",
    "közvetítik": "közvetít",
    "közvetítsen": "közvetít",
    "közvetítése": "közvetítés",
    "közvetítéseket": "közvetítés",
    "közvetítésekhez": "közvetítés",
    "közvetítéssel": "közvetítés",
    "közvetítést": "közvetítés",
    "közvetítésének": "közvetítés",
    "közvetítését": "közvetítés",
    "közvetítésével": "közvetítés",
    "közvetítésükkel": "közvetítés",
    "közvetítőben": "közvetítő",
    "közvetítőből": "közvetítő",
    "közvetítőként": "közvetítő",
    "közvetítőnek": "közvetítő",
    "közvetítőnk": "közvetítő",
    "közvéleménnyel": "közvélemény",
    "közvélemény-kutatásainak": "közvélemény-kutatás",
    "közvéleményben": "közvélemény",
    "közvéleménynek": "közvélemény",
    "közvéleményt": "közvélemény",
    "közzé": "köz",
    "közzéteszi": "közzétesz",
    "közzétett": "közzétesz",
    "közzétették": "közzétesz",
    "közzétételét": "közzététel",
    "közé": "köz",
    "közéjük": "közéj",
    "közéküldött": "közéküld",
    "közéletben": "közélet",
    "közéletünk": "közélet",
    "közénk": "közé",
    "középen": "közép",
    "középiskolában": "középiskola",
    "középiskoláik": "középiskola",
    "középiskolákat": "középiskola",
    "középiskolákban": "középiskola",
    "középiskolát": "középiskola",
    "középkor": "közép",
    "középkorban": "középkor",
    "középkornak": "középkor",
    "középkorukat": "középkor",
    "középosztályból": "középosztály",
    "középpontja": "középpont",
    "középpontjába": "középpont",
    "középpontjában": "középpont",
    "középpontjáról": "középpont",
    "középrétegek": "középréteg",
    "középvállalkozások": "középvállalkozás",
    "középületnek": "középület",
    "közérzetét": "közérzet",
    "közöd": "köz",
    "közölhetné": "közölhet",
    "közöljük": "közöl",
    "közöljünk": "közöl",
    "közölni": "közöl",
    "közölt": "közöl",
    "közölte": "közöl",
    "közöltek": "közölt",
    "közölték": "közöl",
    "közömbösen": "közömbös",
    "közömbösséget": "közömbösség",
    "közönnyel": "közöny",
    "közönsége": "közönség",
    "közönségesebb": "közönséges",
    "közönséget": "közönség",
    "közönséggel": "közönség",
    "közönségnek": "közönség",
    "közönségükkel": "közönség",
    "közönyt": "közöny",
    "közönyért": "közöny",
    "közönyével": "közöny",
    "közönyön": "közöny",
    "közönyösen": "közönyös",
    "közösen": "közös",
    "közösségbe": "közösség",
    "közösségben": "közösség",
    "közössége": "közösség",
    "közösségeiben": "közösség",
    "közösségek": "közösség",
    "közösséget": "közösség",
    "közösségéből": "közösség",
    "közöttiek": "közötti",
    "közöttire": "közötti",
    "közöttük": "között",
    "közöttünk": "között",
    "közügyekkel": "közügy",
    "közügyet": "közügy",
    "közük": "köz",
    "közül": "köz",
    "közületekből": "közület",
    "közülük": "közül",
    "közülünk": "közül",
    "közünk": "köz",
    "kúráltad": "kúrált",
    "kúsznak": "kúszik",
    "kúszott": "kúszik",
    "kútba": "kút",
    "kútforrása": "kútforrás",
    "kútjánál": "kút",
    "küblire": "kübli",
    "küldelek": "küld",
    "küldeményben": "küldemény",
    "küldeményekben": "küldemény",
    "küldenek": "küld",
    "küldeni": "küld",
    "küldetése": "küldetés",
    "küldetésemnek": "küldetés",
    "küldetését": "küldetés",
    "küldhetik": "küldhet",
    "küldi": "küld",
    "küldik": "küld",
    "küldje": "küld",
    "küldjenek": "küld",
    "küldjön": "küld",
    "küldjünk": "küld",
    "küldte": "küld",
    "küldtek": "küld",
    "küldték": "küld",
    "küldök": "küld",
    "küldönccel": "küldönc",
    "küldöncök": "küldönc",
    "küldött": "küld",
    "küldöttek": "küldött",
    "küldöttsége": "küldöttség",
    "küldöttségeiben": "küldöttség",
    "küldöttségnek": "küldöttség",
    "küldöttségről": "küldöttség",
    "küldöttségének": "küldöttség",
    "küldöttségét": "küldöttség",
    "külföldiek": "külföldi",
    "külföldieket": "külföldi",
    "külföldiekkel": "külföldi",
    "külföldiekétől": "külföldi",
    "külföldit": "külföldi",
    "külföldre": "külföld",
    "külföldről": "külföld",
    "külföldön": "külföld",
    "küllemében": "küllem",
    "külpolitikát": "külpolitika",
    "külseje": "külső",
    "külsejében": "külső",
    "külsejüket": "külső",
    "külsőben": "külső",
    "külsőm": "külső",
    "külsőre": "külső",
    "külsőségeiben": "külsőség",
    "külsőt": "külső",
    "külvilággal": "külvilág",
    "különalkura": "különalku",
    "különbek": "különb",
    "különbekkel": "különb",
    "különben": "különb",
    "különbségeiben": "különbség",
    "különbségek": "különbség",
    "különbségeknek": "különbség",
    "különbséget": "különbség",
    "különbséggel": "különbség",
    "különbözetet": "különbözet",
    "különbözhetik": "különbözhet",
    "különböznek": "különbözik",
    "különbözött": "különbözik",
    "különbözünk": "különbözik",
    "különbözőbb": "különböző",
    "különbözők": "különböző",
    "különcködésnek": "különcködés",
    "különcködést": "különcködés",
    "különcséget": "különcség",
    "különcségére": "különcség",
    "különdíjat": "különdíj",
    "különdíját": "különdíj",
    "különlegesen": "különleges",
    "különlegessége": "különlegesség",
    "különtárgyalásokról": "különtárgyalás",
    "különváláshoz": "különválás",
    "különítenek": "különít",
    "különítettek": "különített",
    "különítették": "különítet",
    "különítmények": "különítmény",
    "különítményekkel": "különítmény",
    "különítményhez": "különítmény",
    "különítsenek": "különít",
    "különösebb": "különös",
    "különösebben": "különös",
    "különösebbet": "különös",
    "különösen": "különös",
    "különösképp": "különös",
    "különösképpen": "különös",
    "különösségnek": "különösség",
    "külügyminisztereinek": "külügyminiszter",
    "külügyminisztereként": "külügyminiszter",
    "külügyminiszternél": "külügyminiszter",
    "külügyminiszterrel": "külügyminiszter",
    "külügyminisztériumba": "külügyminisztérium",
    "kürtök": "kürt",
    "küszködnek": "küszködik",
    "küszködtek": "küszködik",
    "küszöbről": "küszöb",
    "küszöbén": "küszöb",
    "küszöböket": "küszöb",
    "küszöbölni": "küszöböl",
    "küszöbölnünk": "küszöböl",
    "küszöbön": "küszöb",
    "küszöböt": "küszöb",
    "küzdelemben": "küzdelem",
    "küzdelemnek": "küzdelem",
    "küzdelemre": "küzdelem",
    "küzdelmeiben": "küzdelem",
    "küzdelmet": "küzdelem",
    "küzdenek": "küzd",
    "küzdeni": "küzd",
    "küzdenie": "küzd",
    "küzdeniük": "küzd",
    "küzdenünk": "küzd",
    "küzdhetett": "küzdhet",
    "küzdött": "küzd",
    "küzdünk": "küzd",
    "küzdők": "küzdő",
    "kőhalmazokon": "kőhalmaz",
    "kőkockák": "kőkocka",
    "kőolajtermékekkel": "kőolajtermék",
    "kőpadlójára": "kőpadló",
    "kőrisfák": "kőrisfa",
    "kőszénfüstje": "kőszénfüst",
    "kőtömbök": "kőtömb",
    "kővel": "kő",
    "kőzetek": "kőzet",
    "kőzetmozgást": "kőzetmozgás",
    "l-nél": "l",
    "l-én": "l",
    "labdarúgó-bajnokságok": "labdarúgó-bajnokság",
    "labdarúgó-mérkőzések": "labdarúgó-mérkőzés",
    "labdarúgó-válogatottja": "labdarúgó-válogatott",
    "labdarúgói": "labdarúgó",
    "labdarúgók": "labdarúgó",
    "labdarúgókért": "labdarúgó",
    "labdák": "labda",
    "labirintusban": "labirintus",
    "labirintusában": "labirintus",
    "laboratóriumaiban": "laboratórium",
    "laboratóriumokban": "laboratórium",
    "laboratóriumot": "laboratórium",
    "lagymatagok": "lagymatag",
    "lajstromot": "lajstrom",
    "lajthoz": "lajt",
    "lajtnál": "lajt",
    "lajtot": "lajt",
    "lajttal": "lajt",
    "lakatlanok": "lakatlan",
    "lakatosnak": "lakatos",
    "lakatra": "lakat",
    "lakbért": "lakbér",
    "lakcímmel": "lakcím",
    "lakcímük": "lakcím",
    "lakhelyein": "lakhely",
    "lakjak": "lakik",
    "lakkgyárban": "lakkgyár",
    "lakkozott": "lakkoz",
    "lakmározni": "lakmározik",
    "laknak": "lakik",
    "lakniuk": "lakik",
    "laknák": "lakik",
    "laknának": "lakik",
    "lakodalmakban": "lakodalom",
    "lakodalomba": "lakodalom",
    "lakodalomban": "lakodalom",
    "lakodalomra": "lakodalom",
    "lakom": "lakik",
    "lakomájáról": "lakoma",
    "lakosa": "lakos",
    "lakosai": "lakos",
    "lakosainak": "lakos",
    "lakosnak": "lakos",
    "lakosok": "lakos",
    "lakosokat": "lakos",
    "lakosokkal": "lakos",
    "lakosoknak": "lakos",
    "lakosonként": "lakos",
    "lakossága": "lakosság",
    "lakossággal": "lakosság",
    "lakosságot": "lakosság",
    "lakosságának": "lakosság",
    "lakosságától": "lakosság",
    "lakosért": "lakos",
    "lakott": "lakik",
    "lakrészt": "lakrész",
    "laktak": "lakik",
    "laktanyában": "laktanya",
    "laktanyáiban": "laktanya",
    "laktanyán": "laktanya",
    "laktunk": "lakik",
    "lakunk": "lakik",
    "lakájai": "lakáj",
    "lakájok": "lakáj",
    "lakás-takarékpénztárakról": "lakás-takarékpénztár",
    "lakása": "lakás",
    "lakásai": "lakás",
    "lakásaik": "lakás",
    "lakásainak": "lakás",
    "lakásba": "lakás",
    "lakásban": "lakás",
    "lakásbetörést": "lakásbetörés",
    "lakásból": "lakás",
    "lakáscserére": "lakáscsere",
    "lakáshoz": "lakás",
    "lakásig": "lakás",
    "lakásnégyzetméterre": "lakásnégyzetméter",
    "lakások": "lakás",
    "lakásokat": "lakás",
    "lakásokba": "lakás",
    "lakásokban": "lakás",
    "lakásokból": "lakás",
    "lakásomról": "lakás",
    "lakásonként": "lakás",
    "lakásra": "lakás",
    "lakással": "lakás",
    "lakást": "lakás",
    "lakástulajdonosok": "lakástulajdonos",
    "lakásukat": "lakás",
    "lakásukban": "lakás",
    "lakásunkon": "lakás",
    "lakásunkra": "lakás",
    "lakásába": "lakás",
    "lakásában": "lakás",
    "lakásárak": "lakásár",
    "lakását": "lakás",
    "lakásépítések": "lakásépítés",
    "lakó-fogyasztót": "lakó-fogyasztó",
    "lakóhelyük": "lakóhely",
    "lakóhelyünk": "lakóhely",
    "lakóháza": "lakóház",
    "lakóházak": "lakóház",
    "lakóházakhoz": "lakóház",
    "lakóházat": "lakóház",
    "lakói": "lakó",
    "lakóihoz": "lakói",
    "lakóinak": "lakóín",
    "lakóiról": "lakói",
    "lakóit": "lakói",
    "lakója": "lakó",
    "lakók": "lakó",
    "lakókkal": "lakó",
    "lakókról": "lakó",
    "lakónegyedet": "lakónegyed",
    "lakótelepek": "lakótelep",
    "lakótelepeken": "lakótelep",
    "lakóteleppel": "lakótelep",
    "lakóterületté": "lakóterület",
    "lakótársa": "lakótárs",
    "langyosabb": "langyos",
    "langyosnál": "langyos",
    "lanyhult": "lanyhul",
    "lapban": "lap",
    "lapból": "lap",
    "laphoz": "lap",
    "lapjaik": "lap",
    "lapjaikat": "lap",
    "lapjain": "lap",
    "lapjuk": "lap",
    "lapján": "lap",
    "lapját": "lap",
    "lapnak": "lap",
    "lapnyomdában": "lapnyomda",
    "lapok": "lap",
    "lapokat": "lap",
    "lapokból": "lap",
    "lapon": "lap",
    "laposok": "lapos",
    "laposokat": "lapos",
    "lapot": "lap",
    "lapozni": "lapoz",
    "lappangott": "lappang",
    "lapszélekre": "lapszél",
    "lapult": "lapul",
    "lapultunk": "lapult",
    "lapunk": "lapu",
    "lapunkat": "lapu",
    "lapunkhoz": "lapu",
    "lapunkkal": "lapu",
    "lapunknak": "lapu",
    "lapzártakor": "lapzárta",
    "lapzártáig": "lapzárta",
    "lapzártánkig": "lapzárta",
    "lapzártánkkor": "lapzárta",
    "lapátnyelük": "lapátnyél",
    "lapátokat": "lapát",
    "lapátot": "lapát",
    "lassabban": "lassabb",
    "lassulni": "lassul",
    "lassult": "lassul",
    "lassulásával": "lassulás",
    "lassított": "lassít",
    "lassúak": "lassú",
    "latba": "lat",
    "latinban": "latin",
    "latolgatást": "latolgatás",
    "lavinát": "lavina",
    "lavórban": "lavór",
    "lazaságot": "lazaság",
    "lazult": "lazul",
    "lazábbak": "laza",
    "lazán": "laza",
    "lazítottak": "lazított",
    "leadni": "lead",
    "leadniuk": "lead",
    "leadta": "lead",
    "lealacsonyodásukat": "lealacsonyodás",
    "leapadt": "leapad",
    "learatnak": "learat",
    "learatni": "learat",
    "learatták": "learat",
    "lebbencset": "lebbencs",
    "lebbencslevessel": "lebbencsleves",
    "lebbencsnél": "lebbencs",
    "lebbentek": "lebbent",
    "lebecsüléssel": "lebecsülés",
    "lebegett": "lebeg",
    "lebegni": "lebeg",
    "lebegnék": "lebeg",
    "lebernyegek": "lebernyeg",
    "lebombázták": "lebombáz",
    "lebontásával": "lebontás",
    "lebonyolításához": "lebonyolítás",
    "lebonyolítására": "lebonyolítás",
    "lebonyolítását": "lebonyolítás",
    "leborították": "leborít",
    "lebukott": "lebukik",
    "lebzselnek": "lebzsel",
    "lebzselt": "lebzsel",
    "lebélyegzéssel": "lebélyegzés",
    "leckéjét": "lecke",
    "leckét": "lecke",
    "lecsapnak": "lecsap",
    "lecsendesítette": "lecsendesít",
    "lecserélésére": "lecserélés",
    "lecsillapodott": "lecsillapodik",
    "lecsillapult": "lecsillapul",
    "lecsillapította": "lecsillapít",
    "lecsupaszítottak": "lecsupaszított",
    "lecsökkentette": "lecsökkent",
    "lecsúszott": "lecsúszik",
    "ledobott": "ledob",
    "ledobta": "ledob",
    "ledobták": "ledob",
    "ledobálták": "ledobál",
    "ledolgoznia": "ledolgozik",
    "ledolgozta": "ledolgozik",
    "ledörzsölte": "ledörzsöl",
    "leemeli": "leemel",
    "leemelte": "leemel",
    "leemeltek": "leemelt",
    "leemeltük": "leemel",
    "leengedik": "leenged",
    "leengedte": "leenged",
    "leengedtük": "leenged",
    "leereszkedett": "leereszkedik",
    "leereszkedtem": "leereszkedik",
    "leereszkedünk": "leereszkedik",
    "leereszkedőn": "leereszkedő",
    "leeresztett": "leereszt",
    "leeresztette": "leereszt",
    "leeresztettem": "leeresztett",
    "leesett": "leesik",
    "lefaragásán": "lefaragás",
    "lefaragásáról": "lefaragás",
    "lefaragásáért": "lefaragás",
    "lefegyverezték": "lefegyverez",
    "lefegyverezéséről": "lefegyverezés",
    "lefejtettem": "lefejtett",
    "lefekszenek": "lefekszik",
    "lefektetett": "lefektet",
    "lefektetik": "lefektet",
    "lefektette": "lefektet",
    "lefeküdni": "lefekszik",
    "lefeküdt": "lefekszik",
    "lefeküdtünk": "lefeküdt",
    "lefeszített": "lefeszít",
    "lefizeti": "lefizet",
    "lefoglalják": "lefoglal",
    "lefoglalt": "lefoglal",
    "lefogták": "lefog",
    "lefogyott": "lefogy",
    "lefojtott": "lefojt",
    "lefolyt": "lefolyik",
    "lefolytatnunk": "lefolytat",
    "lefolytatott": "lefolytat",
    "lefolytatását": "lefolytatás",
    "lefordíthatatlanok": "lefordíthatatlan",
    "leforgása": "leforgás",
    "leforráztak": "leforráz",
    "lefékezni": "lefékez",
    "lefényképeztek": "lefényképez",
    "lefújta": "lefúj",
    "legaktívabb": "aktív",
    "legalacsonyabb": "alacsony",
    "legalantasabb": "alantas",
    "legalját": "legalja",
    "legalkalmasabb": "alkalmas",
    "legalsó": "alsó",
    "legalsóból": "alsó",
    "legapróbb": "apró",
    "legbelseje": "belső",
    "legbelsejét": "legbelseje",
    "legbensejét": "benső",
    "legbensőbb": "benső",
    "legbiztonságosabb": "biztonságos",
    "legborzasztóbb": "borzasztó",
    "legbágyasztóbb": "bágyasztó",
    "legbüszkébb": "büszke",
    "legbűnösebb": "bűnös",
    "legcsekélyebb": "csekély",
    "legdinamikusabban": "dinamikus",
    "legdivatosabb": "divatos",
    "legdrágább": "drága",
    "legdurvább": "durva",
    "legegyszerűbb": "egyszerű",
    "legegyszerűbben": "egyszerű",
    "legellentmondásosabb": "ellentmondásos",
    "legelső": "első",
    "legeltessem": "legeltet",
    "legeltetett": "legeltet",
    "legeltetni": "legeltet",
    "legeltették": "legeltet",
    "legelvakultabb": "elvakult",
    "legelészett": "legelész",
    "legelőkön": "legelő",
    "legelőn": "legelő",
    "legelőnek": "legelő",
    "legelőt": "legelő",
    "legendában": "legenda",
    "legendák": "legenda",
    "legendássá": "legendás",
    "legendát": "legenda",
    "legenyhébb": "enyhe",
    "legeredményesebb": "eredményes",
    "legeredményesebben": "eredményes",
    "legerősebb": "erős",
    "legeslegkisebb": "kis",
    "legeslegnagyobb": "nagy",
    "legfejlettebb": "fejlett",
    "legfelsőbb": "legfelső",
    "legfelül": "felül",
    "legfiatalabb": "fiatal",
    "legfinomabb": "finom",
    "legfogékonyabb": "fogékony",
    "legfontosabb": "fontos",
    "legfontosabbat": "fontos",
    "legforróbb": "forró",
    "legfrissebb": "friss",
    "legfurcsább": "furcsa",
    "legfájdalmasabb": "fájdalmas",
    "legfélelmetesebb": "félelmetes",
    "legfőbb": "fő",
    "leggazdagabb": "gazdag",
    "leggyakoribb": "gyakori",
    "leggyorsabban": "gyors",
    "leggúnyosabb": "gúnyos",
    "leghalványabb": "halvány",
    "leghalálosabb": "halálos",
    "leghamarabb": "hamar",
    "leghevesebb": "heves",
    "leghidegebb": "hideg",
    "leghosszabb": "hosszú",
    "legideálisabb": "ideális",
    "leginkább": "inka",
    "legintenzívebb": "intenzív",
    "legismertebb": "ismert",
    "legitimitása": "legitimitás",
    "legitimitását": "legitimitás",
    "legizgatóbb": "izgató",
    "legjavát": "java",
    "legjelentéktelenebb": "jelentéktelen",
    "legjelentéktelenebbekké": "jelentéktelen",
    "legjelentősebb": "jelentős",
    "legjelesebb": "jeles",
    "legjobb": "jó",
    "legjobbak": "jó",
    "legjobbaknak": "jó",
    "legjobban": "jó",
    "legjobbat": "jó",
    "legjobbjai": "jó",
    "legjobbjait": "jó",
    "legjobbjaitól": "jó",
    "legjobbkor": "jó",
    "legjobbnak": "jó",
    "legjámborabb": "jámbor",
    "legkedvesebb": "kedves",
    "legkedvezőbb": "kedvező",
    "legkeményebb": "kemény",
    "legkevesebb": "kevés",
    "legkiegyensúlyozottabb": "kiegyensúlyozott",
    "legkiemelkedőbb": "kiemelkedő",
    "legkifinomultabb": "kifinomult",
    "legkisebb": "kis",
    "legkiválóbbakat": "kiváló",
    "legkomolyabb": "komoly",
    "legkorrektebb": "korrekt",
    "legkorszerűbb": "korszerű",
    "legkorábban": "kora",
    "legkényesebb": "kényes",
    "legkésőbb": "késő",
    "legkézenfekvőbb": "kézenfekvő",
    "legkínosabb": "kínos",
    "legkönnyebb": "könnyű",
    "legkönnyebben": "könnyű",
    "legkörmönfontabb": "körmönfont",
    "legkövetelőbb": "követelő",
    "legközelebb": "közel",
    "legközelebbi": "közelebbi",
    "legközhelyszerűbb": "közhelyszerű",
    "legközönségesebb": "közönséges",
    "legkülönbözőbb": "különböző",
    "leglényegesebb": "lényeges",
    "legmagasabb": "magas",
    "legmegfelelőbb": "megfelelő",
    "legmegnyugtatóbb": "megnyugtató",
    "legmesszemenőbb": "messzemenő",
    "legmélyebb": "mély",
    "legmélyére": "legmélye",
    "legmélyéről": "legmélye",
    "legműveltebb": "művelt",
    "legnagyobb": "nagy",
    "legnagyobbak": "nagy",
    "legnehezebb": "nehéz",
    "legnyilvánvalóbb": "nyilvánvaló",
    "legnyomorultabb": "nyomorult",
    "legnépesebb": "népes",
    "legnépszerűbb": "népszerű",
    "legokosabb": "okos",
    "legokosabban": "okos",
    "legolcsóbban": "olcsó",
    "legolcsóbbnál": "olcsó",
    "legostobább": "ostoba",
    "legrangosabb": "rangos",
    "legrejtelmesebb": "rejtelmes",
    "legritkább": "ritka",
    "legrosszabb": "rossz",
    "legrosszabbat": "rossz",
    "legrászorultabbak": "rászorult",
    "legrövidebben": "rövid",
    "legsikeresebb": "sikeres",
    "legsimábban": "sima",
    "legszebb": "szép",
    "legszebbek": "szép",
    "legszebben": "szép",
    "legszegényebb": "szegény",
    "legszegényebbek": "szegény",
    "legszelídebb": "szelíd",
    "legszembetűnőbb": "szembetűnő",
    "legszentebb": "szent",
    "legszerencsétlenebb": "szerencsétlen",
    "legszilárdabban": "szilárd",
    "legszorgosabb": "szorgos",
    "legszélső": "szélső",
    "legszívesebben": "szíves",
    "legszörnyűbb": "szörnyű",
    "legsötétebb": "sötét",
    "legsúlyosabb": "súlyos",
    "legsületlenebb": "sületlen",
    "legsűrűbb": "sűrű",
    "legtehetségesebb": "tehetséges",
    "legtehetségesebbeket": "tehetséges",
    "legteljesebb": "teljes",
    "legtermészetesebb": "természetes",
    "legtisztességesebb": "tisztességes",
    "legtisztább": "tiszta",
    "legtávolabbi": "távolabbi",
    "legtöbb": "több",
    "legtöbben": "több",
    "legtöbbet": "több",
    "legtöbbjük": "több",
    "legtöbbször": "több",
    "legtörékenyebb": "törékeny",
    "leguggolt": "leguggol",
    "legundorítóbb": "undorító",
    "legutolsó": "utolsó",
    "legutolsóhoz": "utolsó",
    "legvadabb": "vad",
    "legvadabbul": "vad",
    "legvakmerőbb": "vakmerő",
    "legvallásosabb": "vallásos",
    "legvalószínűbb": "valószínű",
    "legveszedelmesebbek": "veszedelmes",
    "legveszélyeztetettebb": "veszélyeztetett",
    "legvisszataszítóbbnak": "visszataszító",
    "legvonzóbbak": "vonzó",
    "legvonzóbbnak": "vonzó",
    "legválogatottabb": "válogatott",
    "legvégén": "legvége",
    "legyek": "lesz",
    "legyeket": "légy",
    "legyen": "lesz",
    "legyenek": "lesz",
    "legyengültem": "legyengül",
    "legyezőként": "legyező",
    "legyintett": "legyint",
    "legyintettek": "legyintett",
    "legyél": "lesz",
    "legyünk": "lesz",
    "legyőzetéstől": "legyőzetés",
    "legyőzhetetlennek": "legyőzhetetlen",
    "legyőzhetné": "legyőzhet",
    "legyőzik": "legyőz",
    "legyőznek": "legyőz",
    "legyőzni": "legyőz",
    "legyőzte": "legyőz",
    "legyőztem": "legyőz",
    "legyőztünk": "legyőz",
    "legyőzze": "legyőz",
    "legyőzésével": "legyőzés",
    "legyőzött": "legyőz",
    "legyőzöttet": "legyőzött",
    "legyőzője": "legyőző",
    "legyűrhesse": "legyűrhet",
    "legádázabb": "ádáz",
    "legálisan": "legális",
    "legégetőbb": "égető",
    "legények": "legény",
    "legényeket": "legény",
    "legényekhez": "legény",
    "legénykék": "legényke",
    "legénynek": "legény",
    "legényről": "legény",
    "legénysége": "legénység",
    "legényt": "legény",
    "legényéletről": "legényélet",
    "legépelték": "legépel",
    "legérdekesebb": "érdekes",
    "legérdekesebbet": "érdekes",
    "legértékesebbek": "értékes",
    "legérzékenyebb": "érzékeny",
    "legésszerűbb": "ésszerű",
    "legínyencebb": "ínyenc",
    "legöregebb": "öreg",
    "legújabb": "új",
    "legügyesebb": "ügyes",
    "legüresebb": "üres",
    "legütőképesebb": "ütőképes",
    "legőrültebb": "őrült",
    "lehajolt": "lehajol",
    "lehajtott": "lehajt",
    "lehajtotta": "lehajt",
    "lehalkította": "lehalkít",
    "lehelte": "lehel",
    "lehessen": "lehet",
    "lehessenek": "lehet",
    "lehetek": "lehet",
    "lehetetlennek": "lehetetlen",
    "lehetetlenné": "lehetetlen",
    "lehetetlent": "lehetetlen",
    "lehetett": "lehet",
    "lehetne": "lehet",
    "lehetnek": "lehet",
    "lehetnék": "lehet",
    "lehetnének": "lehet",
    "lehetnénk": "lehet",
    "lehetségesek": "lehetséges",
    "lehetségesnek": "lehetséges",
    "lehetségessé": "lehetséges",
    "lehettek": "lehet",
    "lehetünk": "lehet",
    "lehetőségben": "lehetőség",
    "lehetősége": "lehetőség",
    "lehetőségei": "lehetőség",
    "lehetőségeiből": "lehetőség",
    "lehetőségeik": "lehetőség",
    "lehetőségeiket": "lehetőség",
    "lehetőségeinek": "lehetőség",
    "lehetőségeink": "lehetőség",
    "lehetőségeinket": "lehetőség",
    "lehetőségeiről": "lehetőség",
    "lehetőségeit": "lehetőség",
    "lehetőségek": "lehetőség",
    "lehetőségeket": "lehetőség",
    "lehetőségekkel": "lehetőség",
    "lehetőségekről": "lehetőség",
    "lehetőséget": "lehetőség",
    "lehetőséggel": "lehetőség",
    "lehetőségről": "lehetőség",
    "lehetőségtől": "lehetőség",
    "lehetőségéről": "lehetőség",
    "lehetőségét": "lehetőség",
    "lehetőségétől": "lehetőség",
    "lehetőségével": "lehetőség",
    "lehetőségük": "lehetőség",
    "lehetőségünk": "lehetőség",
    "lehetővé": "lehető",
    "lehiggadt": "lehiggad",
    "lehiggadtam": "lehiggadt",
    "lehordott": "lehord",
    "lehorzsolódott": "lehorzsolódik",
    "lehullott": "lehullik",
    "lehunyt": "lehuny",
    "lehunyta": "lehuny",
    "lehányatják": "lehányat",
    "lehívták": "lehív",
    "lehúzta": "lehúz",
    "lehúzzák": "lehúz",
    "lehúzódtunk": "lehúzódik",
    "lehűlt": "lehűl",
    "lehűtötte": "lehűt",
    "leiesből": "leies",
    "leiest": "leies",
    "leigazoltat": "leigazolt",
    "leigazoltatják": "leigazoltat",
    "leigázták": "leigáz",
    "leinthetik": "leinthet",
    "leit": "lei",
    "leiért": "lei",
    "leiünk": "lei",
    "lejegyzése": "lejegyzés",
    "lejegyzésére": "lejegyzés",
    "lejegyzője": "lejegyző",
    "lejtett": "lejt",
    "lejutottak": "lejutott",
    "lejárat": "lejár",
    "lejáratban": "lejárat",
    "lejáratni": "lejárat",
    "lejáratnál": "lejárat",
    "lejáratok": "lejárat",
    "lejáratott": "lejárat",
    "lejáratra": "lejárat",
    "lejárt": "lejár",
    "lejárta": "lejár",
    "lejártával": "lejárta",
    "lejátsszák": "lejátszik",
    "lejátszott": "lejátszik",
    "lejönnek": "lejön",
    "lejönni": "lejön",
    "lekaparta": "lekapar",
    "lekaparták": "lekapar",
    "lekaszabolt": "lekaszabol",
    "lekefélt": "lekefél",
    "lekentem": "lekent",
    "lekvárt": "lekvár",
    "leköpdösik": "leköpdös",
    "lekötött": "leköt",
    "lekötötte": "leköt",
    "leküldhette": "leküldhet",
    "lelankadt": "lelankad",
    "lelassult": "lelassul",
    "lelassulásához": "lelassulás",
    "lelassította": "lelassít",
    "lelegelni": "lelegel",
    "leleményességnek": "leleményesség",
    "leleménytől": "lelemény",
    "leleplezi": "leleplez",
    "leleplezik": "leleplez",
    "leleplezni": "leleplez",
    "lelepleznék": "leleplez",
    "leleplezte": "leleplez",
    "leleplezze": "leleplez",
    "leleplezésben": "leleplezés",
    "leleplezése": "leleplezés",
    "leleplezésekor": "leleplezés",
    "leleplezést": "leleplezés",
    "leleplezéstől": "leleplezés",
    "leleplezését": "leleplezés",
    "leleplezésük": "leleplezés",
    "lelepleződésének": "lelepleződés",
    "leletre": "lelet",
    "leli": "lel",
    "leljék": "lel",
    "leljétek": "lel",
    "leljük": "lel",
    "lelke": "lélek",
    "lelked": "lélek",
    "lelkedet": "lélek",
    "lelkeket": "lélek",
    "lelkekkel": "lélek",
    "lelkesedett": "lelkesedik",
    "lelkesednek": "lelkesedik",
    "lelkesedni": "lelkesedik",
    "lelkesedésfélével": "lelkesedésféle",
    "lelkesedést": "lelkesedés",
    "lelkesen": "lelkes",
    "lelkesült": "lelkesül",
    "lelket": "lélek",
    "lelkierejét": "lelkierő",
    "lelkierőre": "lelkierő",
    "lelkiismeretedért": "lelkiismeret",
    "lelkiismeretesen": "lelkiismeretes",
    "lelkiismeretre": "lelkiismeret",
    "lelkiismerettel": "lelkiismeret",
    "lelkiismerettől": "lelkiismeret",
    "lelkiismereténél": "lelkiismeret",
    "lelkipásztorok": "lelkipásztor",
    "lelkiállapota": "lelkiállapot",
    "lelkiállapotában": "lelkiállapot",
    "lelkiállapotának": "lelkiállapot",
    "lelkébe": "lélek",
    "lelkében": "lélek",
    "lelkét": "lélek",
    "lelkük": "lélek",
    "lelküket": "lélek",
    "lelkükre": "lélek",
    "lelkűségéről": "lelkűség",
    "lelohadt": "lelohad",
    "lelte": "lel",
    "leltárba": "leltár",
    "leltárban": "leltár",
    "leltárból": "leltár",
    "lelték": "lel",
    "lelógott": "lelóg",
    "lelökték": "lelök",
    "lelökött": "lelök",
    "lelökünk": "lelök",
    "lelövik": "lelő",
    "lelövésén": "lelövés",
    "lelőlek": "lelő",
    "lelőnek": "lelő",
    "lelőtte": "lelő",
    "lemaradni": "lemarad",
    "lemaradt": "lemarad",
    "lement": "lemegy",
    "lementem": "lement",
    "lemezfelvételeit": "lemezfelvétel",
    "lemezzel": "lemez",
    "lemezén": "lemez",
    "lemondanak": "lemond",
    "lemondani": "lemond",
    "lemondjon": "lemond",
    "lemondott": "lemond",
    "lemondásra": "lemondás",
    "lemondásához": "lemondás",
    "lemondását": "lemondás",
    "lemondásával": "lemondás",
    "lemondóan": "lemondó",
    "lemosni": "lemos",
    "lemosták": "lemos",
    "lemészárlása": "lemészárlás",
    "lemészárlásáról": "lemészárlás",
    "lencsék": "lencse",
    "lendületet": "lendület",
    "lendülettel": "lendület",
    "lengedezett": "lengedez",
    "lengette": "lenget",
    "lengették": "lenget",
    "lengi": "leng",
    "lenne": "lesz",
    "lenned": "lesz",
    "lennem": "lesz",
    "lenni": "lesz",
    "lennie": "lesz",
    "lenniük": "lesz",
    "lennék": "lesz",
    "lennének": "lesz",
    "lennénk": "lesz",
    "lennétek": "lesz",
    "lent": "len",
    "lenyelnek": "lenyel",
    "lenyelni": "lenyel",
    "lenyelte": "lenyel",
    "lenyomta": "lenyom",
    "lenyomták": "lenyom",
    "lenyírta": "lenyír",
    "lenyúlt": "lenyúlik",
    "lenyűgözött": "lenyűgöz",
    "lenyűgözően": "lenyűgöző",
    "lenézett": "lenéz",
    "lenézi": "lenéz",
    "lenézik": "lenéz",
    "lenézte": "lenéz",
    "leoldódott": "leoldódik",
    "leolvasott": "leolvas",
    "leopárddal": "leopárd",
    "leopárdot": "leopárd",
    "lepecsételt": "lepecsétel",
    "lepedőjük": "lepedő",
    "lepedőkkel": "lepedő",
    "lepedőt": "lepedő",
    "lepi": "lep",
    "lepkék": "lepke",
    "leplezetlenül": "leplezetlen",
    "leplezett": "leplez",
    "leplezetten": "leplezett",
    "leplezték": "leplez",
    "leplezze": "leplez",
    "leplezésében": "leplezés",
    "lepnek": "lep",
    "lepocskondiázzák": "lepocskondiáz",
    "leporolta": "leporolik",
    "leprával": "lepra",
    "lepréselt": "leprésel",
    "lepte": "lep",
    "lepusztult": "lepusztul",
    "lepusztultak": "lepusztult",
    "leragadt": "leragad",
    "lerajzolom": "lerajzol",
    "lerajzoltam": "lerajzolt",
    "lerakodott": "lerakodik",
    "lerakásánál": "lerakás",
    "lerakódott": "lerakódik",
    "lerobbant": "lerobban",
    "lerogyott": "lerogyik",
    "lerohant": "lerohan",
    "lerombolni": "lerombol",
    "lerombolta": "lerombol",
    "leromlott": "leromlik",
    "lerontja": "leront",
    "lerovom": "leró",
    "lerágják": "lerág",
    "lerágnák": "lerág",
    "lerántotta": "leránt",
    "lerántották": "leránt",
    "leráztuk": "leráz",
    "lerázták": "leráz",
    "lerítt": "lerí",
    "leróják": "leró",
    "leróni": "leró",
    "lerövidíti": "lerövidít",
    "leselkedem": "leselkedik",
    "lesett": "les",
    "lesi": "les",
    "lesik": "les",
    "lesnek": "les",
    "lesni": "les",
    "lesodort": "lesodor",
    "lesrófolhatom": "lesrófolhat",
    "leste": "les",
    "lestek": "les",
    "lestem": "les",
    "lesték": "les",
    "lestük": "les",
    "lestünk": "les",
    "leszakadt": "leszakad",
    "leszakított": "leszakít",
    "leszaladt": "leszalad",
    "leszavazott": "leszavaz",
    "leszedem": "leszed",
    "leszedetheti": "leszedethet",
    "leszednék": "leszed",
    "leszedte": "leszed",
    "leszek": "lesz",
    "leszel": "lesz",
    "leszerelik": "leszerel",
    "leszerelni": "leszerel",
    "leszerelőkkel": "leszerelő",
    "leszerelőknek": "leszerelő",
    "leszidást": "leszidás",
    "lesznek": "lesz",
    "leszokott": "leszokik",
    "leszorított": "leszorít",
    "leszorították": "leszorít",
    "lesztek": "lesz",
    "leszállnak": "leszáll",
    "leszállni": "leszáll",
    "leszálltunk": "leszállt",
    "leszállunk": "leszáll",
    "leszállítani": "leszállít",
    "leszállították": "leszállít",
    "leszállításáról": "leszállítás",
    "leszállóegységet": "leszállóegység",
    "leszállópályának": "leszállópálya",
    "leszállópályáé": "leszállópálya",
    "leszállópályáért": "leszállópálya",
    "leszámolni": "leszámol",
    "leszámítjuk": "leszámít",
    "leszóródott": "leszóródik",
    "leszögezte": "leszögez",
    "leszünk": "lesz",
    "leszűkülne": "leszűkül",
    "lesöpört": "lesöpör",
    "lesújtotta": "lesújt",
    "lesüllyedjen": "lesüllyed",
    "lesüllyedt": "lesüllyed",
    "letagadhatom": "letagadhat",
    "letagadja": "letagad",
    "letagadják": "letagad",
    "letagadni": "letagad",
    "letagadod": "letagad",
    "letagadta": "letagad",
    "letaglózta": "letaglóz",
    "letakarják": "letakar",
    "letakarította": "letakarít",
    "letanyáztak": "letanyázik",
    "letaposott": "letapos",
    "letaposottnak": "letaposott",
    "letargiájából": "letargia",
    "letarolták": "letarol",
    "letartóztatják": "letartóztat",
    "letartóztatni": "letartóztat",
    "letartóztatott": "letartóztat",
    "letartóztatottak": "letartóztatott",
    "letartóztatottakat": "letartóztatott",
    "letartóztattak": "letartóztat",
    "letartóztatták": "letartóztat",
    "letartóztatása": "letartóztatás",
    "letartóztatásba": "letartóztatás",
    "letartóztatások": "letartóztatás",
    "letartóztatásom": "letartóztatás",
    "letartóztatásról": "letartóztatás",
    "letartóztatásának": "letartóztatás",
    "letaszított": "letaszít",
    "letelepedek": "letelepedik",
    "letelepedett": "letelepedik",
    "letelt": "letelik",
    "leteltével": "letelte",
    "leterheltsége": "leterheltség",
    "letett": "letesz",
    "letette": "letesz",
    "letették": "letet",
    "letettük": "letett",
    "letiltotta": "letilt",
    "letisztítjuk": "letisztít",
    "letisztított": "letisztít",
    "letolta": "letol",
    "letorkolta": "letorkol",
    "lett": "lesz",
    "lettek": "lett",
    "lettem": "lett",
    "lettél": "lesz",
    "lettünk": "lett",
    "letudjuk": "letud",
    "letépett": "letép",
    "letépnék": "letép",
    "letépte": "letép",
    "letépték": "letép",
    "letérdelt": "letérdel",
    "letérni": "letér",
    "letértem": "letért",
    "letértünk": "letért",
    "letétese": "letétes",
    "letöltése": "letöltés",
    "letörte": "letörik",
    "letörésére": "letörés",
    "letörölgetni": "letörölget",
    "letörölni": "letöröl",
    "letűnt": "letűnik",
    "letűnőben": "letűnő",
    "leugrani": "leugrik",
    "leugrunk": "leugrik",
    "leutazását": "leutazás",
    "levagdosták": "levagdos",
    "levakarják": "levakar",
    "leve": "lé",
    "levegőbe": "levegő",
    "levegőben": "levegő",
    "levegőellátással": "levegőellátás",
    "levegőhöz": "levegő",
    "levegője": "levegő",
    "levegőn": "levegő",
    "levegőt": "levegő",
    "levegővel": "levegő",
    "levele": "levél",
    "levelei": "levél",
    "leveleik": "levél",
    "levelek": "levél",
    "leveleken": "levél",
    "leveleket": "levél",
    "levelekkel": "levél",
    "leveleként": "levél",
    "levelestül": "levél",
    "levelet": "levél",
    "leveleztek": "levelez",
    "levelezésben": "levelezés",
    "levelezőlapokat": "levelezőlap",
    "levelében": "levél",
    "leveléből": "levél",
    "levenni": "levesz",
    "leverte": "lever",
    "leverten": "levert",
    "leverték": "lever",
    "levesbe": "leves",
    "levesben": "leves",
    "levese": "leves",
    "levest": "leves",
    "leveszed": "leveszik",
    "leveszem": "leveszik",
    "levesét": "leves",
    "levetette": "levetet",
    "levetették": "levetet",
    "levetettük": "levetett",
    "levetkőzött": "levetkőzik",
    "levett": "levesz",
    "levette": "levesz",
    "levették": "levesz",
    "levetítette": "levetít",
    "levezetnie": "levezet",
    "levezette": "levezet",
    "levezetései": "levezetés",
    "levitt": "levisz",
    "levittek": "levitt",
    "levont": "levon",
    "levontak": "levont",
    "levonása": "levonás",
    "levágja": "levág",
    "levágod": "levág",
    "levágott": "levág",
    "levágtuk": "levág",
    "levágását": "levágás",
    "leválasztja": "leválaszt",
    "leválasztása": "leválasztás",
    "leválhatunk": "leválhat",
    "levált": "leválik",
    "leváltották": "levált",
    "leváltásáról": "leváltás",
    "leválók": "leváló",
    "levélben": "levél",
    "levélkéjét": "levélkéj",
    "lexikonban": "lexikon",
    "lexikonok": "lexikon",
    "lezajlanak": "lezajlik",
    "lezajlott": "lezajlik",
    "lezárják": "lezár",
    "lezárt": "lezár",
    "lezárta": "lezár",
    "lezárták": "lezár",
    "lezárult": "lezárul",
    "leágazása": "leágazás",
    "leállításának": "leállítás",
    "leállítására": "leállítás",
    "leállításáról": "leállítás",
    "leállítását": "leállítás",
    "leánnyá": "leány",
    "leánya": "leány",
    "leányai": "leány",
    "leánygyermekből": "leánygyermek",
    "leányiskolában": "leányiskola",
    "leánykák": "leányka",
    "leánynak": "leány",
    "leányok": "leány",
    "leányvállalataira": "leányvállalat",
    "leányának": "leány",
    "leányát": "leány",
    "leányává": "leány",
    "leégett": "leég",
    "leégtek": "leég",
    "leélik": "leél",
    "leélni": "leél",
    "leépíteni": "leépít",
    "leépítésében": "leépítés",
    "leépítésének": "leépítés",
    "leértékelése": "leértékelés",
    "leértékelésére": "leértékelés",
    "leérünk": "leérik",
    "leírhassa": "leírhat",
    "leírjon": "leír",
    "leírni": "leír",
    "leírt": "leír",
    "leírta": "leír",
    "leírták": "leír",
    "leírtál": "leír",
    "leírása": "leírás",
    "leírását": "leírás",
    "leömlöttek": "leömlött",
    "leöntik": "leönt",
    "leülhessen": "leülhet",
    "leülne": "leül",
    "leülni": "leül",
    "leült": "leül",
    "leültek": "leül",
    "leültetni": "leültet",
    "leültünk": "leült",
    "leülök": "leül",
    "leütötte": "leüt",
    "leütötték": "leüt",
    "libamájjal": "libamáj",
    "libapecsenyével": "libapecsenye",
    "libegtette": "libegtet",
    "liberalizmusnak": "liberalizmus",
    "liberalizmusról": "liberalizmus",
    "liberalizálják": "liberalizál",
    "liberalizálódására": "liberalizálódás",
    "liberálisak": "liberális",
    "liberálisok": "liberális",
    "liberálisokkal": "liberális",
    "libuskák": "libuska",
    "libákat": "liba",
    "libákba": "liba",
    "licitált": "licitál",
    "liftaknával": "liftakna",
    "lignitbányából": "lignitbánya",
    "ligájában": "liga",
    "ligájának": "liga",
    "lihegővé": "lihegő",
    "likviditását": "likviditás",
    "liliomok": "liliom",
    "lilában": "lila",
    "listában": "lista",
    "listáit": "lista",
    "listáján": "lista",
    "listájára": "lista",
    "listáját": "lista",
    "listákon": "lista",
    "listán": "lista",
    "listára": "lista",
    "lisztből": "liszt",
    "lisztet": "liszt",
    "literekkel": "liter",
    "literekről": "liter",
    "literjét": "liter",
    "lobban": "lob",
    "lobbant": "lobban",
    "lobbantásához": "lobbantás",
    "lobbanását": "lobbanás",
    "lobbizni": "lobbizik",
    "lobbyzók": "lobbyzó",
    "lobogtatják": "lobogtat",
    "lobogtattak": "lobogtat",
    "lobogókat": "lobogó",
    "lobogót": "lobogó",
    "logikusan": "logikus",
    "logikája": "logika",
    "logikának": "logika",
    "logikát": "logika",
    "logikátlanságát": "logikátlanság",
    "logikával": "logika",
    "lojálisan": "lojális",
    "lombjait": "lomb",
    "lombok": "lomb",
    "lopja": "lop",
    "lopkodott": "lopkod",
    "lopnak": "lop",
    "lopni": "lop",
    "lopná": "lop",
    "lopom": "lop",
    "lopott": "lop",
    "loptad": "lop",
    "loptak": "lop",
    "lopták": "lop",
    "lopással": "lopás",
    "lopást": "lopás",
    "lopásért": "lopás",
    "lopóztak": "lopóz",
    "lordok": "lord",
    "lottójátékoknál": "lottójáték",
    "lottómonopóliumot": "lottómonopólium",
    "lottóval": "lottó",
    "lova": "ló",
    "lovagiasabbá": "lovagias",
    "lovai": "ló",
    "lovasaival": "lovas",
    "lovasok": "lovas",
    "lovat": "ló",
    "luftballonszerűen": "luftballonszerű",
    "lugasból": "lugas",
    "lugasként": "lugas",
    "lugasát": "lugas",
    "lukat": "luk",
    "lustábbak": "lusta",
    "lusták": "lusta",
    "luxuskörülmények": "luxuskörülmény",
    "luxusállatokat": "luxusállat",
    "lyukadtak": "lyukadt",
    "lyukadtunk": "lyukadt",
    "lyukain": "lyuk",
    "lyukakat": "lyuk",
    "lyukakkal": "lyuk",
    "lyukakon": "lyuk",
    "lyukat": "lyuk",
    "lyukkal": "lyuk",
    "lyukon": "lyuk",
    "lyukra": "lyuk",
    "lába": "láb",
    "lábad": "láb",
    "lábadon": "láb",
    "lábadozók": "lábadozó",
    "lábadt": "lábad",
    "lábai": "láb",
    "lábaik": "láb",
    "lábaikkal": "láb",
    "lábaikon": "láb",
    "lábain": "láb",
    "lábaink": "láb",
    "lábaival": "láb",
    "lábak": "láb",
    "lábakra": "láb",
    "lábam": "láb",
    "lábamba": "láb",
    "lábammal": "láb",
    "lábamról": "láb",
    "lábasban": "lábas",
    "lábasok": "lábas",
    "lábast": "lábas",
    "lábbal": "láb",
    "lábbelik": "lábbeli",
    "lábbelit": "lábbeli",
    "lábikráiban": "lábikra",
    "lábikráján": "lábikra",
    "lábikráját": "lábikra",
    "lábon": "láb",
    "lábra": "láb",
    "lábszára": "lábszár",
    "lábszárain": "lábszár",
    "lábszárcsontjain": "lábszárcsont",
    "lábszárcsontjába": "lábszárcsont",
    "lábszárfekélye": "lábszárfekély",
    "lábszárfekélyét": "lábszárfekély",
    "lábszártekercsem": "lábszártekercs",
    "lábtörlők": "lábtörlő",
    "lábujjaid": "lábujj",
    "lábujjait": "lábujj",
    "lábujjak": "lábujj",
    "lábujjal": "lábujj",
    "lábujját": "lábujj",
    "lábuk": "láb",
    "lábukat": "láb",
    "lábukon": "láb",
    "lábukról": "láb",
    "lábunkat": "láb",
    "lábunkba": "láb",
    "lábában": "láb",
    "lábán": "láb",
    "lábáról": "láb",
    "lábát": "láb",
    "ládák": "láda",
    "ládákat": "láda",
    "ládánk": "láda",
    "lágerbe": "láger",
    "lágerben": "láger",
    "lágerek": "láger",
    "lágerekből": "láger",
    "lágernek": "láger",
    "lágert": "láger",
    "lágya": "lágy",
    "lágyabbnak": "lágy",
    "lágyan": "lágy",
    "lágynak": "lágy",
    "lágysága": "lágyság",
    "lágyékába": "lágyék",
    "lámpafényben": "lámpafény",
    "lámpagömbjei": "lámpagömb",
    "lámpalázát": "lámpaláz",
    "lámpaoszlopokat": "lámpaoszlop",
    "lámpába": "lámpa",
    "lámpáját": "lámpa",
    "lámpák": "lámpa",
    "lámpákat": "lámpa",
    "lámpákkal": "lámpa",
    "lámpát": "lámpa",
    "lámpával": "lámpa",
    "láncaiktól": "lánc",
    "lánccal": "lánc",
    "láncolt": "láncol",
    "láncon": "lánc",
    "láncot": "lánc",
    "láncreakcióra": "láncreakció",
    "láncszeme": "láncszem",
    "láncszemet": "láncszem",
    "lándzsát": "lándzsa",
    "lángban": "láng",
    "lánggal": "láng",
    "lángja": "láng",
    "lángjának": "láng",
    "lángokban": "láng",
    "lángolt": "lángol",
    "lángra": "láng",
    "lánnyal": "lány",
    "lánya": "lány",
    "lányaink": "lány",
    "lányaitokkal": "lány",
    "lányhoz": "lány",
    "lánykorából": "lánykor",
    "lánynak": "lány",
    "lánynál": "lány",
    "lányok": "lány",
    "lányokat": "lány",
    "lányokból": "lány",
    "lányokkal": "lány",
    "lányoknak": "lány",
    "lányokra": "lány",
    "lányokról": "lány",
    "lányokért": "lány",
    "lányom": "lány",
    "lányra": "lány",
    "lányról": "lány",
    "lányt": "lány",
    "lánytanítványaid": "lánytanítvány",
    "lánytesthez": "lánytest",
    "lánytól": "lány",
    "lányunkért": "lány",
    "lányára": "lány",
    "lányát": "lány",
    "lányával": "lány",
    "lármába": "lárma",
    "lármája": "lárma",
    "lármán": "lárma",
    "lármásak": "lármás",
    "lármásan": "lármás",
    "lármát": "lárma",
    "lármázott": "lármáz",
    "lásd": "lát",
    "láss": "lát",
    "lássa": "lát",
    "lássam": "lát",
    "lásson": "lát",
    "lássuk": "lát",
    "lássák": "lát",
    "lássátok": "lát",
    "láthassa": "láthat",
    "láthassanak": "láthat",
    "láthasson": "láthat",
    "láthatatlanná": "láthatatlan",
    "láthatatlanul": "láthatatlan",
    "láthatja": "láthat",
    "láthatjuk": "láthat",
    "láthatjátok": "láthat",
    "láthatnak": "láthat",
    "láthatnák": "láthat",
    "láthatnánk": "láthat",
    "láthatod": "láthat",
    "láthatom": "láthat",
    "láthatott": "láthat",
    "láthatta": "láthat",
    "láthattak": "láthat",
    "láthattuk": "láthat",
    "láthattunk": "láthat",
    "láthatták": "láthat",
    "láthatásról": "láthatás",
    "láthatóan": "látható",
    "láthatók": "látható",
    "láthatónál": "látható",
    "láthatóvá": "látható",
    "látja": "lát",
    "látjuk": "lát",
    "látják": "lát",
    "látna": "lát",
    "látnak": "lát",
    "látni": "lát",
    "látnia": "lát",
    "látnivalóira": "látnivalói",
    "látnivalókat": "látnivaló",
    "látnom": "lát",
    "látnunk": "lát",
    "látná": "lát",
    "látnád": "lát",
    "látnák": "lát",
    "látnám": "lát",
    "látnék": "lát",
    "látod": "lát",
    "látogathattak": "látogathat",
    "látogatják": "látogat",
    "látogatni": "látogat",
    "látogatta": "látogat",
    "látogattuk": "látogat",
    "látogatása": "látogatás",
    "látogatásaikon": "látogatás",
    "látogatásakor": "látogatás",
    "látogatásra": "látogatás",
    "látogatást": "látogatás",
    "látogatásukat": "látogatás",
    "látogatásunk": "látogatás",
    "látogatásán": "látogatás",
    "látogatásának": "látogatás",
    "látogatását": "látogatás",
    "látogatókat": "látogató",
    "látogatót": "látogató",
    "látok": "lát",
    "látom": "lát",
    "látomások": "látomás",
    "látomást": "látomás",
    "látott": "lát",
    "látsz": "lát",
    "látszanak": "látszik",
    "látszani": "látszik",
    "látszata": "látszat",
    "látszatot": "látszat",
    "látszatra": "látszat",
    "látszatát": "látszat",
    "látszol": "látszik",
    "látszott": "látszik",
    "látszottak": "látszott",
    "látta": "lát",
    "láttad": "lát",
    "láttak": "lát",
    "láttam": "lát",
    "láttamoztatni": "láttamoztat",
    "láttok": "lát",
    "láttuk": "lát",
    "láttunk": "lát",
    "látták": "látta",
    "láttál": "lát",
    "láttán": "látta",
    "láttára": "látta",
    "látunk": "lát",
    "látványa": "látvány",
    "látványon": "látvány",
    "látványosan": "látványos",
    "látványt": "látvány",
    "látványát": "látvány",
    "látványától": "látvány",
    "látványával": "látvány",
    "látása": "látás",
    "látásból": "látás",
    "látásom": "látás",
    "látásra": "látás",
    "látást": "látás",
    "látásától": "látás",
    "látóképességét": "látóképesség",
    "látóköréből": "látókör",
    "látókörén": "látókör",
    "látókörét": "látókör",
    "látómezejébe": "látómező",
    "látómezején": "látómező",
    "látómezőn": "látómező",
    "látószögébe": "látószög",
    "lázadnak": "lázad",
    "lázadni": "lázad",
    "lázadozott": "lázadozik",
    "lázadozásaikról": "lázadozás",
    "lázadtak": "lázadt",
    "lázadása": "lázadás",
    "lázadásra": "lázadás",
    "lázadást": "lázadás",
    "lázadásának": "lázadás",
    "lázadását": "lázadás",
    "lázadók": "lázadó",
    "lázadókhoz": "lázadó",
    "lázasan": "lázas",
    "lázassága": "lázasság",
    "lázban": "láz",
    "lázzá": "láz",
    "lázálomképtől": "lázálomkép",
    "lébe": "lé",
    "lében": "lé",
    "léceit": "léc",
    "léghuzatokról": "léghuzat",
    "légiesen": "légies",
    "légitámadások": "légitámadás",
    "légitársasághoz": "légitársaság",
    "légitársaságok": "légitársaság",
    "légkörbe": "légkör",
    "légkörben": "légkör",
    "légkörből": "légkör",
    "légköre": "légkör",
    "légkörébe": "légkör",
    "légkörében": "légkör",
    "légkörét": "légkör",
    "légnyomásban": "légnyomás",
    "légpuskát": "légpuska",
    "légrétegekre": "légréteg",
    "légszennyezéséért": "légszennyezés",
    "légterünkből": "légtér",
    "légtömegek": "légtömeg",
    "légy": "van",
    "légáram": "légár",
    "légáramlattal": "légáramlat",
    "léhaságomban": "léhaság",
    "lélegeztek": "lélegezik",
    "lélegezz": "lélegezik",
    "lélegzete": "lélegzet",
    "lélegzetet": "lélegzet",
    "lélegzethez": "lélegzet",
    "lélegzethezjutásért": "lélegzethezjutás",
    "lélegzett": "lélegzik",
    "lélegzettől": "lélegzett",
    "lélegzetvétele": "lélegzetvétel",
    "lélegzetéből": "lélegzet",
    "lélegzetét": "lélegzet",
    "lélegzetével": "lélegzet",
    "lélekben": "lélek",
    "lélekbúvárok": "lélekbúvár",
    "lélekkel": "lélek",
    "léleknek": "lélek",
    "lélekre": "lélek",
    "lélekszámarányosan": "lélekszámarányos",
    "lélektant": "lélektan",
    "lélektelenné": "lélektelen",
    "lélektelenül": "lélektelen",
    "lényege": "lényeg",
    "lényegesek": "lényeges",
    "lényegesen": "lényeges",
    "lényegesnek": "lényeges",
    "lényeget": "lényeg",
    "lényegnél": "lényeg",
    "lényegtelenek": "lényegtelen",
    "lényegtelennek": "lényegtelen",
    "lényegében": "lényeg",
    "lényegét": "lényeg",
    "lényei": "lény",
    "lények": "lény",
    "lényekből": "lény",
    "lényeken": "lény",
    "lényeket": "lény",
    "lényként": "lény",
    "lénynek": "lény",
    "lényre": "lény",
    "lényük": "lény",
    "lépcsőben": "lépcső",
    "lépcsőházba": "lépcsőház",
    "lépcsőházban": "lépcsőház",
    "lépcsőházból": "lépcsőház",
    "lépcsői": "lépcső",
    "lépcsőn": "lépcső",
    "lépcsőre": "lépcsőr",
    "lépcsőtől": "lépcső",
    "lépdelt": "lépdel",
    "lépek": "lép",
    "lépett": "lép",
    "léphessen": "léphet",
    "léphetett": "léphet",
    "lépheti": "léphet",
    "léphetne": "léphet",
    "léphetünk": "léphét",
    "lépj": "lép",
    "lépjen": "lép",
    "lépjenek": "lépjen",
    "lépjünk": "lép",
    "lépkedett": "lépked",
    "lépkedni": "lépked",
    "lépkedtünk": "lépked",
    "lépne": "lép",
    "lépnek": "lép",
    "lépni": "lép",
    "lépnie": "lép",
    "lépre": "lép",
    "léptei": "lépt",
    "léptek": "lépt",
    "léptekkel": "lépt",
    "léptem": "lépt",
    "léptetni": "léptet",
    "lépték": "lépte",
    "léptünk": "lépt",
    "lépésben": "lépés",
    "lépése": "lépés",
    "lépései": "lépés",
    "lépéseinek": "lépés",
    "lépéseit": "lépés",
    "lépéseivel": "lépés",
    "lépések": "lépés",
    "lépéseket": "lépés",
    "lépésekkel": "lépés",
    "lépésekor": "lépés",
    "lépésként": "lépés",
    "lépésnél": "lépés",
    "lépésre": "lépés",
    "lépéssel": "lépés",
    "lépést": "lépés",
    "lépését": "lépés",
    "lépésével": "lépés",
    "lépünk": "lép",
    "lét": "lé",
    "létben": "lét",
    "létbizonytalanságnak": "létbizonytalanság",
    "létesítenek": "létesít",
    "létesített": "létesít",
    "létesítették": "létesítet",
    "létesítményei": "létesítmény",
    "létesítményeit": "létesítmény",
    "létesítmények": "létesítmény",
    "létesítményeket": "létesítmény",
    "létesítményt": "létesítmény",
    "létesítsen": "létesít",
    "létesítsünk": "létesít",
    "létesítésére": "létesítés",
    "létesítéséről": "létesítés",
    "létezel": "létezik",
    "létezem": "létezik",
    "létezett": "létezik",
    "létezhessék": "létezhet",
    "létezhetett": "létezhet",
    "létezik": "létez",
    "léteznek": "létezik",
    "létezni": "létezik",
    "léteznének": "létezik",
    "léteztek": "létezik",
    "léteztél": "létezik",
    "létezzék": "létezik",
    "létezésből": "létezés",
    "létezésjogát": "létezésjog",
    "létezésében": "létezés",
    "létezéséről": "létezés",
    "létezését": "létezés",
    "létezésük": "létezés",
    "létformái": "létformá",
    "létjogosultsága": "létjogosultság",
    "létnek": "lét",
    "létre": "lét",
    "létrehozni": "létrehoz",
    "létrehozniuk": "létrehoz",
    "létrehozott": "létrehoz",
    "létrehozta": "létrehoz",
    "létrehozták": "létrehoz",
    "létrehozza": "létrehoz",
    "létrehozzanak": "létrehoz",
    "létrehozzák": "létrehoz",
    "létrehozása": "létrehozás",
    "létrehozásában": "létrehozás",
    "létrehozásának": "létrehozás",
    "létrehozásáról": "létrehozás",
    "létrehozását": "létrehozás",
    "létrejöhessen": "létrejöhet",
    "létrejöjjön": "létrejön",
    "létrejönnek": "létrejön",
    "létrejött": "létrejön",
    "létrejöttek": "létrejön",
    "létrejöttének": "létrejötte",
    "létrákon": "létrák",
    "létrán": "létra",
    "létszemléletét": "létszemlélet",
    "létszáma": "létszám",
    "létszámba": "létszám",
    "létszámban": "létszám",
    "létszámhiánnyal": "létszámhiány",
    "létszámmal": "létszám",
    "létszámot": "létszám",
    "létszámuk": "létszám",
    "létszámának": "létszám",
    "létszámát": "létszám",
    "létszámúak": "létszámú",
    "létszükséglete": "létszükséglet",
    "létéhez": "lét",
    "létére": "lét",
    "létét": "lét",
    "létük": "lét",
    "lévők": "lévő",
    "lévőket": "lévő",
    "lévővel": "lévő",
    "lévőé": "lévő",
    "lézengtünk": "lézeng",
    "líbiaiak": "líbiai",
    "lírikusnak": "lírikus",
    "lízingcégek": "lízingcég",
    "lízingelnének": "lízingel",
    "lízingelt": "lízingel",
    "lízingelőnek": "lízingelő",
    "lízingelőtől": "lízingelő",
    "lízinglehetőséget": "lízinglehetőség",
    "lízingpiacon": "lízingpiac",
    "lízingtársaságnak": "lízingtársaság",
    "lízingügyleteit": "lízingügylet",
    "lócán": "lóca",
    "lódenkabátok": "lódenkabát",
    "lódult": "lódul",
    "lódította": "lódít",
    "lógott": "lóg",
    "lógóban": "lógó",
    "lóháton": "lóhát",
    "lók": "ló",
    "lóra": "ló",
    "lóról": "ló",
    "lószerszámok": "lószerszám",
    "lóval": "ló",
    "lökdöste": "lökdös",
    "lökdösődnek": "lökdösődik",
    "lökdösődött": "lökdösődik",
    "lökik": "lök",
    "löknek": "lök",
    "lökte": "lök",
    "löktek": "lök",
    "lökték": "lök",
    "lökéssel": "lökés",
    "lökést": "lökés",
    "lökött": "lök",
    "löttyedtet": "löttyedt",
    "lövedékekkel": "lövedék",
    "lövedéket": "lövedék",
    "löveti": "lövet",
    "lövik": "lő",
    "lövöldözésre": "lövöldözés",
    "lüktetett": "lüktet",
    "lüktetését": "lüktetés",
    "lődörgést": "lődörgés",
    "lődözni": "lődöz",
    "lőfegyvert": "lőfegyver",
    "lőhetik": "lőhet",
    "lőjetek": "lő",
    "lőjük": "lő",
    "lőnek": "lő",
    "lőni": "lő",
    "lőrése": "lőrés",
    "lőszerrel": "lőszer",
    "lőszert": "lőszer",
    "lőtt": "lő",
    "lőtte": "lő",
    "lőttek": "lőtt",
    "lőtték": "lő",
    "macerálják": "macerál",
    "maceráltak": "macerált",
    "maceráltuk": "macerál",
    "macerálták": "macerál",
    "macskamozdulatokkal": "macskamozdulat",
    "macskája": "macska",
    "macskájukkal": "macska",
    "macskák": "macska",
    "macskát": "macska",
    "madarak": "madár",
    "madarasról": "madaras",
    "madarunk": "madár",
    "madzagokkal": "madzag",
    "madárhangjával": "madárhang",
    "maffiózók": "maffiózó",
    "magabiztosságot": "magabiztosság",
    "magad": "maga",
    "magadat": "maga",
    "magadban": "maga",
    "magadból": "maga",
    "magaddal": "maga",
    "magadnak": "maga",
    "magalakulását": "magalakulás",
    "magam": "maga",
    "magamat": "maga",
    "magamnak": "maga",
    "magamét": "maga",
    "magasabb": "magas",
    "magasabban": "magas",
    "magasabbra": "magas",
    "magasak": "magas",
    "magasan": "magas",
    "magasba": "magas",
    "magaslataira": "magaslat",
    "magaslatról": "magaslat",
    "magasnak": "magas",
    "magasra": "magas",
    "magasságban": "magasság",
    "magasságig": "magasság",
    "magasságnak": "magasság",
    "magasságában": "magasság",
    "magasztalta": "magasztal",
    "magasztosabbnak": "magasztos",
    "magasába": "magas",
    "magatartása": "magatartás",
    "magatartások": "magatartás",
    "magatartást": "magatartás",
    "magatartásukat": "magatartás",
    "magatartásában": "magatartás",
    "magatartását": "magatartás",
    "magatokat": "maga",
    "maghatottan": "maghatott",
    "magjuk": "mag",
    "magkocát": "magkoca",
    "magnak": "mag",
    "magnéziumfények": "magnéziumfény",
    "magnókazettánál": "magnókazetta",
    "magok": "mag",
    "magtárba": "magtár",
    "magtárban": "magtár",
    "magtárnál": "magtár",
    "magtárport": "magtárpor",
    "maguk": "maga",
    "magukat": "maga",
    "magukba": "maga",
    "magukban": "maga",
    "magukhoz": "maga",
    "magukkal": "maga",
    "maguknak": "maga",
    "maguknál": "maga",
    "magukon": "maga",
    "magukra": "maga",
    "magukról": "maga",
    "maguktól": "maga",
    "magukéhoz": "maga",
    "magukéit": "maga",
    "magukénak": "maga",
    "magukét": "maga",
    "magukévá": "maga",
    "magunk": "maga",
    "magunkat": "maga",
    "magunkhoz": "maga",
    "magunkkal": "maga",
    "magunknak": "maga",
    "magunkra": "maga",
    "magunkról": "maga",
    "magyarabb": "magyar",
    "magyarban": "magyar",
    "magyarból": "magyar",
    "magyarnak": "magyar",
    "magyarnál": "magyar",
    "magyarok": "magyar",
    "magyarokat": "magyar",
    "magyarokból": "magyar",
    "magyarokká": "magyar",
    "magyaroknak": "magyar",
    "magyarokon": "magyar",
    "magyarokra": "magyar",
    "magyarországiak": "magyarországi",
    "magyarországit": "magyarországi",
    "magyarral": "magyar",
    "magyarságképemet": "magyarságkép",
    "magyarságot": "magyarság",
    "magyart": "magyar",
    "magyarul": "magyar",
    "magyarázatba": "magyarázat",
    "magyarázatok": "magyarázat",
    "magyarázatot": "magyarázat",
    "magyarázatra": "magyarázat",
    "magyarázattal": "magyarázat",
    "magyarázattól": "magyarázat",
    "magyarázatára": "magyarázat",
    "magyarázatát": "magyarázat",
    "magyarázkodásra": "magyarázkodás",
    "magyarázni": "magyaráz",
    "magyarázom": "magyaráz",
    "magyarázott": "magyaráz",
    "magyarázta": "magyaráz",
    "magyaráztam": "magyaráz",
    "magyaráztuk": "magyaráz",
    "magyarázták": "magyaráz",
    "magyarázza": "magyaráz",
    "magyarázzák": "magyaráz",
    "magzatokat": "magzat",
    "magzatokon": "magzat",
    "magzatukról": "magzat",
    "magzott": "magzik",
    "magába": "maga",
    "magában": "maga",
    "magából": "maga",
    "magához": "maga",
    "magán": "maga",
    "magán-teleképkészülékbe": "magán-teleképkészülék",
    "magának": "magán",
    "magánbefektetők": "magánbefektető",
    "magánbetegeit": "magánbeteg",
    "magánbetegek": "magánbeteg",
    "magángazdaságban": "magángazdaság",
    "magángyűjteményként": "magángyűjtemény",
    "magángépkocsija": "magángépkocsi",
    "magánhelyen": "magánhely",
    "magánmegnyilatkozásokban": "magánmegnyilatkozások",
    "magánosították": "magánosít",
    "magánosításból": "magánosítás",
    "magánosításánál": "magánosítás",
    "magánszektorban": "magánszektor",
    "magánszemélyek": "magánszemély",
    "magánszemélyt": "magánszemély",
    "magánszférába": "magánszférá",
    "magánszorgalomból": "magánszorgalom",
    "magántulajdonban": "magántulajdon",
    "magánya": "magány",
    "magányban": "magány",
    "magányosan": "magányos",
    "magányra": "magány",
    "magányában": "magány",
    "magányát": "magány",
    "magánzárkában": "magánzárka",
    "magánzárkával": "magánzárka",
    "magánéletemmel": "magánélet",
    "magánéletnek": "magánélet",
    "magánéletét": "magánélet",
    "magánépítkezésekre": "magánépítkezés",
    "magánúton": "magánút",
    "magánügyként": "magánügy",
    "magánügyéből": "magánügy",
    "magára": "maga",
    "magáról": "maga",
    "magát": "maga",
    "magától": "maga",
    "magával": "maga",
    "magáé": "maga",
    "magáénak": "maga",
    "magáért": "maga",
    "magáét": "maga",
    "mahagóniággyal": "mahagóniágy",
    "mahagóniágyra": "mahagóniágy",
    "mainál": "mai",
    "majmokkal": "majom",
    "majomszerűvé": "majomszerű",
    "majorosok": "majoros",
    "makacskodott": "makacskodik",
    "makacssága": "makacsság",
    "makacssággal": "makacsság",
    "makacsságáról": "makacsság",
    "makacsul": "makacs",
    "maketteket": "makett",
    "malacai": "malac",
    "malacok": "malac",
    "malacokat": "malac",
    "malacoknak": "malac",
    "malacokról": "malac",
    "malacot": "malac",
    "malomba": "malom",
    "malomban": "malom",
    "malomból": "malom",
    "maláriafészekben": "maláriafészek",
    "maláriám": "malária",
    "maláriásak": "maláriás",
    "mamaligát": "mamaliga",
    "mamaligával": "mamaliga",
    "mamutokéval": "mamut",
    "mamáját": "mama",
    "mancsa": "mancs",
    "mancsaival": "mancs",
    "mancsában": "mancs",
    "mandátumot": "mandátum",
    "manipulációk": "manipuláció",
    "manőverei": "manőver",
    "manőverrel": "manőver",
    "manővert": "manőver",
    "maradandósága": "maradandóság",
    "maradhasson": "maradhat",
    "maradhatna": "maradhat",
    "maradhatott": "maradhat",
    "maradj": "marad",
    "maradjanak": "marad",
    "maradjon": "marad",
    "maradjunk": "marad",
    "maradjál": "marad",
    "maradna": "marad",
    "maradnak": "marad",
    "maradni": "marad",
    "maradniuk": "marad",
    "maradnod": "marad",
    "maradnának": "marad",
    "maradnánk": "marad",
    "maradok": "marad",
    "maradottak": "maradott",
    "maradsz": "marad",
    "maradt": "marad",
    "maradtak": "maradt",
    "maradtam": "maradt",
    "maradtok": "marad",
    "maradtunk": "maradt",
    "maradunk": "maradu",
    "maradványa": "maradvány",
    "maradványai": "maradvány",
    "maradványait": "maradvány",
    "maradéktalanul": "maradéktalan",
    "maradók": "maradó",
    "marakodjunk": "marakodik",
    "marakodtak": "marakodik",
    "marhabőrből": "marhabőr",
    "marhacsapásra": "marhacsapás",
    "marhacsordákból": "marhacsorda",
    "marhaeledelt": "marhaeledel",
    "marina": "marín",
    "marja": "mar",
    "marjai": "mar",
    "marka": "marok",
    "marketingre": "marketing",
    "markolászta": "markolászik",
    "markosnak": "markos",
    "markosok": "markos",
    "markost": "markos",
    "markosunk": "markos",
    "markosát": "markos",
    "markot": "marok",
    "markába": "marok",
    "markában": "marok",
    "markának": "marok",
    "markánsan": "markáns",
    "markával": "marok",
    "marokkóiak": "marokkói",
    "maroknyian": "maroknyi",
    "marokszedőikkel": "marokszedő",
    "marokszedője": "marokszedő",
    "marokszedőjük": "marokszedő",
    "marokszedők": "marokszedő",
    "marokszedőkhöz": "marokszedő",
    "marokszedőknek": "marokszedő",
    "marokszedőnek": "marokszedő",
    "marokszedőt": "marokszedő",
    "marokszámra": "marokszám",
    "marsallját": "marsall",
    "marsallnak": "marsall",
    "marta": "mar",
    "martalócait": "martalóc",
    "martina": "martín",
    "marton": "mart",
    "marxistának": "marxista",
    "marékra": "marék",
    "marékszedő-bért": "marékszedő-bér",
    "marékszedője": "marékszedő",
    "marékszedők": "marékszedő",
    "marékszedőnek": "marékszedő",
    "marékszedőt": "marékszedő",
    "marékszedővel": "marékszedő",
    "masinisztákat": "masiniszta",
    "masinisztát": "masiniszta",
    "masiná-nak": "masina",
    "maszkot": "maszk",
    "masztodonokéval": "masztodon",
    "matematikusaink": "matematikus",
    "matracokat": "matrac",
    "mattot": "matt",
    "maximumot": "maximum",
    "maximumának": "maximum",
    "maximálisan": "maximális",
    "meccsből": "meccs",
    "meccsek": "meccs",
    "mechanizmust": "mechanizmus",
    "mechanizmusának": "mechanizmus",
    "mechanizmusát": "mechanizmus",
    "mecsetben": "mecset",
    "mecsetet": "mecset",
    "medaliont": "medalion",
    "medencéjét": "medence",
    "medencéket": "medence",
    "medrekbe": "meder",
    "medret": "meder",
    "medvebundákat": "medvebunda",
    "medvék": "medve",
    "meg-meglepték": "meg-meglep",
    "meg-megreccsent": "meg-megreccsen",
    "megadjuk": "megad",
    "megadják": "megad",
    "megadnak": "megad",
    "megadni": "megad",
    "megadod": "megad",
    "megadom": "megad",
    "megadott": "megad",
    "megadta": "megad",
    "megadtad": "megad",
    "megadásra": "megadás",
    "megadóan": "megadó",
    "megajándékozni": "megajándékoz",
    "megajándékozta": "megajándékoz",
    "megakadhatnak": "megakadhat",
    "megakadt": "megakad",
    "megakadályozni": "megakadályoz",
    "megakadályozza": "megakadályoz",
    "megakadályozzam": "megakadályoz",
    "megakadályozzák": "megakadályoz",
    "megakadályozásának": "megakadályozás",
    "megakadályozására": "megakadályozás",
    "megakasztották": "megakaszt",
    "megalakult": "megalakul",
    "megalakulása": "megalakulás",
    "megalakuláskor": "megalakulás",
    "megalakulásáért": "megalakulás",
    "megalakítsanak": "megalakít",
    "megalapozatlannak": "megalapozatlan",
    "megalapozott": "megalapoz",
    "megalapozottnak": "megalapozott",
    "megalapozással": "megalapozás",
    "megalapítják": "megalapít",
    "megalapítója": "megalapító",
    "megalkotásáig": "megalkotás",
    "megalkotására": "megalkotás",
    "megalkotását": "megalkotás",
    "megalkudni": "megalkuszik",
    "megalkuvást": "megalkuvás",
    "megalázkodni": "megalázkodik",
    "megalázkodással": "megalázkodás",
    "megalázottnak": "megalázott",
    "megaláztatása": "megaláztatás",
    "megaláztatásba": "megaláztatás",
    "megaláztatást": "megaláztatás",
    "megaláztatástól": "megaláztatás",
    "megalázzanak": "megaláz",
    "megalázzák": "megaláz",
    "megavasodott": "megavasodik",
    "megbabonázottan": "megbabonázott",
    "megbarnult": "megbarnul",
    "megbecsülendők": "megbecsülendő",
    "megbecsülik": "megbecsül",
    "megbecsülni": "megbecsül",
    "megbeszélni": "megbeszél",
    "megbeszélt": "megbeszél",
    "megbeszéltek": "megbeszélt",
    "megbeszéltük": "megbeszél",
    "megbeszélése": "megbeszélés",
    "megbeszélések": "megbeszélés",
    "megbeszéléseken": "megbeszélés",
    "megbeszéléseket": "megbeszélés",
    "megbeszélésen": "megbeszélés",
    "megbeszélésre": "megbeszélés",
    "megbeszéléssel": "megbeszélés",
    "megbeszélést": "megbeszélés",
    "megbeszélésükön": "megbeszélés",
    "megbiccentették": "megbiccentet",
    "megbizonyosodjék": "megbizonyosodik",
    "megbizonyosodott": "megbizonyosodik",
    "megbocsátani": "megbocsát",
    "megbocsátja": "megbocsát",
    "megbocsátják": "megbocsát",
    "megbocsátottak": "megbocsátott",
    "megbocsátották": "megbocsát",
    "megbocsátással": "megbocsátás",
    "megbocsátóan": "megbocsátó",
    "megbocsátón": "megbocsátó",
    "megbolondítja": "megbolondít",
    "megbolygassák": "megbolygat",
    "megbomlott": "megbomlik",
    "megbontani": "megbont",
    "megbontja": "megbont",
    "megborotválkozott": "megborotválkozik",
    "megborzongott": "megborzong",
    "megbotlott": "megbotlik",
    "megbotránkozással": "megbotránkozás",
    "megbukhatnak": "megbukhat",
    "megbukott": "megbukik",
    "megbuktatják": "megbuktat",
    "megbuktatnak": "megbuktat",
    "megbuktatni": "megbuktat",
    "megbuktál": "megbukik",
    "megbánásukra": "megbánás",
    "megbékélésről": "megbékélés",
    "megbékélést": "megbékélés",
    "megbékíteni": "megbékít",
    "megbékíttetést": "megbékíttetés",
    "megbélyegezte": "megbélyegez",
    "megbélyegzésévé": "megbélyegzésév",
    "megbénult": "megbénul",
    "megbénulásához": "megbénulás",
    "megbénítják": "megbénít",
    "megbénította": "megbénít",
    "megbírságolt": "megbírságol",
    "megbízatásokkal": "megbízatás",
    "megbízatásomat": "megbízatás",
    "megbízatását": "megbízatás",
    "megbízhatóan": "megbízható",
    "megbízhatóbb": "megbízható",
    "megbízhatóknak": "megbízható",
    "megbízhatóságot": "megbízhatóság",
    "megbízott": "megbízik",
    "megbízottai": "megbízott",
    "megbízottak": "megbízott",
    "megbízottja": "megbízott",
    "megbízottjára": "megbízott",
    "megbízottságot": "megbízottság",
    "megbízták": "megbízik",
    "megbízásából": "megbízás",
    "megbüntessétek": "megbüntet",
    "megbüntessük": "megbüntet",
    "megcibált": "megcibál",
    "megcibálta": "megcibál",
    "megcirógatta": "megcirógat",
    "megcsaltak": "megcsalt",
    "megcsalták": "megcsal",
    "megcsapta": "megcsap",
    "megcsiklandozta": "megcsiklandoz",
    "megcsinálni": "megcsinál",
    "megcsinálod": "megcsinál",
    "megcsinált": "megcsinál",
    "megcsináltattuk": "megcsináltat",
    "megcsinálták": "megcsinál",
    "megcsodálni": "megcsodál",
    "megcsodálása": "megcsodálás",
    "megcsonkíthatták": "megcsonkíthat",
    "megcsontosodott": "megcsontosodik",
    "megcsókolni": "megcsókol",
    "megcsókolta": "megcsókol",
    "megcsörrentek": "megcsörrent",
    "megcsörrentette": "megcsörrent",
    "megcsúfolt": "megcsúfol",
    "megcáfolják": "megcáfol",
    "megcáfolni": "megcáfol",
    "megcáfolta": "megcáfol",
    "megcáfolták": "megcáfol",
    "megcédulázott": "megcéduláz",
    "megcímzett": "megcímez",
    "megdagadt": "megdagad",
    "megdermednek": "megdermed",
    "megdermedt": "megdermed",
    "megdermedtek": "megdermedt",
    "megdobbant": "megdobban",
    "megdobálják": "megdobál",
    "megdrágult": "megdrágul",
    "megduplázza": "megdupláz",
    "megduzzasztja": "megduzzaszt",
    "megdézsmálták": "megdézsmál",
    "megdöbbent": "megdöbben",
    "megdöbbentette": "megdöbbent",
    "megdöbbentően": "megdöbbentő",
    "megdöbbenéssel": "megdöbbenés",
    "megdöglött": "megdöglik",
    "megdöglöttek": "megdöglött",
    "megdöntése": "megdöntés",
    "megdöntésére": "megdöntés",
    "megdöntötte": "megdönt",
    "megdöntötték": "megdönt",
    "megdörzsölte": "megdörzsöl",
    "megegyezett": "megegyez",
    "megegyezik": "megegyez",
    "megegyezne": "megegyez",
    "megegyeznek": "megegyez",
    "megegyezni": "megegyez",
    "megegyeznie": "megegyez",
    "megegyezniük": "megegyez",
    "megegyeznénk": "megegyez",
    "megegyeztek": "megegyez",
    "megegyeztünk": "megegyez",
    "megegyezésnek": "megegyezés",
    "megegyezésre": "megegyezés",
    "megegyezést": "megegyezés",
    "megegyezésükkel": "megegyezés",
    "megehetnek": "megehet",
    "megelégednie": "megelégedik",
    "megelégedtek": "megelégedik",
    "megelégedéssel": "megelégedés",
    "megelőlegezi": "megelőlegez",
    "megelőlegezése": "megelőlegezés",
    "megelőzi": "megelőz",
    "megelőznie": "megelőz",
    "megelőzniük": "megelőz",
    "megelőzte": "megelőz",
    "megelőzze": "megelőz",
    "megelőzően": "megelőző",
    "megemeli": "megemel",
    "megemelkedhetnek": "megemelkedhet",
    "megemelni": "megemel",
    "megemelt": "megemel",
    "megemelte": "megemel",
    "megemelésével": "megemelés",
    "megemlegetik": "megemleget",
    "megemlékezni": "megemlékezik",
    "megemlíteni": "megemlít",
    "megemlítette": "megemlít",
    "megemlítik": "megemlít",
    "megemészthetetlenül": "megemészthetetlen",
    "megemészti": "megemészt",
    "megengeded": "megenged",
    "megengedi": "megenged",
    "megengedjen": "megenged",
    "megengedni": "megenged",
    "megengedte": "megenged",
    "megengedték": "megenged",
    "megenni": "megeszik",
    "megenyhült": "megenyhül",
    "megereszkedett": "megereszkedik",
    "megeresztik": "megereszt",
    "megerőltetést": "megerőltetés",
    "megerőltetésére": "megerőltetés",
    "megerősítené": "megerősít",
    "megerősített": "megerősít",
    "megerősítette": "megerősít",
    "megerősítettem": "megerősített",
    "megerősítették": "megerősítet",
    "megerősítettük": "megerősített",
    "megerősíti": "megerősít",
    "megerősítik": "megerősít",
    "megerősítésében": "megerősítés",
    "megerősítésére": "megerősítés",
    "megerősítését": "megerősítés",
    "megerősödik": "megerősöd",
    "megerősödése": "megerősödés",
    "megerősödött": "megerősödik",
    "megesett": "megesik",
    "megesküdnek": "megesküszik",
    "megeszik": "megesz",
    "megeteti": "megetet",
    "megettek": "megeszik",
    "megettük": "megeszik",
    "megettünk": "megeszik",
    "megevett": "megeszik",
    "megfagyasztott": "megfagyaszt",
    "megfagyott": "megfagy",
    "megfehéredett": "megfehéredik",
    "megfejteni": "megfejt",
    "megfejtette": "megfejt",
    "megfejtést": "megfejtés",
    "megfejtésére": "megfejtés",
    "megfeketedett": "megfeketedik",
    "megfeledkezel": "megfeledkezik",
    "megfeledkezett": "megfeledkezik",
    "megfeledkezni": "megfeledkezik",
    "megfeledkezniük": "megfeledkezik",
    "megfeledkeztek": "megfeledkezik",
    "megfelelne": "megfelel",
    "megfelelnek": "megfelel",
    "megfelelni": "megfelel",
    "megfelelt": "megfelel",
    "megfeleltünk": "megfelelt",
    "megfelelőbb": "megfelelő",
    "megfelelőbbnek": "megfelelő",
    "megfelelően": "megfelelő",
    "megfelelőnek": "megfelelő",
    "megfenik": "megfen",
    "megfenyegetett": "megfenyeget",
    "megfenyegetik": "megfenyeget",
    "megfertőzhette": "megfertőzhet",
    "megfertőzte": "megfertőz",
    "megfertőzték": "megfertőz",
    "megfesteni": "megfest",
    "megfestette": "megfest",
    "megfigyelheti": "megfigyelhet",
    "megfigyelhetik": "megfigyelhet",
    "megfigyelik": "megfigyel",
    "megfigyelje": "megfigyel",
    "megfigyelni": "megfigyel",
    "megfigyelte": "megfigyel",
    "megfigyeltek": "megfigyelt",
    "megfigyelése": "megfigyelés",
    "megfigyeléseire": "megfigyelés",
    "megfigyelések": "megfigyelés",
    "megfigyelésére": "megfigyelés",
    "megfigyelők": "megfigyelő",
    "megfigyelőket": "megfigyelő",
    "megfizetni": "megfizet",
    "megfizetnie": "megfizet",
    "megfizettesse": "megfizettes",
    "megfizetését": "megfizetés",
    "megfizetünk": "megfizet",
    "megfogadta": "megfogad",
    "megfogadták": "megfogad",
    "megfogalmazni": "megfogalmaz",
    "megfogalmazott": "megfogalmaz",
    "megfogalmazták": "megfogalmaz",
    "megfogalmazza": "megfogalmaz",
    "megfogalmazásán": "megfogalmazás",
    "megfogalmazódott": "megfogalmazódik",
    "megfoghatónak": "megfogható",
    "megfogott": "megfog",
    "megfogta": "megfog",
    "megfogtuk": "megfog",
    "megfontolandónak": "megfontolandó",
    "megfontolt": "megfontol",
    "megfontoltan": "megfontolt",
    "megfontolások": "megfontolás",
    "megfordulna": "megfordul",
    "megfordult": "megfordul",
    "megfordultam": "megfordult",
    "megfordítani": "megfordít",
    "megforgatni": "megforgat",
    "megforgatott": "megforgat",
    "megforgatta": "megforgat",
    "megforgattam": "megforgat",
    "megformálni": "megformál",
    "megformálása": "megformálás",
    "megfossza": "megfoszt",
    "megfosszák": "megfoszt",
    "megfosztja": "megfoszt",
    "megfosztják": "megfoszt",
    "megfosztott": "megfoszt",
    "megfosztotta": "megfoszt",
    "megfosztották": "megfoszt",
    "megfulladtak": "megfulladt",
    "megfáradt": "megfárad",
    "megfázástól": "megfázás",
    "megfékezni": "megfékez",
    "megfélemlítették": "megfélemlítet",
    "megfért": "megfér",
    "megfülledt": "megfülled",
    "megfürösztötték": "megfüröszt",
    "megfőtt": "megfő",
    "megfőzitek": "megfőz",
    "megfőznek": "megfőz",
    "megfőzte": "megfőz",
    "megfőzze": "megfőz",
    "megfőzésig": "megfőzés",
    "megfőzött": "megfőz",
    "meggondolatlanul": "meggondolatlan",
    "meggondoljuk": "meggondol",
    "meggondolom": "meggondol",
    "meggondolták": "meggondol",
    "meggyaláztak": "meggyaláz",
    "meggyengíteni": "meggyengít",
    "meggyilkolni": "meggyilkol",
    "meggyilkolónál": "meggyilkoló",
    "meggyorsítjuk": "meggyorsít",
    "meggyorsítását": "meggyorsítás",
    "meggyérült": "meggyérül",
    "meggyógyulhass": "meggyógyulhat",
    "meggyógyulni": "meggyógyul",
    "meggyógyítottam": "meggyógyított",
    "meggyógyítsunk": "meggyógyít",
    "meggyújtott": "meggyújt",
    "meggyújtotta": "meggyújt",
    "meggyújtották": "meggyújt",
    "meggyőzni": "meggyőz",
    "meggyőznöm": "meggyőz",
    "meggyőzték": "meggyőz",
    "meggyőzöd": "meggyőz",
    "meggyőződhetett": "meggyőződhet",
    "meggyőződhetnek": "meggyőződhet",
    "meggyőződhettem": "meggyőződhet",
    "meggyőződjék": "meggyőződik",
    "meggyőződni": "meggyőződik",
    "meggyőződtem": "meggyőződik",
    "meggyőződtünk": "meggyőződik",
    "meggyőződésből": "meggyőződés",
    "meggyőződése": "meggyőződés",
    "meggyőződéseitől": "meggyőződés",
    "meggyőződéssel": "meggyőződés",
    "meggyőződést": "meggyőződés",
    "meggyőződését": "meggyőződés",
    "meggyőződésük": "meggyőződés",
    "meggyőzőek": "meggyőző",
    "meggyőzően": "meggyőző",
    "meggyűlölni": "meggyűlöl",
    "meggátolja": "meggátol",
    "meggörnyedt": "meggörnyed",
    "meghagyni": "meghagy",
    "meghagyta": "meghagy",
    "meghagytak": "meghagy",
    "meghagytam": "meghagy",
    "meghagyták": "meghagy",
    "meghagyása": "meghagyás",
    "meghajlott": "meghajlik",
    "meghajlított": "meghajlít",
    "meghajolt": "meghajol",
    "meghajoltak": "meghajolt",
    "meghajszolt": "meghajszol",
    "meghajtja": "meghajt",
    "meghajtotta": "meghajt",
    "meghaladja": "meghalad",
    "meghaladta": "meghalad",
    "meghaladták": "meghalad",
    "meghallanak": "meghallik",
    "meghallgassam": "meghallgat",
    "meghallgatja": "meghallgat",
    "meghallgatni": "meghallgat",
    "meghallgatnia": "meghallgat",
    "meghalljuk": "meghallik",
    "meghallotta": "meghallik",
    "meghallották": "meghallik",
    "meghalni": "meghal",
    "meghalniuk": "meghal",
    "meghalsz": "meghal",
    "meghalt": "meghal",
    "meghaltok": "meghal",
    "meghalásra": "meghalás",
    "meghamisítani": "meghamisít",
    "meghamisítja": "meghamisít",
    "meghamisítják": "meghamisít",
    "meghamisított": "meghamisít",
    "meghamisítottak": "meghamisított",
    "meghamisították": "meghamisít",
    "meghamisítsák": "meghamisít",
    "meghamisítása": "meghamisítás",
    "meghamisításának": "meghamisítás",
    "megharagudhatnék": "megharagudhat",
    "megharagudhatunk": "megharagudhat",
    "megharagudni": "megharagszik",
    "megharagudott": "megharagszik",
    "megharagítottak": "megharagított",
    "meghasonlott": "meghasonlik",
    "meghassanak": "meghat",
    "meghatja": "meghat",
    "meghatottnak": "meghatott",
    "meghatottságra": "meghatottság",
    "meghatározhatnánk": "meghatározhat",
    "meghatározni": "meghatároz",
    "meghatározott": "meghatároz",
    "meghatározottságáról": "meghatározottság",
    "meghatározta": "meghatároz",
    "meghatározták": "meghatároz",
    "meghatározza": "meghatároz",
    "meghatározzák": "meghatároz",
    "meghatározása": "meghatározás",
    "meghatározásakor": "meghatározás",
    "meghatározások": "meghatározás",
    "meghatározására": "meghatározás",
    "meghatározását": "meghatározás",
    "meghatározásával": "meghatározás",
    "meghatározóak": "meghatározó",
    "meghatározónak": "meghatározó",
    "meghatóan": "megható",
    "meghatódást": "meghatódás",
    "meghibásodása": "meghibásodás",
    "meghirdetett": "meghirdet",
    "meghirdeti": "meghirdet",
    "meghirdették": "meghirdet",
    "meghitt": "meghisz",
    "meghiúsulása": "meghiúsulás",
    "meghosszabbodott": "meghosszabbodik",
    "meghosszabbítását": "meghosszabbítás",
    "meghozatala": "meghozatal",
    "meghozott": "meghoz",
    "meghozta": "meghoz",
    "meghozták": "meghoz",
    "meghozza": "meghoz",
    "meghunyászkodom": "meghunyászkodik",
    "meghunyászkodottan": "meghunyászkodott",
    "meghurcolnak": "meghurcol",
    "megháltunk": "meghált",
    "meghánytunk": "meghányt",
    "megháromszorozódtak": "megháromszorozódik",
    "meghívhatlak": "meghívhat",
    "meghívja": "meghív",
    "meghívnék": "meghív",
    "meghívott": "meghív",
    "meghívta": "meghív",
    "meghívták": "meghív",
    "meghívást": "meghívás",
    "meghívók": "meghívó",
    "meghízott": "meghízik",
    "meghódolni": "meghódol",
    "meghódítani": "meghódít",
    "meghódítaná": "meghódít",
    "meghódíthassák": "meghódíthat",
    "meghódíthatja": "meghódíthat",
    "meghódíthatná": "meghódíthat",
    "meghódíthatóvá": "meghódítható",
    "meghódított": "meghódít",
    "meghódításában": "meghódítás",
    "meghódításának": "meghódítás",
    "meghódítását": "meghódítás",
    "meghökkentek": "meghökkent",
    "meghökkentem": "meghökkent",
    "meghökkentette": "meghökkent",
    "meghökkenést": "meghökkenés",
    "meghúzása": "meghúzás",
    "meghűléstől": "meghűlés",
    "megigazítani": "megigazít",
    "megigazította": "megigazít",
    "megigya": "megiszik",
    "megihatnék": "megihat",
    "megijedni": "megijed",
    "megijedt": "megijed",
    "megijedtek": "megijedt",
    "megijedtél": "megijed",
    "megijedtünk": "megijedt",
    "megijedünk": "megijed",
    "megijesztette": "megijeszt",
    "megijesztettem": "megijesztett",
    "megilletné": "megillet",
    "megilletődéssel": "megilletődés",
    "meginduljon": "megindul",
    "megindult": "megindul",
    "megindultak": "megindult",
    "megindultunk": "megindult",
    "megindítja": "megindít",
    "megindítják": "megindít",
    "megindításának": "megindítás",
    "megingattam": "megingat",
    "meginni": "megiszik",
    "meginnia": "megiszik",
    "meginnák": "megiszik",
    "megirigyelte": "megirigyel",
    "megismerhetik": "megismerhet",
    "megismerhetitek": "megismerhet",
    "megismeri": "megismer",
    "megismerkedni": "megismerkedik",
    "megismerkednünk": "megismerkedik",
    "megismerni": "megismer",
    "megismerte": "megismer",
    "megismertelek": "megismer",
    "megismertesse": "megismertet",
    "megismertessék": "megismertet",
    "megismertetésével": "megismertetés",
    "megismerése": "megismerés",
    "megismételt": "megismétel",
    "megismételte": "megismétel",
    "megismételtették": "megismételtet",
    "megismételtük": "megismétel",
    "megismétlődött": "megismétlődik",
    "megissza": "megiszik",
    "megitta": "megiszik",
    "megivott": "megiszik",
    "megjavítani": "megjavít",
    "megjavította": "megjavít",
    "megjegyezni": "megjegyez",
    "megjegyeznék": "megjegyez",
    "megjegyezte": "megjegyez",
    "megjegyezték": "megjegyez",
    "megjegyzett": "megjegyez",
    "megjegyzik": "megjegyez",
    "megjegyzésből": "megjegyzés",
    "megjegyzése": "megjegyzés",
    "megjegyzései": "megjegyzés",
    "megjegyzéseit": "megjegyzés",
    "megjegyzéseivel": "megjegyzés",
    "megjegyzések": "megjegyzés",
    "megjegyzéseket": "megjegyzés",
    "megjegyzést": "megjegyzés",
    "megjegyzéséből": "megjegyzés",
    "megjegyzését": "megjegyzés",
    "megjelenhetett": "megjelenhet",
    "megjelennie": "megjelenik",
    "megjelent": "megjelenik",
    "megjelentek": "megjelent",
    "megjelentetésére": "megjelentetés",
    "megjelenésből": "megjelenés",
    "megjelenése": "megjelenés",
    "megjelenésre": "megjelenés",
    "megjelenéséből": "megjelenés",
    "megjelenésére": "megjelenés",
    "megjelenését": "megjelenés",
    "megjelenésük": "megjelenés",
    "megjelölni": "megjelöl",
    "megjelölt": "megjelöl",
    "megjárják": "megjár",
    "megjárt": "megjár",
    "megjárta": "megjár",
    "megjárták": "megjár",
    "megjósolja": "megjósol",
    "megjósolni": "megjósol",
    "megjósolunk": "megjósol",
    "megjönnek": "megjön",
    "megjött": "megjön",
    "megjöttek": "megjön",
    "megkalapálták": "megkalapál",
    "megkapaszkodsz": "megkapaszkodik",
    "megkaphatom": "megkaphat",
    "megkapja": "megkap",
    "megkapjuk": "megkap",
    "megkapják": "megkap",
    "megkapnia": "megkap",
    "megkapniuk": "megkap",
    "megkapod": "megkap",
    "megkapott": "megkap",
    "megkapta": "megkap",
    "megkaptam": "megkap",
    "megkapták": "megkap",
    "megkapálták": "megkapál",
    "megkaszálják": "megkaszál",
    "megkavarjon": "megkavar",
    "megkavarni": "megkavar",
    "megkeményedett": "megkeményedik",
    "megkeményített": "megkeményít",
    "megkeresi": "megkeres",
    "megkeresik": "megkeres",
    "megkeresni": "megkeres",
    "megkeresnők": "megkeres",
    "megkeresse": "megkeres",
    "megkereste": "megkeres",
    "megkeresték": "megkeres",
    "megkerestük": "megkeres",
    "megkeresést": "megkeresés",
    "megkeresünk": "megkeres",
    "megkerülni": "megkerül",
    "megkerülte": "megkerül",
    "megkeserített": "megkeserít",
    "megkeseríti": "megkeserít",
    "megkezdett": "megkezd",
    "megkezdhessük": "megkezdhet",
    "megkezdi": "megkezd",
    "megkezdik": "megkezd",
    "megkezdte": "megkezd",
    "megkezdtek": "megkezd",
    "megkezdték": "megkezd",
    "megkezdése": "megkezdés",
    "megkezdéséhez": "megkezdés",
    "megkezdését": "megkezdés",
    "megkezdődhessen": "megkezdődhet",
    "megkezdődhetnek": "megkezdődhet",
    "megkezdődnek": "megkezdődik",
    "megkezdődtek": "megkezdődik",
    "megkezdődött": "megkezdődik",
    "megkockáztatja": "megkockáztat",
    "megkockáztatni": "megkockáztat",
    "megkocogtatta": "megkocogtat",
    "megkomponálták": "megkomponál",
    "megkondította": "megkondít",
    "megkontyolták": "megkontyol",
    "megkopaszodott": "megkopaszodik",
    "megkopogtatta": "megkopogtat",
    "megkorbácsoltak": "megkorbácsolt",
    "megkurtított": "megkurtít",
    "megkérdezem": "megkérdez",
    "megkérdezi": "megkérdez",
    "megkérdezik": "megkérdez",
    "megkérdezni": "megkérdez",
    "megkérdezte": "megkérdez",
    "megkérdeztem": "megkérdez",
    "megkérdezték": "megkérdez",
    "megkérdeztük": "megkérdez",
    "megkérdőjelezi": "megkérdőjelez",
    "megkérdőjelezni": "megkérdőjelez",
    "megkérdőjeleznék": "megkérdőjelez",
    "megkérem": "megkér",
    "megkértük": "megkér",
    "megkétszerezi": "megkétszerez",
    "megkétszereződött": "megkétszereződik",
    "megkínozta": "megkínoz",
    "megkínoztak": "megkínoz",
    "megkínoztátok": "megkínoz",
    "megkínzott": "megkínoz",
    "megkínálja": "megkínál",
    "megkínálják": "megkínál",
    "megkínálta": "megkínál",
    "megkínáltak": "megkínált",
    "megkísérelt": "megkísérel",
    "megkísérelte": "megkísérel",
    "megkísértette": "megkísért",
    "megkívánja": "megkíván",
    "megkívánják": "megkíván",
    "megkívánnak": "megkíván",
    "megkívánt": "megkíván",
    "megkönnyebbedést": "megkönnyebbedés",
    "megkönnyebbedéstől": "megkönnyebbedés",
    "megkönnyebbedésükben": "megkönnyebbedés",
    "megkönnyebbülhetnek": "megkönnyebbülhet",
    "megkönnyebbült": "megkönnyebbül",
    "megkönnyebbültem": "megkönnyebbül",
    "megkönnyebbülten": "megkönnyebbült",
    "megkönnyebbülése": "megkönnyebbülés",
    "megkönnyebbüléssel": "megkönnyebbülés",
    "megkönnyebbülést": "megkönnyebbülés",
    "megkönnyíteni": "megkönnyít",
    "megkönnyítette": "megkönnyít",
    "megkönnyíti": "megkönnyít",
    "megkönnyítése": "megkönnyítés",
    "megkörnyékeznetek": "megkörnyékez",
    "megkötésének": "megkötés",
    "megkötött": "megköt",
    "megkötötte": "megköt",
    "megkötötték": "megköt",
    "megköveteli": "megkövetel",
    "megkövetelte": "megkövetel",
    "megközelíteni": "megközelít",
    "megközelítenők": "megközelít",
    "megközelítette": "megközelít",
    "megközelítettek": "megközelített",
    "megközelítették": "megközelítet",
    "megközelíthetetlenek": "megközelíthetetlen",
    "megközelíti": "megközelít",
    "megközelítéssel": "megközelítés",
    "megküldenek": "megküld",
    "megkülönböztetett": "megkülönböztet",
    "megkülönböztetette": "megkülönböztet",
    "megkülönböztetni": "megkülönböztet",
    "megkülönböztetést": "megkülönböztetés",
    "meglangyosodott": "meglangyosodik",
    "meglazították": "meglazít",
    "meglegyen": "meglesz",
    "meglehetősen": "meglehetős",
    "meglelik": "meglel",
    "megleljük": "meglel",
    "megleltük": "meglel",
    "meglendítették": "meglendítet",
    "meglennie": "meglesz",
    "meglepetten": "meglepett",
    "meglepetéscsapata": "meglepetéscsapat",
    "meglepetése": "meglepetés",
    "meglepetések": "meglepetés",
    "meglepetéshullám": "meglepetéshulla",
    "meglepetésiből": "meglepetési",
    "meglepetésként": "meglepetés",
    "meglepetésre": "meglepetés",
    "meglepetésről": "meglepetés",
    "meglepetéssel": "meglepetés",
    "meglepetésszerűen": "meglepetésszerű",
    "meglepetést": "meglepetés",
    "meglepetésére": "meglepetés",
    "meglepte": "meglep",
    "meglepőbb": "meglepő",
    "meglepődését": "meglepődés",
    "meglepődött": "meglepődik",
    "meglepően": "meglepő",
    "meglepőre": "meglepő",
    "meglett": "meglesz",
    "meglopni": "meglop",
    "megloptak": "meglop",
    "meglopták": "meglop",
    "megláboltuk": "meglábol",
    "meglágyítani": "meglágyít",
    "megláthatja": "megláthat",
    "megláthatják": "megláthat",
    "meglátja": "meglát",
    "meglátjuk": "meglát",
    "meglátnak": "meglát",
    "meglátogatta": "meglátogat",
    "meglátogattam": "meglátogat",
    "meglátogatták": "meglátogat",
    "meglátom": "meglát",
    "meglátott": "meglát",
    "meglátta": "meglát",
    "megláttam": "meglát",
    "megláttuk": "meglát",
    "meglátták": "meglát",
    "meglévőt": "meglévő",
    "meglökött": "meglök",
    "meglőtte": "meglő",
    "megmagyarázni": "megmagyaráz",
    "megmagyaráztam": "megmagyaráz",
    "megmagyarázták": "megmagyaráz",
    "megmaradjon": "megmarad",
    "megmaradt": "megmarad",
    "megmaradtak": "megmaradt",
    "megmaradunk": "megmarad",
    "megmarkolni": "megmarkol",
    "megmarkolta": "megmarkol",
    "megmart": "megmar",
    "megmelegíteni": "megmelegít",
    "megmeneküljön": "megmenekül",
    "megmenekülnek": "megmenekül",
    "megmenekülni": "megmenekül",
    "megmenekülsz": "megmenekül",
    "megmenekült": "megmenekül",
    "megmenekülésre": "megmenekülés",
    "megment": "megmegy",
    "megmentened": "megment",
    "megmenteni": "megment",
    "megmentett": "megment",
    "megmentette": "megment",
    "megmentettek": "megmentett",
    "megmentheted": "megmenthet",
    "megmenthetném": "megmenthet",
    "megmentéséhez": "megmentés",
    "megmerevedett": "megmerevedik",
    "megmerülhessünk": "megmerülhet",
    "megmondani": "megmond",
    "megmondania": "megmond",
    "megmondhatná": "megmondhat",
    "megmondhatod": "megmondhat",
    "megmondja": "megmond",
    "megmondjam": "megmond",
    "megmondod": "megmond",
    "megmondom": "megmond",
    "megmondta": "megmond",
    "megmondtam": "megmond",
    "megmondtuk": "megmond",
    "megmondták": "megmond",
    "megmondtátok": "megmond",
    "megmosakodnak": "megmosakodik",
    "megmosdottam": "megmosdott",
    "megmosták": "megmos",
    "megmotozott": "megmotoz",
    "megmotoztak": "megmotoz",
    "megmozdult": "megmozdul",
    "megmozdulások": "megmozdulás",
    "megmozdíthatta": "megmozdíthat",
    "megmozdítja": "megmozdít",
    "megmozdította": "megmozdít",
    "megmozdítást": "megmozdítás",
    "megmozgatni": "megmozgat",
    "megmozgatták": "megmozgat",
    "megmunkálásra": "megmunkálás",
    "megmutathatná": "megmutathat",
    "megmutathatta": "megmutathat",
    "megmutatja": "megmutat",
    "megmutatni": "megmutat",
    "megmutatta": "megmutat",
    "megmutatták": "megmutat",
    "megmutogatni": "megmutogat",
    "megmásítani": "megmásít",
    "megmérgesedett": "megmérgesedik",
    "megmérkőzniük": "megmérkőzik",
    "megnagyított": "megnagyít",
    "megnehezítené": "megnehezít",
    "megnehezítette": "megnehezít",
    "megnehezíti": "megnehezít",
    "megnevezett": "megnevez",
    "megnevezése": "megnevezés",
    "megnevezéséhez": "megnevezés",
    "megnevezésükre": "megnevezés",
    "megnyalta": "megnyal",
    "megnyerni": "megnyer",
    "megnyert": "megnyer",
    "megnyerte": "megnyer",
    "megnyertük": "megnyer",
    "megnyilvánult": "megnyilvánul",
    "megnyilvánulásaira": "megnyilvánulás",
    "megnyithatod": "megnyithat",
    "megnyitják": "megnyit",
    "megnyitom": "megnyit",
    "megnyitott": "megnyit",
    "megnyitotta": "megnyit",
    "megnyitottak": "megnyitott",
    "megnyittatta": "megnyittat",
    "megnyitása": "megnyitás",
    "megnyitásra": "megnyitás",
    "megnyitását": "megnyitás",
    "megnyitója": "megnyitó",
    "megnyitón": "megnyitó",
    "megnyitót": "megnyitó",
    "megnyitóval": "megnyitó",
    "megnyomja": "megnyom",
    "megnyomom": "megnyom",
    "megnyomott": "megnyom",
    "megnyomtam": "megnyom",
    "megnyugodni": "megnyugszik",
    "megnyugodtam": "megnyugszik",
    "megnyugodtunk": "megnyugszik",
    "megnyugtatni": "megnyugtat",
    "megnyugtatott": "megnyugtat",
    "megnyugtatta": "megnyugtat",
    "megnyugtattam": "megnyugtat",
    "megnyugtatóak": "megnyugtató",
    "megnyugtatóan": "megnyugtató",
    "megnyugtatóbb": "megnyugtató",
    "megnyugtatók": "megnyugtató",
    "megnyílt": "megnyílik",
    "megnégyszerezni": "megnégyszerez",
    "megnézd": "megnéz",
    "megnézek": "megnéz",
    "megnézem": "megnéz",
    "megnézett": "megnéz",
    "megnézhesse": "megnézhet",
    "megnézhetnéd": "megnézhet",
    "megnézhette": "megnézhet",
    "megnézi": "megnéz",
    "megnézik": "megnéz",
    "megnézni": "megnéz",
    "megnéznék": "megnéz",
    "megnézte": "megnéz",
    "megnézted": "megnéz",
    "megnéztek": "megnéz",
    "megnézték": "megnéz",
    "megnézze": "megnéz",
    "megnövekedése": "megnövekedés",
    "megnöveli": "megnövel",
    "megnövelte": "megnövel",
    "megnövelését": "megnövelés",
    "megnősült": "megnősül",
    "megnőtt": "megnő",
    "megnőttek": "megnőtt",
    "megokosította": "megokosít",
    "megoldani": "megold",
    "megoldania": "megold",
    "megoldanunk": "megold",
    "megoldotta": "megold",
    "megoldották": "megold",
    "megoldása": "megoldás",
    "megoldásként": "megoldás",
    "megoldásnak": "megoldás",
    "megoldásokhoz": "megoldás",
    "megoldásokkal": "megoldás",
    "megoldásra": "megoldás",
    "megoldásról": "megoldás",
    "megoldással": "megoldás",
    "megoldást": "megoldás",
    "megoldásához": "megoldás",
    "megoldásán": "megoldás",
    "megoldásának": "megoldás",
    "megoldására": "megoldás",
    "megoldását": "megoldás",
    "megoldásával": "megoldás",
    "megoldódtak": "megoldódik",
    "megoltalmazzon": "megoltalmaz",
    "megolvadt": "megolvad",
    "megolvasta": "megolvas",
    "megoszlóbbak": "megoszló",
    "megosztani": "megoszt",
    "megosztanám": "megoszt",
    "megosztja": "megoszt",
    "megosztják": "megoszt",
    "megosztása": "megosztás",
    "megosztásakor": "megosztás",
    "megosztástól": "megosztás",
    "megosztására": "megosztás",
    "megosztásáról": "megosztás",
    "megosztását": "megosztás",
    "megparancsolja": "megparancsol",
    "megparancsolta": "megparancsol",
    "megpendíti": "megpendít",
    "megpihent": "megpihen",
    "megpillantja": "megpillant",
    "megpillantott": "megpillant",
    "megpillantotta": "megpillant",
    "megpróbálja": "megpróbál",
    "megpróbáljuk": "megpróbál",
    "megpróbálkozott": "megpróbálkozik",
    "megpróbálna": "megpróbál",
    "megpróbálná": "megpróbál",
    "megpróbálom": "megpróbál",
    "megpróbált": "megpróbál",
    "megpróbálta": "megpróbál",
    "megpróbáltak": "megpróbált",
    "megpróbáltam": "megpróbált",
    "megpróbálták": "megpróbál",
    "megpucolom": "megpucol",
    "megpuhítása": "megpuhítás",
    "megpályázott": "megpályázik",
    "megpályáztak": "megpályázik",
    "megpótolja": "megpótol",
    "megpördítette": "megpördít",
    "megragadja": "megragad",
    "megragadott": "megragad",
    "megragadta": "megragad",
    "megragadták": "megragad",
    "megragadásához": "megragadás",
    "megrajzolt": "megrajzol",
    "megrakodni": "megrakodik",
    "megrakodtam": "megrakodik",
    "megrakott": "megrak",
    "megraktuk": "megrak",
    "megrebbent": "megrebben",
    "megreformálásán": "megreformálás",
    "megreggelizett": "megreggelizik",
    "megrekedni": "megreked",
    "megrekedt": "megreked",
    "megrendelt": "megrendel",
    "megrendelttel": "megrendelt",
    "megrendelések": "megrendelés",
    "megrendelésre": "megrendelés",
    "megrendelőknek": "megrendelő",
    "megrendelőokmányát": "megrendelőokmány",
    "megrendezett": "megrendez",
    "megrendezheti": "megrendezhet",
    "megrengett": "megreng",
    "megrepedtek": "megrepedt",
    "megrettent": "megretten",
    "megriadt": "megriad",
    "megriasztotta": "megriaszt",
    "megroggyant": "megroggyan",
    "megrohanják": "megrohan",
    "megrohasztani": "megrohaszt",
    "megrongálódott": "megrongálódik",
    "megrontani": "megront",
    "megronthatja": "megronthat",
    "megrontotta": "megront",
    "megropogtatta": "megropogtat",
    "megrugdaltak": "megrugdalt",
    "megruházták": "megruház",
    "megrágom": "megrág",
    "megrágta": "megrág",
    "megrándult": "megrándul",
    "megrázniuk": "megráz",
    "megrázom": "megráz",
    "megrázott": "megráz",
    "megrázta": "megráz",
    "megrémült": "megrémül",
    "megrögzötten": "megrögzött",
    "megröntgeneztek": "megröntgenez",
    "megrövidíteni": "megrövidít",
    "megrövidítették": "megrövidítet",
    "megrövidült": "megrövidül",
    "megrúgja": "megrúg",
    "megrúgott": "megrúg",
    "megsavanyodjon": "megsavanyodik",
    "megsebesítettek": "megsebesített",
    "megsebesültek": "megsebesül",
    "megsebezni": "megsebez",
    "megsegíti": "megsegít",
    "megsegítsék": "megsegít",
    "megsegítésébe": "megsegítés",
    "megsejtené": "megsejt",
    "megsejtette": "megsejt",
    "megsemmisítenek": "megsemmisít",
    "megsemmisíteni": "megsemmisít",
    "megsemmisítenie": "megsemmisít",
    "megsemmisített": "megsemmisít",
    "megsemmisítette": "megsemmisít",
    "megsemmisítettek": "megsemmisített",
    "megsemmisítették": "megsemmisítet",
    "megsemmisíti": "megsemmisít",
    "megsemmisítik": "megsemmisít",
    "megsemmisítsenek": "megsemmisít",
    "megsemmisítése": "megsemmisítés",
    "megsemmisítésre": "megsemmisítés",
    "megsemmisítést": "megsemmisítés",
    "megsemmisítésének": "megsemmisítés",
    "megsemmisítésére": "megsemmisítés",
    "megsemmisítéséről": "megsemmisítés",
    "megsemmisítését": "megsemmisítés",
    "megsemmisítünk": "megsemmisít",
    "megsemmisítőbb": "megsemmisítő",
    "megsemmisítően": "megsemmisítő",
    "megsemmisüljenek": "megsemmisül",
    "megsemmisült": "megsemmisül",
    "megsimogatta": "megsimogat",
    "megsiratja": "megsirat",
    "megsokallotta": "megsokall",
    "megspóroltuk": "megspórol",
    "megstoppolása": "megstoppolás",
    "megszabadulhatsz": "megszabadulhat",
    "megszabaduljon": "megszabadul",
    "megszabadulni": "megszabadul",
    "megszabadult": "megszabadul",
    "megszabadultak": "megszabadult",
    "megszabadultam": "megszabadult",
    "megszabadította": "megszabadít",
    "megszabja": "megszab",
    "megszabott": "megszab",
    "megszabta": "megszab",
    "megszagolja": "megszagol",
    "megszagolta": "megszagol",
    "megszakadt": "megszakad",
    "megszakadása": "megszakadás",
    "megszakadásig": "megszakadás",
    "megszakítani": "megszakít",
    "megszakított": "megszakít",
    "megszakították": "megszakít",
    "megszakíttatta": "megszakíttat",
    "megszaladtak": "megszaladt",
    "megszalasztották": "megszalaszt",
    "megszaporodtak": "megszaporodik",
    "megszavazta": "megszavaz",
    "megszavazták": "megszavaz",
    "megszedett": "megszed",
    "megszegett": "megszeg",
    "megszegheti": "megszeghet",
    "megszegni": "megszeg",
    "megszegné": "megszeg",
    "megszegte": "megszeg",
    "megszegése": "megszegés",
    "megszegését": "megszegés",
    "megszelídítette": "megszelídít",
    "megszelídítse": "megszelídít",
    "megszenvedtek": "megszenved",
    "megszeppenten": "megszeppent",
    "megszerette": "megszeret",
    "megszerették": "megszeret",
    "megszerezheti": "megszerezhet",
    "megszerezhetnének": "megszerezhet",
    "megszerezni": "megszerez",
    "megszerezték": "megszerez",
    "megszerezze": "megszerez",
    "megszerkesztett": "megszerkeszt",
    "megszerzése": "megszerzés",
    "megszerzéséről": "megszerzés",
    "megszerzését": "megszerzés",
    "megszilárdulást": "megszilárdulás",
    "megszokja": "megszokik",
    "megszokott": "megszokik",
    "megszokottabb": "megszokott",
    "megszokottaktól": "megszokott",
    "megszokotthoz": "megszokott",
    "megszokottnál": "megszokott",
    "megszokta": "megszokik",
    "megszoktuk": "megszokik",
    "megszokták": "megszokik",
    "megszokásból": "megszokás",
    "megszoptatta": "megszoptat",
    "megszorongatták": "megszorongat",
    "megszorította": "megszorít",
    "megszorították": "megszorít",
    "megszállott": "megszáll",
    "megszállottak": "megszállott",
    "megszállották": "megszáll",
    "megszállt": "megszáll",
    "megszállása": "megszállás",
    "megszámlálása": "megszámlálás",
    "megszámolni": "megszámol",
    "megszáradtak": "megszáradt",
    "megszégyenítést": "megszégyenítés",
    "megszépítette": "megszépít",
    "megszépítsen": "megszépít",
    "megszíttam": "megszí",
    "megszólaljon": "megszólal",
    "megszólalnak": "megszólal",
    "megszólalni": "megszólal",
    "megszólalt": "megszólal",
    "megszólalását": "megszólalás",
    "megszólított": "megszólít",
    "megszólította": "megszólít",
    "megszólításból": "megszólítás",
    "megszólítással": "megszólítás",
    "megszólításával": "megszólítás",
    "megszórták": "megszór",
    "megszökjék": "megszökik",
    "megszöknek": "megszökik",
    "megszöktek": "megszökik",
    "megszököm": "megszökik",
    "megszökött": "megszökik",
    "megszületett": "megszületik",
    "megszülettek": "megszületik",
    "megszülettem": "megszületik",
    "megszületésekor": "megszületés",
    "megszületésével": "megszületés",
    "megszületésükkor": "megszületés",
    "megszüntetik": "megszüntet",
    "megszüntetjük": "megszüntet",
    "megszüntetni": "megszüntet",
    "megszüntetnék": "megszüntet",
    "megszüntette": "megszüntet",
    "megszüntették": "megszüntet",
    "megszüntetése": "megszüntetés",
    "megszüntetéséhez": "megszüntetés",
    "megszüntetésére": "megszüntetés",
    "megszüntetését": "megszüntetés",
    "megszűnjek": "megszűnik",
    "megszűnne": "megszűnik",
    "megszűnni": "megszűnik",
    "megszűnt": "megszűnik",
    "megszűntek": "megszűnik",
    "megszűnése": "megszűnés",
    "megszűnését": "megszűnés",
    "megsárgult": "megsárgul",
    "megsárgított": "megsárgít",
    "megsértené": "megsért",
    "megsértette": "megsért",
    "megsértették": "megsértet",
    "megsértésének": "megsértés",
    "megsértését": "megsértés",
    "megsértőit": "megsértői",
    "megsérült": "megsérül",
    "megsínyli": "megsínylik",
    "megsötétült": "megsötétül",
    "megsúgták": "megsúg",
    "megsűrűsödtek": "megsűrűsödik",
    "megtagadta": "megtagad",
    "megtagadták": "megtagad",
    "megtagadása": "megtagadás",
    "megtagadást": "megtagadás",
    "megtagadását": "megtagadás",
    "megtakarított": "megtakarít",
    "megtakarításhoz": "megtakarítás",
    "megtakarítások": "megtakarítás",
    "megtakarításokat": "megtakarítás",
    "megtakarításuk": "megtakarítás",
    "megtakarítók": "megtakarító",
    "megtalálhatja": "megtalálhat",
    "megtalálja": "megtalál",
    "megtaláljuk": "megtalál",
    "megtalálják": "megtalál",
    "megtalálni": "megtalál",
    "megtalálta": "megtalál",
    "megtaláltuk": "megtalál",
    "megtalálták": "megtalál",
    "megtalálásában": "megtalálás",
    "megtanulhattuk": "megtanulhat",
    "megtanulja": "megtanul",
    "megtanulják": "megtanul",
    "megtanulnak": "megtanul",
    "megtanulni": "megtanul",
    "megtanult": "megtanul",
    "megtanulta": "megtanul",
    "megtanultam": "megtanult",
    "megtanítanom": "megtanít",
    "megtapogatta": "megtapogat",
    "megtartanak": "megtart",
    "megtartani": "megtart",
    "megtartaná": "megtart",
    "megtartanám": "megtart",
    "megtarthatná": "megtarthat",
    "megtarthatták": "megtarthat",
    "megtartja": "megtart",
    "megtartott": "megtart",
    "megtartotta": "megtart",
    "megtartottak": "megtartott",
    "megtartották": "megtart",
    "megtartsák": "megtart",
    "megtartóztatta": "megtartóztat",
    "megtedd": "megtesz",
    "megtegye": "megtesz",
    "megtegyék": "megtesz",
    "megteheti": "megtehet",
    "megtehetjük": "megtehet",
    "megtehették": "megtehet",
    "megtehettél": "megtehet",
    "megtekintette": "megtekint",
    "megtekintése": "megtekintés",
    "megtelepedett": "megtelepedik",
    "megtelepedni": "megtelepedik",
    "megtelik": "megtel",
    "megtelt": "megtelik",
    "megteltek": "megtelt",
    "megtenni": "megtesz",
    "megtenné": "megtesz",
    "megtenném": "megtesz",
    "megteremtem": "megteremt",
    "megteremteni": "megteremt",
    "megteremtenie": "megteremt",
    "megteremtették": "megteremtetik",
    "megteremti": "megteremt",
    "megteremtése": "megteremtés",
    "megteremtésében": "megteremtés",
    "megteremtésének": "megteremtés",
    "megteremtését": "megteremtés",
    "megteremtődött": "megteremtődik",
    "megterhelése": "megterhelés",
    "megtermett": "megterem",
    "megtermékenyült": "megtermékenyül",
    "megtestesülése": "megtestesülés",
    "megteszi": "megtesz",
    "megteszik": "megtesz",
    "megtetszett": "megtetszik",
    "megtett": "megtesz",
    "megtette": "megtesz",
    "megtettem": "megtett",
    "megtették": "megtesz",
    "megtettünk": "megtett",
    "megtiltana": "megtilt",
    "megtiltja": "megtilt",
    "megtiltják": "megtilt",
    "megtiltották": "megtilt",
    "megtisztelt": "megtisztel",
    "megtisztította": "megtisztít",
    "megtisztításuk": "megtisztítás",
    "megtisztítására": "megtisztítás",
    "megtizedelt": "megtizedel",
    "megtorlásnak": "megtorlás",
    "megtorlások": "megtorlás",
    "megtorlást": "megtorlás",
    "megtorlásától": "megtorlás",
    "megtorpant": "megtorpan",
    "megtorpanásához": "megtorpanás",
    "megtudhatjuk": "megtudhat",
    "megtudhatta": "megtudhat",
    "megtudhatták": "megtudhat",
    "megtudja": "megtud",
    "megtudjuk": "megtud",
    "megtudják": "megtud",
    "megtudni": "megtud",
    "megtudta": "megtud",
    "megtudtam": "megtud",
    "megtudtuk": "megtud",
    "megtákolta": "megtákol",
    "megtámadnak": "megtámad",
    "megtámadnák": "megtámad",
    "megtámadott": "megtámad",
    "megtámasztott": "megtámaszt",
    "megtárgyalják": "megtárgyal",
    "megtárgyalta": "megtárgyal",
    "megtépdeste": "megtépdes",
    "megtépázott": "megtépáz",
    "megtépázottan": "megtépázott",
    "megtépázta": "megtépáz",
    "megtérni": "megtér",
    "megtéríteni": "megtérít",
    "megtéríthetnék": "megtéríthet",
    "megtérítjük": "megtérít",
    "megtérítése": "megtérítés",
    "megtérülésére": "megtérülés",
    "megtévedt": "megtéved",
    "megtévesztettek": "megtévesztett",
    "megtévesztetteknek": "megtévesztett",
    "megtévesztésre": "megtévesztés",
    "megtévesztővé": "megtévesztő",
    "megtölteni": "megtölt",
    "megtöltik": "megtölt",
    "megtöltöd": "megtölt",
    "megtöltötte": "megtölt",
    "megtöltünk": "megtölt",
    "megtörik": "megtör",
    "megtörni": "megtörik",
    "megtört": "megtörik",
    "megtörténne": "megtörténik",
    "megtörténni": "megtörténik",
    "megtörténnék": "megtörténik",
    "megtörtént": "megtörténik",
    "megtörténtek": "megtörtént",
    "megtörtük": "megtörik",
    "megtörése": "megtörés",
    "megtörölte": "megtöröl",
    "megtörölték": "megtöröl",
    "megtűrik": "megtűr",
    "megtűrték": "megtűr",
    "megugrottak": "megugrott",
    "megvacsoráztunk": "megvacsorázik",
    "megvadult": "megvadul",
    "megvagdalja": "megvagdal",
    "megvakarni": "megvakar",
    "megvakarta": "megvakar",
    "megvallassátok": "megvallat",
    "megvallatunk": "megvallat",
    "megvallottuk": "megvall",
    "megvallották": "megvall",
    "megvalósulhatott": "megvalósulhat",
    "megvalósulna": "megvalósul",
    "megvalósulása": "megvalósulás",
    "megvalósulásakor": "megvalósulás",
    "megvalósuláshoz": "megvalósulás",
    "megvalósítani": "megvalósít",
    "megvalósíthatóvá": "megvalósítható",
    "megvalósított": "megvalósít",
    "megvalósítsa": "megvalósít",
    "megvalósítása": "megvalósítás",
    "megvalósításra": "megvalósítás",
    "megvalósításukhoz": "megvalósítás",
    "megvalósításában": "megvalósítás",
    "megvalósításához": "megvalósítás",
    "megvalósítására": "megvalósítás",
    "megvalósítását": "megvalósítás",
    "megvannak": "megvan",
    "megvastagodott": "megvastagodik",
    "megvenni": "megvesz",
    "megveregette": "megvereget",
    "megveretéstől": "megveretés",
    "megverte": "megver",
    "megveszi": "megveszik",
    "megvesznek": "megveszik",
    "megvesztegetésére": "megvesztegetés",
    "megvetemedett": "megvetemedik",
    "megvetett": "megvet",
    "megvetette": "megvet",
    "megvetettük": "megvetett",
    "megveti": "megvet",
    "megvette": "megvesz",
    "megvették": "megvesz",
    "megvettük": "megvett",
    "megvetése": "megvetés",
    "megvetésről": "megvetés",
    "megvetéssel": "megvetés",
    "megvetést": "megvetés",
    "megvetően": "megvető",
    "megvillant": "megvillan",
    "megvilágosodását": "megvilágosodás",
    "megvilágítják": "megvilágít",
    "megvilágított": "megvilágít",
    "megvilágította": "megvilágít",
    "megviselt": "megvisel",
    "megviseltnek": "megviselt",
    "megvitassák": "megvitat",
    "megvitatnia": "megvitat",
    "megvizsgálja": "megvizsgál",
    "megvizsgálják": "megvizsgál",
    "megvizsgálta": "megvizsgál",
    "megvizsgálták": "megvizsgál",
    "megvolt": "megvan",
    "megvoltak": "megvolt",
    "megvonják": "megvon",
    "megvonta": "megvon",
    "megvonták": "megvon",
    "megvonása": "megvonás",
    "megvádolt": "megvádol",
    "megválaszolhatatlanná": "megválaszolhatatlan",
    "megválasztott": "megválaszt",
    "megválasztották": "megválaszt",
    "megválasztását": "megválasztás",
    "megválogatott": "megválogat",
    "megvált": "megválik",
    "megváltottam": "megváltott",
    "megváltottuk": "megvált",
    "megváltozhattak": "megváltozhat",
    "megváltozna": "megváltozik",
    "megváltoznak": "megváltozik",
    "megváltozott": "megváltozik",
    "megváltoztak": "megváltozik",
    "megváltoztassa": "megváltoztat",
    "megváltoztasson": "megváltoztat",
    "megváltoztathassa": "megváltoztathat",
    "megváltoztathatóságáról": "megváltoztathatóság",
    "megváltoztatja": "megváltoztat",
    "megváltoztatjuk": "megváltoztat",
    "megváltoztatni": "megváltoztat",
    "megváltoztatnia": "megváltoztat",
    "megváltoztatná": "megváltoztat",
    "megváltoztatott": "megváltoztat",
    "megváltoztatta": "megváltoztat",
    "megváltoztattak": "megváltoztat",
    "megváltoztatták": "megváltoztat",
    "megváltoztatása": "megváltoztatás",
    "megváltoztatásának": "megváltoztatás",
    "megváltoztatásával": "megváltoztatás",
    "megváltoztunk": "megváltozik",
    "megváltóm": "megváltó",
    "megvárakoztatják": "megvárakoztat",
    "megvárja": "megvár",
    "megvárjuk": "megvár",
    "megvárom": "megvár",
    "megvárta": "megvár",
    "megvártuk": "megvár",
    "megvásárlása": "megvásárlás",
    "megvásárlására": "megvásárlás",
    "megvásárlásával": "megvásárlás",
    "megvásárlók": "megvásárló",
    "megvásárolhatják": "megvásárolhat",
    "megvásárolni": "megvásárol",
    "megvásárolta": "megvásárol",
    "megvásárolták": "megvásárol",
    "megvédeni": "megvéd",
    "megvédenie": "megvéd",
    "megvédje": "megvéd",
    "megvédte": "megvéd",
    "megvédésére": "megvédés",
    "megvétele": "megvétel",
    "megvételének": "megvétel",
    "megvételére": "megvétel",
    "megvívni": "megvív",
    "megvörösödött": "megvörösödik",
    "megyek": "megy",
    "megyeszékhelyeken": "megyeszékhely",
    "megyeszékhelyen": "megyeszékhely",
    "megyében": "megye",
    "megyéből": "megye",
    "megyék": "megye",
    "megyékhez": "megye",
    "megyéknek": "megye",
    "megyékről": "megye",
    "megyén": "megye",
    "megyének": "megye",
    "megyénkről": "megye",
    "megyénként": "megye",
    "megyét": "megye",
    "megyével": "megye",
    "megyünk": "megy",
    "megzavarja": "megzavar",
    "megzavarni": "megzavar",
    "megzavarodott": "megzavarodik",
    "megzavarták": "megzavar",
    "megzsarolják": "megzsarol",
    "megállapodhatnak": "megállapodhat",
    "megállapodni": "megállapodik",
    "megállapodniuk": "megállapodik",
    "megállapodott": "megállapodik",
    "megállapodtak": "megállapodik",
    "megállapodtunk": "megállapodik",
    "megállapodása": "megállapodás",
    "megállapodásban": "megállapodás",
    "megállapodásnak": "megállapodás",
    "megállapodások": "megállapodás",
    "megállapodásra": "megállapodás",
    "megállapodással": "megállapodás",
    "megállapodást": "megállapodás",
    "megállapodásukra": "megállapodás",
    "megállapítani": "megállapít",
    "megállapítja": "megállapít",
    "megállapítják": "megállapít",
    "megállapított": "megállapít",
    "megállapította": "megállapít",
    "megállapítottam": "megállapított",
    "megállapítottuk": "megállapít",
    "megállapították": "megállapít",
    "megállapítása": "megállapítás",
    "megállapításai": "megállapítás",
    "megállapításait": "megállapítás",
    "megállapításban": "megállapítás",
    "megállapításhoz": "megállapítás",
    "megállapítások": "megállapítás",
    "megállapításokat": "megállapítás",
    "megállapításokban": "megállapítás",
    "megállapítást": "megállapítás",
    "megállapításunk": "megállapítás",
    "megállapítását": "megállapítás",
    "megálljon": "megáll",
    "megálljunk": "megáll",
    "megállnak": "megáll",
    "megállni": "megáll",
    "megállt": "megáll",
    "megálltak": "megállt",
    "megállíthatatlanul": "megállíthatatlan",
    "megállíthatják": "megállíthat",
    "megállítja": "megállít",
    "megállította": "megállít",
    "megállítsa": "megállít",
    "megállítsák": "megállít",
    "megállóhelyen": "megállóhely",
    "megállójánál": "megálló",
    "megátkozzák": "megátkoz",
    "megázott": "megázik",
    "megégetett": "megéget",
    "megégette": "megéget",
    "megéhezett": "megéhezik",
    "megélhetéshez": "megélhetés",
    "megélhetést": "megélhetés",
    "megélhetésükhöz": "megélhetés",
    "megélénkült": "megélénkül",
    "megépített": "megépít",
    "megépítése": "megépítés",
    "megépítéséhez": "megépítés",
    "megépítésére": "megépítés",
    "megérdemli": "megérdemel",
    "megérett": "megérik",
    "megérezte": "megérez",
    "megéreztük": "megérez",
    "megéri": "megérik",
    "megérinteni": "megérint",
    "megérintenie": "megérint",
    "megérintette": "megérint",
    "megérinti": "megérint",
    "megérintse": "megérint",
    "megérkezett": "megérkezik",
    "megérkeznek": "megérkezik",
    "megérkezni": "megérkezik",
    "megérkeznie": "megérkezik",
    "megérkeztünk": "megérkezik",
    "megérkezzen": "megérkezik",
    "megérkezéséig": "megérkezés",
    "megérkezésével": "megérkezés",
    "megérném": "megérik",
    "megért": "megérik",
    "megérted": "megért",
    "megértem": "megért",
    "megértene": "megért",
    "megérteni": "megért",
    "megértesz": "megért",
    "megértetni": "megértet",
    "megértette": "megért",
    "megértetted": "megértett",
    "megértettem": "megértett",
    "megértették": "megértet",
    "megértettük": "megértett",
    "megérthessük": "megérthet",
    "megérti": "megért",
    "megértik": "megért",
    "megértitek": "megért",
    "megértse": "megért",
    "megértsék": "megért",
    "megértése": "megértés",
    "megértéssel": "megértés",
    "megértéséhez": "megértés",
    "megértését": "megértés",
    "megígéri": "megígér",
    "megígért": "megígér",
    "megígérte": "megígér",
    "megírta": "megír",
    "megírtam": "megírt",
    "megírtuk": "megír",
    "megírták": "megír",
    "megírásától": "megírás",
    "megítélheti": "megítélhet",
    "megítélni": "megítél",
    "megítélt": "megítél",
    "megítélése": "megítélés",
    "megítélésre": "megítélés",
    "megítélésük": "megítélés",
    "megóvják": "megóv",
    "megóvni": "megóv",
    "megóvása": "megóvás",
    "megölelte": "megölel",
    "megöletném": "megölet",
    "megölhetik": "megölhet",
    "megöli": "megöl",
    "megölje": "megöl",
    "megöljék": "megöl",
    "megöljük": "megöl",
    "megölni": "megöl",
    "megölnék": "megöl",
    "megölsz": "megöl",
    "megölte": "megöl",
    "megöltek": "megöl",
    "megölték": "megöl",
    "megöregedett": "megöregedik",
    "megöregszem": "megöregszik",
    "megörökített": "megörökít",
    "megörült": "megörül",
    "megújíthatja": "megújíthat",
    "megújítása": "megújítás",
    "megújításra": "megújítás",
    "megújításának": "megújítás",
    "megújítását": "megújítás",
    "megújítójaként": "megújító",
    "megússza": "megúszik",
    "megúszom": "megúszik",
    "megúsztam": "megúszik",
    "megúsztuk": "megúszik",
    "megüresedett": "megüresedik",
    "megüsse": "megüt",
    "megüssék": "megüt",
    "megüti": "megüt",
    "megütköznek": "megütközik",
    "megütközést": "megütközés",
    "megütközött": "megütközik",
    "megütöttem": "megütött",
    "megőrizheti": "megőrizhet",
    "megőriznek": "megőriz",
    "megőrizni": "megőriz",
    "megőriznie": "megőriz",
    "megőrizte": "megőriz",
    "megőrizték": "megőriz",
    "megőrizzék": "megőriz",
    "megőrzésében": "megőrzés",
    "megőrzését": "megőrzés",
    "megőrzéséért": "megőrzés",
    "megőszült": "megőszül",
    "mehessen": "mehet",
    "mehessenek": "mehet",
    "mehetek": "mehet",
    "mehetett": "mehet",
    "mehetnek": "mehet",
    "mehettek": "mehet",
    "mehettünk": "mehet",
    "mehetünk": "mehet",
    "mekkorák": "mekkora",
    "melankolikusan": "melankolikus",
    "meleg-et": "meleg1",
    "melegben": "meleg",
    "melegebb": "meleg",
    "melegebbet": "meleg",
    "melegebbé": "meleg",
    "melegedett": "melegedik",
    "melegednek": "melegedik",
    "melegedtek": "melegedik",
    "melegek": "meleg",
    "melegen": "meleg",
    "meleget": "meleg",
    "meleggé": "meleg",
    "melegnek": "meleg",
    "melegtől": "meleg",
    "melegvíz-ellátását": "melegvíz-ellátás",
    "melegért": "meleg",
    "melegét": "meleg",
    "melegével": "meleg",
    "melegítette": "melegít",
    "melegítették": "melegítet",
    "melegíti": "melegít",
    "melegítik": "melegít",
    "melegítése": "melegítés",
    "melegítőcsövekhez": "melegítőcső",
    "melegítőn": "melegítő",
    "melle": "mell",
    "mellemre": "mell",
    "mellette": "mellett",
    "mellettem": "mellett",
    "mellettük": "mellett",
    "mellettünk": "mellett",
    "mellkasa": "mellkas",
    "mellkasára": "mellkas",
    "mellszobrait": "mellszobor",
    "mellszobrát": "mellszobor",
    "melltűk": "melltű",
    "mellvédjének": "mellvéd",
    "mellyel": "mely",
    "mellé": "mell",
    "mellében": "mell",
    "mellédugja": "mellédug",
    "melléfolyatja": "melléfolyat",
    "melléje": "melléj",
    "mellékelni": "mellékel",
    "mellékjelentése": "mellékjelentés",
    "mellékletben": "melléklet",
    "mellékneveink": "melléknév",
    "melléknevek": "melléknév",
    "mellékneveket": "melléknév",
    "melléknevekkel": "melléknév",
    "melléknévként": "melléknév",
    "mellékutak": "mellékút",
    "mellékutakon": "mellékút",
    "mellékutcába": "mellékutca",
    "mellékutcában": "mellékutca",
    "mellékutcából": "mellékutca",
    "mellékutcákban": "mellékutca",
    "mellékutcának": "mellékutca",
    "mellékvágányon": "mellékvágány",
    "mellékvágányán": "mellékvágány",
    "mellékágrendszerben": "mellékágrendszer",
    "mellékösvényre": "mellékösvény",
    "mellénk": "mellé",
    "mellények": "mellény",
    "mellényhez": "mellény",
    "mellényében": "mellény",
    "mellére": "mell",
    "mellét": "mell",
    "melléírják": "melléír",
    "mellük": "mell",
    "mellőztetéstől": "mellőztetés",
    "melybe": "mely",
    "melyben": "mely",
    "melyből": "mely",
    "melyek": "mely",
    "melyeket": "mely",
    "melyekhez": "mely",
    "melyekkel": "mely",
    "melyeknek": "mely",
    "melyekről": "mely",
    "melyektől": "mely",
    "melyen": "mely",
    "melyet": "mely",
    "melyhez": "mely",
    "melyikben": "melyik",
    "melyiket": "melyik",
    "melyikkel": "melyik",
    "melyikük": "melyik",
    "melyikünk": "melyik",
    "melynek": "mely",
    "melyre": "mely",
    "melyről": "mely",
    "melyért": "mely",
    "memorandumokat": "memorandum",
    "memóriájának": "memória",
    "mendemondákat": "mendemonda",
    "menedzseli": "menedzsel",
    "menedzserei": "menedzser",
    "menedzsereket": "menedzser",
    "menedzsmentet": "menedzsment",
    "menedzsmentje": "menedzsment",
    "menedzsmentjével": "menedzsment",
    "menedzsmentnek": "menedzsment",
    "menedéke": "menedék",
    "menekítették": "menekítet",
    "menekülhetett": "menekülhet",
    "menekülhetünk": "menekülhet",
    "meneküljenek": "menekül",
    "meneküljél": "menekül",
    "meneküljön": "menekül",
    "menekülni": "menekül",
    "menekült": "menekül",
    "menekültek": "menekült",
    "menekültekkel": "menekült",
    "menekültem": "menekült",
    "menekülések": "menekülés",
    "menekülőkkel": "menekülő",
    "menekülőnek": "menekülő",
    "menetben": "menet",
    "menetelnek": "menetel",
    "menetelt": "menetel",
    "meneteltek": "menetelt",
    "menetközben": "menetköz",
    "menj": "megy",
    "menjek": "megy",
    "menjen": "megy",
    "menjenek": "megy",
    "menjetek": "megy",
    "menjünk": "megy",
    "menne": "megy",
    "mennek": "megy",
    "mennem": "megy",
    "menni": "megy",
    "mennie": "megy",
    "mennyezete": "mennyezet",
    "mennyezetig": "mennyezet",
    "mennyezetképekig": "mennyezetkép",
    "mennyezetre": "mennyezet",
    "mennyezetről": "mennyezet",
    "mennyibe": "mennyi",
    "mennyiben": "mennyi",
    "mennyien": "mennyi",
    "mennyire": "mennyi",
    "mennyiségben": "mennyiség",
    "mennyisége": "mennyiség",
    "mennyiséget": "mennyiség",
    "mennyiséggel": "mennyiség",
    "mennyit": "mennyi",
    "mennyivel": "mennyi",
    "mennék": "megy",
    "mennél": "megy",
    "mennünk": "megy",
    "ment": "megy",
    "mentalitása": "mentalitás",
    "mente": "ment",
    "mentegetőzhetik": "mentegetőzhet",
    "mentek": "ment",
    "mentem": "ment",
    "menten": "ment",
    "menteni": "ment",
    "mentenie": "ment",
    "mentességét": "mentesség",
    "mentesz": "ment",
    "mentesíteni": "mentesít",
    "mentesíti": "mentesít",
    "mentesülhessen": "mentesülhet",
    "menti": "ment",
    "mentorától": "mentor",
    "mentsen": "ment",
    "mentén": "mente",
    "mentünk": "ment",
    "mentőangyalnak": "mentőangyal",
    "mentőcsónakot": "mentőcsónak",
    "mentők": "mentő",
    "menyasszonyt": "menyasszony",
    "menye": "meny",
    "menyecskék": "menyecské",
    "menyecskéket": "menyecské",
    "menyecskékért": "menyecské",
    "menyecskének": "menyecské",
    "menésünk": "menés",
    "menőben": "menő",
    "meredek": "mered",
    "meredeztek": "meredez",
    "meredt": "mered",
    "meredtek": "meredt",
    "meregette": "mereget",
    "meregették": "mereget",
    "merem": "mer",
    "merengéseihez": "merengés",
    "meresztette": "mereszt",
    "merevedett": "merevedik",
    "mereven": "merev",
    "merevsége": "merevség",
    "merevségével": "merevség",
    "meri": "mer",
    "merik": "mer",
    "mernek": "mer",
    "merné": "mer",
    "mernék": "mer",
    "merném": "mer",
    "mert": "mer",
    "merte": "mer",
    "merted": "mert",
    "mertek": "mert",
    "mertem": "mert",
    "merték": "mer",
    "mertük": "mer",
    "mertünk": "mert",
    "merényletek": "merénylet",
    "merényletet": "merénylet",
    "merényletével": "merénylet",
    "merénylők": "merénylő",
    "merészebb": "merész",
    "merészen": "merész",
    "merülni": "merül",
    "merült": "merül",
    "merülten": "merült",
    "merőkanállal": "merőkanál",
    "mesevilágának": "mesevilág",
    "messzeségbe": "messzeség",
    "messzeségből": "messzeség",
    "messzeségekbe": "messzeség",
    "messzibbre": "messzi",
    "messzire": "messzi",
    "messziről": "messzi",
    "mesterei": "mester",
    "mesterhármast": "mesterhármas",
    "mesteriskolájában": "mesteriskola",
    "mesterkedett": "mesterkedik",
    "mesterkélten": "mesterkélt",
    "mesterrel": "mester",
    "mesterről": "mester",
    "mesterségesen": "mesterséges",
    "mesterségéhez": "mesterség",
    "mestert": "mester",
    "mesterére": "mester",
    "mesterét": "mester",
    "mesterével": "mester",
    "meszelt": "meszel",
    "mesébe": "mese",
    "mesében": "mese",
    "meséiben": "mese",
    "meséit": "mese",
    "meséjét": "mese",
    "mesék": "mese",
    "mesékben": "mese",
    "mesékből": "mese",
    "meséli": "mesél",
    "mesélik": "mesél",
    "mesélni": "mesél",
    "mesélt": "mesél",
    "mesélte": "mesél",
    "meséltek": "mesélt",
    "meséltem": "mesélt",
    "mesélték": "mesél",
    "mesésebbé": "mesés",
    "mesésen": "mesés",
    "mesét": "mese",
    "mesével": "mese",
    "metszetet": "metszet",
    "metszette": "metszet",
    "metódusának": "metódus",
    "mezei": "mező",
    "mezején": "mező",
    "mezejét": "mező",
    "mezt": "mez",
    "meztelenre": "meztelen",
    "meztelenül": "meztelen",
    "mezőben": "mező",
    "mezők": "mező",
    "mezőn": "mező",
    "mezőnek": "mező",
    "mezőnyben": "mezőny",
    "mezőnyében": "mezőny",
    "mezőre": "mezőr",
    "mezőtúrról": "mezőtúr",
    "mezővárosból": "mezőváros",
    "miatta": "miatt",
    "miattunk": "miatt",
    "mibe": "mi",
    "miben": "mi",
    "miből": "mi",
    "micsodák": "micsoda",
    "mid": "mi",
    "miegymást": "miegymás",
    "mieink": "mi",
    "mienk": "mi",
    "mienkhez": "mi",
    "mifelénk": "mifelé",
    "mifélék": "miféle",
    "mihez": "mi",
    "mik": "mi",
    "miket": "mi",
    "mikkel": "mi",
    "mikor": "mi",
    "mikrofonjához": "mikrofon",
    "mikrofonok": "mikrofon",
    "mikrofonról": "mikrofon",
    "mikrofont": "mikrofon",
    "miként": "mi",
    "mikéntjéről": "miként",
    "milicisták": "milicista",
    "milliméterrel": "milliméter",
    "milliárddal": "milliárd",
    "milliárdnyit": "milliárdnyi",
    "milliárdokat": "milliárd",
    "milliárdot": "milliárd",
    "milliárdra": "milliárd",
    "milliárdról": "milliárd",
    "milliárdért": "milliárd",
    "millióba": "millió",
    "milliói": "millió",
    "millióit": "millió",
    "milliókat": "millió",
    "milliókkal": "millió",
    "milliónál": "millió",
    "millióra": "millió",
    "milliószor": "millió",
    "milliót": "millió",
    "milyen": "mily",
    "milyenek": "milyen",
    "min": "mi",
    "mindabban": "mindaz",
    "mindaddig": "mindaz",
    "mindannyian": "mindannyi",
    "mindazok": "mindaz",
    "mindazokat": "mindaz",
    "mindazokkal": "mindaz",
    "mindazokról": "mindaz",
    "mindazt": "mindaz",
    "mindebben": "mindez",
    "mindeddig": "mindez",
    "mindegyikben": "mindegyik",
    "mindegyike": "mindegyik",
    "mindegyiknek": "mindegyik",
    "mindegyikre": "mindegyiker",
    "mindegyikét": "mindegyik",
    "mindegyiküknek": "mindegyik",
    "mindegyikünk": "mindegyik",
    "mindehhez": "mindez",
    "minden": "mind",
    "mindenben": "minden",
    "mindenből": "minden",
    "mindenedből": "minden",
    "mindenek": "minden",
    "mindenen": "minden",
    "mindenesetre": "mindeneset",
    "mindenestre": "mindenest",
    "mindenestül": "mindenest",
    "mindenféleképpen": "mindenféle",
    "mindenfélék": "mindenféle",
    "mindenféléről": "mindenféle",
    "mindenhatók": "mindenható",
    "mindenhez": "minden",
    "mindenkiben": "mindenki",
    "mindenkiből": "mindenki",
    "mindenkin": "mindenki",
    "mindenkinek": "mindenki",
    "mindenkinél": "mindenki",
    "mindenkire": "mindenki",
    "mindenkiről": "mindenki",
    "mindenkit": "mindenki",
    "mindenkivel": "mindenki",
    "mindenkor": "minden",
    "mindenkorra": "mindenkor",
    "mindenképp": "minden",
    "mindenképpen": "minden",
    "mindennapjai": "mindennap",
    "mindennaposak": "mindennapos",
    "mindennek": "mindez",
    "mindennél": "minden",
    "mindenre": "minden",
    "mindenről": "minden",
    "mindent": "minden",
    "mindentudása": "mindentudás",
    "mindentől": "minden",
    "mindenáron": "mindenár",
    "mindenért": "minden",
    "mindenük": "minden",
    "mindenünket": "minden",
    "minderre": "mindez",
    "minderről": "mindez",
    "mindet": "mind",
    "mindezek": "mindez",
    "mindezeket": "mindez",
    "mindezt": "mindez",
    "mindezzel": "mindez",
    "mindhármukat": "mindhárom",
    "mindig": "mind",
    "mindinkább": "mindinka",
    "mindkettejüket": "mindkettő",
    "mindkettőben": "mindkettő",
    "mindkettőből": "mindkettő",
    "mindkettőjük": "mindkettő",
    "mindkettőjüket": "mindkettőjük",
    "mindkettőjükön": "mindkettő",
    "mindkettőre": "mindkettő",
    "mindkettőt": "mindkettő",
    "mindmáig": "mindma",
    "mindnek": "mind",
    "mindnyájukat": "mindnyáj",
    "mindnyájukért": "mindnyáj",
    "mindnyájunkat": "mindnyáj",
    "mindnyájunknak": "mindnyáj",
    "mindvégig": "mindvég",
    "minek": "mi",
    "minekünk": "mi",
    "minimumot": "minimum",
    "minimumra": "minimum",
    "minimumának": "minimum",
    "minimálbérben": "minimálbér",
    "minimálbérrel": "minimálbér",
    "minimálbért": "minimálbér",
    "minimálisan": "minimális",
    "minisztere": "miniszter",
    "miniszterek": "miniszter",
    "minisztereként": "miniszter",
    "miniszterelnök-jelöltként": "miniszterelnök-jelölt",
    "miniszterelnöke": "miniszterelnök",
    "miniszterelnökeként": "miniszterelnök",
    "miniszterelnökkel": "miniszterelnök",
    "miniszterelnökként": "miniszterelnök",
    "miniszterelnöknek": "miniszterelnök",
    "miniszterelnöksége": "miniszterelnökség",
    "miniszterelnökséget": "miniszterelnökség",
    "miniszterelnökünkké": "miniszterelnök",
    "miniszternek": "miniszter",
    "miniszterrel": "miniszter",
    "minisztert": "miniszter",
    "miniszterének": "miniszter",
    "minisztériuma": "minisztérium",
    "minisztériumban": "minisztérium",
    "minisztériumból": "minisztérium",
    "minisztériumnak": "minisztérium",
    "minisztériumok": "minisztérium",
    "minisztériumokban": "minisztérium",
    "minisztériumot": "minisztérium",
    "mink": "mi",
    "minket": "mi",
    "mintapéldánya": "mintapéldány",
    "mintatelepnek": "mintatelep",
    "mintái": "minta",
    "mintájára": "minta",
    "mintákat": "minta",
    "mintán": "minta",
    "mintázott": "mintáz",
    "mintázták": "mintáz",
    "minálunk": "mi",
    "minél": "mi",
    "minőségben": "minőség",
    "minősége": "minőség",
    "minőségre": "minőség",
    "minőségében": "minőség",
    "minőségén": "minőség",
    "minőségérzékére": "minőségérzék",
    "minőségét": "minőség",
    "minőségűek": "minőségű",
    "minősített": "minősít",
    "minősítette": "minősít",
    "minősíthettek": "minősíthet",
    "minősítik": "minősít",
    "minősítést": "minősítés",
    "minősítését": "minősítés",
    "minősítésével": "minősítés",
    "mire": "mi",
    "miről": "mi",
    "misztikuma": "misztikum",
    "misztikumát": "misztikum",
    "mit": "mi",
    "mitológiát": "mitológia",
    "mitévők": "mitévő",
    "mitől": "mi",
    "mivel": "mi",
    "mivoltával": "mivolt",
    "mivé": "mi",
    "miénk": "mi",
    "miénkhez": "mi",
    "miért": "mi",
    "miért-en": "miért",
    "miértet": "miért",
    "mobiltelefonját": "mobiltelefon",
    "mocskolták": "mocskol",
    "mocskolódtunk": "mocskolódik",
    "mocskolója": "mocskoló",
    "mocskosak": "mocskos",
    "mocskosoknak": "mocskos",
    "mocskossága": "mocskosság",
    "mocskot": "mocsok",
    "mocskunk": "mocsok",
    "mocsoktól": "mocsok",
    "mocsárban": "mocsár",
    "modellekben": "modell",
    "modelljeiből": "modell",
    "modelljeinek": "modell",
    "modelljeivel": "modell",
    "modellt": "modell",
    "modora": "modor",
    "modorban": "modor",
    "modorosságát": "modorosság",
    "modoruk": "modor",
    "modorába": "modor",
    "modorában": "modor",
    "modorától": "modor",
    "mogyoróbokrok": "mogyoróbokor",
    "mohón": "mohó",
    "mohósággal": "mohóság",
    "moldáviaiakkal": "moldáviai",
    "molekulák": "molekula",
    "molochnak": "moloch",
    "momentumnak": "momentum",
    "momentumra": "momentum",
    "mondakörben": "mondakör",
    "mondanak": "mond",
    "mondandójára": "mondandó",
    "mondandóját": "mondandó",
    "mondani": "mond",
    "mondania": "mond",
    "mondanivalód": "mondanivaló",
    "mondanivalója": "mondanivaló",
    "mondanivalójuk": "mondanivaló",
    "mondanivalójukat": "mondanivaló",
    "mondanivalójának": "mondanivaló",
    "mondanivalóját": "mondanivaló",
    "mondanivalómat": "mondanivaló",
    "mondanom": "mond",
    "mondanunk": "mond",
    "mondaná": "mond",
    "mondanák": "mond",
    "mondanánk": "mond",
    "mondasz": "mond",
    "mondata": "mondat",
    "mondatai": "mondat",
    "mondataiból": "mondat",
    "mondataihoz": "mondat",
    "mondatait": "mondat",
    "mondatok": "mondat",
    "mondatokat": "mondat",
    "mondatot": "mondat",
    "mondatra": "mondat",
    "mondatról": "mondat",
    "mondatszerkezetet": "mondatszerkezet",
    "mondatta": "mondat",
    "mondatát": "mondat",
    "mondd": "mond",
    "mondhassa": "mondhat",
    "mondhatja": "mondhat",
    "mondhatjuk": "mondhat",
    "mondhatják": "mondhat",
    "mondhatnak": "mondhat",
    "mondhatni": "mondhat",
    "mondhatná": "mondhat",
    "mondhatnám": "mondhat",
    "mondhatnék": "mondhat",
    "mondhatok": "mondhat",
    "mondhatom": "mondhat",
    "mondhattok": "mondhat",
    "mondhatták": "mondhat",
    "mondhatunk": "mondhat",
    "mondj": "mond",
    "mondja": "mond",
    "mondjak": "mond",
    "mondjam": "mond",
    "mondjon": "mond",
    "mondjuk": "mond",
    "mondják": "mond",
    "mondjátok": "mond",
    "mondod": "mond",
    "mondogatni": "mondogat",
    "mondogatta": "mondogat",
    "mondok": "mond",
    "mondom": "mond",
    "mondott": "mond",
    "mondotta": "mond",
    "mondottan": "mondott",
    "mondottunk": "mondott",
    "mondta": "mond",
    "mondtak": "mond",
    "mondtam": "mond",
    "mondtuk": "mond",
    "mondtunk": "mond",
    "mondták": "mond",
    "mondtál": "mond",
    "mondunk": "mond",
    "mondókájába": "mondóka",
    "mondókájában": "mondóka",
    "mongolok": "mongol",
    "monológot": "monológ",
    "monopolhelyzetének": "monopolhelyzet",
    "monopóliumok": "monopólium",
    "monopóliumának": "monopólium",
    "moralizálásra": "moralizálás",
    "morcossága": "morcosság",
    "morgott": "morog",
    "mormogott": "mormog",
    "mormogta": "mormog",
    "mormolja": "mormol",
    "mormolt": "mormol",
    "mormolta": "mormol",
    "morogni": "morog",
    "morogta": "morog",
    "morzsái": "morzsa",
    "morzsákat": "morzsa",
    "morálra": "morál",
    "mosakodhassék": "mosakodhat",
    "mosdatlanul": "mosdatlan",
    "mosdáshoz": "mosdás",
    "mosdásra": "mosdás",
    "mosdóba": "mosdó",
    "mosdók": "mosdó",
    "mosdókban": "mosdó",
    "mosdótálban": "mosdótál",
    "mosnak": "mos",
    "mosni": "mos",
    "mosogatómat": "mosogató",
    "mosogatószaguk": "mosogatószag",
    "mosollyal": "mosoly",
    "mosolya": "mosoly",
    "mosolygott": "mosolyog",
    "mosolyodott": "mosolyodik",
    "mosolyogna": "mosolyog",
    "mosolyognak": "mosolyog",
    "mosolyogni": "mosolyog",
    "mosolyognia": "mosolyog",
    "mosolyogtak": "mosolyog",
    "mosolyok": "mosoly",
    "mosolyt": "mosoly",
    "mosolyán": "mosoly",
    "mosolyával": "mosoly",
    "mosott": "mos",
    "mosta": "mos",
    "mostanihoz": "mostani",
    "mostaninál": "mostani",
    "mostohább": "mostoha",
    "mosták": "mos",
    "mosunk": "mos",
    "moszkvaiak": "moszkvai",
    "mosóteknőt": "mosóteknő",
    "motivációt": "motiváció",
    "motiválja": "motivál",
    "motiválna": "motivál",
    "motorhoz": "motor",
    "motorháztetővel": "motorháztető",
    "motorjának": "motor",
    "motorjává": "motor",
    "motort": "motor",
    "motozott": "motoz",
    "mottója": "mottó",
    "motyogott": "motyog",
    "motyogta": "motyog",
    "mozdonyok": "mozdony",
    "mozdonyt": "mozdony",
    "mozdonyvezetőket": "mozdonyvezető",
    "mozdonyvezetőnk": "mozdonyvezető",
    "mozdonyvezetőt": "mozdonyvezető",
    "mozdulata": "mozdulat",
    "mozdulatai": "mozdulat",
    "mozdulataiban": "mozdulat",
    "mozdulataik": "mozdulat",
    "mozdulatainak": "mozdulat",
    "mozdulataival": "mozdulat",
    "mozdulatlanságában": "mozdulatlanság",
    "mozdulatlanul": "mozdulatlan",
    "mozdulatnak": "mozdulat",
    "mozdulatok": "mozdulat",
    "mozdulatokkal": "mozdulat",
    "mozdulatot": "mozdulat",
    "mozdulattal": "mozdulat",
    "mozdulatában": "mozdulat",
    "mozdulatán": "mozdulat",
    "mozdulatának": "mozdulat",
    "mozdulatára": "mozdulat",
    "mozdulatát": "mozdulat",
    "mozdulatával": "mozdulat",
    "mozdulhatott": "mozdulhat",
    "mozdulj": "mozdul",
    "mozdulni": "mozdul",
    "mozdult": "mozdul",
    "mozdultak": "mozdult",
    "mozdítani": "mozdít",
    "mozdíthatatlanul": "mozdíthatatlan",
    "mozdította": "mozdít",
    "mozgalmak": "mozgalom",
    "mozgalmakkal": "mozgalom",
    "mozgalmaknak": "mozgalom",
    "mozgalmasságában": "mozgalmasság",
    "mozgalmának": "mozgalom",
    "mozgalmát": "mozgalom",
    "mozgalomban": "mozgalom",
    "mozgalomból": "mozgalom",
    "mozgalomnak": "mozgalom",
    "mozgalomra": "mozgalom",
    "mozgatja": "mozgat",
    "mozgatják": "mozgat",
    "mozgattak": "mozgat",
    "mozgatóerők": "mozgatóerő",
    "mozgott": "mozog",
    "mozgása": "mozgás",
    "mozgásképtelenek": "mozgásképtelen",
    "mozgásnak": "mozgás",
    "mozgásokat": "mozgás",
    "mozgásteret": "mozgástér",
    "mozgásuk": "mozgás",
    "mozgását": "mozgás",
    "mozgásával": "mozgás",
    "mozgósította": "mozgósít",
    "mozgósították": "mozgósít",
    "moziban": "mozi",
    "mozik": "mozi",
    "mozogjon": "mozog",
    "mozognak": "mozog",
    "mozogni": "mozog",
    "mozogtak": "mozog",
    "mozogtam": "mozog",
    "mozzanatot": "mozzanat",
    "mulasson": "mulat",
    "mulassza": "mulaszt",
    "mulasszátok": "mulaszt",
    "mulasztani": "mulaszt",
    "mulasztott": "mulaszt",
    "mulasztásban": "mulasztás",
    "mulasztást": "mulasztás",
    "mulatna": "mulat",
    "mulatnak": "mulat",
    "mulatott": "mulat",
    "mulatoztunk": "mulatozik",
    "mulatsághoz": "mulatság",
    "mulatságot": "mulatság",
    "mulatságra": "mulatság",
    "mulatságához": "mulatság",
    "mulattatásnak": "mulattatás",
    "multiplexben": "multiplex",
    "munkaadói": "munkaadó",
    "munkaadók": "munkaadó",
    "munkaadóknál": "munkaadó",
    "munkaadóval": "munkaadó",
    "munkabefektetéssel": "munkabefektetés",
    "munkabizottságnak": "munkabizottság",
    "munkabékét": "munkabéke",
    "munkabérük": "munkabér",
    "munkabírásra": "munkabírás",
    "munkacsoportja": "munkacsoport",
    "munkadarabjaid": "munkadarab",
    "munkadarabot": "munkadarab",
    "munkadokumentumnak": "munkadokumentum",
    "munkaerkölcsöket": "munkaerkölcs",
    "munkaerő-fölöslegét": "munkaerő-fölösleg",
    "munkaerőben": "munkaerő",
    "munkaerőhöz": "munkaerő",
    "munkaerőmérlegét": "munkaerőmérleg",
    "munkaerőpiacon": "munkaerőpiac",
    "munkaerőt": "munkaerő",
    "munkaerőért": "munkaerő",
    "munkahelye": "munkahely",
    "munkahelyedre": "munkahely",
    "munkahelyeikre": "munkahely",
    "munkahelyek": "munkahely",
    "munkahelyre": "munkahely",
    "munkahelyteremtést": "munkahelyteremtés",
    "munkahelyén": "munkahely",
    "munkahelyére": "munkahely",
    "munkaideje": "munkaidő",
    "munkaidejük": "munkaidő",
    "munkakedvet": "munkakedv",
    "munkakönyvemet": "munkakönyv",
    "munkaközben": "munkaköz",
    "munkalehetőséget": "munkalehetőség",
    "munkalátogatásán": "munkalátogatás",
    "munkamegosztásával": "munkamegosztás",
    "munkamódszert": "munkamódszer",
    "munkanapot": "munkanap",
    "munkanélküli-táborral": "munkanélküli-tábor",
    "munkanélküliek": "munkanélküli",
    "munkanélkülieket": "munkanélküli",
    "munkanélkülieknek": "munkanélküli",
    "munkanélkülinek": "munkanélküli",
    "munkanélküliséggel": "munkanélküliség",
    "munkanélküliségnek": "munkanélküliség",
    "munkanélküliségről": "munkanélküliség",
    "munkanélkülit": "munkanélküli",
    "munkanélkülivel": "munkanélküli",
    "munkarendet": "munkarend",
    "munkastílust": "munkastílus",
    "munkaszerződésekkel": "munkaszerződés",
    "munkatelepe": "munkatelep",
    "munkatempót": "munkatempó",
    "munkaterületek": "munkaterület",
    "munkatáborban": "munkatábor",
    "munkatársa": "munkatárs",
    "munkatársai": "munkatárs",
    "munkatársait": "munkatárs",
    "munkatársaitól": "munkatárs",
    "munkatársaival": "munkatárs",
    "munkatársként": "munkatárs",
    "munkatársunknak": "munkatárs",
    "munkatársának": "munkatárs",
    "munkatársától": "munkatárs",
    "munkaviszonyodat": "munkaviszony",
    "munkaviszonyomat": "munkaviszony",
    "munkaviszonyt": "munkaviszony",
    "munkavállalói": "munkavállaló",
    "munkavállalók": "munkavállaló",
    "munkavállalókkal": "munkavállaló",
    "munkavállalóknak": "munkavállaló",
    "munkaügyekben": "munkaügy",
    "munkába": "munka",
    "munkában": "munka",
    "munkából": "munka",
    "munkához": "munka",
    "munkái": "munka",
    "munkáit": "munka",
    "munkája": "munka",
    "munkájuk": "munka",
    "munkájukat": "munka",
    "munkájukban": "munka",
    "munkájukhoz": "munka",
    "munkájukkal": "munka",
    "munkájukról": "munka",
    "munkáján": "munka",
    "munkájának": "munka",
    "munkájára": "munka",
    "munkájáról": "munka",
    "munkáját": "munka",
    "munkájával": "munka",
    "munkák": "munka",
    "munkákat": "munka",
    "munkáknál": "munka",
    "munkálatai": "munkálat",
    "munkálataiba": "munkálat",
    "munkálataiban": "munkálat",
    "munkálatok": "munkálat",
    "munkálatokat": "munkálat",
    "munkálatokra": "munkálat",
    "munkálják": "munkál",
    "munkálkodnak": "munkálkodik",
    "munkáltatói": "munkáltató",
    "munkáltatóinak": "munkáltatóín",
    "munkáltatók": "munkáltató",
    "munkáltatókkal": "munkáltató",
    "munkám": "munka",
    "munkámban": "munka",
    "munkán": "munka",
    "munkának": "munka",
    "munkánk": "munka",
    "munkára": "munka",
    "munkása": "munkás",
    "munkásainak": "munkás",
    "munkáscsapatokat": "munkáscsapat",
    "munkáscsapattal": "munkáscsapat",
    "munkásemberek": "munkásember",
    "munkásembernek": "munkásember",
    "munkásmozgalomban": "munkásmozgalom",
    "munkásnak": "munkás",
    "munkások": "munkás",
    "munkásokat": "munkás",
    "munkásokkal": "munkás",
    "munkásoknak": "munkás",
    "munkáspártnál": "munkáspárt",
    "munkáspártoknak": "munkáspárt",
    "munkáspártra": "munkáspárt",
    "munkással": "munkás",
    "munkássága": "munkásság",
    "munkásságban": "munkásság",
    "munkásságának": "munkásság",
    "munkásságát": "munkásság",
    "munkásságával": "munkásság",
    "munkástanácsot": "munkástanács",
    "munkástársaim": "munkástárs",
    "munkástárssal": "munkástárs",
    "munkásának": "munkás",
    "munkát": "munka",
    "munkától": "munka",
    "munkával": "munka",
    "munkává": "munka",
    "munkáért": "munka",
    "murányit": "murányi",
    "muszlinfüggönyön": "muszlinfüggöny",
    "mutassam": "mutat",
    "mutassanak": "mutat",
    "mutatja": "mutat",
    "mutatjuk": "mutat",
    "mutatják": "mutat",
    "mutatkozhatnak": "mutatkozhat",
    "mutatkoznak": "mutatkozik",
    "mutatkozni": "mutatkozik",
    "mutatkozott": "mutatkozik",
    "mutatkoztak": "mutatkozik",
    "mutatnak": "mutat",
    "mutatni": "mutat",
    "mutatnom": "mutat",
    "mutatná": "mutat",
    "mutatok": "mutat",
    "mutatom": "mutat",
    "mutatott": "mutat",
    "mutatta": "mutat",
    "mutattak": "mutat",
    "mutatták": "mutat",
    "mutatványa": "mutatvány",
    "mutatói": "mutató",
    "mutatóit": "mutatói",
    "mutatója": "mutató",
    "mutatóját": "mutató",
    "mutatók": "mutató",
    "mutatót": "mutató",
    "mutatóujja": "mutatóujj",
    "mutatóujjammal": "mutatóujj",
    "mutatóujjával": "mutatóujj",
    "mutogatná": "mutogat",
    "mutogatott": "mutogat",
    "mutálni": "mutál",
    "muzsikusok": "muzsikus",
    "muzsikust": "muzsikus",
    "muzsikában": "muzsika",
    "muzsikájának": "muzsika",
    "muzsikálnak": "muzsikál",
    "muzsikát": "muzsika",
    "muzulmánok": "muzulmán",
    "máglyán": "máglya",
    "máglyára": "máglya",
    "mágnesként": "mágnes",
    "májusban": "május",
    "májusra": "május",
    "májustól": "május",
    "májusában": "május",
    "májátültetéshez": "májátültetés",
    "mák": "ma",
    "málnafagylaltját": "málnafagylalt",
    "málé": "mál",
    "málét": "málé",
    "málétól": "málé",
    "mámora": "mámor",
    "mámorosan": "mámoros",
    "mámort": "mámor",
    "mámorában": "mámor",
    "mán": "ma",
    "mára": "ma",
    "márciusban": "március",
    "márciusig": "március",
    "márciusra": "március",
    "márciustól": "március",
    "márciusában": "március",
    "márgának": "márga",
    "márkanévvel": "márkanév",
    "márkáig": "márka",
    "márkák": "márka",
    "márkánál": "márka",
    "márkát": "márka",
    "márkával": "márka",
    "mártogatja": "mártogat",
    "mártírjaikkal": "mártír",
    "márványtermében": "márványterem",
    "másból": "más",
    "másfele": "másfél",
    "másik": "más",
    "másikat": "másik",
    "másikba": "másik",
    "másikban": "másik",
    "másikból": "másik",
    "másikhoz": "másik",
    "másikig": "másik",
    "másikkal": "másik",
    "másiknak": "másik",
    "másikon": "másik",
    "másikra": "másik",
    "másikról": "másik",
    "másikuk": "másik",
    "másikéra": "másik",
    "másikért": "másik",
    "másikét": "másik",
    "máskor": "más",
    "máskorra": "máskor",
    "másként": "más",
    "másképp": "más",
    "másképpen": "más",
    "másnak": "más",
    "másnapot": "másnap",
    "másnapra": "másnap",
    "másoddiplomaként": "másoddiploma",
    "másoddiplomát": "másoddiploma",
    "másodfokon": "másodfok",
    "második": "másod",
    "másodikat": "második",
    "másodikba": "második",
    "másodikból": "második",
    "másodikon": "második",
    "másodperccel": "másodperc",
    "másodperce": "másodperc",
    "másodpercek": "másodperc",
    "másodpercekben": "másodperc",
    "másodpercekig": "másodperc",
    "másodpercen": "másodperc",
    "másodpercig": "másodperc",
    "másodpercre": "másodperc",
    "másodsorban": "másodsor",
    "másodvirágzását": "másodvirágzás",
    "mások": "más",
    "másokat": "más",
    "másokban": "más",
    "másokkal": "más",
    "másoknak": "más",
    "másoknál": "más",
    "másokra": "más",
    "másoktól": "más",
    "másoké": "más",
    "másokét": "más",
    "másokéért": "más",
    "másoltam": "másolt",
    "másra": "más",
    "másrészt": "másrész",
    "másról": "más",
    "mással": "más",
    "mást": "más",
    "mástól": "más",
    "másvalakinél": "másvalaki",
    "másvalakire": "másvalaki",
    "másvalakivé": "másvalaki",
    "másvilágról": "másvilág",
    "mászkálnak": "mászkál",
    "másztak": "mászik",
    "mászunk": "mászik",
    "másé": "más",
    "másért": "más",
    "másítania": "másít",
    "mátyásnak": "mátyás",
    "mától": "ma",
    "mázolt": "mázol",
    "mázsát": "mázsa",
    "mécsessel": "mécses",
    "média-tanácsadójának": "média-tanácsadó",
    "médiahatalmáról": "médiahatalom",
    "médiakuratóriumokba": "médiakuratórium",
    "médiatörvénybe": "médiatörvény",
    "médiák": "média",
    "médiáról": "média",
    "mégy": "megy",
    "méhe": "méh",
    "méhükben": "méh",
    "mélabúból": "mélabú",
    "mélabúval": "mélabú",
    "méltatják": "méltat",
    "méltatlanul": "méltatlan",
    "méltatta": "méltat",
    "méltattam": "méltat",
    "méltánylással": "méltánylás",
    "méltányolhatja": "méltányolhat",
    "méltányolni": "méltányol",
    "méltányolta": "méltányol",
    "méltányosságból": "méltányosság",
    "méltánytalanul": "méltánytalan",
    "méltóan": "méltó",
    "méltón": "méltó",
    "méltónak": "méltó",
    "méltósággal": "méltóság",
    "méltóságukat": "méltóság",
    "méltóságának": "méltóság",
    "méltóztatott": "méltóztatik",
    "mélybe": "mély",
    "mélyben": "mély",
    "mélyebb": "mély",
    "mélyebben": "mély",
    "mélyebbre": "mély",
    "mélyebbről": "mély",
    "mélyedt": "mélyed",
    "mélyedésbe": "mélyedés",
    "mélyen": "mély",
    "mélyet": "mély",
    "mélygarázsok": "mélygarázs",
    "mélygarázst": "mélygarázs",
    "mélyhűtőkben": "mélyhűtő",
    "mélypontjára": "mélypont",
    "mélyre": "mély",
    "mélyről": "mély",
    "mélységbe": "mélység",
    "mélységben": "mélység",
    "mélységből": "mélység",
    "mélysége": "mélység",
    "mélységeiben": "mélység",
    "mélységekbe": "mélység",
    "mélységesen": "mélységes",
    "mélységükben": "mélység",
    "mélyébe": "mély",
    "mélyében": "mély",
    "mélyén": "mély",
    "mélyének": "mély",
    "mélyére": "mély",
    "mélyéről": "mély",
    "mélyítik": "mélyít",
    "mércéje": "mérce",
    "mércével": "mérce",
    "méregették": "méreget",
    "méretben": "méret",
    "méretei": "méret",
    "méreteiben": "méret",
    "méreteivel": "méret",
    "méretekben": "méret",
    "méreteket": "méret",
    "méretekre": "méret",
    "méretre": "méret",
    "méretűnek": "méretű",
    "mérgek": "méreg",
    "mérget": "méreg",
    "mérgezett": "mérgez",
    "mérgében": "méreg",
    "mérhetetlenül": "mérhetetlen",
    "mérheti": "mérhet",
    "méri": "mér",
    "mérik": "mér",
    "mérje": "mér",
    "mérjétek": "mér",
    "mérjük": "mér",
    "mérkőzése": "mérkőzés",
    "mérkőzéseiket": "mérkőzés",
    "mérkőzésein": "mérkőzés",
    "mérkőzéseit": "mérkőzés",
    "mérkőzéseitől": "mérkőzés",
    "mérkőzések": "mérkőzés",
    "mérkőzésekre": "mérkőzés",
    "mérkőzésen": "mérkőzés",
    "mérkőzésnek": "mérkőzés",
    "mérkőzésről": "mérkőzés",
    "mérkőzést": "mérkőzés",
    "mérkőzésén": "mérkőzés",
    "mérkőzését": "mérkőzés",
    "mérkőzött": "mérkőzik",
    "mérlegadatai": "mérlegadat",
    "mérlege": "mérleg",
    "mérlegelik": "mérlegel",
    "mérlegelte": "mérlegel",
    "mérlegelve": "mérlegelv",
    "mérleget": "mérleg",
    "mérlegre": "mérleg",
    "mérlegét": "mérleg",
    "mérne": "mér",
    "mérnek": "mér",
    "mérni": "mér",
    "mérnökeivel": "mérnök",
    "mérnökök": "mérnök",
    "mérsékelni": "mérsékel",
    "mérsékelt": "mérsékel",
    "mérsékeltnek": "mérsékelt",
    "mért": "mér",
    "mérte": "mér",
    "mértek": "mért",
    "mérték": "mér",
    "mértékben": "mérték",
    "mértéke": "mérték",
    "mértékig": "mérték",
    "mértékkel": "mérték",
    "mértéktelenül": "mértéktelen",
    "mértékében": "mérték",
    "mértékének": "mérték",
    "mértékéről": "mérték",
    "mértékét": "mérték",
    "mértékétől": "mérték",
    "mértékével": "mérték",
    "mértékük": "mérték",
    "mérve": "mérv",
    "mérése": "mérés",
    "mérései": "mérés",
    "mérések": "mérés",
    "méréseket": "mérés",
    "méréshez": "mérés",
    "mérésre": "mérés",
    "mérőegységet": "mérőegység",
    "mérője": "mérő",
    "mérőn": "mérő",
    "mérővel": "mérő",
    "mérőónként": "mérőón",
    "mészkőpaplannak": "mészkőpaplan",
    "mésztufa-üregek": "mésztufa-üreg",
    "mészárlások": "mészárlás",
    "mészárlásról": "mészárlás",
    "méternyire": "méternyi",
    "méternél": "méter",
    "méterre": "méter",
    "méterrel": "méter",
    "méterről": "méter",
    "métert": "méter",
    "mézeshetek": "mézeshét",
    "mézeshetekben": "mézeshetek",
    "módban": "mód",
    "módja": "mód",
    "módjuk": "mód",
    "módjukban": "mód",
    "módjában": "mód",
    "módján": "mód",
    "módjának": "mód",
    "módjára": "mód",
    "módját": "mód",
    "módnak": "mód",
    "módokat": "mód",
    "módon": "mód",
    "módosak": "módos",
    "módosulnának": "módosul",
    "módosult": "módosul",
    "módosultak": "módosult",
    "módosítani": "módosít",
    "módosíthatja": "módosíthat",
    "módosítják": "módosít",
    "módosította": "módosít",
    "módosították": "módosít",
    "módosítása": "módosítás",
    "módosításaiból": "módosítás",
    "módosításakor": "módosítás",
    "módosításokat": "módosítás",
    "módosításokra": "módosítás",
    "módosításra": "módosítás",
    "módosításukra": "módosítás",
    "módosításában": "módosítás",
    "módosításának": "módosítás",
    "módosításáról": "módosítás",
    "módosítását": "módosítás",
    "módosításától": "módosítás",
    "módot": "mód",
    "módozatot": "módozat",
    "módozatát": "módozat",
    "módra": "mód",
    "módszere": "módszer",
    "módszerei": "módszer",
    "módszereikben": "módszer",
    "módszereiről": "módszer",
    "módszereit": "módszer",
    "módszerek": "módszer",
    "módszereket": "módszer",
    "módszerekkel": "módszer",
    "módszeresebb": "módszeres",
    "módszeresen": "módszeres",
    "módszernek": "módszer",
    "módszerrel": "módszer",
    "módszert": "módszer",
    "módszerét": "módszer",
    "módszerével": "módszer",
    "mögéje": "mögé",
    "mögötted": "mögött",
    "mögöttük": "mögött",
    "mögüle": "mögül",
    "múlatják": "múlat",
    "múlja": "múlik",
    "múljék": "múlik",
    "múlott": "múlik",
    "múlt": "múl",
    "múltak": "múlt",
    "múltat": "múlt",
    "múltba": "múlt",
    "múltban": "múlt",
    "múltból": "múlt",
    "múlthoz": "múlt",
    "múltjukból": "múlt",
    "múltját": "múlt",
    "múltkor": "múlt",
    "múltnak": "múlt",
    "múltra": "múlt",
    "múltról": "múlt",
    "múlttal": "múlt",
    "múlttól": "múlt",
    "múltunk": "múlt",
    "múltunkat": "múlt",
    "múltával": "múlt",
    "múlását": "múlás",
    "múlásával": "múlás",
    "múlóban": "múló",
    "múzeumnak": "múzeum",
    "múzeumra": "múzeum",
    "műalkotások": "műalkotás",
    "műbútorasztalosságot": "műbútorasztalosság",
    "műemlékek": "műemlék",
    "műemlékeknél": "műemlék",
    "műemlékesek": "műemlékes",
    "műemlékvédelemről": "műemlékvédelem",
    "műfajban": "műfaj",
    "műfajból": "műfaj",
    "műfajának": "műfaj",
    "műfogam": "műfog",
    "műgyűjtőnek": "műgyűjtő",
    "műhelyben": "műhely",
    "műhelyek": "műhely",
    "műhelyekben": "műhely",
    "működhetett": "működhet",
    "működjön": "működik",
    "működnek": "működik",
    "működni": "működik",
    "működnie": "működik",
    "működsz": "működik",
    "működtek": "működik",
    "működtem": "működik",
    "működtesse": "működtet",
    "működtetett": "működtet",
    "működtethetnének": "működtethet",
    "működteti": "működtet",
    "működtetne": "működtet",
    "működtetni": "működtet",
    "működtetnie": "működtet",
    "működtetésére": "működtetés",
    "működtetőit": "működtetői",
    "működésbe": "működés",
    "működésben": "működés",
    "működésből": "működés",
    "működése": "működés",
    "működésképtelenné": "működésképtelen",
    "működésre": "működés",
    "működéséhez": "működés",
    "működésére": "működés",
    "működéséről": "működés",
    "működését": "működés",
    "működéséért": "működés",
    "működésük": "működés",
    "működésükhöz": "működés",
    "működött": "működik",
    "működőképességét": "működőképesség",
    "műmellékleteit": "műmelléklet",
    "műmellékleten": "műmelléklet",
    "műsora": "műsor",
    "műsoraiban": "műsor",
    "műsorban": "műsor",
    "műsorhoz": "műsor",
    "műsorok": "műsor",
    "műsorom": "műsor",
    "műsort": "műsor",
    "műsorvezetését": "műsorvezetés",
    "műsorán": "műsor",
    "műszakra": "műszak",
    "műszerek": "műszer",
    "műterem": "műtér",
    "műtermében": "műterem",
    "műterméből": "műterem",
    "műtermének": "műterem",
    "műtárgyától": "műtárgy",
    "műtéteket": "műtét",
    "műve": "mű",
    "művei": "mű",
    "műveinek": "mű",
    "műveit": "mű",
    "műveivel": "mű",
    "művek": "mű",
    "műveket": "mű",
    "művel": "mű",
    "műveleteit": "művelet",
    "műveletekből": "művelet",
    "műveleteket": "művelet",
    "műveletet": "művelet",
    "műveletnek": "művelet",
    "műveletét": "művelet",
    "műveli": "művel",
    "művelik": "művel",
    "műveljen": "művel",
    "művelnek": "művel",
    "művelt": "művel",
    "műveltebbé": "művelt",
    "művelted": "művelt",
    "műveltek": "művelt",
    "műveltette": "műveltet",
    "műveltsége": "műveltség",
    "műveltséget": "műveltség",
    "műveltségét": "műveltség",
    "művelték": "művel",
    "művelődéspolitikája": "művelődéspolitika",
    "művelődést": "művelődés",
    "művében": "mű",
    "művész-értelmiségiek": "művész-értelmiségi",
    "művészei": "művész",
    "művészeink": "művész",
    "művészek": "művész",
    "művészeket": "művész",
    "művészekkel": "művész",
    "művészekre": "művész",
    "művészetből": "művészet",
    "művészete": "művészet",
    "művészetek": "művészet",
    "művészeteket": "művészet",
    "művészeteknél": "művészet",
    "művészetet": "művészet",
    "művészetről": "művészet",
    "művészettől": "művészet",
    "művészetéről": "művészet",
    "művészetéért": "művészet",
    "művészetüket": "művészet",
    "művésznek": "művész",
    "művészt": "művész",
    "művésztehetségek": "művésztehetség",
    "n-t": "n",
    "nacionalizmussal": "nacionalizmus",
    "nacionalizmusáról": "nacionalizmus",
    "nadrágját": "nadrág",
    "nadrágom": "nadrág",
    "nadrágot": "nadrág",
    "nagyanyóra": "nagyanyó",
    "nagyapja": "nagyapa",
    "nagyapját": "nagyapa",
    "nagyapában": "nagyapa",
    "nagyapám": "nagyapa",
    "nagyapát": "nagyapa",
    "nagyban": "nagy",
    "nagybankok": "nagybank",
    "nagyberuházásokat": "nagyberuházás",
    "nagybetűket": "nagybetű",
    "nagybetűkkel": "nagybetű",
    "nagybetűvel": "nagybetű",
    "nagybirtokok": "nagybirtok",
    "nagybátyjai": "nagybátya",
    "nagybátyját": "nagybátya",
    "nagybátyám": "nagybátya",
    "nagybérlők": "nagybérlő",
    "nagyepikából": "nagyepika",
    "nagygazdák": "nagygazda",
    "nagyhatalmak": "nagyhatalom",
    "nagyjából": "nagy",
    "nagyját": "nagy",
    "nagykastélyból": "nagykastély",
    "nagyképűségre": "nagyképűség",
    "nagykövet": "nagykő",
    "nagykövetet": "nagykövet",
    "nagykövettől": "nagykövet",
    "nagykövetüket": "nagykövet",
    "nagylelkűen": "nagylelkű",
    "nagylelkűséggel": "nagylelkűség",
    "nagylányok": "nagylány",
    "nagymosásban": "nagymosás",
    "nagymértékben": "nagymérték",
    "nagynak": "nagy",
    "nagynénéink": "nagynéne",
    "nagyobb": "nagy",
    "nagyobbak": "nagy",
    "nagyobbakban": "nagy",
    "nagyobbat": "nagy",
    "nagyobbnak": "nagy",
    "nagyobbra": "nagy",
    "nagyok": "nagy",
    "nagyokat": "nagy",
    "nagyoknak": "nagy",
    "nagyon": "nagy",
    "nagyoperában": "nagyopera",
    "nagyot": "nagy",
    "nagypapok": "nagypap",
    "nagyra": "nagy",
    "nagyrészt": "nagyrész",
    "nagyszeget": "nagyszeg",
    "nagyszerűbben": "nagyszerű",
    "nagyszerűek": "nagyszerű",
    "nagyszerűen": "nagyszerű",
    "nagyszülei": "nagyszülő",
    "nagyszüleihez": "nagyszülő",
    "nagyszülők": "nagyszülő",
    "nagysága": "nagyság",
    "nagyságig": "nagyság",
    "nagyságok": "nagyság",
    "nagyságrenddel": "nagyságrend",
    "nagyságrendekben": "nagyságrend",
    "nagyságára": "nagysága",
    "nagyságáról": "nagysága",
    "nagyságát": "nagysága",
    "nagytanyát": "nagytanya",
    "nagyterem": "nagytér",
    "nagytermében": "nagyterem",
    "nagyvilágba": "nagyvilág",
    "nagyvágóktól": "nagyvágó",
    "nagyvállalatoknál": "nagyvállalat",
    "nagyvárad": "nagyvár",
    "nagyváradig": "nagyvár",
    "nagyváradnak": "nagyvár",
    "nagyváradra": "nagyvár",
    "nagyvárosban": "nagyváros",
    "nagyvárosokban": "nagyváros",
    "nagyzolni": "nagyzol",
    "nagyállomáshoz": "nagyállomás",
    "nagyállomáson": "nagyállomás",
    "nagyított": "nagyít",
    "nagyüzemben": "nagyüzem",
    "nagyüzemeinek": "nagyüzem",
    "nagyüzemek": "nagyüzem",
    "naivak": "naiv",
    "naivul": "naiv",
    "napfeljöttekor": "napfeljötte",
    "napfogyatkozást": "napfogyatkozás",
    "napfénnyel": "napfény",
    "napfényben": "napfény",
    "naphosszat": "naphossz",
    "napig": "nap",
    "napilapja": "napilap",
    "napilapjához": "napilap",
    "napilapok": "napilap",
    "napiparancsa": "napiparancs",
    "napiparancsának": "napiparancs",
    "napiparancsát": "napiparancs",
    "napirendjén": "napirend",
    "napirendjének": "napirend",
    "napirendjére": "napirend",
    "napirendjéről": "napirend",
    "napirendjét": "napirend",
    "napirendre": "napirend",
    "napirendről": "napirend",
    "napit": "napi",
    "napja": "nap",
    "napjaiban": "nap",
    "napjaink": "nap",
    "napjainkban": "nap",
    "napjainkra": "nap",
    "napjait": "nap",
    "napjukat": "nap",
    "napjában": "nap",
    "napján": "nap",
    "napjának": "nap",
    "napjára": "nap",
    "napját": "nap",
    "napközben": "napköz",
    "naplementét": "naplemente",
    "naplopók": "naplopó",
    "naplóba": "napló",
    "naplódba": "napló",
    "naplója": "napló",
    "naplójába": "napló",
    "naplójához": "napló",
    "naplóját": "napló",
    "naplónak": "napló",
    "naplót": "napló",
    "naplóírásba": "naplóírás",
    "napnak": "nap",
    "napnál": "nap",
    "napok": "nap",
    "napokat": "nap",
    "napokban": "nap",
    "napokig": "nap",
    "napoknak": "nap",
    "napokon": "nap",
    "napokra": "nap",
    "napokról": "nap",
    "napon": "nap",
    "naponként": "nap",
    "naposcsibék": "naposcsibe",
    "naposcsibéket": "naposcsibe",
    "naposcsibéről": "naposcsibe",
    "naposcsibét": "naposcsibe",
    "napot": "nap",
    "nappal": "nap",
    "nappaliba": "nappali",
    "nappalit": "nappali",
    "napra": "nap",
    "napról": "nap",
    "napsugarakat": "napsugár",
    "napsugárfiúk": "napsugárfiú",
    "napszakra": "napszak",
    "napszámban": "napszám",
    "napszámból": "napszám",
    "napszámosok": "napszámos",
    "napszámosokkal": "napszámos",
    "napszámossal": "napszámos",
    "napszámot": "napszám",
    "napszámra": "napszám",
    "napsütésben": "napsütés",
    "naptól": "nap",
    "napvilágot": "napvilág",
    "napvilágra": "napvilág",
    "narancsot": "narancs",
    "nedve": "nedv",
    "nedvesedett": "nedvesedik",
    "nedvesek": "nedves",
    "nedvesen": "nedves",
    "nedvességcseppek": "nedvességcsepp",
    "nedvességéről": "nedvesség",
    "negatívan": "negatív",
    "negatívumnál": "negatívum",
    "negyeddöntőbe": "negyeddöntő",
    "negyeddöntőben": "negyeddöntő",
    "negyeddöntőjében": "negyeddöntő",
    "negyeddöntők": "negyeddöntő",
    "negyede": "negyed",
    "negyedek": "negyed",
    "negyedre": "negyed",
    "negyedrésze": "negyedrész",
    "negyedrészt": "negyedrész",
    "negyedrészét": "negyedrész",
    "negyedében": "negyed",
    "negyedét": "negyed",
    "negyedévben": "negyedév",
    "negyedéve": "negyedév",
    "negyedével": "negyed",
    "negyedévében": "negyedév",
    "negyedévére": "negyedév",
    "negyedóráig": "negyedóra",
    "negyedórán": "negyedóra",
    "negyedóránként": "negyedóra",
    "negyvenig": "negyven",
    "negyvennél": "negyven",
    "nehezebb": "nehéz",
    "nehezebben": "nehéz",
    "nehezebbet": "nehéz",
    "nehezedett": "nehezedik",
    "nehezedtek": "nehezedik",
    "nehezen": "nehéz",
    "nehezet": "nehéz",
    "neheztelni": "neheztel",
    "nehezéknek": "nehezék",
    "nehezén": "nehéz",
    "nehezére": "nehéz",
    "nehezíti": "nehezít",
    "nehézkesen": "nehézkes",
    "nehézségbe": "nehézség",
    "nehézsége": "nehézség",
    "nehézségei": "nehézség",
    "nehézségeim": "nehézség",
    "nehézségeink": "nehézség",
    "nehézségek": "nehézség",
    "nehézségekkel": "nehézség",
    "nehézséget": "nehézség",
    "neked": "te",
    "neki": "ő",
    "nekidőlt": "nekidől",
    "nekifeszítjük": "nekifeszít",
    "nekifeszült": "nekifeszül",
    "nekifutásra": "nekifutás",
    "nekiindultak": "nekiindult",
    "nekik": "ők",
    "nekilátott": "nekilát",
    "nekiláttak": "nekilát",
    "nekirontott": "nekiront",
    "nekiszaladt": "nekiszalad",
    "nekivágna": "nekivág",
    "nekivágni": "nekivág",
    "nekiütődtem": "nekiütődik",
    "nekiütődött": "nekiütődik",
    "nekrológjában": "nekrológ",
    "nektek": "ti",
    "nekünk": "mi",
    "nem-et": "nem",
    "nemekkel": "nem",
    "nemesemberre": "nemesember",
    "nemesnek": "nemes",
    "nemet": "nem",
    "nemfolytatni": "nemfolytat",
    "nemgondolkodást": "nemgondolkodás",
    "nemhasérzik": "nemhasérez",
    "nemiségtől": "nemiség",
    "nemiórákat": "nemiórák",
    "nemlétezését": "nemlétezés",
    "nemmel": "nem",
    "nemnek": "nem",
    "nemszemélyek": "nemszemély",
    "nemtetszését": "nemtetszés",
    "nemtőit": "nemtői",
    "nemzedékben": "nemzedék",
    "nemzedéket": "nemzedék",
    "nemzedékhez": "nemzedék",
    "nemzedékkel": "nemzedék",
    "nemzedékre": "nemzedék",
    "nemzedékről": "nemzedék",
    "nemzedékének": "nemzedék",
    "nemzete": "nemzet",
    "nemzetek": "nemzet",
    "nemzeteket": "nemzet",
    "nemzetet": "nemzet",
    "nemzetgazdaságunknak": "nemzetgazdaság",
    "nemzetgyűlésnek": "nemzetgyűlés",
    "nemzeti": "nemzet",
    "nemzetiségek": "nemzetiség",
    "nemzetnek": "nemzet",
    "nemzetnélküliek": "nemzetnélküli",
    "nemzetük": "nemzet",
    "nemzetünket": "nemzet",
    "nemükre": "nem",
    "neszezésekre": "neszezés",
    "neurológusaink": "neurológus",
    "neve": "név",
    "nevedet": "név",
    "neveket": "név",
    "nevelhetnénk": "nevelhet",
    "neveli": "nevel",
    "nevelik": "nevel",
    "neveljen": "nevel",
    "neveljenek": "nevel",
    "nevelkedett": "nevelkedik",
    "nevelnek": "nevel",
    "neveltek": "nevelt",
    "neveltem": "nevelt",
    "neveltetést": "neveltetés",
    "nevelték": "nevel",
    "nevelése": "nevelés",
    "nevelésemről": "nevelés",
    "nevelésében": "nevelés",
    "nevelői": "nevelő",
    "nevelőiskolája": "nevelőiskola",
    "nevelőt": "nevelő",
    "nevem": "név",
    "nevemet": "név",
    "nevet": "név",
    "nevetett": "nevet",
    "nevetgélnek": "nevetgél",
    "nevetni": "nevet",
    "nevetségesnek": "nevetséges",
    "nevetségessé": "nevetséges",
    "nevettek": "nevet",
    "nevették": "nevet",
    "nevetésben": "nevetés",
    "nevetéssel": "nevetés",
    "nevetést": "nevetés",
    "nevetéstől": "nevetés",
    "nevezetesen": "nevezetes",
    "nevezett": "nevez",
    "nevezhettek": "nevezhet",
    "nevezi": "nevez",
    "nevezik": "nevez",
    "neveznek": "nevez",
    "nevezni": "nevez",
    "nevezte": "nevez",
    "neveztek": "nevez",
    "nevezték": "nevez",
    "neveztük": "nevez",
    "neveztünk": "nevez",
    "nevezzük": "nevez",
    "nevezünk": "nevez",
    "nevében": "név",
    "nevéhez": "név",
    "nevén": "név",
    "nevének": "név",
    "nevét": "név",
    "nevével": "név",
    "nevük": "név",
    "nevüket": "név",
    "nevükhöz": "név",
    "nevükön": "név",
    "nevünkre": "név",
    "nincstelenek": "nincstelen",
    "nitromint": "nitromin",
    "noctis-nak": "noctis",
    "nominálértékét": "nominálérték",
    "normalizálásáról": "normalizálás",
    "normalizálódtak": "normalizálódik",
    "normatívnak": "normatív",
    "normatívát": "normatíva",
    "normáival": "norma",
    "normáját": "norma",
    "normák": "norma",
    "normáknak": "norma",
    "normálisan": "normális",
    "normálisnak": "normális",
    "noszogathatlak": "noszogathat",
    "noszogatni": "noszogat",
    "nosztalgiafélét": "nosztalgiaféle",
    "nosztalgiájáról": "nosztalgia",
    "nosztalgiáznak": "nosztalgiáz",
    "noteszbe": "notesz",
    "noteszt": "notesz",
    "novemberben": "november",
    "novembere": "november",
    "novemberig": "november",
    "novembertől": "november",
    "novemberében": "november",
    "nullára": "nulla",
    "nyafogott": "nyafog",
    "nyaka": "nyak",
    "nyakadat": "nyak",
    "nyakig": "nyak",
    "nyakkendőjébe": "nyakkendő",
    "nyakkendők": "nyakkendő",
    "nyakkendőkre": "nyakkendő",
    "nyakon": "nyak",
    "nyakuk": "nyak",
    "nyakukat": "nyak",
    "nyakunkat": "nyak",
    "nyakába": "nyak",
    "nyakából": "nyak",
    "nyakán": "nyak",
    "nyakára": "nyak",
    "nyakát": "nyak",
    "nyalkán": "nyalka",
    "nyalábbal": "nyaláb",
    "nyalábban": "nyaláb",
    "nyarukat": "nyár",
    "nyarán": "nyár",
    "nyele": "nyél",
    "nyeljük": "nyel",
    "nyelni": "nyel",
    "nyelt": "nyel",
    "nyeltem": "nyelt",
    "nyelvben": "nyelv",
    "nyelve": "nyelv",
    "nyelvek": "nyelv",
    "nyelveket": "nyelv",
    "nyelven": "nyelv",
    "nyelvet": "nyelv",
    "nyelvhasználatról": "nyelvhasználat",
    "nyelvnek": "nyelv",
    "nyelvre": "nyelv",
    "nyelvtannal": "nyelvtan",
    "nyelvtanának": "nyelvtan",
    "nyelvtől": "nyelv",
    "nyelvén": "nyelv",
    "nyelvére": "nyelv",
    "nyelvét": "nyelv",
    "nyelvével": "nyelv",
    "nyelvünkbe": "nyelv",
    "nyelvünkben": "nyelv",
    "nyelének": "nyél",
    "nyelével": "nyél",
    "nyereményeivel": "nyeremény",
    "nyereményeket": "nyeremény",
    "nyeresége": "nyereség",
    "nyereségesen": "nyereséges",
    "nyereséget": "nyereség",
    "nyereségük": "nyereség",
    "nyerhetett": "nyerhet",
    "nyerheti": "nyerhet",
    "nyerhetünk": "nyerhet",
    "nyeri": "nyer",
    "nyerik": "nyer",
    "nyernek": "nyer",
    "nyerni": "nyer",
    "nyernie": "nyer",
    "nyersanyagokért": "nyersanyag",
    "nyersebben": "nyers",
    "nyersen": "nyers",
    "nyert": "nyer",
    "nyerte": "nyer",
    "nyertek": "nyert",
    "nyertesei": "nyertes",
    "nyerték": "nyer",
    "nyerésnek": "nyerés",
    "nyerésre": "nyerés",
    "nyikorgásával": "nyikorgás",
    "nyilakkal": "nyíl",
    "nyilallt": "nyilall",
    "nyilat": "nyíl",
    "nyilatkozata": "nyilatkozat",
    "nyilatkozatai": "nyilatkozat",
    "nyilatkozataiból": "nyilatkozat",
    "nyilatkozatok": "nyilatkozat",
    "nyilatkozatokat": "nyilatkozat",
    "nyilatkozatokon": "nyilatkozat",
    "nyilatkozatot": "nyilatkozat",
    "nyilatkozatában": "nyilatkozat",
    "nyilatkozatára": "nyilatkozat",
    "nyilatkozatát": "nyilatkozat",
    "nyilatkozatával": "nyilatkozat",
    "nyilatkozni": "nyilatkozik",
    "nyilatkozott": "nyilatkozik",
    "nyilatkozta": "nyilatkozik",
    "nyilatkoztak": "nyilatkozik",
    "nyilatkoztatta": "nyilatkoztat",
    "nyilatkozzanak": "nyilatkozik",
    "nyilvánosan": "nyilvános",
    "nyilvánossága": "nyilvánosság",
    "nyilvánosságot": "nyilvánosság",
    "nyilvánosságra": "nyilvánosság",
    "nyilvánosságához": "nyilvánosság",
    "nyilvántarthatnák": "nyilvántarthat",
    "nyilvántartott": "nyilvántart",
    "nyilvántartása": "nyilvántartás",
    "nyilvántartásba": "nyilvántartás",
    "nyilvántartásban": "nyilvántartás",
    "nyilvántartásokban": "nyilvántartás",
    "nyilvántartásokból": "nyilvántartás",
    "nyilvántartásában": "nyilvántartás",
    "nyilvánult": "nyilvánul",
    "nyilvánvalóak": "nyilvánvaló",
    "nyilvánvalóan": "nyilvánvaló",
    "nyilvánvalóbbá": "nyilvánvaló",
    "nyilvánvalóvá": "nyilvánvaló",
    "nyilvánítani": "nyilvánít",
    "nyilvánítasz": "nyilvánít",
    "nyilvánította": "nyilvánít",
    "nyilvánították": "nyilvánít",
    "nyilvánítsa": "nyilvánít",
    "nyilvánításához": "nyilvánítás",
    "nyirkosabb": "nyirkos",
    "nyisd": "nyit",
    "nyisson": "nyit",
    "nyithatod": "nyithat",
    "nyitja": "nyit",
    "nyitják": "nyitja",
    "nyitna": "nyit",
    "nyitnak": "nyit",
    "nyitni": "nyit",
    "nyitnának": "nyit",
    "nyitogatta": "nyitogat",
    "nyitott": "nyit",
    "nyitotta": "nyit",
    "nyitottak": "nyitott",
    "nyitottan": "nyitott",
    "nyitottságot": "nyitottság",
    "nyitották": "nyit",
    "nyitásakor": "nyitás",
    "nyitómeccse": "nyitómeccs",
    "nyitóprogramban": "nyitóprogram",
    "nyivákolást": "nyivákolás",
    "nyolc-kilenchónaposok": "nyolc-kilenchónapos",
    "nyolcadikosok": "nyolcadikos",
    "nyolcadikosoknak": "nyolcadikos",
    "nyolcban": "nyolc",
    "nyolcvanra": "nyolcvan",
    "nyoma": "nyom",
    "nyomasztott": "nyomaszt",
    "nyomatékkal": "nyomaték",
    "nyomatékosabb": "nyomatékos",
    "nyomdahelyiségek": "nyomdahelyiség",
    "nyomdahibákra": "nyomdahiba",
    "nyomdakapacitásának": "nyomdakapacitás",
    "nyomja": "nyom",
    "nyomjam": "nyom",
    "nyomjuk": "nyom",
    "nyomkodta": "nyomkod",
    "nyomon": "nyom",
    "nyomornegyedben": "nyomornegyed",
    "nyomorultságnak": "nyomorultság",
    "nyomorékká": "nyomorék",
    "nyomorúsága": "nyomorúság",
    "nyomot": "nyom",
    "nyomozni": "nyomoz",
    "nyomoznunk": "nyomoz",
    "nyomozással": "nyomozás",
    "nyomozóhivatala": "nyomozóhivatal",
    "nyomozóinak": "nyomozóín",
    "nyomozók": "nyomozó",
    "nyomta": "nyom",
    "nyomtalanul": "nyomtalan",
    "nyomtatott": "nyomtat",
    "nyomtattak": "nyomtat",
    "nyomtatták": "nyomtat",
    "nyomtatványok": "nyomtatvány",
    "nyomult": "nyomul",
    "nyomában": "nyom",
    "nyomán": "nyom",
    "nyomása": "nyomás",
    "nyomásgyakorlást": "nyomásgyakorlás",
    "nyomást": "nyomás",
    "nyomásának": "nyomás",
    "nyomát": "nyom",
    "nyugalma": "nyugalom",
    "nyugalmasabb": "nyugalmas",
    "nyugalmat": "nyugalom",
    "nyugalmát": "nyugalom",
    "nyugalmáért": "nyugalom",
    "nyugalommal": "nyugalom",
    "nyugalomnak": "nyugalom",
    "nyugaton": "nyugat",
    "nyugatra": "nyugat",
    "nyugattal": "nyugat",
    "nyugdíjalapról": "nyugdíjalap",
    "nyugdíjasok": "nyugdíjas",
    "nyugdíjasokká": "nyugdíjas",
    "nyugdíjba": "nyugdíj",
    "nyugdíjbiztosítót": "nyugdíjbiztosító",
    "nyugdíjjal": "nyugdíj",
    "nyugdíjreformmal": "nyugdíjreform",
    "nyugdíjából": "nyugdíj",
    "nyugodjak": "nyugszik",
    "nyugodni": "nyugszik",
    "nyugodnom": "nyugszik",
    "nyugodtabb": "nyugodt",
    "nyugodtabban": "nyugodt",
    "nyugodtan": "nyugodt",
    "nyugszanak": "nyugszik",
    "nyugtalankodjanak": "nyugtalankodik",
    "nyugtalankodjon": "nyugtalankodik",
    "nyugtalanságba": "nyugtalanság",
    "nyugtalanságot": "nyugtalanság",
    "nyugtalanságunk": "nyugtalanság",
    "nyugtalanul": "nyugtalan",
    "nyugtalanítóak": "nyugtalanító",
    "nyugtatja": "nyugtat",
    "nyugtatta": "nyugtat",
    "nyugtatókat": "nyugtató",
    "nyugton": "nyugt",
    "nyugtot": "nyugt",
    "nyugtát": "nyugta",
    "nyugtázta": "nyugtáz",
    "nyugtázza": "nyugtáz",
    "nyugtázzák": "nyugtáz",
    "nyulak": "nyúl",
    "nyájasabb": "nyájas",
    "nyájasabban": "nyájas",
    "nyájasan": "nyájas",
    "nyájassággal": "nyájasság",
    "nyájat": "nyáj",
    "nyájnak": "nyáj",
    "nyájszerűsége": "nyájszerűség",
    "nyállal": "nyál",
    "nyáluk": "nyál",
    "nyárestit": "nyáresti",
    "nyárnak": "nyár",
    "nyáron": "nyár",
    "nyárra": "nyár",
    "nyártól": "nyár",
    "nyélbe": "nyél",
    "nyílna": "nyílik",
    "nyílt": "nyílik",
    "nyíltabban": "nyílt",
    "nyíltak": "nyílt",
    "nyíltan": "nyílt",
    "nyílások": "nyílás",
    "nyíregyházán": "nyíregyház",
    "nyírfaerdőt": "nyírfaerdő",
    "nyírt": "nyír",
    "nyögte": "nyög",
    "nyögtek": "nyög",
    "nyögésekkel": "nyögés",
    "nyöszörögni": "nyöszörög",
    "nyújtana": "nyújt",
    "nyújtanak": "nyújt",
    "nyújtani": "nyújt",
    "nyújthatnának": "nyújthat",
    "nyújtja": "nyújt",
    "nyújtják": "nyújt",
    "nyújtod": "nyújt",
    "nyújtok": "nyújt",
    "nyújtom": "nyújt",
    "nyújtott": "nyújt",
    "nyújtotta": "nyújt",
    "nyújtson": "nyújt",
    "nyúlj": "nyúlik",
    "nyúlketrecekkel": "nyúlketrec",
    "nyúllá": "nyúl",
    "nyúlnak": "nyúlik",
    "nyúlni": "nyúlik",
    "nyúlnia": "nyúlik",
    "nyúlnom": "nyúlik",
    "nyúlt": "nyúlik",
    "nyúltak": "nyúlt",
    "nyúlóssá": "nyúlós",
    "nyúzottnak": "nyúzott",
    "nyúzzanak": "nyúz",
    "nyüzsgött": "nyüzsög",
    "nyüzsögnek": "nyüzsög",
    "nyüzsögtek": "nyüzsög",
    "nyűgözné": "nyűgöz",
    "nácik": "náci",
    "nácikkal": "náci",
    "nádudvaron": "nádudvar",
    "nála": "ő",
    "nálad": "te",
    "nálam": "én",
    "nálatok": "ti",
    "náluk": "ők",
    "nálunk": "mi",
    "nászúton": "nászút",
    "négerek": "néger",
    "négert": "néger",
    "néggyel": "négy",
    "négy-nulla-hétre": "négy-nulla-hét",
    "négyektől": "négy",
    "négyen": "négy",
    "négyet": "négy",
    "négyevezőse": "négyevezős",
    "négyezret": "négyezer",
    "négyméternyire": "négyméternyi",
    "négynek": "négy",
    "négyszer": "négy",
    "négyszer-ötször": "négy-öt",
    "négyszöget": "négyszög",
    "négyszögletesre": "négyszögletes",
    "négyzetméteren": "négyzetméter",
    "négyzetmétert": "négyzetméter",
    "néhányan": "néhány",
    "néhányat": "néhány",
    "néhányszor": "néhány",
    "néhánytól": "néhány",
    "néhányukét": "néhány",
    "nélküle": "nélkül",
    "nélküliek": "nélküli",
    "nélkülözni": "nélkülöz",
    "nélkülözéstől": "nélkülözés",
    "nélkülözünk": "nélkülöz",
    "nélkülünk": "nélkül",
    "némaságot": "némaság",
    "némelyek": "némely",
    "némelyiket": "némelyik",
    "némelyikük": "némelyik",
    "némelyikünk": "némelyik",
    "németek": "német",
    "németeket": "német",
    "németnél": "német",
    "németül": "német",
    "némán": "néma",
    "nénit": "néni",
    "nénjük": "néne",
    "népakarattól": "népakarat",
    "népcsoportja": "népcsoport",
    "népe": "nép",
    "népek": "nép",
    "népeket": "nép",
    "népekkel": "nép",
    "népen": "nép",
    "népességnek": "népesség",
    "népességről": "népesség",
    "népességének": "népesség",
    "népet": "nép",
    "népiek": "népi",
    "népiesek": "népies",
    "népiességből": "népiesség",
    "népkertet": "népkert",
    "népligetben": "népliget",
    "népművelők": "népművelő",
    "népnek": "nép",
    "néppel": "nép",
    "néppártban": "néppárt",
    "néppártnak": "néppárt",
    "néppárttal": "néppárt",
    "néprajzra": "néprajz",
    "népszabadságban": "népszabadság",
    "népszabadságéhoz": "népszabadság",
    "népszava": "népszó",
    "népszavazásnak": "népszavazás",
    "népszavazásra": "népszavazás",
    "népszavazásról": "népszavazás",
    "népszavazást": "népszavazás",
    "népszerűbb": "népszerű",
    "népszerűnek": "népszerű",
    "népszerűségben": "népszerűség",
    "népszerűsége": "népszerűség",
    "népszerűségét": "népszerűség",
    "népszerűsíteni": "népszerűsít",
    "népszerűsítse": "népszerűsít",
    "népszerűsítsék": "népszerűsít",
    "népszerűtlenek": "népszerűtlen",
    "népségek": "népség",
    "néptömegek": "néptömeg",
    "néptömeget": "néptömeg",
    "néptől": "nép",
    "népvezérünk": "népvezér",
    "népzenéről": "népzene",
    "népén": "nép",
    "népének": "nép",
    "népünk": "nép",
    "néven": "név",
    "névházassággal": "névházasság",
    "névjegye": "névjegy",
    "névjegyének": "névjegy",
    "névre": "név",
    "névről": "név",
    "névsora": "névsor",
    "névsorhoz": "névsor",
    "névsorokat": "névsor",
    "névsorral": "névsor",
    "névsort": "névsor",
    "névsorát": "névsor",
    "névtelenek": "névtelen",
    "névtelenül": "névtelen",
    "névvel": "név",
    "névértékben": "névérték",
    "névértéke": "névérték",
    "névértékét": "névérték",
    "nézd": "néz",
    "nézegették": "nézeget",
    "nézegettük": "nézeget",
    "nézek": "néz",
    "nézel": "néz",
    "nézelődtek": "nézelődik",
    "nézelődött": "nézelődik",
    "nézete": "nézet",
    "nézetei": "nézet",
    "nézeteinek": "nézet",
    "nézeteiről": "nézet",
    "nézeteit": "nézet",
    "nézetek": "nézet",
    "nézeteket": "nézet",
    "nézeteltérések": "nézeteltérés",
    "nézeten": "nézet",
    "nézett": "néz",
    "nézettel": "nézett",
    "nézhetik": "nézhet",
    "nézhettek": "nézhet",
    "nézhettem": "nézhet",
    "nézi": "néz",
    "nézik": "néz",
    "nézne": "néz",
    "néznek": "néz",
    "nézni": "néz",
    "néznie": "néz",
    "néznék": "néz",
    "nézte": "néz",
    "nézted": "néz",
    "néztek": "néz",
    "néztem": "néz",
    "nézték": "néz",
    "néztünk": "néz",
    "nézz": "néz",
    "nézze": "néz",
    "nézzem": "néz",
    "nézzen": "néz",
    "nézzetek": "néz",
    "nézzétek": "néz",
    "nézzük": "néz",
    "nézzünk": "néz",
    "nézünk": "néz",
    "nézőben": "néző",
    "nézőhelyért": "nézőhely",
    "nézők": "néző",
    "nézőket": "néző",
    "nézőpontjából": "nézőpont",
    "nézőpontjának": "nézőpont",
    "nézőre": "néző",
    "nézőt": "néző",
    "nívódíjak": "nívódíj",
    "nívódíjakat": "nívódíj",
    "nótája": "nóta",
    "nótájuk": "nóta",
    "nótákat": "nóta",
    "nótára": "nóta",
    "nótával": "nóta",
    "nótáznak": "nótázik",
    "növekedett": "növekedik",
    "növekedjék": "növekedik",
    "növekedne": "növekedik",
    "növekedni": "növekedik",
    "növekedtek": "növekedik",
    "növekedésből": "növekedés",
    "növekedése": "növekedés",
    "növekedésre": "növekedés",
    "növekedéssel": "növekedés",
    "növekedést": "növekedés",
    "növekedését": "növekedés",
    "növelhették": "növelhet",
    "növeli": "növel",
    "növelik": "növel",
    "növelni": "növel",
    "növelné": "növel",
    "növelte": "növel",
    "növelték": "növel",
    "növelése": "növelés",
    "növelésére": "növelés",
    "növelését": "növelés",
    "növelésével": "növelés",
    "növendék-urakat": "növendék-úr",
    "növendékét": "növendék",
    "növeszteni": "növeszt",
    "növesztett": "növeszt",
    "növényekkel": "növény",
    "nőcselédek": "nőcseléd",
    "nőcselédeket": "nőcseléd",
    "nőcselédeknek": "nőcseléd",
    "nőhöz": "nő",
    "női": "nő",
    "nőiesebbé": "nőies",
    "nője": "nő",
    "nőjenek": "nőjen",
    "nőjön": "nő",
    "nők": "nő",
    "nőket": "nő",
    "nőkhöz": "nő",
    "nőkkel": "nő",
    "nőknél": "nő",
    "nőké": "nő",
    "nőkétől": "nő",
    "nőnek": "nő",
    "nőszemélyek": "nőszemély",
    "nősülnöd": "nősül",
    "nőt": "nő",
    "nőtagja": "nőtag",
    "nőtt": "nő",
    "nőttek": "nőtt",
    "nőtől": "nő",
    "nővel": "nő",
    "nővérek": "nővér",
    "nővérrel": "nővér",
    "objektivitásban": "objektivitás",
    "ocsúdni": "ocsúdik",
    "ocsúdott": "ocsúdik",
    "odaadnak": "odaad",
    "odaadom": "odaad",
    "odaadta": "odaad",
    "odaadtuk": "odaad",
    "odaadták": "odaad",
    "odaadást": "odaadás",
    "odadobott": "odadob",
    "odadörmögte": "odadörmög",
    "odaejtette": "odaejt",
    "odaengedi": "odaenged",
    "odafentről": "odafent",
    "odafigyelni": "odafigyel",
    "odajutni": "odajut",
    "odajött": "odajön",
    "odakerültek": "odakerül",
    "odaköszönt": "odaköszön",
    "odaláncolta": "odaláncol",
    "odalépett": "odalép",
    "odalépni": "odalép",
    "odamenni": "odamegy",
    "odamennie": "odamegy",
    "odament": "odamegy",
    "odanősült": "odanősül",
    "odarajzoltam": "odarajzolt",
    "odasettenkedtem": "odasettenkedik",
    "odaszaladni": "odaszalad",
    "odaszállított": "odaszállít",
    "odaszíjazott": "odaszíjaz",
    "odaszólt": "odaszól",
    "odaszóltak": "odaszólt",
    "odatartja": "odatart",
    "odaugrott": "odaugrik",
    "odavagyok": "odavan",
    "odavinni": "odavisz",
    "odavitte": "odavisz",
    "odavágta": "odavág",
    "odaállt": "odaáll",
    "odaállásait": "odaállás",
    "odaértünk": "odaért",
    "odaírtam": "odaírt",
    "odaírták": "odaír",
    "odaítélt": "odaítél",
    "odaült": "odaül",
    "odaütnek": "odaüt",
    "odázhatja": "odázhat",
    "odáznunk": "odáz",
    "offenzíváját": "offenzíva",
    "offenzívájával": "offenzíva",
    "oka": "ok",
    "okai": "ok",
    "okairól": "ok",
    "okait": "ok",
    "okból": "ok",
    "okiratban": "okirat",
    "okkal": "ok",
    "oklevelet": "oklevél",
    "okmányait": "okmány",
    "okmányok": "okmány",
    "okmányokat": "okmány",
    "okmányszerűen": "okmányszerű",
    "okmányt": "okmány",
    "okok": "ok",
    "okokból": "ok",
    "okoknak": "ok",
    "okokra": "ok",
    "okolhatok": "okolhat",
    "okolták": "okol",
    "okom": "ok",
    "okosabb": "okos",
    "okosabbak": "okos",
    "okosan": "okos",
    "okoskodott": "okoskodik",
    "okosságát": "okosság",
    "okot": "ok",
    "okozhatja": "okozhat",
    "okozhatják": "okozhat",
    "okozhatta": "okozhat",
    "okozna": "okoz",
    "okozni": "okoz",
    "okozott": "okoz",
    "okozta": "okoz",
    "okozza": "okoz",
    "okozója": "okozó",
    "oktatásban": "oktatás",
    "oktatáspolitikusai": "oktatáspolitikus",
    "oktatáspolitikusaiból": "oktatáspolitikus",
    "oktatásra": "oktatás",
    "oktatást": "oktatás",
    "oktatásáról": "oktatás",
    "oktatóit": "oktatói",
    "októberben": "október",
    "októbere": "október",
    "októberig": "október",
    "októbertől": "október",
    "októberében": "október",
    "októberéig": "október",
    "okuk": "ok",
    "okulni": "okul",
    "okunk": "ok",
    "okádékodban": "okádék",
    "okádékszagot": "okádékszag",
    "okán": "ok",
    "okának": "ok",
    "okáról": "ok",
    "okát": "ok",
    "olajat": "olaj",
    "olajfestéket": "olajfesték",
    "olajlámpát": "olajlámpa",
    "olajnak": "olaj",
    "olajozott": "olajoz",
    "olajszagot": "olajszag",
    "olajvásárlásaikat": "olajvásárlás",
    "olaszból": "olasz",
    "olaszoknak": "olasz",
    "olaszul": "olasz",
    "olaszunk": "olasz",
    "olaszé": "olasz",
    "olcsóbb": "olcsó",
    "olcsóbban": "olcsó",
    "olcsóbbá": "olcsó",
    "olcsón": "olcsó",
    "oldala": "oldal",
    "oldalad": "oldal",
    "oldalainak": "oldal",
    "oldalba": "oldal",
    "oldalfalon": "oldalfal",
    "oldalon": "oldal",
    "oldalpillantást": "oldalpillantás",
    "oldalra": "oldal",
    "oldalról": "oldal",
    "oldalt": "oldal",
    "oldalukra": "oldal",
    "oldalába": "oldal",
    "oldalában": "oldal",
    "oldalán": "oldal",
    "oldalára": "oldal",
    "oldaláról": "oldal",
    "oldalát": "oldal",
    "oldalával": "oldal",
    "oldani": "old",
    "oldaniuk": "old",
    "oldaná": "old",
    "oldja": "old",
    "oldják": "old",
    "oldottunk": "oldott",
    "oldunk": "old",
    "oldódott": "oldódik",
    "oligarchiájától": "oligarchia",
    "olimpián": "olimpia",
    "oltalmazni": "oltalmaz",
    "oltalmából": "oltalom",
    "oltja": "olt",
    "oltják": "olt",
    "oltotta": "olt",
    "oltárainál": "oltár",
    "oltószert": "oltószer",
    "olvadt": "olvad",
    "olvadáskor": "olvadás",
    "olvasatot": "olvasat",
    "olvasgatott": "olvasgat",
    "olvashasson": "olvashat",
    "olvashatod": "olvashat",
    "olvashatunk": "olvashat",
    "olvashatók": "olvasható",
    "olvasmányairól": "olvasmány",
    "olvasmányokat": "olvasmány",
    "olvasmányokkal": "olvasmány",
    "olvasna": "olvas",
    "olvasni": "olvas",
    "olvasnia": "olvas",
    "olvasnivalót": "olvasnivaló",
    "olvasnunk": "olvas",
    "olvasná": "olvas",
    "olvasok": "olvas",
    "olvasom": "olvas",
    "olvasott": "olvas",
    "olvassa": "olvas",
    "olvassák": "olvas",
    "olvasta": "olvas",
    "olvastad": "olvas",
    "olvastak": "olvas",
    "olvastam": "olvas",
    "olvastatja": "olvastat",
    "olvastatok": "olvastat",
    "olvastál": "olvas",
    "olvasztotta": "olvaszt",
    "olvasást": "olvasás",
    "olvasói": "olvasó",
    "olvasókat": "olvasó",
    "olvasókörben": "olvasókör",
    "olyanabb": "olyan",
    "olyanformán": "olyanformá",
    "olyankor": "olyan",
    "olyannak": "olyan",
    "olyannyira": "olyannyi",
    "olyanok": "olyan",
    "olyanokat": "olyan",
    "olyanoknak": "olyan",
    "olyanra": "olyan",
    "olyasformán": "olyasforma",
    "olyasmim": "olyasmi",
    "olyasmire": "olyasmi",
    "olyasmit": "olyasmi",
    "olyasvalamin": "olyasvalami",
    "olyasvalamivé": "olyasvalami",
    "olyat": "oly",
    "olykor": "oly",
    "omlott": "omlik",
    "omlottak": "omlott",
    "ontja": "ont",
    "ontotta": "ont",
    "opciójukat": "opció",
    "operaházat": "operaház",
    "operaházban": "operaház",
    "operarendezésben": "operarendezés",
    "operaszínpadon": "operaszínpad",
    "operaénekes-vállalkozót": "operaénekes-vállalkozó",
    "operettben": "operett",
    "operához": "opera",
    "operált": "operál",
    "operát": "opera",
    "optimalizálással": "optimalizálás",
    "optimistán": "optimista",
    "optimizmusa": "optimizmus",
    "optimizmusát": "optimizmus",
    "optimálisan": "optimális",
    "optimálisra": "optimális",
    "opáljaimat": "opál",
    "opáljaitól": "opál",
    "orcára": "orca",
    "ordítania": "ordít",
    "ordított": "ordít",
    "ordította": "ordít",
    "ordítottak": "ordított",
    "ordítottál": "ordít",
    "ordítoztak": "ordítozik",
    "ordítozták": "ordítozik",
    "ordítozással": "ordítozás",
    "ordítson": "ordít",
    "ordítása": "ordítás",
    "ordításban": "ordítás",
    "orgazdái": "orgazda",
    "orgazdának": "orgazda",
    "orgazmust": "orgazmus",
    "orgonaillatot": "orgonaillat",
    "ormaira": "orom",
    "oroszlánokat": "oroszlán",
    "oroszlánokkal": "oroszlán",
    "oroszlánrészt": "oroszlánrész",
    "oroszok": "orosz",
    "oroszoknak": "orosz",
    "orra": "orr",
    "orral": "orr",
    "orrhangra": "orrhang",
    "orrlyukaiba": "orrlyuk",
    "orrod": "orr",
    "orrom": "orr",
    "orrontok": "orront",
    "orrot": "orr",
    "orrukkal": "orr",
    "orrukra": "orr",
    "orrunkat": "orr",
    "orrzöngésbe": "orrzöngés",
    "orrában": "orr",
    "orrából": "orr",
    "orrán": "orr",
    "orrának": "orr",
    "orrára": "orr",
    "orrát": "orr",
    "orrától": "orr",
    "orrával": "orr",
    "ország-világnak": "ország-világ",
    "országa": "ország",
    "országaiban": "ország",
    "országba": "ország",
    "országban": "ország",
    "országból": "ország",
    "országgal": "ország",
    "országgyűlésbe": "országgyűlés",
    "országgyűlésre": "országgyűlés",
    "országhatáron": "országhatár",
    "országhoz": "ország",
    "országnak": "ország",
    "országok": "ország",
    "országokat": "ország",
    "országokban": "ország",
    "országokból": "ország",
    "országokhoz": "ország",
    "országokkal": "ország",
    "országoknak": "ország",
    "országoktól": "ország",
    "országon": "ország",
    "országosan": "országos",
    "országot": "ország",
    "országra": "ország",
    "országrészben": "országrész",
    "országrészeken": "országrész",
    "országtól": "ország",
    "országuk": "ország",
    "országunk": "ország",
    "országutakon": "országút",
    "országában": "ország",
    "országát": "ország",
    "országéval": "ország",
    "országút": "országú",
    "országúton": "országút",
    "országútra": "országút",
    "orvosai": "orvos",
    "orvosegyetemek": "orvosegyetem",
    "orvoshoz": "orvos",
    "orvosnak": "orvos",
    "orvosok": "orvos",
    "orvosoknak": "orvos",
    "orvossal": "orvos",
    "orvossága": "orvosság",
    "orvosságot": "orvosság",
    "orvostanárról": "orvostanár",
    "orvosé": "orvos",
    "orvtámadások": "orvtámadás",
    "orákulumoknak": "orákulum",
    "ossza": "oszt",
    "osszák": "oszt",
    "ostobaságaiban": "ostobaság",
    "ostobaságnak": "ostobaság",
    "ostobaságok": "ostobaság",
    "ostobaságot": "ostobaság",
    "ostobaságával": "ostobaság",
    "ostobák": "ostoba",
    "ostobán": "ostoba",
    "ostobának": "ostoba",
    "ostorcsattogással": "ostorcsattogás",
    "ostorozta": "ostoroz",
    "ostroma": "ostrom",
    "ostromlott": "ostromol",
    "ostromlók": "ostromló",
    "ostromolnák": "ostromol",
    "ostrománál": "ostrom",
    "oszlanak": "oszlik",
    "oszlatta": "oszlat",
    "oszlopai": "oszlop",
    "oszlopait": "oszlop",
    "oszlopfők": "oszlopfő",
    "oszlopfőkre": "oszlopfő",
    "oszlophoz": "oszlop",
    "oszlopok": "oszlop",
    "oszlopokba": "oszlop",
    "oszlopra": "oszlop",
    "oszlopával": "oszlop",
    "oszlott": "oszlik",
    "oszlottak": "oszlott",
    "osztalékigényeit": "osztalékigény",
    "osztanak": "oszt",
    "osztani": "oszt",
    "osztaniuk": "oszt",
    "osztatta": "osztat",
    "oszthatom": "oszthat",
    "osztja": "oszt",
    "osztják": "oszt",
    "osztogatni": "osztogat",
    "osztott": "oszt",
    "osztotta": "oszt",
    "osztottak": "osztott",
    "osztottam": "osztott",
    "osztották": "oszt",
    "osztoznak": "osztozik",
    "osztrákok": "osztrák",
    "osztrákokkal": "osztrák",
    "osztálya": "osztály",
    "osztályainak": "osztály",
    "osztályba": "osztály",
    "osztályfőnöke": "osztályfőnök",
    "osztályfőnökhöz": "osztályfőnök",
    "osztályhoz": "osztály",
    "osztályidegen": "osztályideg",
    "osztálykiváltság-nak": "osztálykiváltság",
    "osztálykülönbségek": "osztálykülönbség",
    "osztálykülönbségekre": "osztálykülönbség",
    "osztálylétszámok": "osztálylétszám",
    "osztálynak": "osztály",
    "osztályok": "osztály",
    "osztályokat": "osztály",
    "osztályokban": "osztály",
    "osztályokkal": "osztály",
    "osztályokra": "osztály",
    "osztályom": "osztály",
    "osztályon": "osztály",
    "osztályozták": "osztályoz",
    "osztályról": "osztály",
    "osztályszempontok": "osztályszempont",
    "osztályt": "osztály",
    "osztálytársaim": "osztálytárs",
    "osztálytársak": "osztálytárs",
    "osztályvezetője": "osztályvezető",
    "osztályvezetők": "osztályvezető",
    "osztályvezetővel": "osztályvezető",
    "osztályán": "osztály",
    "osztályának": "osztály",
    "osztályát": "osztály",
    "osztása": "osztás",
    "osztásainál": "osztás",
    "osztáshoz": "osztás",
    "osztásnál": "osztás",
    "osztásra": "osztás",
    "osztást": "osztás",
    "otrombább": "otromba",
    "ottfelejtették": "ottfelejtet",
    "otthagyja": "otthagy",
    "otthagyni": "otthagy",
    "otthagyott": "otthagy",
    "otthagyta": "otthagy",
    "otthagytuk": "otthagy",
    "otthagyták": "otthagy",
    "otthonai": "otthon",
    "otthonban": "otthon",
    "otthonhoz": "otthon",
    "otthonitól": "otthoni",
    "otthonok": "otthon",
    "otthonokkal": "otthon",
    "otthonosak": "otthonos",
    "otthonról": "otthon",
    "otthont": "otthon",
    "otthonuk": "otthon",
    "otthonukba": "otthon",
    "otthonukban": "otthon",
    "otthonába": "otthon",
    "otthonában": "otthon",
    "ottmaradtak": "ottmaradt",
    "ottmaradtam": "ottmaradt",
    "ottrekedt": "ottreked",
    "overall-egyenruhába": "overall-egyenruha",
    "overallja": "overall",
    "overalljukat": "overall",
    "overallján": "overall",
    "overallját": "overall",
    "overallnak": "overall",
    "overallt": "overall",
    "pacallá": "pacal",
    "padján": "pad",
    "padláson": "padlás",
    "padlását": "padlás",
    "padlója": "padló",
    "padlóján": "padló",
    "padlón": "padló",
    "padlónkba": "padló",
    "padlóra": "padló",
    "padlóról": "padló",
    "padlót": "padló",
    "padokkal": "pad",
    "padon": "pad",
    "padra": "pad",
    "padról": "pad",
    "pajkost": "pajkos",
    "pakettból": "pakett",
    "paketteket": "pakett",
    "pakettet": "pakett",
    "pakettjának": "pakett",
    "pakettre": "pakett",
    "palackban": "palack",
    "palackból": "palack",
    "palackja": "palack",
    "palackkal": "palack",
    "palackot": "palack",
    "palacsintát": "palacsinta",
    "palatáblát": "palatábla",
    "palesztinok": "palesztin",
    "palesztint": "palesztin",
    "palettáján": "paletta",
    "palik": "pali",
    "palimpszeszt": "palimpszesz",
    "pallókat": "palló",
    "palotáinak": "palota",
    "palotája": "palota",
    "palotájának": "palota",
    "palást": "palás",
    "pamfletekben": "pamflet",
    "pamfletet": "pamflet",
    "pamlagot": "pamlag",
    "panaszairól": "panasz",
    "panaszkodjunk": "panaszkodik",
    "panaszkodnak": "panaszkodik",
    "panaszkodott": "panaszkodik",
    "panaszkodtak": "panaszkodik",
    "panaszkodások": "panaszkodás",
    "panaszok": "panasz",
    "panaszokba": "panasz",
    "panaszra": "panasz",
    "panaszt": "panasz",
    "panaszával": "panasz",
    "panelek": "panel",
    "panelházak": "panelház",
    "panelházakban": "panelház",
    "panelházaknak": "panelház",
    "panellakásokban": "panellakás",
    "pannonhalma": "pannonhalom",
    "pannonhalmára": "pannonhalom",
    "pantallóm": "pantalló",
    "panzióit": "panziói",
    "panzióst": "panziós",
    "papirosba": "papiros",
    "papjai": "pap",
    "papnak": "pap",
    "papok": "pap",
    "paprika-salátát": "paprika-saláta",
    "paprikából": "paprika",
    "paprikást": "paprikás",
    "paprikát": "paprika",
    "paprikával": "paprika",
    "papám": "papa",
    "papé": "pap",
    "papírboltban": "papírbolt",
    "papírból": "papír",
    "papírcsomagok": "papírcsomag",
    "papírcsíptetővel": "papírcsíptető",
    "papírdarabbal": "papírdarab",
    "papírdarabkára": "papírdarabka",
    "papírdarabkát": "papírdarabka",
    "papírdarabkával": "papírdarabka",
    "papírdarabot": "papírdarab",
    "papírdarabról": "papírdarab",
    "papírfoszlányokat": "papírfoszlány",
    "papírhengerek": "papírhenger",
    "papírhengert": "papírhenger",
    "papírhulladékokkal": "papírhulladék",
    "papírja": "papír",
    "papírjai": "papír",
    "papírjaiból": "papír",
    "papírjaidat": "papír",
    "papírjaimat": "papír",
    "papírjainak": "papír",
    "papírjainkat": "papír",
    "papírjaira": "papír",
    "papírjuk": "papír",
    "papírjáról": "papír",
    "papírjáért": "papír",
    "papírlapjára": "papírlap",
    "papírlapot": "papírlap",
    "papírmaséból": "papírmasé",
    "papírmunkát": "papírmunka",
    "papírnyomóba": "papírnyomó",
    "papírnyomóban": "papírnyomó",
    "papírnyomónak": "papírnyomó",
    "papírnyomót": "papírnyomó",
    "papírnyomóval": "papírnyomó",
    "papírok": "papír",
    "papírokat": "papír",
    "papírokkal": "papír",
    "papírokra": "papír",
    "papíron": "papír",
    "papírra": "papír",
    "papírral": "papír",
    "papírruhát": "papírruha",
    "papírszalagját": "papírszalag",
    "papírszalagot": "papírszalag",
    "papírt": "papír",
    "papírunk": "papír",
    "paradicsomtonnák": "paradicsomtonna",
    "paramétereit": "paraméter",
    "parancsa": "parancs",
    "parancsait": "parancs",
    "parancsaival": "parancs",
    "parancsnoka": "parancsnok",
    "parancsnokaik": "parancsnok",
    "parancsnokhoz": "parancsnok",
    "parancsnoklását": "parancsnoklás",
    "parancsnokok": "parancsnok",
    "parancsnoksága": "parancsnokság",
    "parancsnokságnak": "parancsnokság",
    "parancsnokságtól": "parancsnokság",
    "parancsnokságunknál": "parancsnokság",
    "parancsnokságának": "parancsnokság",
    "parancsokat": "parancs",
    "parancsoknak": "parancs",
    "parancsolhassanak": "parancsolhat",
    "parancsolj": "parancsol",
    "parancsolnak": "parancsol",
    "parancsolni": "parancsol",
    "parancsolnánk": "parancsol",
    "parancsolt": "parancsol",
    "parancsolta": "parancsol",
    "parancsoltok": "parancsol",
    "parancsot": "parancs",
    "paraszt-értelmiségünk": "paraszt-értelmiség",
    "parasztasszonyok": "parasztasszony",
    "parasztcsavargóknak": "parasztcsavargó",
    "parasztfestők": "parasztfestő",
    "parasztfiúnak": "parasztfiú",
    "parasztfiút": "parasztfiú",
    "parasztgazdám": "parasztgazda",
    "parasztgazdának": "parasztgazda",
    "parasztgyerekeket": "parasztgyerek",
    "parasztlegényekhez": "parasztlegény",
    "parasztlányok": "parasztlány",
    "parasztnak": "paraszt",
    "parasztnál": "paraszt",
    "parasztok": "paraszt",
    "parasztokat": "paraszt",
    "parasztokkal": "paraszt",
    "parasztoknak": "paraszt",
    "parasztokra": "paraszt",
    "parasztoktól": "paraszt",
    "parasztot": "paraszt",
    "parazitákat": "parazita",
    "parfümje": "parfüm",
    "parfümöm": "parfüm",
    "parkba": "park",
    "parkban": "park",
    "parkok": "park",
    "parkokban": "park",
    "parkolóban": "parkoló",
    "parkolójában": "parkoló",
    "parkolók": "parkoló",
    "parkolót": "parkoló",
    "parkon": "park",
    "parkosításával": "parkosítás",
    "parkot": "park",
    "parlagon": "parlag",
    "parlamentarizmussal": "parlamentarizmus",
    "parlamentbe": "parlament",
    "parlamentben": "parlament",
    "parlamentből": "parlament",
    "parlamentet": "parlament",
    "parlamentje": "parlament",
    "parlamentnek": "parlament",
    "partijában": "parti",
    "partikkal": "parti",
    "partikulák": "partikula",
    "partja": "part",
    "partjai": "part",
    "partján": "part",
    "partjára": "part",
    "partjáról": "part",
    "partnere": "partner",
    "partnerei": "partner",
    "partnereiket": "partner",
    "partnereiktől": "partner",
    "partnereinek": "partner",
    "partnereit": "partner",
    "partnerek": "partner",
    "partnereket": "partner",
    "partnerként": "partner",
    "partnerrel": "partner",
    "partnerének": "partner",
    "partról": "part",
    "partvidékre": "partvidék",
    "parádékat": "parádé",
    "parádésan": "parádés",
    "paráználkodni": "paráználkodik",
    "paráználkodást": "paráználkodás",
    "paréjjal": "paréj",
    "paréjt": "paréj",
    "paródiája": "paródia",
    "passzióból": "passzió",
    "passzióidat": "passzió",
    "passzust": "passzus",
    "pasztelljeire": "pasztell",
    "pasztelljén": "pasztell",
    "pasztellszínekben": "pasztellszín",
    "paszulyra": "paszuly",
    "paszulyt": "paszuly",
    "patakról": "patak",
    "patentkapcsot": "patentkapocs",
    "patikusnak": "patikus",
    "patikusok": "patikus",
    "patikusságot": "patikusság",
    "patikust": "patikus",
    "patikába": "patika",
    "patikában": "patika",
    "patikából": "patika",
    "patkányfészkeket": "patkányfészek",
    "patkánylyukakra": "patkánylyuk",
    "patkányok": "patkány",
    "patkányokat": "patkány",
    "patkányokkal": "patkány",
    "patkányoktól": "patkány",
    "patkányt": "patkány",
    "patkánytól": "patkány",
    "patkókat": "patkó",
    "patkót": "patkó",
    "patrónusává": "patrónus",
    "pattant": "pattan",
    "pattogatott": "pattogat",
    "patáin": "pata",
    "pauszpapírba": "pauszpapír",
    "pazaroljon": "pazarol",
    "pazarolni": "pazarol",
    "pecsétek": "pecsét",
    "pecsételte": "pecsétel",
    "pecsétje": "pecsét",
    "pecsétjeiken": "pecsét",
    "pecsétjéről": "pecsét",
    "pedagógiából": "pedagógia",
    "pedagógusbérek": "pedagógusbér",
    "pedagógusok": "pedagógus",
    "pedálgombról": "pedálgomb",
    "pelenkákat": "pelenka",
    "pellengérről": "pellengér",
    "pengéje": "penge",
    "pengét": "penge",
    "pengőből": "pengő",
    "pengőik": "pengő",
    "pengőjét": "pengő",
    "pengőjükből": "pengő",
    "pengőt": "pengő",
    "perbe": "per",
    "perben": "per",
    "percbe": "perc",
    "percben": "perc",
    "perccel": "perc",
    "perce": "perc",
    "perceiben": "perc",
    "perceik": "perc",
    "perceire": "perc",
    "percek": "perc",
    "percekben": "perc",
    "perceket": "perc",
    "percen": "perc",
    "percenként": "perc",
    "percet": "perc",
    "percig": "perc",
    "perckor": "perc",
    "percre": "perc",
    "percről": "perc",
    "percéig": "perc",
    "percüket": "perc",
    "percünk": "perc",
    "pere": "per",
    "perecért": "perec",
    "perecéért": "perec",
    "pereli": "perel",
    "pereme": "perem",
    "pereméhez": "perem",
    "peremén": "perem",
    "peren": "per",
    "pereskedése": "pereskedés",
    "pergésével": "pergés",
    "perifériára": "periféria",
    "periodikusan": "periodikus",
    "periratban": "perirat",
    "perkupaiaknak": "perkupai",
    "perkupán": "perkupa",
    "perkupának": "perkupa",
    "pernyével": "pernye",
    "peronjáról": "peron",
    "perre": "per",
    "perrel": "per",
    "pert": "per",
    "perzselte": "perzsel",
    "perük": "per",
    "pesten": "pest",
    "petrencékben": "petrence",
    "petrencéket": "petrence",
    "petróleumfőzőre": "petróleumfőző",
    "petróleumfőzőt": "petróleumfőző",
    "pezsgőt": "pezsgő",
    "piaca": "piac",
    "piacbővülést": "piacbővülés",
    "piacgazdasága": "piacgazdaság",
    "piacgazdasághoz": "piacgazdaság",
    "piacgazdaságról": "piacgazdaság",
    "piachoz": "piac",
    "piaclehetőségek": "piaclehetőség",
    "piacnapon": "piacnap",
    "piacokért": "piac",
    "piacon": "piac",
    "piacot": "piac",
    "piacra": "piac",
    "piacról": "piac",
    "piacszerzést": "piacszerzés",
    "piacán": "piac",
    "pihenhessen": "pihenhet",
    "pihenhessenek": "pihenhet",
    "pihenj": "pihen",
    "pihenni": "pihen",
    "pihent": "pihen",
    "pihentebben": "pihent",
    "pihenteti": "pihentet",
    "pihenéshez": "pihenés",
    "pihenésre": "pihenés",
    "pihenésért": "pihenés",
    "pihenőszékével": "pihenőszék",
    "pihenőt": "pihenő",
    "pikantériája": "pikantéria",
    "pillanata": "pillanat",
    "pillanataiban": "pillanat",
    "pillanatban": "pillanat",
    "pillanatig": "pillanat",
    "pillanatnál": "pillanat",
    "pillanatok": "pillanat",
    "pillanatokban": "pillanat",
    "pillanatokra": "pillanat",
    "pillanatonként": "pillanat",
    "pillanatot": "pillanat",
    "pillanatra": "pillanat",
    "pillanatról": "pillanat",
    "pillanattól": "pillanat",
    "pillanatában": "pillanat",
    "pillanatától": "pillanat",
    "pillantani": "pillant",
    "pillantgattak": "pillantgat",
    "pillanthatta": "pillanthat",
    "pillanthattak": "pillanthat",
    "pillantott": "pillant",
    "pillantotta": "pillant",
    "pillantása": "pillantás",
    "pillantásban": "pillantás",
    "pillantásnak": "pillantás",
    "pillantások": "pillantás",
    "pillantásokat": "pillantás",
    "pillantásra": "pillantás",
    "pillantást": "pillantás",
    "pillantásuk": "pillantás",
    "pillantásában": "pillantás",
    "pillantásából": "pillantás",
    "pillantásának": "pillantás",
    "pillantását": "pillantás",
    "pillákkal": "pilla",
    "pilótákat": "pilóta",
    "pinceklubok": "pinceklub",
    "pincekönyvtárban": "pincekönyvtár",
    "pincében": "pince",
    "pincéből": "pince",
    "pincéje": "pince",
    "pincéjében": "pince",
    "pincék": "pince",
    "pincékben": "pince",
    "pincérek": "pincér",
    "pincérként": "pincér",
    "pinteset": "pintes",
    "pintet": "pint",
    "pintje": "pint",
    "pintnek": "pint",
    "pipája": "pipa",
    "pipájába": "pipa",
    "pipájából": "pipa",
    "pipát": "pipa",
    "pipázni": "pipázik",
    "pipáért": "pipa",
    "piramisok": "piramis",
    "pirosabbnak": "piros",
    "pirostól": "piros",
    "pirult": "pirul",
    "pirítanak": "pirít",
    "pirítóst": "pirítós",
    "pislogott": "pislog",
    "pislogtunk": "pislog",
    "pislogásuk": "pislogás",
    "pisszegik": "pisszeg",
    "pisszegtették": "pisszegtet",
    "piszkoskodni": "piszkoskodik",
    "piszkosnak": "piszkos",
    "piszkossá": "piszkos",
    "piszkot": "piszok",
    "piszkált": "piszkál",
    "piszkával": "piszok",
    "pisztollyal": "pisztoly",
    "pisztolyokat": "pisztoly",
    "pisztolyt": "pisztoly",
    "pisztolyával": "pisztoly",
    "pityeregte": "pityereg",
    "pityergéssel": "pityergés",
    "pizsamára": "pizsama",
    "pizsamát": "pizsama",
    "pizsamáért": "pizsama",
    "plafonig": "plafon",
    "plakátok": "plakát",
    "plakátokat": "plakát",
    "plakátokkal": "plakát",
    "plakátokon": "plakát",
    "plakátokról": "plakát",
    "plakáton": "plakát",
    "plakátot": "plakát",
    "plakátra": "plakát",
    "plakátról": "plakát",
    "platformot": "platform",
    "platánok": "platán",
    "pletykabeszédet": "pletykabeszéd",
    "pletykák": "pletyka",
    "pocsolyában": "pocsolya",
    "pocsolyából": "pocsolya",
    "pocsolyáig": "pocsolya",
    "pocsolyája": "pocsolya",
    "pocsolyák": "pocsolya",
    "pocsékolják": "pocsékol",
    "poeticáját": "poetica",
    "pofacsontja": "pofacsont",
    "pofacsontjaiig": "pofacsont",
    "pofacsontok": "pofacsont",
    "pofaszakállát": "pofaszakáll",
    "pofon": "pof",
    "pofoncsapáson": "pofoncsapás",
    "pofonjainak": "pofon",
    "pofonnal": "pofon",
    "pofonok": "pofon",
    "pofont": "pofon",
    "pofozták": "pofoz",
    "pofájához": "pofa",
    "pofájává": "pofa",
    "pofátlanok": "pofátlan",
    "pogácsáira": "pogácsa",
    "pogácsát": "pogácsa",
    "pogányoknak": "pogány",
    "pohara": "pohár",
    "poharaikat": "pohár",
    "poharak": "pohár",
    "poharakat": "pohár",
    "poharakkal": "pohár",
    "poharat": "pohár",
    "poharába": "pohár",
    "poharára": "pohár",
    "poharát": "pohár",
    "pohárba": "pohár",
    "pohárra": "pohár",
    "pohárral": "pohár",
    "pojácáival": "pojáca",
    "pokolian": "pokoli",
    "pokrócokat": "pokróc",
    "polcok": "polc",
    "polcon": "polc",
    "polcról": "polc",
    "polcuk": "polc",
    "polcán": "polc",
    "polgára": "polgár",
    "polgárait": "polgár",
    "polgáremberek": "polgárember",
    "polgárfiút": "polgárfiú",
    "polgárháborúk": "polgárháború",
    "polgármestere": "polgármester",
    "polgármesterek": "polgármester",
    "polgármesternek": "polgármester",
    "polgármesternének": "polgármesterné",
    "polgármesterrel": "polgármester",
    "polgármestert": "polgármester",
    "polgármesterének": "polgármester",
    "polgárnak": "polgár",
    "polgárok": "polgár",
    "polgárokat": "polgár",
    "polgárra": "polgár",
    "polgárságot": "polgárság",
    "polgárának": "polgár",
    "polik-ként": "poli",
    "politikusa": "politikus",
    "politikusnak": "politikus",
    "politikusok": "politikus",
    "politikusokat": "politikus",
    "politikusokból": "politikus",
    "politikusoknak": "politikus",
    "politikusom": "politikus",
    "politikust": "politikus",
    "politikába": "politika",
    "politikában": "politika",
    "politikája": "politika",
    "politikájuk": "politika",
    "politikájának": "politika",
    "politikáját": "politika",
    "politikának": "politika",
    "politikára": "politika",
    "politikát": "politika",
    "politikától": "politika",
    "politikával": "politika",
    "politizálnunk": "politizál",
    "politizáltak": "politizált",
    "politizáláshoz": "politizálás",
    "poliéderek": "poliéder",
    "poloskafészkek": "poloskafészek",
    "poloskaszagból": "poloskaszag",
    "poloskák": "poloska",
    "poloskákat": "poloska",
    "poloskával": "poloska",
    "polémiára": "polémia",
    "pompáját": "pompa",
    "pompásan": "pompás",
    "ponciustól": "poncius",
    "pongyolába": "pongyola",
    "ponthoz": "pont",
    "pontig": "pont",
    "pontja": "pont",
    "pontjait": "pont",
    "pontján": "pont",
    "pontját": "pont",
    "pontok": "pont",
    "pontokat": "pont",
    "ponton": "pont",
    "pontonhídon": "pontonhíd",
    "pontosabb": "pontos",
    "pontosabbak": "pontos",
    "pontosabban": "pontos",
    "pontosabbra": "pontos",
    "pontosan": "pontos",
    "pontossággal": "pontosság",
    "pontosvesszők": "pontosvessző",
    "pontosítani": "pontosít",
    "pontot": "pont",
    "pontozta": "pontoz",
    "ponttal": "pont",
    "ponyvafüzetek": "ponyvafüzet",
    "ponyvából": "ponyva",
    "ponyvák": "ponyva",
    "ponyvára": "ponyva",
    "ponyvát": "ponyva",
    "ponyvával": "ponyva",
    "populistáinak": "populista",
    "populistáktól": "populista",
    "populistának": "populista",
    "pora": "por",
    "porba": "por",
    "porból": "por",
    "porcelánból": "porcelán",
    "porceláncsészékben": "porceláncsésze",
    "porcelándugót": "porcelándugó",
    "porcelánok": "porcelán",
    "porcelántéglákat": "porcelántégla",
    "porciót": "porció",
    "porfellegekre": "porfelleg",
    "porig": "por",
    "porként": "por",
    "porladt": "porlad",
    "pornográfiát": "pornográfia",
    "pornégyszöget": "pornégyszög",
    "pornószek-nek": "pornószek",
    "pornószekben": "pornószek",
    "porondon": "porond",
    "porondról": "porond",
    "porra": "por",
    "porral": "por",
    "porszemecskék": "porszemecské",
    "porszemet": "porszem",
    "port": "por",
    "portrét": "portré",
    "portásokat": "portás",
    "portékája": "portéka",
    "portól": "por",
    "porviharba": "porvihar",
    "porával": "por",
    "porért": "por",
    "poshadt": "poshad",
    "postabankhoz": "postabank",
    "postabanknak": "postabank",
    "postán": "posta",
    "postára": "posta",
    "postásnak": "postás",
    "postával": "posta",
    "postázza": "postáz",
    "postázzák": "postáz",
    "poszt-elméletek": "poszt-elmélet",
    "posztgraduális-képzésre": "posztgraduális-képzés",
    "posztjára": "poszt",
    "posztkommunisták": "posztkommunista",
    "posztot": "poszt",
    "posztra": "poszt",
    "posztért": "poszt",
    "posztógyárban": "posztógyár",
    "posztóhuzatra": "posztóhuzat",
    "posztósapkát": "posztósapka",
    "posztószagban": "posztószag",
    "posztóval": "posztó",
    "potentáttá": "potentát",
    "pottyanjon": "pottyan",
    "pottyant": "pottyan",
    "pottyantak": "pottyant",
    "potyogott": "potyog",
    "potyára": "potya",
    "potyát": "potya",
    "pozitívumot": "pozitívum",
    "pozícióba": "pozíció",
    "pozícióból": "pozíció",
    "pozíciói": "pozíció",
    "pozícióit": "pozíciói",
    "pozíciója": "pozíció",
    "pozíciójavulást": "pozíciójavulás",
    "pozíciójában": "pozíció",
    "pozíciójából": "pozíció",
    "pozícióját": "pozíció",
    "pozíciókat": "pozíció",
    "pozíciónkon": "pozíció",
    "poétájának": "poéta",
    "praxisod": "praxis",
    "praxisomból": "praxis",
    "precedensértékűnek": "precedensértékű",
    "precízen": "precíz",
    "precíznek": "precíz",
    "preferálná": "preferál",
    "premierje": "premier",
    "presbiterek": "presbiter",
    "presbitereket": "presbiter",
    "presbiterekre": "presbiter",
    "presbiterektől": "presbiter",
    "presbitériummal": "presbitérium",
    "presztízsszempontok": "presztízsszempont",
    "presztízsét": "presztízs",
    "priccsről": "priccs",
    "priccsén": "priccs",
    "primerkörzetet": "primerkörzet",
    "primitívebb": "primitív",
    "privatizációban": "privatizáció",
    "privatizációja": "privatizáció",
    "privatizációjára": "privatizáció",
    "privatizációját": "privatizáció",
    "privatizációra": "privatizáció",
    "privatizációról": "privatizáció",
    "privatizációval": "privatizáció",
    "privatizációért": "privatizáció",
    "privatizált": "privatizál",
    "privatizálta": "privatizál",
    "privatizálására": "privatizálás",
    "problémái": "probléma",
    "problémáid": "probléma",
    "problémáikat": "probléma",
    "problémáink": "probléma",
    "problémáit": "probléma",
    "problémáival": "probléma",
    "problémája": "probléma",
    "problémáját": "probléma",
    "problémák": "probléma",
    "problémákat": "probléma",
    "problémákkal": "probléma",
    "problémán": "probléma",
    "problémát": "probléma",
    "problémával": "probléma",
    "producerét": "producer",
    "produkciójukat": "produkció",
    "produkciók": "produkció",
    "produkciót": "produkció",
    "produkálni": "produkál",
    "produkált": "produkál",
    "professzorunktól": "professzor",
    "profitjukat": "profit",
    "profitot": "profit",
    "profitra": "profit",
    "prognosztizálnak": "prognosztizál",
    "programban": "program",
    "programhoz": "program",
    "programja": "program",
    "programjában": "program",
    "programjához": "program",
    "programját": "program",
    "programmal": "program",
    "programnak": "program",
    "programnyilatkozatának": "programnyilatkozat",
    "programod": "program",
    "programok": "program",
    "programokat": "program",
    "programokban": "program",
    "programokkal": "program",
    "programokra": "program",
    "programot": "program",
    "programozott": "programoz",
    "projektet": "projekt",
    "projekthez": "projekt",
    "projektjeinek": "projekt",
    "proletariátusnak": "proletariátus",
    "proletárnak": "proletár",
    "proletárok": "proletár",
    "proletároknak": "proletár",
    "proletároktól": "proletár",
    "prolik": "proli",
    "prolik-nak": "proli",
    "prolikat": "proli",
    "prolikban": "proli",
    "prolikkal": "proli",
    "proliknak": "proli",
    "prolikról": "proli",
    "proliké": "proli",
    "prolilakásokban": "prolilakás",
    "prolinegyedekben": "prolinegyed",
    "prolit": "proli",
    "propagandahazugságok": "propagandahazugság",
    "propagandakiállításokat": "propagandakiállítás",
    "propagandája": "propaganda",
    "propagandával": "propaganda",
    "propagált": "propagál",
    "proponálhatja": "proponálhat",
    "prostituáltak": "prostituált",
    "prostituáltakkal": "prostituált",
    "prostituálttal": "prostituált",
    "prostitúciót": "prostitúció",
    "protekciósoknak": "protekciós",
    "protekciósokra": "protekciós",
    "providenciát": "providencia",
    "provokációktól": "provokáció",
    "provokációnak": "provokáció",
    "prédikálok": "prédikál",
    "prédikálták": "prédikál",
    "prédája": "préda",
    "prédájául": "préda",
    "prémiummal": "prémium",
    "préselni": "présel",
    "préselt": "présel",
    "préselődött": "préselődik",
    "présházat": "présház",
    "présében": "prés",
    "prímások": "prímás",
    "próbaidőre": "próbaidő",
    "próbalépést": "próbalépés",
    "próbája": "próba",
    "próbáját": "próba",
    "próbák": "próba",
    "próbáld": "próbál",
    "próbálj": "próbál",
    "próbálja": "próbál",
    "próbáljanak": "próbál",
    "próbáljon": "próbál",
    "próbáljuk": "próbál",
    "próbáljunk": "próbál",
    "próbálják": "próbál",
    "próbáljátok": "próbál",
    "próbálkozhatott": "próbálkozhat",
    "próbálkozni": "próbálkozik",
    "próbálkoznod": "próbálkozik",
    "próbálkozott": "próbálkozik",
    "próbálkoztam": "próbálkozik",
    "próbálkozások": "próbálkozás",
    "próbálkozásokat": "próbálkozás",
    "próbálkozással": "próbálkozás",
    "próbálni": "próbál",
    "próbálnának": "próbál",
    "próbálod": "próbál",
    "próbálok": "próbál",
    "próbálom": "próbál",
    "próbálsz": "próbál",
    "próbált": "próbál",
    "próbálta": "próbál",
    "próbáltak": "próbált",
    "próbáltam": "próbált",
    "próbáltatta": "próbáltat",
    "próbáltuk": "próbál",
    "próbálták": "próbál",
    "próbán": "próba",
    "próbánál": "próba",
    "próbára": "próba",
    "próbát": "próba",
    "próféciái": "prófécia",
    "prófétákat": "próféta",
    "prózában": "próza",
    "prózából": "próza",
    "pszichiáterként": "pszichiáter",
    "pszichiáterét": "pszichiáter",
    "pszichológiával": "pszichológia",
    "pszichológusnak": "pszichológus",
    "pszichológusok": "pszichológus",
    "pszichológussal": "pszichológus",
    "pszichéjéről": "psziché",
    "publicistaként": "publicista",
    "publikálásával": "publikálás",
    "pucolni": "pucol",
    "pufajkáját": "pufajka",
    "puffadt": "puffad",
    "puffogtatja": "puffogtat",
    "pufogását": "pufogás",
    "puhaságával": "puhaság",
    "puhulnak": "puhul",
    "puhán": "puha",
    "puliszkán": "puliszka",
    "pulthoz": "pult",
    "pultjain": "pult",
    "pultjának": "pult",
    "pultnál": "pult",
    "pultokon": "pult",
    "pulton": "pult",
    "pultra": "pult",
    "pulttól": "pult",
    "pulykacsontok": "pulykacsont",
    "pulykaszállítmányok": "pulykaszállítmány",
    "pulykái": "pulyka",
    "pulzusát": "pulzus",
    "pulóvereket": "pulóver",
    "pumpolásért": "pumpolás",
    "pumpált": "pumpál",
    "puritanizmusa": "puritanizmus",
    "puritanizmust": "puritanizmus",
    "puritanizmusának": "puritanizmus",
    "puskájukat": "puska",
    "puskákat": "puska",
    "puskákkal": "puska",
    "puskával": "puska",
    "pusztadombiaknak": "pusztadombi",
    "pusztuljon": "pusztul",
    "pusztulását": "pusztulás",
    "puszták": "puszta",
    "pusztákra": "puszta",
    "pusztán": "puszta",
    "pusztítanak": "pusztít",
    "pusztítani": "pusztít",
    "pusztítanák": "pusztít",
    "pusztítja": "pusztít",
    "pusztítjuk": "pusztít",
    "pusztított": "pusztít",
    "pusztítása": "pusztítás",
    "pusztításait": "pusztítás",
    "pusztításnál": "pusztítás",
    "pusztítások": "pusztítás",
    "pusztítást": "pusztítás",
    "páciense": "páciens",
    "páciensei": "páciens",
    "pácienseihez": "páciens",
    "pácienseim": "páciens",
    "pácienseket": "páciens",
    "páciensemet": "páciens",
    "páciensként": "páciens",
    "páciensét": "páciens",
    "pácolt": "pácol",
    "páholyt": "páholy",
    "pálcát": "pálca",
    "pálfordulást": "pálfordulás",
    "pálinkabarátainak": "pálinkabarát",
    "pálinkája": "pálinka",
    "pálinkára": "pálinka",
    "pálinkát": "pálinka",
    "pálinkával": "pálinka",
    "pállott": "pállik",
    "pályaelhagyással": "pályaelhagyás",
    "pályaelhagyók": "pályaelhagyó",
    "pályafutása": "pályafutás",
    "pályakezdők": "pályakezdő",
    "pályamunkák": "pályamunka",
    "pályaudvarig": "pályaudvar",
    "pályaudvarnál": "pályaudvar",
    "pályaudvaron": "pályaudvar",
    "pályaudvarra": "pályaudvar",
    "pályaválasztásomat": "pályaválasztás",
    "pályája": "pálya",
    "pályájának": "pálya",
    "pályák": "pálya",
    "pályáktól": "pálya",
    "pályám": "pálya",
    "pályán": "pálya",
    "pályára": "pálya",
    "pályáról": "pálya",
    "pályát": "pálya",
    "pályázatokat": "pályázat",
    "pályázaton": "pályázat",
    "pályázatot": "pályázat",
    "pályázatán": "pályázat",
    "pályázatára": "pályázat",
    "pályáznak": "pályázik",
    "pályázott": "pályázik",
    "páncélosok": "páncélos",
    "páncélruhát": "páncélruha",
    "pánik": "páni",
    "pánikot": "pánik",
    "pánikszerűen": "pánikszerű",
    "pántlikára": "pántlika",
    "pántot": "pánt",
    "pára": "pá",
    "párat": "pár",
    "páratlanul": "páratlan",
    "párbajt": "párbaj",
    "párban": "pár",
    "párbeszédek": "párbeszéd",
    "párbeszédét": "párbeszéd",
    "párducból": "párduc",
    "párhuzamosan": "párhuzamos",
    "párját": "pár",
    "párkányról": "párkány",
    "párkányán": "párkánya",
    "párkányára": "párkánya",
    "párkányát": "párkánya",
    "párnafélébe": "párnaféle",
    "párnahalmokkal": "párnahalom",
    "párnákkal": "párna",
    "párnán": "párna",
    "párnának": "párna",
    "párnára": "párna",
    "párnává": "párna",
    "párolgott": "párolog",
    "párolhatnák": "párolhat",
    "párosítása": "párosítás",
    "pároztatását": "pároztatás",
    "párra": "pár",
    "párról": "pár",
    "párszor": "pár",
    "párt": "pár",
    "párt-tagnak": "párt-tag",
    "pártatlanságát": "pártatlanság",
    "pártba": "párt",
    "pártban": "párt",
    "pártból": "párt",
    "pártdédelgetettségéből": "pártdédelgetettség",
    "pártelnök-miniszterelnököt": "pártelnök-miniszterelnök",
    "pártelnököt": "pártelnök",
    "pártfoglyok": "pártfogoly",
    "pártfoglyokkal": "pártfogoly",
    "pártfogolja": "pártfogol",
    "pártfogoltja": "pártfogolt",
    "pártfogói": "pártfogó",
    "pártfogóinak": "pártfogóín",
    "pártfogók": "pártfogó",
    "pártfogókat": "pártfogó",
    "pártfőtitkárra": "pártfőtitkár",
    "pártgyűléseken": "pártgyűlés",
    "párthoz": "párt",
    "pártházba": "pártház",
    "párthűnek": "párthű",
    "párthűt": "párthű",
    "pártja": "párt",
    "pártjaiban": "párt",
    "pártjukat": "párt",
    "pártjából": "párt",
    "pártján": "párt",
    "pártjának": "párt",
    "pártkiküldetésükön": "pártkiküldetés",
    "pártkongresszuson": "pártkongresszus",
    "pártkongresszusra": "pártkongresszus",
    "pártmegbízatással": "pártmegbízatás",
    "pártmunkája": "pártmunka",
    "pártnak": "párt",
    "pártnapon": "pártnap",
    "pártnők": "pártnő",
    "pártnőt": "pártnő",
    "pártok": "párt",
    "pártokban": "párt",
    "pártokkal": "párt",
    "pártoknak": "párt",
    "párton": "párt",
    "pártot": "párt",
    "pártra": "párt",
    "pártról": "párt",
    "pártszervezetnek": "pártszervezet",
    "pártszerűek": "pártszerű",
    "pártszerűen": "pártszerű",
    "pártszékházakat": "pártszékház",
    "pártszónokok": "pártszónok",
    "párttagba": "párttag",
    "párttaggal": "párttag",
    "párttaggyűléseken": "párttaggyűlés",
    "párttagnak": "párttag",
    "párttagok": "párttag",
    "párttagokat": "párttag",
    "párttagokban": "párttag",
    "párttagokkal": "párttag",
    "párttagoknak": "párttag",
    "párttagokon": "párttag",
    "párttagokról": "párttag",
    "párttagot": "párttag",
    "párttagra": "párttag",
    "párttagtól": "párttag",
    "párttal": "párt",
    "párttársai": "párttárs",
    "párttól": "párt",
    "párttörténetben": "párttörténet",
    "pártvezetői": "pártvezető",
    "pártvezetők": "pártvezető",
    "párté": "párt",
    "pártért": "párt",
    "pártértelmiségiek": "pártértelmiségi",
    "párájában": "pára",
    "pásztorembert": "pásztorember",
    "pásztorgyerekek": "pásztorgyerek",
    "pásztorának": "pásztor",
    "pásztát": "pászta",
    "pásztázik": "pásztáz",
    "pázsiton": "pázsit",
    "pékeknél": "pék",
    "pékműhelyben": "pékműhely",
    "péküzletek": "péküzlet",
    "péküzletet": "péküzlet",
    "példaként": "példa",
    "példáimmal": "példa",
    "példák": "példa",
    "példánkban": "példa",
    "példánya": "példány",
    "példányaihoz": "példány",
    "példányainak": "példány",
    "példányait": "példány",
    "példányban": "példány",
    "példánynak": "példány",
    "példányokat": "példány",
    "példányt": "példány",
    "példányáról": "példány",
    "példányát": "példány",
    "példát": "példa",
    "például": "példa",
    "példázza": "példáz",
    "pénteken": "péntek",
    "péntekig": "péntek",
    "pénzalapokból": "pénzalap",
    "pénzbírsággal": "pénzbírság",
    "pénzbüntetésre": "pénzbüntetés",
    "pénzből": "pénz",
    "pénzdarabot": "pénzdarab",
    "pénze": "pénz",
    "pénzei": "pénz",
    "pénzeiket": "pénz",
    "pénzeinek": "pénz",
    "pénzeiről": "pénz",
    "pénzek": "pénz",
    "pénzeket": "pénz",
    "pénzekhez": "pénz",
    "pénzekkel": "pénz",
    "pénzekről": "pénz",
    "pénzektől": "pénz",
    "pénzellátásra": "pénzellátás",
    "pénzelőinek": "pénzelői",
    "pénzem": "pénz",
    "pénzetek": "pénz",
    "pénzforrásait": "pénzforrás",
    "pénzintézetek": "pénzintézet",
    "pénzintézetektől": "pénzintézet",
    "pénzintézeteként": "pénzintézet",
    "pénzintézethez": "pénzintézet",
    "pénzintézetnél": "pénzintézet",
    "pénzjuttatást": "pénzjuttatás",
    "pénznek": "pénz",
    "pénzpiaca": "pénzpiac",
    "pénzpiacon": "pénzpiac",
    "pénzre": "pénz",
    "pénzről": "pénz",
    "pénzsóvárok": "pénzsóvár",
    "pénzt": "pénz",
    "pénztára": "pénztár",
    "pénztárak": "pénztár",
    "pénztárban": "pénztár",
    "pénztárcák": "pénztárca",
    "pénztárnak": "pénztár",
    "pénztárnál": "pénztár",
    "pénztárt": "pénztár",
    "pénzzel": "pénz",
    "pénzzé": "pénz",
    "pénzért": "pénz",
    "pénzét": "pénz",
    "pénzügyeket": "pénzügy",
    "pénzügyminiszterek": "pénzügyminiszter",
    "pénzügyminiszterem": "pénzügyminiszter",
    "pénzügyminiszternek": "pénzügyminiszter",
    "pénzügyminisztert": "pénzügyminiszter",
    "pénzügyminisztériumban": "pénzügyminisztérium",
    "pénzügyőrnek": "pénzügyőr",
    "pénzügyőrök": "pénzügyőr",
    "pénzügyőröket": "pénzügyőr",
    "pénzük": "pénz",
    "pénzüket": "pénz",
    "pénzünkből": "pénz",
    "pénzünket": "pénz",
    "pénzünkért": "pénz",
    "péppé": "pép",
    "pórul": "pór",
    "pórusai": "pórus",
    "pótköltségvetésből": "pótköltségvetés",
    "pótlása": "pótlás",
    "pótlásra": "pótlás",
    "pótlását": "pótlás",
    "pótlékairól": "pótlék",
    "pótlékokat": "pótlék",
    "pótlékokkal": "pótlék",
    "pótolhatja": "pótolhat",
    "pótolhatók": "pótolható",
    "pótolja": "pótol",
    "pótolni": "pótol",
    "pótolniuk": "pótol",
    "pótolná": "pótol",
    "pótolták": "pótol",
    "pózba": "póz",
    "pörkölt": "pörköl",
    "pörkölte": "pörköl",
    "pörköltet": "pörkölt",
    "púdert": "púder",
    "pünkösdig": "pünkösd",
    "pünkösdkor": "pünkösd",
    "püspöke": "püspök",
    "püspökökről": "püspök",
    "rabláncára": "rablánc",
    "rabláshoz": "rablás",
    "rablások": "rablás",
    "rablók": "rabló",
    "rablókat": "rabló",
    "rablómeséje": "rablómese",
    "rablónak": "rabló",
    "rablót": "rabló",
    "rablótámadása": "rablótámadás",
    "rabnak": "rab",
    "rabok": "rab",
    "rabolnak": "rabol",
    "raboltak": "rabolt",
    "rabszolgalázadásokig": "rabszolgalázadás",
    "rabszolgamunkára": "rabszolgamunka",
    "rabszolganépei": "rabszolganép",
    "rabszolganépek": "rabszolganép",
    "rabszolgasorba": "rabszolgasor",
    "rabszolgasorban": "rabszolgasor",
    "rabszolgavásárt": "rabszolgavásár",
    "rabszolgáik": "rabszolga",
    "rabszolgája": "rabszolga",
    "rabszolgájuk": "rabszolga",
    "rabszolgák": "rabszolga",
    "rabszolgákat": "rabszolga",
    "rabszolgának": "rabszolga",
    "rabsággal": "rabság",
    "rabtársak": "rabtárs",
    "racionalizálása": "racionalizálás",
    "radarrendszerek": "radarrendszer",
    "radikalizálódnak": "radikalizálódik",
    "radikálisabb": "radikális",
    "radikálisan": "radikális",
    "radikálisok": "radikális",
    "radiátorain": "radiátor",
    "radiátorok": "radiátor",
    "radiátort": "radiátor",
    "radírgumival": "radírgumi",
    "rafinált": "rafinál",
    "rafináltabb": "rafinált",
    "ragadja": "ragad",
    "ragadják": "ragad",
    "ragadott": "ragad",
    "ragadt": "ragad",
    "ragadta": "ragad",
    "ragadták": "ragad",
    "ragaszkodnak": "ragaszkodik",
    "ragaszkodnia": "ragaszkodik",
    "ragaszkodom": "ragaszkodik",
    "ragaszkodott": "ragaszkodik",
    "ragaszkodsz": "ragaszkodik",
    "ragaszkodtak": "ragaszkodik",
    "ragaszkodunk": "ragaszkodik",
    "ragasztottak": "ragasztott",
    "ragyogott": "ragyog",
    "ragyogóan": "ragyogó",
    "ragyogón": "ragyogó",
    "rajokba": "raj",
    "rajongásának": "rajongás",
    "rajongóinak": "rajongóín",
    "rajongók": "rajongó",
    "rajt": "raj",
    "rajta": "ő",
    "rajtad": "te",
    "rajtakapják": "rajtakap",
    "rajtakapnák": "rajtakap",
    "rajtakaptak": "rajtakap",
    "rajtam": "én",
    "rajtavesztett": "rajtaveszt",
    "rajtja": "rajt",
    "rajton": "rajt",
    "rajtuk": "ők",
    "rajtunk": "rajt",
    "rajzai": "rajz",
    "rajzaira": "rajz",
    "rajzani": "rajzik",
    "rajzban": "rajz",
    "rajzokat": "rajz",
    "rajzol": "rajzik",
    "rajzolnak": "rajzol",
    "rajzolni": "rajzol",
    "rajzolt": "rajzol",
    "rajzolódtak": "rajzolódik",
    "rajzon": "rajz",
    "rajzot": "rajz",
    "rajzunkon": "rajz",
    "rajzán": "rajz",
    "rakjuk": "rak",
    "rakják": "rak",
    "raknak": "rak",
    "rakni": "rak",
    "raknia": "rak",
    "rakodnak": "rakodik",
    "rakodni": "rakodik",
    "rakodom": "rakodik",
    "rakogatott": "rakogat",
    "rakosgatták": "rakosgat",
    "rakott": "rak",
    "rakta": "rak",
    "raktak": "rak",
    "raktere": "raktér",
    "rakterét": "raktér",
    "raktuk": "rak",
    "rakták": "rak",
    "raktárak": "raktár",
    "raktárakat": "raktár",
    "raktárakban": "raktár",
    "raktárakról": "raktár",
    "raktárba": "raktár",
    "raktárban": "raktár",
    "raktárházaiban": "raktárház",
    "raktáron": "raktár",
    "raktárosok": "raktáros",
    "raktárosunk": "raktáros",
    "raktározzák": "raktároz",
    "raktárunkban": "raktár",
    "raktárában": "raktár",
    "rakétabombák": "rakétabomba",
    "rakétabombákat": "rakétabomba",
    "rakéták": "rakéta",
    "rakétákat": "rakéta",
    "rakétákkal": "rakéta",
    "randevúja": "randevú",
    "rangadóján": "rangadó",
    "rangadón": "rangadó",
    "rangja": "rang",
    "ranglétrán": "ranglétra",
    "rangosabb": "rangos",
    "rangra": "rang",
    "rangsorban": "rangsor",
    "rangsorolják": "rangsorol",
    "rangsorolnia": "rangsorol",
    "rangsort": "rangsor",
    "rasszizmussal": "rasszizmus",
    "ratifikációja": "ratifikáció",
    "ratifikációjának": "ratifikáció",
    "ratifikációra": "ratifikáció",
    "ratifikációt": "ratifikáció",
    "ratifikálja": "ratifikál",
    "ratifikálnia": "ratifikál",
    "ratifikálása": "ratifikálás",
    "ratifikálást": "ratifikálás",
    "ratifikálására": "ratifikálás",
    "ratifikálását": "ratifikálás",
    "ravaszabb": "ravasz",
    "ravaszkodni": "ravaszkodik",
    "ravaszkodtuk": "ravaszkodik",
    "ravaszok": "ravasz",
    "ravaszra": "ravasz",
    "ravaszsággal": "ravaszság",
    "ravasztól": "ravasz",
    "ravaszul": "ravasz",
    "ravatalnál": "ravatal",
    "ravatalozóba": "ravatalozó",
    "ravatalozóból": "ravatalozó",
    "ravatalozója": "ravatalozó",
    "razziák": "razzia",
    "reagálni": "reagál",
    "reagált": "reagál",
    "reakciója": "reakció",
    "reakcióssággal": "reakciósság",
    "reaktorba": "reaktor",
    "reaktorral": "reaktor",
    "realisták": "realista",
    "realitások": "realitás",
    "realitásérzéküket": "realitásérzék",
    "rebarbarát": "rebarbara",
    "rebbent": "rebben",
    "rebbenésében": "rebbenés",
    "reccsent": "reccsen",
    "reccsenése": "reccsenés",
    "receptet": "recept",
    "receptje": "recept",
    "receptjei": "recept",
    "recesszióból": "recesszió",
    "recitálja": "recitál",
    "recsegésén": "recsegés",
    "redőiben": "redői",
    "redőnylécek": "redőnyléc",
    "redősen": "redős",
    "referenciadokumentációk": "referenciadokumentáció",
    "referencialisták": "referencialista",
    "reflex-szerűen": "reflex-szerű",
    "reflexeit": "reflex",
    "reformerben": "reformer",
    "reformereinek": "reformerő",
    "reformerek": "reformer",
    "reformja": "reform",
    "reformjavaslat-csomagon": "reformjavaslat-csomag",
    "reformjához": "reform",
    "reformjának": "reform",
    "reformjára": "reform",
    "reformjáról": "reform",
    "reformját": "reform",
    "reformjával": "reform",
    "reformkor": "reform",
    "reformmal": "reform",
    "reformokat": "reform",
    "reformoktól": "reform",
    "reformot": "reform",
    "reggelen": "reggel",
    "reggelenként": "reggel",
    "reggelig": "reggel",
    "reggelihez": "reggeli",
    "reggelire": "reggeli",
    "reggelit": "reggeli",
    "reggeliztünk": "reggelizik",
    "reggelre": "reggel",
    "reggeltől": "reggel",
    "regisztrációból": "regisztráció",
    "regisztrált": "regisztrál",
    "regénye": "regény",
    "regények": "regény",
    "regényeket": "regény",
    "regényekkel": "regény",
    "regénynek": "regény",
    "regényolvasást": "regényolvasás",
    "regényt": "regény",
    "regényírógépek": "regényírógép",
    "regényírógépnél": "regényírógép",
    "rehabilitált": "rehabilitál",
    "rejlenek": "rejlik",
    "rejlett": "rejlik",
    "rejtegethetek": "rejtegethet",
    "rejtegethetett": "rejtegethet",
    "rejtegetnek": "rejteget",
    "rejtegetni": "rejteget",
    "rejtekhelyed": "rejtekhely",
    "rejtekhelyeiről": "rejtekhely",
    "rejtekhelyeit": "rejtekhely",
    "rejtekhelyen": "rejtekhely",
    "rejtekhelyet": "rejtekhely",
    "rejtekhelyén": "rejtekhely",
    "rejtekhelyük": "rejtekhely",
    "rejtekhelyükön": "rejtekhely",
    "rejtekhelyünkre": "rejtekhely",
    "rejtelmeibe": "rejtelem",
    "rejtelmesen": "rejtelmes",
    "rejtelmet": "rejtelem",
    "rejteni": "rejt",
    "rejtett": "rejt",
    "rejtette": "rejt",
    "rejtették": "rejtet",
    "rejteznek": "rejtezik",
    "rejthessenek": "rejthet",
    "rejtik": "rejt",
    "rejtjelezett": "rejtjelez",
    "rejtse": "rejt",
    "rejtéllyel": "rejtély",
    "rejtélyeinek": "rejtély",
    "rejtőznek": "rejtőzik",
    "rejtőztek": "rejtőzik",
    "rekedt": "reked",
    "rekedtesebb": "rekedtes",
    "rekedtsége": "rekedtség",
    "rekedtünk": "rekedt",
    "rekesszel": "rekesz",
    "rekeszben": "rekesz",
    "rekeszek": "rekesz",
    "rekeszeket": "rekesz",
    "rekeszizma": "rekeszizom",
    "rekeszébe": "rekesz",
    "rekeszéből": "rekesz",
    "reklámbevételeken": "reklámbevétel",
    "reklámfotósként": "reklámfotós",
    "reklámozásában": "reklámozás",
    "reklámra": "reklám",
    "reklámszakemberekből": "reklámszakember",
    "rekonstrukcióhoz": "rekonstrukció",
    "rekordforgalmat": "rekordforgalom",
    "rekordhiánnyal": "rekordhiány",
    "rekordmagasságokat": "rekordmagasság",
    "rekordonként": "rekord",
    "rekordot": "rekord",
    "rekordszintet": "rekordszint",
    "rekordszintig": "rekordszint",
    "rektora": "rektor",
    "remegett": "remeg",
    "remegjen": "remeg",
    "remegni": "remeg",
    "remegése": "remegés",
    "remegését": "remegés",
    "remekműveket": "remekmű",
    "remekművet": "remekmű",
    "remekül": "remek",
    "remélem": "remél",
    "reméli": "remél",
    "remélik": "remél",
    "reméljük": "remél",
    "remélnek": "remél",
    "remélné": "remél",
    "remélt": "remél",
    "remélte": "remél",
    "reméltek": "remélt",
    "reméltem": "remélt",
    "reméltnél": "remélt",
    "remélték": "remél",
    "reméltünk": "remélt",
    "reménnyel": "remény",
    "reményben": "remény",
    "reménye": "remény",
    "reményei": "remény",
    "reményeik": "remény",
    "reményeink": "remény",
    "reményeit": "remény",
    "remények": "remény",
    "reményeket": "remény",
    "reménykedett": "reménykedik",
    "reménykedhetett": "reménykedhet",
    "reménykedni": "reménykedik",
    "reménykedtek": "reménykedik",
    "reménykedtem": "reménykedik",
    "reménykedtünk": "reménykedik",
    "reménykedéssel": "reménykedés",
    "reménysugárként": "reménysugár",
    "reménységek": "reménység",
    "reménységet": "reménység",
    "reménységgel": "reménység",
    "reménységünk": "reménység",
    "reményt": "remény",
    "reménytelenebbek": "reménytelen",
    "reménytelennek": "reménytelen",
    "reménytelensége": "reménytelenség",
    "reménytelenül": "reménytelen",
    "reményteljesen": "reményteljes",
    "reményében": "remény",
    "reményéhez": "remény",
    "reményét": "remény",
    "rendbe": "rend",
    "rendbelit": "rendbeli",
    "rendben": "rend",
    "rendbetétele": "rendbetétel",
    "rendeletben": "rendelet",
    "rendelete": "rendelet",
    "rendeleteinek": "rendelet",
    "rendeletet": "rendelet",
    "rendeletnek": "rendelet",
    "rendelettel": "rendelet",
    "rendeletében": "rendelet",
    "rendeletére": "rendelet",
    "rendeletük": "rendelet",
    "rendeli": "rendel",
    "rendelkezett": "rendelkezik",
    "rendelkezhessen": "rendelkezhet",
    "rendelkezhetett": "rendelkezhet",
    "rendelkeznek": "rendelkezik",
    "rendelkezni": "rendelkezik",
    "rendelkeztek": "rendelkezik",
    "rendelkezzenek": "rendelkezik",
    "rendelkezései": "rendelkezés",
    "rendelkezések": "rendelkezés",
    "rendelkezésekre": "rendelkezés",
    "rendelkezésre": "rendelkezés",
    "rendelkezést": "rendelkezés",
    "rendelkezésének": "rendelkezés",
    "rendelkezésére": "rendelkezés",
    "rendelkezésükre": "rendelkezés",
    "rendelkezésünkre": "rendelkezés",
    "rendelkezők": "rendelkező",
    "rendelkezőktől": "rendelkező",
    "rendellenességei": "rendellenesség",
    "rendelni": "rendel",
    "rendelnie": "rendel",
    "rendelnék": "rendel",
    "rendelt": "rendel",
    "rendelte": "rendel",
    "rendeltek": "rendelt",
    "rendeltetése": "rendeltetés",
    "rendeltünk": "rendelt",
    "rendelő-szobája": "rendelő-szoba",
    "rendelőjét": "rendelő",
    "rendelővel": "rendelő",
    "rendesebb": "rendes",
    "rendesek": "rendes",
    "rendesen": "rendes",
    "rendet": "rend",
    "rendezett": "rendez",
    "rendezgetett": "rendezget",
    "rendezgetne": "rendezget",
    "rendezgette": "rendezget",
    "rendezgettük": "rendezget",
    "rendezhesse": "rendezhet",
    "rendezhetné": "rendezhet",
    "rendezhette": "rendezhet",
    "rendezi": "rendez",
    "rendezik": "rendez",
    "rendezkedtünk": "rendezkedik",
    "rendeznek": "rendez",
    "rendezni": "rendez",
    "rendeznie": "rendez",
    "rendezné": "rendez",
    "rendezte": "rendez",
    "rendeztek": "rendez",
    "rendezték": "rendez",
    "rendezvényei": "rendezvény",
    "rendezvényeket": "rendezvény",
    "rendezvényen": "rendezvény",
    "rendezvénynek": "rendezvény",
    "rendezvénysorozatnak": "rendezvénysorozat",
    "rendezzék": "rendez",
    "rendezése": "rendezés",
    "rendezéseként": "rendezés",
    "rendezésre": "rendezés",
    "rendezést": "rendezés",
    "rendezéséhez": "rendezés",
    "rendezésének": "rendezés",
    "rendezésére": "rendezés",
    "rendezéséről": "rendezés",
    "rendezésével": "rendezés",
    "rendeződött": "rendeződik",
    "rendezői": "rendező",
    "rendezőinek": "rendezői",
    "rendezőire": "rendezői",
    "rendezőivel": "rendezői",
    "rendezők": "rendező",
    "rendfenntartói": "rendfenntartó",
    "rendfenntartókkal": "rendfenntartó",
    "rendje": "rend",
    "rendjének": "rend",
    "rendjéről": "rend",
    "rendjét": "rend",
    "rendjük": "rend",
    "rendkívülisége": "rendkívüliség",
    "rendlábat": "rendláb",
    "rendre": "rend",
    "rendreutasítja": "rendreutasít",
    "rendszabályok": "rendszabály",
    "rendszerbe": "rendszer",
    "rendszerben": "rendszerb",
    "rendszerből": "rendszer",
    "rendszere": "rendszer",
    "rendszerei": "rendszer",
    "rendszereiből": "rendszer",
    "rendszerek": "rendszer",
    "rendszerekben": "rendszer",
    "rendszereké": "rendszer",
    "rendszeresebb": "rendszeres",
    "rendszeresen": "rendszeres",
    "rendszerezte": "rendszerez",
    "rendszerre": "rendszer",
    "rendszerrel": "rendszer",
    "rendszerről": "rendszer",
    "rendszert": "rendszer",
    "rendszertelenebbül": "rendszertelen",
    "rendszerváltással": "rendszerváltás",
    "rendszerváltást": "rendszerváltás",
    "rendszeré": "rendszer",
    "rendszerében": "rendszer",
    "rendszerének": "rendszer",
    "rendszerét": "rendszer",
    "rendszerével": "rendszer",
    "rendszerünknek": "rendszer",
    "rendőrautót": "rendőrautó",
    "rendőrei": "rendőr",
    "rendőrkapitánya": "rendőrkapitány",
    "rendőrkapitányságokhoz": "rendőrkapitányság",
    "rendőrkapitányságtól": "rendőrkapitányság",
    "rendőrként": "rendőr",
    "rendőrnek": "rendőr",
    "rendőrségen": "rendőrség",
    "rendőrséget": "rendőrség",
    "rendőrséghez": "rendőrség",
    "rendőrségnek": "rendőrség",
    "rendőrségnél": "rendőrség",
    "rendőrségre": "rendőrség",
    "rendőrségtől": "rendőrség",
    "rendőrségéhez": "rendőrség",
    "rendőrt": "rendőr",
    "rendőrtisztviselőhöz": "rendőrtisztviselő",
    "rendőrtől": "rendőr",
    "rendőrök": "rendőr",
    "rendőröket": "rendőr",
    "rendőröknek": "rendőr",
    "rendőrőrsön": "rendőrőrs",
    "rengeteget": "rengeteg",
    "repcecséplést": "repcecséplés",
    "repceszalmát": "repceszalma",
    "repcének": "repce",
    "repedésben": "repedés",
    "repedéseiben": "repedés",
    "repertoárjuk": "repertoár",
    "repertoárrendszerben": "repertoárrendszer",
    "reprezentánsát": "reprezentáns",
    "reprivatizációt": "reprivatizáció",
    "reprodukciók": "reprodukció",
    "reprodukciókat": "reprodukció",
    "reprodukálni": "reprodukál",
    "repülj": "repül",
    "repült": "repül",
    "repültem": "repül",
    "repülést": "repülés",
    "repülünk": "repül",
    "repülőflottát": "repülőflotta",
    "repülőgépek": "repülőgép",
    "repülőgépeket": "repülőgép",
    "repülőgépet": "repülőgép",
    "repülőgépgyárát": "repülőgépgyár",
    "repülőtereik": "repülőtér",
    "repülőterén": "repülőtér",
    "repülőtéren": "repülőtér",
    "repülőtérről": "repülőtér",
    "repülőutam": "repülőút",
    "restek": "rest",
    "restellik": "restell",
    "reszelte": "reszel",
    "reszkettem": "reszket",
    "reszkettünk": "reszket",
    "reszketésén": "reszketés",
    "reteszt": "retesz",
    "rettegek": "retteg",
    "rettegett": "retteg",
    "rettegnek": "retteg",
    "rettegésben": "rettegés",
    "rettegése": "rettegés",
    "rettegéssel": "rettegés",
    "rettegést": "rettegés",
    "rettegéstől": "rettegés",
    "rettenetesen": "rettenetes",
    "rettenti": "rettent",
    "revolvert": "revolver",
    "rezdült": "rezdül",
    "rezegtetnie": "rezegtet",
    "rezgetik": "rezget",
    "rezgések": "rezgés",
    "rezgéseket": "rezgés",
    "rezgőkörébe": "rezgőkör",
    "rezignációba": "rezignáció",
    "rezignált": "rezignál",
    "rezignáltan": "rezignált",
    "rezignáltsággal": "rezignáltság",
    "rezsiköltségesen": "rezsiköltséges",
    "reálisan": "reális",
    "reáljövedelmek": "reáljövedelem",
    "reálérték-csökkenés": "reálértékcsökkenés",
    "reálértékben": "reálérték",
    "reálértéke": "reálérték",
    "riadalmát": "riadalom",
    "riadjunk": "riad",
    "riadnak": "riad",
    "riadt": "riad",
    "riadtunk": "riadt",
    "riadókészültségbe": "riadókészültség",
    "riasztaná": "riaszt",
    "riasztotta": "riaszt",
    "ricsajban": "ricsaj",
    "ridegebbé": "rideg",
    "rigmusai": "rigmus",
    "rigmusnak": "rigmus",
    "rigmusokból": "rigmus",
    "rigmust": "rigmus",
    "rigóra": "rigó",
    "rigóról": "rigó",
    "rikácsolássá": "rikácsolás",
    "rimánkodnak": "rimánkodik",
    "ringathatják": "ringathat",
    "ringatja": "ringat",
    "ringatta": "ringat",
    "ringbe": "ring",
    "ringlók": "ringló",
    "riportere": "riporter",
    "ritkaságnak": "ritkaság",
    "ritkaságszámba": "ritkaságszám",
    "ritkultak": "ritkult",
    "ritkábban": "ritka",
    "ritkán": "ritka",
    "ritkítani": "ritkít",
    "riválissal": "rivális",
    "riválisára": "rivális",
    "rizskását": "rizskása",
    "robbant": "robban",
    "robbantak": "robbant",
    "robbantani": "robbant",
    "robbantottak": "robbantott",
    "robbantották": "robbant",
    "robbantsa": "robbant",
    "robbantások": "robbantás",
    "robbantásokat": "robbantás",
    "robbantással": "robbantás",
    "robbantást": "robbantás",
    "robbanáskor": "robbanás",
    "robbanások": "robbanás",
    "robbanásszerűen": "robbanásszerű",
    "robbanást": "robbanás",
    "robbanását": "robbanás",
    "robbanóanyaggal": "robbanóanyag",
    "robbanóanyagokat": "robbanóanyag",
    "robbanóanyagot": "robbanóanyag",
    "robogott": "robog",
    "robotok": "robot",
    "robotot": "robot",
    "robusztusabb": "robusztus",
    "rohadóban": "rohadó",
    "rohamai": "roham",
    "rohamban": "roham",
    "rohamosan": "rohamos",
    "rohamozni": "rohamoz",
    "rohangálnak": "rohangál",
    "rohangáltak": "rohangált",
    "rohannak": "rohan",
    "rohanni": "rohan",
    "rohant": "rohan",
    "rohantak": "rohant",
    "rohasztásáról": "rohasztás",
    "rokkantakat": "rokkant",
    "rokonai": "rokon",
    "rokonainak": "rokon",
    "rokonnak": "rokon",
    "rokonok": "rokon",
    "rokonokat": "rokon",
    "rokonoktól": "rokon",
    "rokonszenvet": "rokonszenv",
    "rokonszenvezően": "rokonszenvező",
    "rokonszenvvel": "rokonszenv",
    "rokonszenvében": "rokonszenv",
    "rokonsága": "rokonság",
    "rokonának": "rokon",
    "romantikusnak": "romantikus",
    "romantikusának": "romantikus",
    "romba": "rom",
    "romban": "rom",
    "rombolják": "rombol",
    "rombolásoktól": "rombolás",
    "romhalmazok": "romhalmaz",
    "romlanak": "romlik",
    "romlatlanok": "romlatlan",
    "romlott": "romlik",
    "romlottságát": "romlottság",
    "romlása": "romlás",
    "romlásba": "romlás",
    "romlásával": "romlás",
    "rommá": "rom",
    "romok": "rom",
    "romokban": "rom",
    "romokból": "rom",
    "romoljon": "romol",
    "romról": "rom",
    "román": "roma",
    "románnak": "román",
    "románok": "román",
    "románokat": "román",
    "románokból": "román",
    "románokkal": "román",
    "románoknak": "román",
    "románoknál": "román",
    "románosan": "romános",
    "románul": "román",
    "roncsolt": "roncsol",
    "roncsot": "roncs",
    "rongyait": "rongy",
    "rongydarabok": "rongydarab",
    "rongyokból": "rongy",
    "rontják": "ront",
    "rontott": "ront",
    "rontotta": "ront",
    "rontottak": "rontott",
    "rontsuk": "ront",
    "ropogósnak": "ropogós",
    "rossz-ra": "rossz",
    "rosszabb": "rossz",
    "rosszabbak": "rosszabb",
    "rosszabbat": "rosszabb",
    "rosszabbodni": "rosszabbodik",
    "rosszabbul": "rosszabb",
    "rosszak": "rossz",
    "rosszat": "rossz",
    "rosszhiszeműségével": "rosszhiszeműség",
    "rosszkedvűen": "rosszkedvű",
    "rossznak": "rossz",
    "rosszul": "rossz",
    "rosszullétnek": "rosszullét",
    "rosszára": "rossz",
    "rostálják": "rostál",
    "rostálnak": "rostál",
    "rothadnak": "rothad",
    "rothadt": "rothad",
    "rothadást": "rothadás",
    "rovatban": "rovat",
    "rovatot": "rovat",
    "rovásomon": "rovás",
    "rovására": "rovás",
    "rovátkolt": "rovátkol",
    "rozsból": "rozs",
    "rozsdát": "rozsda",
    "rozskenyérrel": "rozskenyér",
    "rozstarlóra": "rozstarló",
    "rozstáblák": "rozstábla",
    "rozzsal": "rozs",
    "rt.-be": "rt.",
    "rt.-ben": "rt.",
    "rt.-nek": "rt.",
    "rt.-nél": "rt.",
    "rt.-t": "rt.",
    "rt.-től": "rt.",
    "rubelt": "rubel",
    "rugalmasabb": "rugalmas",
    "rugalmasan": "rugalmas",
    "rugalmassága": "rugalmasság",
    "rugalmasságra": "rugalmasság",
    "rugdalja": "rugdal",
    "rugdalta": "rugdal",
    "rugdalóznak": "rugdalózik",
    "rugónyikkanásban": "rugónyikkanás",
    "ruhacsíptetőkkel": "ruhacsíptető",
    "ruhadarabot": "ruhadarab",
    "ruhagyárban": "ruhagyár",
    "ruhaneműk": "ruhanemű",
    "ruhaszelvényt": "ruhaszelvény",
    "ruhatáraiban": "ruhatárai",
    "ruhába": "ruha",
    "ruhában": "ruha",
    "ruhád": "ruha",
    "ruháiban": "ruha",
    "ruháik": "ruha",
    "ruháikat": "ruha",
    "ruháinak": "ruha",
    "ruháit": "ruha",
    "ruhája": "ruha",
    "ruhájuk": "ruha",
    "ruhájukat": "ruha",
    "ruhájából": "ruha",
    "ruháját": "ruha",
    "ruhák": "ruha",
    "ruhákat": "ruha",
    "ruhákban": "ruha",
    "ruhám": "ruha",
    "ruhámat": "ruha",
    "ruhát": "ruha",
    "ruhátlanul": "ruhátlan",
    "ruházatunk": "ruházat",
    "ruházatán": "ruházat",
    "ruházta": "ruház",
    "ruháztak": "ruház",
    "rukkolt": "rukkol",
    "rutinnal": "rutin",
    "rá": "ő",
    "ráadással": "ráadás",
    "ráadást": "ráadás",
    "ráadásul": "ráadás",
    "rábeszéli": "rábeszél",
    "rábeszélni": "rábeszél",
    "rábeszélt": "rábeszél",
    "rábilincselni": "rábilincsel",
    "ráborult": "ráborul",
    "rábukkant": "rábukkan",
    "rábámult": "rábámul",
    "rábíznak": "rábízik",
    "rácok": "rác",
    "rácokra": "rác",
    "rácsa": "rács",
    "rácshoz": "rács",
    "rácskerítéssel": "rácskerítés",
    "rácsnak": "rács",
    "rácsok": "rács",
    "rácson": "rács",
    "rácsra": "rács",
    "rácsán": "rács",
    "rácsára": "rács",
    "rád": "te",
    "rádióadásokat": "rádióadás",
    "rádióadásokból": "rádióadás",
    "rádióban": "rádió",
    "rádióhullámok": "rádióhullám",
    "rádiójának": "rádió",
    "rádiókészülékek": "rádiókészülék",
    "rádiónak": "rádió",
    "rádiósugárzásának": "rádiósugárzás",
    "rádiósugárzásért": "rádiósugárzás",
    "rádiót": "rádió",
    "rádiótelefonoknál": "rádiótelefon",
    "rádióújságban": "rádióújság",
    "rádöbbent": "rádöbben",
    "ráeszmélni": "ráeszmél",
    "ráeszmélt": "ráeszmél",
    "ráfizetésesnek": "ráfizetéses",
    "ráfordításaikat": "ráfordítás",
    "ráfújt": "ráfúj",
    "rágcsálóé": "rágcsáló",
    "rágják": "rág",
    "rágondolni": "rágondol",
    "rágta": "rág",
    "rágyújtani": "rágyújt",
    "rágyújtott": "rágyújt",
    "rágyújtották": "rágyújt",
    "rágóizmai": "rágóizom",
    "ráhagyni": "ráhagy",
    "ráhagyta": "ráhagy",
    "ráhajigálták": "ráhajigál",
    "ráhajtani": "ráhajt",
    "ráhullott": "ráhullik",
    "ráhúzta": "ráhúz",
    "ráijeszteni": "ráijeszt",
    "ráismerek": "ráismer",
    "ráismernek": "ráismer",
    "ráismerni": "ráismer",
    "ráismersz": "ráismer",
    "ráismert": "ráismer",
    "rájuk": "ők",
    "rájöhetne": "rájöhet",
    "rájöjjenek": "rájön",
    "rájönnek": "rájön",
    "rájönni": "rájön",
    "rájött": "rájön",
    "rájöttek": "rájön",
    "rájöttem": "rájön",
    "rájövök": "rájön",
    "rákapatta": "rákapat",
    "rákapott": "rákap",
    "rákenődött": "rákenődik",
    "rákényszerítsenek": "rákényszerít",
    "rákényszerítsék": "rákényszerít",
    "rálátásból": "rálátás",
    "rálépett": "rálép",
    "rám": "én",
    "rámenni": "rámegy",
    "rámondhattuk": "rámondhat",
    "rámutatnak": "rámutat",
    "rámutatott": "rámutat",
    "ráncigálja": "ráncigál",
    "ráncigálják": "ráncigál",
    "ráncok": "ránc",
    "ráncosak": "ráncos",
    "rándult": "rándul",
    "rándulása": "rándulás",
    "ránehezedett": "ránehezedik",
    "rángatnak": "rángat",
    "rángattunk": "rángat",
    "rángatták": "rángat",
    "rángatózott": "rángatózik",
    "rángott": "ráng",
    "rángások": "rángás",
    "ránk": "mi",
    "rántott": "ránt",
    "rántották": "rántotta",
    "rántottát": "rántotta",
    "rántottával": "rántotta",
    "rántsa": "ránt",
    "rántást": "rántás",
    "rányisd": "rányit",
    "ránézett": "ránéz",
    "ránézni": "ránéz",
    "ránéztünk": "ránéz",
    "ránézésre": "ránézés",
    "ránézőből": "ránéző",
    "ráomlasztani": "ráomlaszt",
    "ráordítottak": "ráordított",
    "ráordítsanak": "ráordít",
    "ráparancsoltam": "ráparancsolt",
    "rápillantott": "rápillant",
    "rápirítanak": "rápirít",
    "rászakadt": "rászakad",
    "rászedésének": "rászedés",
    "rászokott": "rászokik",
    "rászorult": "rászorul",
    "rászorultak": "rászorult",
    "rászorultaknak": "rászorult",
    "rászánt": "rászán",
    "rászólt": "rászól",
    "rásütött": "rásüt",
    "rátaláljanak": "rátalál",
    "rátekerőzik": "rátekerőz",
    "rátereltem": "ráterelt",
    "ráteszik": "rátesz",
    "rátette": "rátesz",
    "rátok": "ti",
    "rátája": "ráta",
    "rátájával": "ráta",
    "rátát": "ráta",
    "rátával": "ráta",
    "rátört": "rátörik",
    "ráugatott": "ráugat",
    "rávegye": "rávesz",
    "rávehetik": "rávehet",
    "rávenni": "rávesz",
    "ráveszik": "rávesz",
    "rávett": "rávesz",
    "rávette": "rávesz",
    "rávezeti": "rávezet",
    "rávezetni": "rávezet",
    "rázendítettek": "rázendített",
    "rázkódtak": "rázkódik",
    "rázkódásokra": "rázkódás",
    "rázkódást": "rázkódás",
    "ráznak": "ráz",
    "rázott": "ráz",
    "rázta": "ráz",
    "rázza": "ráz",
    "ráébredt": "ráébred",
    "ráérsz": "ráérik",
    "ráértek": "ráért",
    "ráöntöttük": "ráöntött",
    "régebben": "rég",
    "régen": "rég",
    "régibb": "régi",
    "régiben": "régi",
    "régiek": "régi",
    "régiekből": "régi",
    "régiekkel": "régi",
    "réginél": "régi",
    "régire": "régi",
    "régiségek": "régiség",
    "régiségkereskedelemnek": "régiségkereskedelem",
    "régit": "régi",
    "régióban": "régió",
    "régióból": "régió",
    "régiói": "régió",
    "régiók": "régió",
    "régiókban": "régió",
    "régión": "régió",
    "régiót": "régió",
    "régtől": "rég",
    "rémhíreket": "rémhír",
    "rémisztette": "rémisztet",
    "rémképet": "rémkép",
    "rémleni": "rémlik",
    "rémlett": "rémlik",
    "rémlátomása": "rémlátomás",
    "rémületbe": "rémület",
    "rémülete": "rémület",
    "rémületeket": "rémület",
    "rémületet": "rémület",
    "rémülettel": "rémület",
    "rémülettől": "rémület",
    "rémületét": "rémület",
    "rémült": "rémül",
    "rémülten": "rémült",
    "répaegyesítéssel": "répaegyesítés",
    "répamunkások": "répamunkás",
    "répasorokon": "répasor",
    "répatáblák": "répatábla",
    "répába": "répa",
    "répára": "répa",
    "répát": "répa",
    "réseket": "rés",
    "résen": "rés",
    "rést": "rés",
    "részaránya": "részarány",
    "részasztaguk": "részasztag",
    "részbe": "rész",
    "részben": "rész",
    "részcséplést": "részcséplés",
    "része": "rész",
    "részed": "rész",
    "részegek": "részeg",
    "részegen": "részeg",
    "részegységek": "részegység",
    "részegységekre": "részegység",
    "részei": "rész",
    "részein": "rész",
    "részeit": "rész",
    "részek": "rész",
    "részeken": "rész",
    "részektől": "rész",
    "részeként": "rész",
    "részelnek": "részel",
    "részen": "rész",
    "részese": "részes",
    "részesedhetnek": "részesedhet",
    "részesedjék": "részesedik",
    "részesedése": "részesedés",
    "részesedéseihez": "részesedés",
    "részesedést": "részesedés",
    "részesedésére": "részesedés",
    "részesedését": "részesedés",
    "részesíteni": "részesít",
    "részesítenék": "részesít",
    "részesített": "részesít",
    "részesítette": "részesítet",
    "részesíthetjük": "részesíthet",
    "részesíti": "részesít",
    "részesítik": "részesít",
    "részesítését": "részesítés",
    "részesült": "részesül",
    "részesülők": "részesülő",
    "részetek": "rész",
    "részibe": "részi",
    "részjegyzésre": "részjegyzés",
    "részkereszteket": "részkereszt",
    "részkeresztjeink": "részkereszt",
    "részlegben": "részleg",
    "részlege": "részleg",
    "részlegesen": "részleges",
    "részlegében": "részleg",
    "részlegének": "részleg",
    "részletben": "részlet",
    "részleteiben": "részlet",
    "részleteinek": "részlet",
    "részleteire": "részlet",
    "részleteiről": "részlet",
    "részleteit": "részlet",
    "részletek": "részlet",
    "részletekbe": "részlet",
    "részletekben": "részlet",
    "részleteken": "részlet",
    "részleteket": "részlet",
    "részletekig": "részlet",
    "részletesebb": "részletes",
    "részletesen": "részletes",
    "részletet": "részlet",
    "részletezett": "részletez",
    "részletezni": "részletez",
    "részletezte": "részletez",
    "részletezésére": "részletezés",
    "részletezésével": "részletezés",
    "részletezően": "részletező",
    "részletfizetést": "részletfizetés",
    "részletkérdést": "részletkérdés",
    "részletszabályok": "részletszabály",
    "részletét": "részlet",
    "részmérésnél": "részmérés",
    "részre": "rész",
    "részről": "rész",
    "részt": "rész",
    "résztulajdonosa": "résztulajdonos",
    "résztvevői": "résztvevő",
    "résztvevője": "résztvevő",
    "résztvevők": "résztvevő",
    "résztvevőket": "résztvevő",
    "részvénycserében": "részvénycsere",
    "részvénycseréjét": "részvénycsere",
    "részvénycsomagból": "részvénycsomag",
    "részvénycsomagjából": "részvénycsomag",
    "részvénycsomagjának": "részvénycsomag",
    "részvénycsomagját": "részvénycsomag",
    "részvénycsomagot": "részvénycsomag",
    "részvényei": "részvény",
    "részvényeiből": "részvény",
    "részvényeik": "részvény",
    "részvényeinek": "részvény",
    "részvényeit": "részvény",
    "részvények": "részvény",
    "részvényeket": "részvény",
    "részvényekkel": "részvény",
    "részvényesek": "részvényes",
    "részvényjegyzést": "részvényjegyzés",
    "részvényjuttatásra": "részvényjuttatás",
    "részvénypakettjéről": "részvénypakett",
    "részvénypiacokon": "részvénypiac",
    "részvényre": "részvény",
    "részvényszekciója": "részvényszekció",
    "részvényt": "részvény",
    "részvényátadást": "részvényátadás",
    "részvényért": "részvény",
    "részvételtől": "részvétel",
    "részvételével": "részvétel",
    "részvételük": "részvétel",
    "részvéttel": "részvét",
    "részébe": "rész",
    "részében": "rész",
    "részéből": "rész",
    "részén": "rész",
    "részének": "rész",
    "részére": "rész",
    "részért": "rész",
    "részéről": "rész",
    "részét": "rész",
    "részétől": "rész",
    "részével": "rész",
    "részévé": "részév",
    "részük": "rész",
    "részüket": "rész",
    "részükről": "rész",
    "részünk": "rész",
    "részünkről": "rész",
    "réséhez": "rés",
    "rétegei": "réteg",
    "rétegeiből": "réteg",
    "rétegek": "réteg",
    "rétegekkel": "réteg",
    "rétegeknek": "réteg",
    "rétegekre": "réteg",
    "réteget": "réteg",
    "rétegéből": "réteg",
    "rétek": "rét",
    "réten": "rét",
    "rétet": "rét",
    "rétre": "rét",
    "révedezéséből": "révedezés",
    "révedezővé": "révedező",
    "révedt": "réved",
    "révetegen": "réveteg",
    "révén": "rév",
    "révükön": "rév",
    "rézbe": "réz",
    "rézkarikái": "rézkarika",
    "rézkarikáit": "rézkarika",
    "rézmetszettel": "rézmetszett",
    "rézpénzt": "rézpénz",
    "réztárgyak": "réztárgy",
    "rímekkel": "rím",
    "rímelt": "rímel",
    "rímeltek": "rímelt",
    "róla": "ő",
    "rólad": "te",
    "rólam": "én",
    "rólatok": "ti",
    "róluk": "ők",
    "rólunk": "mi",
    "rótt": "ró",
    "rótták": "ró",
    "rózsadombja": "rózsadomb",
    "rózsaillatban": "rózsaillat",
    "rózsaszínűvé": "rózsaszínű",
    "rózsák": "rózsa",
    "rózsállott": "rózsállik",
    "rózsára": "rózsa",
    "rögeszmédhez": "rögeszme",
    "rögeszméje": "rögeszme",
    "rögtönzése": "rögtönzés",
    "rögtönzöttségnek": "rögtönzöttség",
    "rögzíteni": "rögzít",
    "rögzített": "rögzít",
    "rögzítette": "rögzítet",
    "rögzítették": "rögzítet",
    "rögzíti": "rögzít",
    "rögzítik": "rögzít",
    "rögzítését": "rögzítés",
    "rögök": "rög",
    "röhögtünk": "röhög",
    "röpiratokat": "röpirat",
    "röpiratokban": "röpirat",
    "röpködött": "röpköd",
    "röppent": "röppen",
    "röppentek": "röppent",
    "röpítette": "röpítet",
    "röpítsük": "röpít",
    "röstelkedett": "röstelkedik",
    "rövidebb": "rövid",
    "rövidebben": "rövid",
    "rövidebbnek": "rövid",
    "rövidek": "rövid",
    "rövidesen": "rövides",
    "rövidnadrágjába": "rövidnadrág",
    "rövidnadrágját": "rövidnadrág",
    "rövidnadrágot": "rövidnadrág",
    "rövidítenek": "rövidít",
    "rövidített": "rövidít",
    "rövidítik": "rövidít",
    "rövidítésben": "rövidítés",
    "rövidítések": "rövidítés",
    "rövidítésekből": "rövidítés",
    "rövidítéseknek": "rövidítés",
    "rövidüljön": "rövidül",
    "rúderdőt": "rúderdő",
    "rúdját": "rúd",
    "rúgja": "rúg",
    "rúgna": "rúg",
    "rúgni": "rúg",
    "rúgott": "rúg",
    "rúgta": "rúg",
    "rúgtak": "rúg",
    "rúgásokat": "rúgás",
    "rúgást": "rúgás",
    "rúgásával": "rúgás",
    "rúzsfoltok": "rúzsfolt",
    "rúzst": "rúzs",
    "s-től": "s",
    "sablonnak": "sablon",
    "sajgott": "sajog",
    "sajnálatosan": "sajnálatos",
    "sajnálatát": "sajnálat",
    "sajnálja": "sajnál",
    "sajnálják": "sajnál",
    "sajnálnak": "sajnál",
    "sajnálom": "sajnál",
    "sajnálta": "sajnál",
    "sajnáltuk": "sajnál",
    "sajnálták": "sajnál",
    "sajtjával": "sajt",
    "sajttal": "sajt",
    "sajtóban": "sajtó",
    "sajtóbeszélgetésen": "sajtóbeszélgetés",
    "sajtóbeszélgetést": "sajtóbeszélgetés",
    "sajtóból": "sajtó",
    "sajtóhibát": "sajtóhiba",
    "sajtóholdingjának": "sajtóholding",
    "sajtószabadságot": "sajtószabadság",
    "sajtószolgálatát": "sajtószolgálat",
    "sajtótájékoztatóján": "sajtótájékoztató",
    "sajtótájékoztatón": "sajtótájékoztató",
    "sajtótájékoztatót": "sajtótájékoztató",
    "sajtóval": "sajtó",
    "sajtóvállalkozásának": "sajtóvállalkozás",
    "sajtóértekezleten": "sajtóértekezlet",
    "sajtóértekezletén": "sajtóértekezlet",
    "sajátjai": "saját",
    "sajátjának": "saját",
    "sajátod": "saját",
    "sajátosan": "sajátos",
    "sajátossága": "sajátosság",
    "sajátosságokat": "sajátosság",
    "sajátosságoknak": "sajátosság",
    "sajátosságát": "sajátosság",
    "sajátságosan": "sajátságos",
    "sajátélet-nek": "sajátélet",
    "sajátíthattak": "sajátíthat",
    "sakkban": "sakk",
    "sakkfeladványban": "sakkfeladvány",
    "sakkfeladványnál": "sakkfeladvány",
    "sakkfeladványt": "sakkfeladvány",
    "sakkról": "sakk",
    "sakktáblához": "sakktábla",
    "sakktáblát": "sakktábla",
    "sakktáblával": "sakktábla",
    "sandított": "sandít",
    "sanzonokat": "sanzon",
    "sarat": "sár",
    "sarjadtak": "sarjadt",
    "sarka": "sarok",
    "sarkaiból": "sarok",
    "sarkait": "sarok",
    "sarkam": "sark",
    "sarkban": "sark",
    "sarkokból": "sarok",
    "sarkon": "sarok",
    "sarkában": "sarok",
    "sarkából": "sarok",
    "sarkán": "sarok",
    "sarkára": "sarok",
    "sarkát": "sarok",
    "sarkától": "sarok",
    "sarkával": "sarok",
    "sarlachban": "sarlach",
    "sarokasztalát": "sarokasztal",
    "sarokba": "sarok",
    "sarokban": "sarok",
    "sarokvasa": "sarokvas",
    "savanyúbb": "savanyú",
    "savanyút": "savanyú",
    "saváról": "só",
    "savóját": "savó",
    "schillingért": "schilling",
    "sebek": "seb",
    "sebesebben": "sebes",
    "sebesen": "sebes",
    "sebessége": "sebesség",
    "sebességesen": "sebességes",
    "sebességgel": "sebesség",
    "sebesítették": "sebesítet",
    "sebesült": "sebesül",
    "sebet": "seb",
    "sebészeink": "sebész",
    "segédanyagai": "segédanyag",
    "segédeszközök": "segédeszköz",
    "segédeszközöket": "segédeszköz",
    "segédkezett": "segédkezik",
    "segédkeznek": "segédkezik",
    "segédkezzék": "segédkezik",
    "segéllyel": "segély",
    "segélyből": "segély",
    "segélyek": "segély",
    "segélyeket": "segély",
    "segélyezett": "segélyez",
    "segélyezettek": "segélyezett",
    "segélyre": "segély",
    "segélyt": "segély",
    "segélyére": "segély",
    "segélyét": "segély",
    "segítene": "segít",
    "segítenek": "segít",
    "segíteni": "segít",
    "segítenie": "segít",
    "segített": "segít",
    "segítette": "segítet",
    "segítettek": "segített",
    "segítettem": "segített",
    "segíthessek": "segíthet",
    "segíthettek": "segíthet",
    "segíti": "segít",
    "segítik": "segít",
    "segítse": "segít",
    "segítsen": "segít",
    "segítsenek": "segít",
    "segítségben": "segítség",
    "segítsége": "segítség",
    "segítséget": "segítség",
    "segítséggel": "segítség",
    "segítségre": "segítség",
    "segítségére": "segítség",
    "segítségét": "segítség",
    "segítségével": "segítség",
    "segítségükkel": "segítség",
    "segítségükre": "segítség",
    "segítése": "segítés",
    "segítésen": "segítés",
    "segítésére": "segítés",
    "segítünk": "segít",
    "segítőtársai": "segítőtárs",
    "sejtelme": "sejtelem",
    "sejtelmét": "sejtelme",
    "sejtem": "sejt",
    "sejteni": "sejt",
    "sejteti": "sejtet",
    "sejtette": "sejt",
    "sejtettem": "sejtett",
    "sejtették": "sejtet",
    "sejtettük": "sejtett",
    "sejtetően": "sejtető",
    "sejtheti": "sejthet",
    "sejthetni": "sejthet",
    "sejthette": "sejthet",
    "sejtik": "sejt",
    "sejtjeink": "sejt",
    "sejtjeinkig": "sejt",
    "sejtszerűen": "sejtszerű",
    "sejtése": "sejtés",
    "sejtőn": "sejtő",
    "selejtezésre": "selejtezés",
    "selejtezőkből": "selejtező",
    "selejtezőket": "selejtező",
    "selyemfüggönyeivel": "selyemfüggöny",
    "selyemharisnyát": "selyemharisnya",
    "selymekből": "selyem",
    "selymével": "selyem",
    "semelyikhez": "semelyik",
    "semlegesen": "semleges",
    "semlegessége": "semlegesség",
    "semlegesítését": "semlegesítés",
    "semmibe": "semmi",
    "semmiben": "semmi",
    "semmije": "semmi",
    "semmijük": "semmi",
    "semmiképp": "semmi",
    "semmiképpen": "semmi",
    "semmilyen": "semmily",
    "semmin": "semmi",
    "semminek": "semmi",
    "semminél": "semmi",
    "semmire": "semmi",
    "semmiről": "semmi",
    "semmiségnek": "semmiség",
    "semmisíteni": "semmisít",
    "semmisítenie": "semmisít",
    "semmisített": "semmisít",
    "semmisítette": "semmisít",
    "semmisítették": "semmisítet",
    "semmisült": "semmisül",
    "semmit": "semmi",
    "semmitől": "semmi",
    "semmivel": "semmi",
    "semmivé": "semmi",
    "semmiért": "semmi",
    "senkijük": "senki",
    "senkin": "senki",
    "senkinek": "senki",
    "senkit": "senki",
    "senkitől": "senki",
    "senkivel": "senki",
    "senyvedtek": "senyved",
    "seperjen": "seper",
    "sepert": "seper",
    "sepregetést": "sepregetés",
    "serege": "sereg",
    "seregei": "sereg",
    "seregek": "sereg",
    "seregekben": "sereg",
    "seregeket": "sereg",
    "seregszemlén": "seregszemle",
    "serkentette": "serkent",
    "serpenyőben": "serpenyő",
    "serpenyőből": "serpenyő",
    "sertéseket": "sertés",
    "sertésekért": "sertés",
    "serényen": "serény",
    "settenkedett": "settenkedik",
    "setét": "sete",
    "show-ban": "show",
    "show-hoz": "show",
    "sietek": "siet",
    "sietett": "siet",
    "sietnek": "siet",
    "sietnünk": "siet",
    "sietségével": "sietség",
    "siettek": "siet",
    "sikere": "sikér",
    "sikeredett": "sikeredik",
    "sikereik": "sikér",
    "sikereket": "sikér",
    "sikeresen": "sikeres",
    "sikeresnek": "sikeres",
    "sikerhez": "siker",
    "sikernek": "siker",
    "sikerrel": "siker",
    "sikert": "sikér",
    "sikertelenebb": "sikertelen",
    "sikeréről": "sikér",
    "sikerét": "sikér",
    "sikerül": "siker",
    "sikerülnek": "sikerül",
    "sikerülni": "sikerül",
    "sikerült": "sikerül",
    "sikerünkben": "sikér",
    "sikkasztott": "sikkaszt",
    "sikkasztottak": "sikkasztott",
    "sikkasztót": "sikkasztó",
    "siklott": "siklik",
    "sikoltásfélét": "sikoltásféle",
    "sikolya": "sikoly",
    "sikongatott": "sikongat",
    "silányulhatnak": "silányulhat",
    "simogatta": "simogat",
    "simult": "simul",
    "simára": "sima",
    "simításokig": "simítás",
    "siralmasnak": "siralmas",
    "sistergett": "sistereg",
    "sivatagban": "sivatag",
    "sivatagon": "sivatag",
    "sivatagából": "sivatag",
    "sivárabb": "sivár",
    "sivárnak": "sivár",
    "sivárrá": "sivár",
    "sivársága": "sivárság",
    "sivította": "sivít",
    "siófokkal": "siófok",
    "skarlátszínűvé": "skarlátszínű",
    "skizofrénnek": "skizofrén",
    "skrupulusai": "skrupulus",
    "sodort": "sodor",
    "sodorta": "sodor",
    "sodródtak": "sodródik",
    "sokak": "sok",
    "sokakat": "sok",
    "sokakban": "sok",
    "sokaktól": "sok",
    "sokallja": "sokall",
    "sokan": "sok",
    "sokaságán": "sokaság",
    "sokaságává": "sokaság",
    "sokat": "sok",
    "sokatmondóan": "sokatmondó",
    "sokba": "sok",
    "sokféleképpen": "sokféle",
    "sokkal": "sokk",
    "sokkolónak": "sokkoló",
    "sokkon": "sokk",
    "sokkterápiájával": "sokkterápia",
    "sokméternyire": "sokméternyi",
    "sokra": "sok",
    "sokrétűbb": "sokrétű",
    "sokszor": "sok",
    "sokszínűséghez": "sokszínűség",
    "sokukat": "sok",
    "sokuknak": "sok",
    "sokáig": "sok",
    "sokára": "sok",
    "sopánkodott": "sopánkodik",
    "sopánkodtunk": "sopánkodik",
    "sora": "sor",
    "soraiba": "sor",
    "soraiban": "sor",
    "soraiból": "sor",
    "soraikban": "sor",
    "sorakoztak": "sorakozik",
    "sorakoztatott": "sorakoztat",
    "sorba": "sor",
    "sorban": "sor",
    "sorházak": "sorház",
    "sorjáztak": "sorjázik",
    "sornak": "sor",
    "sornál": "sor",
    "sorok": "sor",
    "sorokat": "sor",
    "sorokban": "sor",
    "sorokon": "sor",
    "sorolja": "sorol",
    "sorolnak": "sorol",
    "sorolt": "sorol",
    "soroltak": "sorolt",
    "sorompói": "sorompó",
    "sorompón": "sorompó",
    "soron": "sor",
    "sorozata": "sorozat",
    "sorozatban": "sorozat",
    "sorozathoz": "sorozat",
    "sorozatot": "sorozat",
    "sorozatvetők": "sorozatvető",
    "sorozatáról": "sorozat",
    "sorozzák": "soroz",
    "sorozások": "sorozás",
    "sorra": "sor",
    "sorrendbe": "sorrend",
    "sorrendben": "sorrend",
    "sorrendje": "sorrend",
    "sorsa": "sors",
    "sorsanalízisnek": "sorsanalízis",
    "sorsdöntőnek": "sorsdöntő",
    "sorselméletét": "sorselmélet",
    "sorsjegyekről": "sorsjegy",
    "sorsjátékhoz": "sorsjáték",
    "sorsjátékról": "sorsjáték",
    "sorskérdésének": "sorskérdés",
    "sorsközösségem": "sorsközösség",
    "sorsok": "sors",
    "sorsolásra": "sorsolás",
    "sorsolást": "sorsolás",
    "sorsra": "sors",
    "sorssal": "sors",
    "sorstól": "sors",
    "sorsuk": "sors",
    "sorsukat": "sors",
    "sorsukon": "sors",
    "sorsunkat": "sors",
    "sorsunkon": "sors",
    "sorsán": "sors",
    "sorsára": "sors",
    "sorsáról": "sors",
    "sorsát": "sors",
    "sort": "sor",
    "sorukat": "sor",
    "sorvadt": "sorvad",
    "sorába": "sor",
    "sorában": "sor",
    "során": "sor",
    "soráról": "sor",
    "sorát": "sor",
    "sorával": "sor",
    "soványak": "sovány",
    "soványodnak": "soványodik",
    "soványsága": "soványság",
    "soványságtól": "soványság",
    "soványságát": "soványság",
    "spanyolból": "spanyol",
    "spanyolok": "spanyol",
    "specialistája": "specialista",
    "specialisták": "specialista",
    "specializálódott": "specializálódik",
    "specializálódtak": "specializálódik",
    "spektákulumok": "spektákulum",
    "spekulálni": "spekulál",
    "spekulált": "spekulál",
    "spirituszt": "spiritusz",
    "spirálisan": "spirális",
    "sportbizottságban": "sportbizottság",
    "sportbizottságának": "sportbizottság",
    "sportblúzt": "sportblúz",
    "sportcsarnokban": "sportcsarnok",
    "sportegyesületek": "sportegyesület",
    "sporteszközök": "sporteszköz",
    "sportfeladatokat": "sportfeladat",
    "sporthorgászok": "sporthorgász",
    "sporthírességek": "sporthíresség",
    "sportklubok": "sportklub",
    "sportlétesítmények": "sportlétesítmény",
    "sportminisztere": "sportminiszter",
    "sportnak": "sport",
    "sportokhoz": "sport",
    "sportolójának": "sportoló",
    "sporton": "sport",
    "sportot": "sport",
    "sportpszichológusok": "sportpszichológus",
    "sportpályán": "sportpálya",
    "sportra": "sport",
    "sportszakértői": "sportszakértő",
    "sportszervezetek": "sportszervezet",
    "sportszervezeteknek": "sportszervezet",
    "sporttal": "sport",
    "sporttörvényt": "sporttörvény",
    "sportágakat": "sportág",
    "sprayt": "spray",
    "spórolhattak": "spórolhat",
    "spórolnak": "spórol",
    "spórolásom": "spórolás",
    "stabilan": "stabil",
    "stabilitása": "stabilitás",
    "stabilitásban": "stabilitás",
    "stabilitást": "stabilitás",
    "stabilitását": "stabilitás",
    "stabilizálása": "stabilizálás",
    "stabilizálódásával": "stabilizálódás",
    "stabilnak": "stabil",
    "stadionban": "stadion",
    "stadionjának": "stadion",
    "stagnálásából": "stagnálás",
    "stagnálására": "stagnálás",
    "staniclival": "stanicli",
    "statisztikában": "statisztika",
    "statisztikáiban": "statisztika",
    "statisztikájukból": "statisztika",
    "statisztikájából": "statisztika",
    "statisztikák": "statisztika",
    "statisztikákat": "statisztika",
    "statisztikákban": "statisztika",
    "statisztikát": "statisztika",
    "stb.-re": "stb.",
    "sterilizálta": "sterilizál",
    "stilárisan": "stiláris",
    "stoppolt": "stoppol",
    "stratégiájának": "stratégia",
    "stratégiájáról": "stratégia",
    "stratégiáját": "stratégia",
    "stratégiát": "stratégia",
    "struktúrában": "struktúra",
    "struktúrája": "struktúra",
    "struktúráját": "struktúra",
    "struktúrák": "struktúra",
    "struktúrának": "struktúra",
    "struktúrát": "struktúra",
    "stréberségre": "stréberség",
    "strófát": "strófa",
    "strómanjaként": "stróman",
    "strómanokat": "stróman",
    "stábjának": "stáb",
    "stábjával": "stáb",
    "stádiuméra": "stádium",
    "státusra": "státus",
    "stílusa": "stílus",
    "stílusában": "stílus",
    "stílusának": "stílus",
    "stúdióban": "stúdió",
    "stúdiók": "stúdió",
    "sugallta": "sugall",
    "sugalmazta": "sugalmaz",
    "sugalmazása": "sugalmazás",
    "sugara": "sugár",
    "sugarai": "sugár",
    "sugarainak": "sugár",
    "sugarak": "sugár",
    "sugározza": "sugároz",
    "sugárutat": "sugárút",
    "sugárzott": "sugárzik",
    "sugárzása": "sugárzás",
    "sugárzással": "sugárzás",
    "sugárútra": "sugárút",
    "suhant": "suhan",
    "suhanásán": "suhanás",
    "sukkokkal": "sukk",
    "summába": "summa",
    "summásnak": "summás",
    "summások": "summás",
    "summásokkal": "summás",
    "summát": "summa",
    "summázott": "summáz",
    "summázza": "summáz",
    "sunyiságuk": "sunyiság",
    "sunyított": "sunyít",
    "surrant": "surran",
    "surrantak": "surrant",
    "surrantunk": "surrant",
    "suszterek": "suszter",
    "suttogott": "suttog",
    "suttogta": "suttog",
    "suttogtak": "suttog",
    "suttogások": "suttogás",
    "suttogáson": "suttogás",
    "suttogására": "suttogás",
    "svábbogarak": "svábbogár",
    "svájcinak": "svájci",
    "svédek": "svéd",
    "szabad-ot": "szabad",
    "szabadban": "szabad",
    "szabaddemokraták": "szabaddemokrata",
    "szabaddemokratákéhoz": "szabaddemokrata",
    "szabaddá": "szabad",
    "szabadjára": "szabad",
    "szabadkozott": "szabadkozik",
    "szabadkozására": "szabadkozás",
    "szabadna": "szabad",
    "szabadnak": "szabad",
    "szabadnapjaik": "szabadnap",
    "szabadnapjuk": "szabadnap",
    "szabadok": "szabad",
    "szabadon": "szabad",
    "szabadpiacon": "szabadpiac",
    "szabadsága": "szabadság",
    "szabadságharcunk": "szabadságharc",
    "szabadsághoz": "szabadság",
    "szabadságjogok": "szabadságjog",
    "szabadságod": "szabadság",
    "szabadságot": "szabadság",
    "szabadságuk": "szabadság",
    "szabadságukat": "szabadság",
    "szabadságunkban": "szabadság",
    "szabadságvesztésre": "szabadságvesztés",
    "szabadságát": "szabadság",
    "szabadságért": "szabadság",
    "szabadul": "szabad",
    "szabadulhatott": "szabadulhat",
    "szabaduljon": "szabadul",
    "szabadulni": "szabadul",
    "szabadulnunk": "szabadul",
    "szabadulsz": "szabadul",
    "szabadult": "szabadul",
    "szabadultak": "szabadult",
    "szabadulunk": "szabadul",
    "szabadulása": "szabadulás",
    "szabadította": "szabadít",
    "szabatosabban": "szabatos",
    "szabatossága": "szabatosság",
    "szabatosságot": "szabatosság",
    "szabatosságával": "szabatosság",
    "szabja": "szab",
    "szabni": "szab",
    "szabotázsakciókat": "szabotázsakció",
    "szabotázscselekményekre": "szabotázscselekmény",
    "szabotázsra": "szabotázs",
    "szabotőrök": "szabotőr",
    "szabotőröket": "szabotőr",
    "szabta": "szab",
    "szabták": "szab",
    "szabvány-férfiakra": "szabvány-férfi",
    "szabálya": "szabály",
    "szabályai": "szabály",
    "szabályainak": "szabály",
    "szabályait": "szabály",
    "szabályok": "szabály",
    "szabályokat": "szabály",
    "szabályokkal": "szabály",
    "szabályokra": "szabály",
    "szabályokról": "szabály",
    "szabályoktól": "szabály",
    "szabályosan": "szabályos",
    "szabályossággal": "szabályosság",
    "szabályostól": "szabályos",
    "szabályozhatná": "szabályozhat",
    "szabályozhatóvá": "szabályozható",
    "szabályozni": "szabályoz",
    "szabályozott": "szabályoz",
    "szabályozza": "szabályoz",
    "szabályozzák": "szabályoz",
    "szabályozása": "szabályozás",
    "szabályozással": "szabályozás",
    "szabályozásában": "szabályozás",
    "szabályozásának": "szabályozás",
    "szabályozóeszközöket": "szabályozóeszköz",
    "szabályozógombján": "szabályozógomb",
    "szabályozórendszerébe": "szabályozórendszer",
    "szabályszerűen": "szabályszerű",
    "szabályszerűnek": "szabályszerű",
    "szabályszerűséggel": "szabályszerűség",
    "szabályt": "szabály",
    "szabálytalannak": "szabálytalan",
    "szabálytalanságok": "szabálytalanság",
    "szabálytalanul": "szabálytalan",
    "szabálytól": "szabály",
    "szabályzata": "szabályzat",
    "szabályzatban": "szabályzat",
    "szabályzatnak": "szabályzat",
    "szabályzatot": "szabályzat",
    "szabályát": "szabály",
    "szacharintablettáját": "szacharintabletta",
    "szacharintablettát": "szacharintabletta",
    "szacharintablettáért": "szacharintabletta",
    "szaga": "szag",
    "szaggal": "szag",
    "szaggatja": "szaggat",
    "szaggatni": "szaggat",
    "szaggatott": "szaggat",
    "szagokkal": "szag",
    "szagolgatni": "szagolgat",
    "szagolgatta": "szagolgat",
    "szagot": "szag",
    "szagából": "szag",
    "szagáról": "szag",
    "szagát": "szag",
    "szagától": "szag",
    "szagával": "szag",
    "szajkózta": "szajkóz",
    "szakadozottak": "szakadozott",
    "szakadt": "szakad",
    "szakadtából": "szakadt",
    "szakadása": "szakadás",
    "szakadékba": "szakadék",
    "szakasza": "szakasz",
    "szakaszba": "szakasz",
    "szakaszban": "szakasz",
    "szakaszmérnökségének": "szakaszmérnökség",
    "szakasznak": "szakasz",
    "szakaszok": "szakasz",
    "szakaszokat": "szakasz",
    "szakaszon": "szakasz",
    "szakaszparancsnokságuk": "szakaszparancsnokság",
    "szakaszt": "szakasz",
    "szakaszában": "szakasz",
    "szakaszán": "szakasz",
    "szakaszának": "szakasz",
    "szakaszára": "szakasz",
    "szakaszért": "szakasz",
    "szakbizottsága": "szakbizottság",
    "szakbizottságára": "szakbizottság",
    "szakembere": "szakember",
    "szakemberei": "szakember",
    "szakembereiből": "szakember",
    "szakemberek": "szakember",
    "szakembereket": "szakember",
    "szakembereknek": "szakember",
    "szakemberekre": "szakember",
    "szakembernek": "szakember",
    "szakintézményektől": "szakintézmény",
    "szakirodalomban": "szakirodalom",
    "szakkörök": "szakkör",
    "szakkörökben": "szakkör",
    "szakközépiskolák": "szakközépiskola",
    "szakközépiskolákban": "szakközépiskola",
    "szakközépiskolákon": "szakközépiskola",
    "szaklapjaiban": "szaklap",
    "szakmabeliek": "szakmabeli",
    "szakmunkásként": "szakmunkás",
    "szakmunkásképzőben": "szakmunkásképző",
    "szakmában": "szakma",
    "szakmához": "szakma",
    "szakmája": "szakmáj",
    "szakmájának": "szakmáj",
    "szakmák": "szakma",
    "szakmákat": "szakma",
    "szakmákban": "szakmák",
    "szakmám": "szakma",
    "szakmányban": "szakmány",
    "szakmát": "szakma",
    "szakosztályvezetője": "szakosztályvezető",
    "szakosztályának": "szakosztály",
    "szakot": "szak",
    "szakra": "szak",
    "szakszervezete": "szakszervezet",
    "szakszervezetek": "szakszervezet",
    "szakszervezeteken": "szakszervezet",
    "szakszervezeteket": "szakszervezet",
    "szakszervezetének": "szakszervezet",
    "szakszervezetével": "szakszervezet",
    "szakszerűen": "szakszerű",
    "szakszerűsége": "szakszerűség",
    "szaktudományoktól": "szaktudomány",
    "szaktudományának": "szaktudomány",
    "szaktársával": "szaktárs",
    "szakvéleménye": "szakvélemény",
    "szakácsaink": "szakács",
    "szakácshoz": "szakács",
    "szakácsok": "szakács",
    "szakácsokat": "szakács",
    "szakácson": "szakács",
    "szakácsra": "szakács",
    "szakálla": "szakáll",
    "szakállasak": "szakállas",
    "szakértelemmel": "szakértelem",
    "szakértői": "szakértő",
    "szakértője": "szakértő",
    "szakértőjét": "szakértő",
    "szakértők": "szakértő",
    "szakértőkből": "szakértő",
    "szakértőket": "szakértő",
    "szakértőktől": "szakértő",
    "szakértőként": "szakértő",
    "szakértőnek": "szakértő",
    "szakértőt": "szakértő",
    "szakítják": "szakít",
    "szakított": "szakít",
    "szakította": "szakít",
    "szakítson": "szakít",
    "szakításnyit": "szakításnyi",
    "szakítások": "szakítás",
    "szakítást": "szakítás",
    "szaladgált": "szaladgál",
    "szaladgáltak": "szaladgált",
    "szaladjak": "szalad",
    "szaladjanak": "szalad",
    "szaladna": "szalad",
    "szaladnak": "szalad",
    "szaladni": "szalad",
    "szaladnom": "szalad",
    "szaladt": "szalad",
    "szaladtak": "szaladt",
    "szaladókhoz": "szaladó",
    "szalasztania": "szalaszt",
    "szalasztja": "szalaszt",
    "szalasztották": "szalaszt",
    "szalmakazlaik": "szalmakazal",
    "szalmakazlak": "szalmakazal",
    "szalmakazlakig": "szalmakazal",
    "szalmalyukban": "szalmalyuk",
    "szalmatetőit": "szalmatetői",
    "szalmatetők": "szalmatető",
    "szalmatetőket": "szalmatető",
    "szalmában": "szalma",
    "szalmát": "szalma",
    "szalmával": "szalma",
    "szalonban": "szalon",
    "szalonképességre": "szalonképesség",
    "szalonnában": "szalonna",
    "szalonnából": "szalonna",
    "szalonnája": "szalonna",
    "szalonnájánál": "szalonna",
    "szalonnájával": "szalonna",
    "szalonnának": "szalonna",
    "szalonnára": "szalonna",
    "szalonnáról": "szalonna",
    "szalonnát": "szalonna",
    "szalonnával": "szalonna",
    "szalvétáját": "szalvéta",
    "szamárságból": "szamárság",
    "szamárságokkal": "szamárság",
    "szankcionálni": "szankcionál",
    "szankciók": "szankció",
    "szankciókat": "szankció",
    "szankcióval": "szankció",
    "szanált": "szanál",
    "szanálása": "szanálás",
    "szanálással": "szanálás",
    "szanálásáról": "szanálás",
    "szaporasága": "szaporaság",
    "szaporodnak": "szaporodik",
    "szaporodott": "szaporodik",
    "szaporodtak": "szaporodik",
    "szaporák": "szapora",
    "szaporítani": "szaporít",
    "szaporítja": "szaporít",
    "szaporította": "szaporít",
    "szaporítóanyagot": "szaporítóanyag",
    "szappangyáraknak": "szappangyár",
    "szappannal": "szappan",
    "szapulták": "szapul",
    "szarva": "szarv",
    "szarvait": "szarv",
    "szarvak": "szarv",
    "szarvasagancsot": "szarvasagancs",
    "szarváért": "szarv",
    "szatyrába": "szatyor",
    "szatírként": "szatír",
    "szava": "szó",
    "szavahihetősége": "szavahihetőség",
    "szavahihetőségét": "szavahihetőség",
    "szavai": "szó",
    "szavaiból": "szó",
    "szavaikat": "szó",
    "szavaikból": "szó",
    "szavainak": "szó",
    "szavait": "szó",
    "szavaival": "szó",
    "szavak": "szó",
    "szavakat": "szó",
    "szavakba": "szó",
    "szavakban": "szó",
    "szavakból": "szó",
    "szavakig": "szó",
    "szavakkal": "szó",
    "szavaknak": "szó",
    "szavakra": "szó",
    "szavaktól": "szó",
    "szavalja": "szaval",
    "szavalt": "szaval",
    "szavalta": "szaval",
    "szavaltassák": "szavaltas",
    "szavam": "szó",
    "szavatolja": "szavatol",
    "szavatolják": "szavatol",
    "szavatolta": "szavatol",
    "szavatolásának": "szavatolás",
    "szavazatai": "szavazat",
    "szavazatot": "szavazat",
    "szavazattal": "szavazat",
    "szavazatát": "szavazat",
    "szavazna": "szavaz",
    "szavaznak": "szavaz",
    "szavazni": "szavaz",
    "szavazott": "szavaz",
    "szavazta": "szavaz",
    "szavaztunk": "szavaz",
    "szavazták": "szavaz",
    "szavazáskor": "szavazás",
    "szavazáson": "szavazás",
    "szavazással": "szavazás",
    "szavazástól": "szavazás",
    "szavazóhelyiségben": "szavazóhelyiség",
    "szavazókhoz": "szavazó",
    "szavazóknak": "szavazó",
    "szavazót": "szavazó",
    "szavuk": "szó",
    "szavukat": "szó",
    "szavunk": "szó",
    "szavába": "szó",
    "szavában": "szó",
    "szavára": "szó",
    "szavát": "szó",
    "szebben": "szebb",
    "szebbet": "szebb",
    "szedegetni": "szedeget",
    "szederlekvárnak": "szederlekvár",
    "szedett": "szed",
    "szedi": "szed",
    "szedik": "szed",
    "szedje": "szed",
    "szedjem": "szed",
    "szedjen": "szed",
    "szedjék": "szed",
    "szedjük": "szed",
    "szedjünk": "szed",
    "szedni": "szed",
    "szedte": "szed",
    "szedtek": "szed",
    "szedték": "szed",
    "szedték-vitték": "szed-visz",
    "szedése": "szedés",
    "szedésnél": "szedés",
    "szefárdok": "szefárd",
    "szefárdokat": "szefárd",
    "szeged": "szeg",
    "szegeden": "szeg",
    "szegedre": "szeg",
    "szegezett": "szegez",
    "szegezi": "szegez",
    "szegeztek": "szegez",
    "szegeződött": "szegeződik",
    "szegfűszeggel": "szegfűszeg",
    "szegni": "szeg",
    "szegélyezett": "szegélyez",
    "szegélyezik": "szegélyez",
    "szegénnyel": "szegény",
    "szegények": "szegény",
    "szegényeken": "szegény",
    "szegényeknek": "szegény",
    "szegényen": "szegény",
    "szegényesebben": "szegényes",
    "szegényesen": "szegényes",
    "szegénykémet": "szegénykém",
    "szegénynegyedeiben": "szegénynegyed",
    "szegénynegyedekben": "szegénynegyed",
    "szegénynegyedében": "szegénynegyed",
    "szegénynek": "szegény",
    "szegénységben": "szegénység",
    "szegénységből": "szegénység",
    "szegénységen": "szegénység",
    "szegénységre": "szegénység",
    "szegül": "szeg",
    "szekciója": "szekció",
    "szekciójában": "szekció",
    "szekerek": "szekér",
    "szekereken": "szekér",
    "szekeret": "szekér",
    "szekerük": "szekér",
    "szekrényajtót": "szekrényajtó",
    "szekrényben": "szekrény",
    "szekrényekre": "szekrény",
    "szekrényektől": "szekrény",
    "szekrényen": "szekrény",
    "szekrényhez": "szekrény",
    "szekrényre": "szekrény",
    "szekrényt": "szekrény",
    "szekrénytől": "szekrény",
    "szekrényébe": "szekrény",
    "szekérderekát": "szekérderék",
    "szekérre": "szekér",
    "szekérrel": "szekér",
    "szeldelte": "szeldel",
    "szele": "szél",
    "szelek": "szél",
    "szelektálni": "szelektál",
    "szelepeket": "szelep",
    "szelet": "szél",
    "szeletet": "szelet",
    "szellemben": "szellem",
    "szellemesen": "szellemes",
    "szellemet": "szellem",
    "szellemisége": "szellemiség",
    "szellemiségének": "szellemiség",
    "szellemnek": "szellem",
    "szellemről": "szellem",
    "szellemtoronyból": "szellemtorony",
    "szellemével": "szellem",
    "szelleműnek": "szellemű",
    "szellővel": "szellő",
    "szellőztetett": "szellőztet",
    "szelvényeken": "szelvény",
    "szelvényt": "szelvény",
    "szelídebben": "szelíd",
    "szelíden": "szelíd",
    "szembe": "szem",
    "szembefordult": "szembefordul",
    "szembefordultak": "szembefordult",
    "szembefordítani": "szembefordít",
    "szembehelyezkedtél": "szembehelyezkedik",
    "szembekerült": "szembekerül",
    "szembemenni": "szembemegy",
    "szemben": "szem",
    "szembenállásuk": "szembenállás",
    "szembenállók": "szembenálló",
    "szembenézett": "szembenéz",
    "szembenézni": "szembenéz",
    "szembeszegültek": "szembeszegül",
    "szembeszálljon": "szembeszáll",
    "szembeszállt": "szembeszáll",
    "szembesítésen": "szembesítés",
    "szembesülnek": "szembesül",
    "szembeállítása": "szembeállítás",
    "szembeötlőbb": "szembeötlő",
    "szemcsék": "szemcse",
    "szeme": "szem",
    "szemed": "szem",
    "szemedet": "szem",
    "szemek": "szem",
    "szemekbe": "szem",
    "szemeken": "szem",
    "szemeket": "szem",
    "szemekkel": "szem",
    "szemektől": "szem",
    "szemem": "szem",
    "szemembe": "szem",
    "szememben": "szem",
    "szemesnek": "szemes",
    "szemet": "szem",
    "szemete": "szemét",
    "szemetet": "szemét",
    "szemfényvesztésnek": "szemfényvesztés",
    "szemfülesek": "szemfüles",
    "szemgolyóira": "szemgolyói",
    "szemgolyóival": "szemgolyói",
    "szemgolyók": "szemgolyó",
    "szemhéja": "szemhéj",
    "szemhéjaira": "szemhéjai",
    "szemhéjak": "szemhéj",
    "szemhéjakkal": "szemhéj",
    "szemhéját": "szemhéja",
    "szemináriumán": "szeminárium",
    "szemközt": "szemköz",
    "szemléletmódját": "szemléletmód",
    "szemlélettel": "szemlélet",
    "szemléli": "szemlél",
    "szemlélik": "szemlél",
    "szemléltette": "szemléltet",
    "szemmel": "szem",
    "szemnek": "szem",
    "szempillák": "szempilla",
    "szempontból": "szempont",
    "szempontja": "szempont",
    "szempontjai": "szempont",
    "szempontjaimat": "szempont",
    "szempontjait": "szempont",
    "szempontjuk": "szempont",
    "szempontjából": "szempont",
    "szempontnál": "szempont",
    "szempontok": "szempont",
    "szempontokat": "szempont",
    "szempárok": "szempár",
    "szempáron": "szempár",
    "szempárra": "szempár",
    "szempárral": "szempár",
    "szempárt": "szempár",
    "szemrehányásokat": "szemrehányás",
    "szemrehányást": "szemrehányás",
    "szemrehányástól": "szemrehányás",
    "szemszögéből": "szemszög",
    "szemtanúk": "szemtanú",
    "szemtelenkedni": "szemtelenkedik",
    "szemtől": "szem",
    "szemébe": "szem",
    "szemében": "szem",
    "szeméből": "szem",
    "személlyel": "személy",
    "személlyé": "személy",
    "személyautók": "személyautó",
    "személyazonosságát": "személyazonosság",
    "személye": "személy",
    "személyek": "személy",
    "személyeket": "személy",
    "személyekről": "személy",
    "személyesebbé": "személyes",
    "személyesen": "személyes",
    "személyeskedjünk": "személyeskedik",
    "személygépkocsiból": "személygépkocsi",
    "személygépkocsik": "személygépkocsi",
    "személygépkocsival": "személygépkocsi",
    "személyhez": "személy",
    "személyijövedelemadó-kulcsok": "személyijövedelemadó-kulcs",
    "személyijövedelemadó-tartozását": "személyijövedelemadó-tartozás",
    "személyisége": "személyiség",
    "személyiségeket": "személyiség",
    "személyiségem": "személyiség",
    "személyiségemnek": "személyiség",
    "személyiséget": "személyiség",
    "személyiségeteket": "személyiség",
    "személyiséggel": "személyiség",
    "személyleírásról": "személyleírás",
    "személyre": "személy",
    "személyszállításban": "személyszállítás",
    "személyszállításhoz": "személyszállítás",
    "személyszállításra": "személyszállítás",
    "személyt": "személy",
    "személytelenségében": "személytelenség",
    "személytelenül": "személytelen",
    "személytől": "személy",
    "személyvonatra": "személyvonat",
    "személyzete": "személyzet",
    "személyzetet": "személyzet",
    "személyében": "személy",
    "személyén": "személy",
    "személyének": "személy",
    "személyéről": "személy",
    "személyétől": "személy",
    "személyével": "személy",
    "szemén": "szem",
    "szemének": "szem",
    "szemére": "szem",
    "szemérmetlenül": "szemérmetlen",
    "szemét": "szem",
    "szemétből": "szemét",
    "szemétdombja": "szemétdomb",
    "szemétdombokon": "szemétdomb",
    "szemétdombunkon": "szemétdomb",
    "szemétládákban": "szemétláda",
    "szemétre": "szemét",
    "szeméttel": "szemét",
    "szeméttelepre": "szeméttelep",
    "szeméttelepén": "szeméttelep",
    "szemével": "szem",
    "szemöldöke": "szemöldök",
    "szemöldökei": "szemöldök",
    "szemöldökfája": "szemöldökfa",
    "szemöldökük": "szemöldök",
    "szemügyre": "szemügy",
    "szemük": "szem",
    "szemükbe": "szem",
    "szemükből": "szem",
    "szemüket": "szem",
    "szemükre": "szem",
    "szemünk": "szem",
    "szemünkből": "szem",
    "szemünket": "szem",
    "szemünkkel": "szem",
    "szemünkre": "szem",
    "szemüvege": "szemüveg",
    "szemüvegekre": "szemüveg",
    "szemüveget": "szemüveg",
    "szemüvegén": "szemüveg",
    "szemüvegét": "szemüveg",
    "szemüvegével": "szemüveg",
    "szenespincéje": "szenespince",
    "szenespincéjében": "szenespince",
    "szenespincénkben": "szenespince",
    "szenespincét": "szenespince",
    "szenet": "szén",
    "szennycsatornába": "szennycsatorna",
    "szennyek": "szenny",
    "szennyet": "szenny",
    "szennyezheti": "szennyezhet",
    "szennyeződött": "szennyeződik",
    "szennyvízelvezetése": "szennyvízelvezetés",
    "szennyébe": "szenny",
    "szennyében": "szenny",
    "szentbeszédben": "szentbeszéd",
    "szentek": "szent",
    "szenteli": "szentel",
    "szentelni": "szentel",
    "szentelt": "szentel",
    "szentelte": "szentel",
    "szentelték": "szentel",
    "szentesítik": "szentesít",
    "szentjénél": "szent",
    "szentképeknek": "szentkép",
    "szentlelket": "szentlélek",
    "szentmisét": "szentmise",
    "szenvedett": "szenved",
    "szenvednek": "szenved",
    "szenvedni": "szenved",
    "szenvedsz": "szenved",
    "szenvedtek": "szenved",
    "szenvedték": "szenved",
    "szenvedéllyel": "szenvedély",
    "szenvedélye": "szenvedély",
    "szenvedélyeiről": "szenvedély",
    "szenvedélyesen": "szenvedélyes",
    "szenvedélyességgel": "szenvedélyesség",
    "szenvedélynek": "szenvedély",
    "szenvedélyt": "szenvedély",
    "szenvedélyéről": "szenvedély",
    "szenvedései": "szenvedés",
    "szenvedéseinek": "szenvedés",
    "szenvedéssel": "szenvedés",
    "szenvedést": "szenvedés",
    "szenvedéstörténetének": "szenvedéstörténet",
    "szenvedésén": "szenvedés",
    "szenvedőkön": "szenvedő",
    "szenátorokhoz": "szenátor",
    "szeparált": "szeparál",
    "szeplői": "szeplő",
    "szeppent": "szeppen",
    "szeptemberben": "szeptember",
    "szeptemberre": "szeptember",
    "szeptembertől": "szeptember",
    "szeptemberében": "szeptember",
    "szeptemberétől": "szeptember",
    "szerbek": "szerb",
    "szerbeket": "szerb",
    "szerdán": "szerda",
    "szere": "szer",
    "szerelem": "szerel",
    "szerelemben": "szerelem",
    "szerelemmel": "szerelem",
    "szerelemre": "szerelem",
    "szerelemtől": "szerelem",
    "szerelik": "szerel",
    "szerelme": "szerelem",
    "szerelmei": "szerelem",
    "szerelmek": "szerelem",
    "szerelmem": "szerelem",
    "szerelmesek": "szerelmes",
    "szerelmeskedhettek": "szerelmeskedhet",
    "szerelmeskedni": "szerelmeskedik",
    "szerelmet": "szerelem",
    "szerelmének": "szerelme",
    "szerelméről": "szerelme",
    "szerelmünk": "szerelem",
    "szerelnek": "szerel",
    "szerelni": "szerel",
    "szerelt": "szerel",
    "szerelvénnyel": "szerelvény",
    "szerelvények": "szerelvény",
    "szerelvényről": "szerelvény",
    "szerelvényt": "szerelvény",
    "szerelőiért": "szerelői",
    "szerelőkkel": "szerelő",
    "szerencseamuletteket": "szerencseamulett",
    "szerencséje": "szerencse",
    "szerencséjének": "szerencse",
    "szerencséjük": "szerencse",
    "szerencséjüknek": "szerencse",
    "szerencsém": "szerencse",
    "szerencsén": "szerencse",
    "szerencsénk": "szerencse",
    "szerencsére": "szerencse",
    "szerencsésebb": "szerencsés",
    "szerencsések": "szerencsés",
    "szerencsésekre": "szerencsés",
    "szerencsésen": "szerencsés",
    "szerencsét": "szerencse",
    "szerencsétlenné": "szerencsétlen",
    "szerencsétlenül": "szerencsétlen",
    "szerepbe": "szerep",
    "szerepe": "szerep",
    "szerepekbe": "szerep",
    "szerepelhetett": "szerepelhet",
    "szerepelne": "szerepel",
    "szerepelnek": "szerepel",
    "szerepelni": "szerepel",
    "szerepelt": "szerepel",
    "szerepeltek": "szerepelt",
    "szerepeltem": "szerepelt",
    "szerepeltették": "szerepeltet",
    "szerepeltetését": "szerepeltetés",
    "szerepem": "szerep",
    "szerepemet": "szerep",
    "szerepen": "szerep",
    "szerepet": "szerep",
    "szereplése": "szereplés",
    "szerepléstől": "szereplés",
    "szereplői": "szereplő",
    "szereplőinek": "szereplői",
    "szereplőire": "szereplői",
    "szereplőit": "szereplői",
    "szereplőivel": "szereplői",
    "szereplőjének": "szereplő",
    "szereplők": "szereplő",
    "szereposztásban": "szereposztás",
    "szereppel": "szerep",
    "szerepre": "szereper",
    "szerepvállalását": "szerepvállalás",
    "szerepéből": "szerepe",
    "szerepére": "szerepe",
    "szerepét": "szerepe",
    "szeresek": "szeres",
    "szeressék": "szeret",
    "szereted": "szeret",
    "szeretek": "szeret",
    "szeretem": "szeret",
    "szeretet-minisztériumba": "szeretet-minisztérium",
    "szeretet-minisztériumban": "szeretet-minisztérium",
    "szeretet-minisztériumon": "szeretet-minisztérium",
    "szeretetet": "szeretet",
    "szeretetintézmények": "szeretetintézmény",
    "szeretetintézményekre": "szeretetintézmény",
    "szeretetnek": "szeretet",
    "szeretetre": "szeretet",
    "szeretett": "szeret",
    "szeretettel": "szeretett",
    "szeretetvendégségeiről": "szeretetvendégség",
    "szerethetik": "szerethet",
    "szerethette": "szerethet",
    "szereti": "szeret",
    "szeretik": "szeret",
    "szeretkezni": "szeretkezik",
    "szeretkezniük": "szeretkezik",
    "szeretkeztek": "szeretkezik",
    "szeretkezéseikről": "szeretkezés",
    "szeretkezésük": "szeretkezés",
    "szeretkezünk": "szeretkezik",
    "szeretlek": "szeret",
    "szeretne": "szeret",
    "szeretned": "szeret",
    "szeretnek": "szeret",
    "szeretni": "szeret",
    "szeretné": "szeret",
    "szeretnék": "szeret",
    "szeretném": "szeret",
    "szeretnének": "szeret",
    "szeretnénk": "szeret",
    "szerette": "szeret",
    "szeretted": "szeret",
    "szerettek": "szeret",
    "szerettem": "szeret",
    "szerették": "szeret",
    "szerettünk": "szeret",
    "szerezhetik": "szerezhet",
    "szerezne": "szerez",
    "szerezned": "szerez",
    "szereznek": "szerez",
    "szerezni": "szerez",
    "szerezniük": "szerez",
    "szerezte": "szerez",
    "szereztek": "szerez",
    "szereztem": "szerez",
    "szerezték": "szerez",
    "szereztünk": "szerez",
    "szerezzen": "szerez",
    "szerinte": "szerint",
    "szerinted": "szerint",
    "szerintem": "szerint",
    "szerkesztettek": "szerkesztett",
    "szerkesztették": "szerkesztet",
    "szerkesztik": "szerkeszt",
    "szerkesztése": "szerkesztés",
    "szerkesztőhöz": "szerkesztő",
    "szerkesztőinek": "szerkesztői",
    "szerkesztője": "szerkesztő",
    "szerkesztőségben": "szerkesztőség",
    "szerkesztősége": "szerkesztőség",
    "szerkesztőségek": "szerkesztőség",
    "szerkesztőségébe": "szerkesztőség",
    "szerkesztővel": "szerkesztő",
    "szerkezet": "szerkéz",
    "szerkezetek": "szerkezet",
    "szerkezetet": "szerkezet",
    "szerkezetátalakítása": "szerkezetátalakítás",
    "szerkezetében": "szerkezet",
    "szerkezetét": "szerkezet",
    "szerkezetükből": "szerkezet",
    "szerpapként": "szerpap",
    "szerszámait": "szerszám",
    "szerszámja": "szerszám",
    "szerszámok": "szerszám",
    "szerszámokat": "szerszám",
    "szerszámot": "szerszám",
    "szerszámtáskáját": "szerszámtáska",
    "szerszámtáskát": "szerszámtáska",
    "szert": "szer",
    "szertartásokat": "szertartás",
    "szertartásosan": "szertartásos",
    "szertartásról": "szertartás",
    "szertartást": "szertartás",
    "szertefoszlóban": "szertefoszló",
    "szertehányt": "szertehány",
    "szerve": "szerv",
    "szerveik": "szerv",
    "szerveiket": "szerv",
    "szervek": "szerv",
    "szerveket": "szerv",
    "szervekkel": "szerv",
    "szervezetből": "szervezet",
    "szervezete": "szervezet",
    "szervezetek": "szervezet",
    "szervezetekbe": "szervezet",
    "szervezeteket": "szervezet",
    "szervezeteknek": "szervezet",
    "szervezetemben": "szervezet",
    "szervezeten": "szervezet",
    "szervezetet": "szervezet",
    "szervezeti": "szervezet",
    "szervezetnek": "szervezet",
    "szervezetről": "szervezet",
    "szervezett": "szervez",
    "szervezettel": "szervezett",
    "szervezetten": "szervezett",
    "szervezettől": "szervezett",
    "szervezetének": "szervezet",
    "szervezetére": "szervezet",
    "szervezetük": "szervezet",
    "szervezni": "szervez",
    "szervezte": "szervez",
    "szerveztek": "szervez",
    "szervezték": "szervez",
    "szerveztünk": "szervez",
    "szervezésében": "szervezés",
    "szervezéséhez": "szervezés",
    "szervezésére": "szervezés",
    "szervezésért": "szervezés",
    "szervezéséről": "szervezés",
    "szervezésével": "szervezés",
    "szerveződött": "szerveződik",
    "szervezője": "szervező",
    "szervezőjének": "szervező",
    "szervezők": "szervező",
    "szervezőkből": "szervező",
    "szervezőket": "szervező",
    "szervát": "szerva",
    "szerzek": "szerez",
    "szerzeményt": "szerzemény",
    "szerzett": "szerez",
    "szerzettekkel": "szerzett",
    "szerződtek": "szerződik",
    "szerződtem": "szerződik",
    "szerződtetett": "szerződtet",
    "szerződtetésével": "szerződtetés",
    "szerződésben": "szerződés",
    "szerződésből": "szerződés",
    "szerződése": "szerződés",
    "szerződések": "szerződés",
    "szerződéseket": "szerződés",
    "szerződésen": "szerződés",
    "szerződéssel": "szerződés",
    "szerződésszegéseikkel": "szerződésszegés",
    "szerződést": "szerződés",
    "szerződéstervezetének": "szerződéstervezet",
    "szerződéstől": "szerződés",
    "szerződésének": "szerződés",
    "szerződését": "szerződés",
    "szerződésírások": "szerződésírás",
    "szerződésük": "szerződés",
    "szerződésüket": "szerződés",
    "szerződött": "szerződik",
    "szerződötteket": "szerződött",
    "szerzői": "szerző",
    "szerzőit": "szerzői",
    "szerzők": "szerző",
    "szerzőknek": "szerző",
    "szerzőnek": "szerző",
    "szerzőt": "szerző",
    "szeráj-könyvtárt": "szeráj-könyvtár",
    "szerényebb": "szerény",
    "szerényebben": "szerény",
    "szerényen": "szerény",
    "szerénységével": "szerénység",
    "szerünk": "szer",
    "szeszélyesen": "szeszélyes",
    "szettben": "szett",
    "szettet": "szett",
    "szextelefon-vonalat": "szextelefon-vonal",
    "szexualitásnál": "szexualitás",
    "szexuálisan": "szexuális",
    "szférába": "szféra",
    "szférában": "szféra",
    "szidalmai": "szidalom",
    "szidja": "szid",
    "szidják": "szid",
    "szidták": "szid",
    "szidást": "szidás",
    "szifilisszel": "szifilisz",
    "szigetecskéhez": "szigetecské",
    "szigetein": "sziget",
    "szigeteit": "sziget",
    "szigeteket": "sziget",
    "szigetekkel": "sziget",
    "szigetelése": "szigetelés",
    "szigetet": "sziget",
    "szigetközben": "szigetköz",
    "szigetnél": "sziget",
    "szigetért": "sziget",
    "szigorúak": "szigorú",
    "szigorúan": "szigorú",
    "szigorúbb": "szigorú",
    "szigorúbban": "szigorú",
    "szigorúsága": "szigorúság",
    "szigorúsággal": "szigorúság",
    "szigorúvá": "szigorú",
    "szikesiek": "szikesi",
    "sziket": "szik",
    "szikfoltok": "szikfolt",
    "szikfüvet": "szikfű",
    "szikfűnek": "szikfű",
    "szikfűszedők": "szikfűszedő",
    "szikfűszedőket": "szikfűszedő",
    "szikfűszedőkkel": "szikfűszedő",
    "szikfűszedőknek": "szikfűszedő",
    "szikfűszárítót": "szikfűszárító",
    "szikfűt": "szikfű",
    "szikfűteát": "szikfűtea",
    "szikfűvel": "szikfű",
    "szikfűvirágot": "szikfűvirág",
    "szikkadjon": "szikkad",
    "szikkadt": "szikkad",
    "sziklafoltok": "sziklafolt",
    "sziklaként": "szikla",
    "sziklaszirthez": "sziklaszirt",
    "sziklák": "szikla",
    "sziklákat": "szikla",
    "sziklákkal": "szikla",
    "szikláról": "szikla",
    "sziklát": "szikla",
    "szikrázott": "szikrázik",
    "szikszói": "szikszó",
    "szilajságuk": "szilajság",
    "szilfák": "szilfa",
    "szilvát": "szilva",
    "szilágyinak": "szilágyi",
    "szilágyira": "szilágyi",
    "szilágyit": "szilágyi",
    "szilágyival": "szilágyi",
    "szilágyié": "szilágyi",
    "szilánk": "szila",
    "szilárdan": "szilárd",
    "szilárdságához": "szilárdság",
    "szilíciumvölgyként": "szilíciumvölgy",
    "szimatolhatnák": "szimatolhat",
    "szimatolt": "szimatol",
    "szimatolók": "szimatoló",
    "szimbóluma": "szimbólum",
    "szimpatizánsok": "szimpatizáns",
    "szimpatizánsokat": "szimpatizáns",
    "szimpátiája": "szimpátia",
    "szimulált": "szimulál",
    "szimulánst": "szimuláns",
    "szinkrontolmácsa": "szinkrontolmács",
    "szinteken": "szint",
    "szinten": "szint",
    "szintet": "szint",
    "szintje": "szint",
    "szintjén": "szint",
    "szintjének": "szint",
    "szintjét": "szint",
    "szintre": "szint",
    "szintszabályozásban": "szintszabályozás",
    "szintén": "szint",
    "szippantásra": "szippantás",
    "szippantást": "szippantás",
    "szirénéneke": "szirénének",
    "szisztematikusan": "szisztematikus",
    "szisztémákat": "szisztéma",
    "szitkokkal": "szitok",
    "szitán": "szita",
    "szivarral": "szivar",
    "szivart": "szivar",
    "szivikém": "szivike",
    "szivárgott": "szivárog",
    "szivárgása": "szivárgás",
    "szivárogtak": "szivárog",
    "szivárványok": "szivárvány",
    "sziámit": "sziámi",
    "szkepticizmusnak": "szkepticizmus",
    "szobafestékbe": "szobafesték",
    "szobanövényeket": "szobanövény",
    "szobatársam": "szobatárs",
    "szobatársának": "szobatárs",
    "szobornak": "szobor",
    "szoborra": "szobor",
    "szobra": "szobor",
    "szobrokat": "szobor",
    "szobroktól": "szobor",
    "szobrot": "szobor",
    "szobába": "szoba",
    "szobában": "szoba",
    "szobából": "szoba",
    "szobácskában": "szobácská",
    "szobácskájában": "szobácská",
    "szobácskájának": "szobácská",
    "szobád": "szoba",
    "szobájába": "szoba",
    "szobájában": "szoba",
    "szobájának": "szoba",
    "szobáját": "szoba",
    "szobák": "szoba",
    "szobákban": "szoba",
    "szobákból": "szoba",
    "szobán": "szoba",
    "szobának": "szoba",
    "szobánk": "szoba",
    "szobára": "szoba",
    "szobáról": "szoba",
    "szobát": "szoba",
    "szobáért": "szoba",
    "szocialisták": "szocialista",
    "szocialistákat": "szocialista",
    "szocialistákkal": "szocialista",
    "szocialistáknak": "szocialista",
    "szocialistának": "szocialista",
    "szocialistát": "szocialista",
    "szocializmusnak": "szocializmus",
    "szocializmuson": "szocializmus",
    "szocializmussal": "szocializmus",
    "szocializálása": "szocializálás",
    "szociológusokból": "szociológus",
    "szociáldemokraták": "szociáldemokrata",
    "szociáldemokratának": "szociáldemokrata",
    "szokatlanul": "szokatlan",
    "szokjanak": "szokik",
    "szokni": "szokik",
    "szoknyába": "szoknya",
    "szoknyájuk": "szoknya",
    "szoknyáját": "szoknya",
    "szoknyát": "szoknya",
    "szoknának": "szokik",
    "szokott": "szokik",
    "szokottnál": "szokott",
    "szokta": "szokik",
    "szoktad": "szokik",
    "szoktak": "szokik",
    "szoktam": "szokik",
    "szoktuk": "szokik",
    "szoktunk": "szokik",
    "szokták": "szokik",
    "szoktál": "szokik",
    "szokványosnak": "szokványos",
    "szokása": "szokás",
    "szokásai": "szokás",
    "szokásaiban": "szokás",
    "szokásaikat": "szokás",
    "szokásainak": "szokás",
    "szokásait": "szokás",
    "szokásban": "szokás",
    "szokások": "szokás",
    "szokásokat": "szokás",
    "szokásokba": "szokás",
    "szokásoknak": "szokás",
    "szokásom": "szokás",
    "szokásrendjüket": "szokásrend",
    "szokással": "szokás",
    "szokást": "szokás",
    "szokásuk": "szokás",
    "szokásához": "szokás",
    "szokásává": "szokás",
    "szolgaságát": "szolgaság",
    "szolgáik": "szolga",
    "szolgáknak": "szolga",
    "szolgálata": "szolgálat",
    "szolgálataikat": "szolgálat",
    "szolgálatba": "szolgálat",
    "szolgálatkésznek": "szolgálatkész",
    "szolgálatot": "szolgálat",
    "szolgálatra": "szolgálat",
    "szolgálattól": "szolgálat",
    "szolgálatuk": "szolgálat",
    "szolgálatukhoz": "szolgálat",
    "szolgálatában": "szolgálat",
    "szolgálatára": "szolgálat",
    "szolgálatát": "szolgálat",
    "szolgálhatnak": "szolgálhat",
    "szolgálhatok": "szolgálhat",
    "szolgálja": "szolgál",
    "szolgáljon": "szolgál",
    "szolgálna": "szolgál",
    "szolgálnak": "szolgál",
    "szolgálnia": "szolgál",
    "szolgálná": "szolgál",
    "szolgált": "szolgál",
    "szolgáltak": "szolgált",
    "szolgáltassa": "szolgáltat",
    "szolgáltassák": "szolgáltat",
    "szolgáltat": "szolgált",
    "szolgáltatna": "szolgáltat",
    "szolgáltatnak": "szolgáltat",
    "szolgáltatni": "szolgáltat",
    "szolgáltatnod": "szolgáltat",
    "szolgáltatott": "szolgáltat",
    "szolgáltattak": "szolgáltat",
    "szolgáltatásait": "szolgáltatás",
    "szolgáltatásba": "szolgáltatás",
    "szolgáltatásból": "szolgáltatás",
    "szolgáltatások": "szolgáltatás",
    "szolgáltatásokat": "szolgáltatás",
    "szolgáltatásokban": "szolgáltatás",
    "szolgáltatásoknál": "szolgáltatás",
    "szolgáltatást": "szolgáltatás",
    "szolgáltatásért": "szolgáltatás",
    "szolgáltatói": "szolgáltató",
    "szolgáltatók": "szolgáltató",
    "szolgáltatókat": "szolgáltató",
    "szolgáltatóknak": "szolgáltató",
    "szolgáltunk": "szolgált",
    "szolgálták": "szolgál",
    "szolgálója": "szolgáló",
    "szolgálóját": "szolgáló",
    "szolgálónak": "szolgáló",
    "szolgálóra": "szolgáló",
    "szolgálóval": "szolgáló",
    "szolgától": "szolga",
    "szolgáéval": "szolga",
    "szolidaritása": "szolidaritás",
    "szolidaritásnak": "szolidaritás",
    "szolidaritásról": "szolidaritás",
    "szolidaritást": "szolidaritás",
    "szolidárisabb": "szolidáris",
    "szombatban": "szombat",
    "szombathelyen": "szombathely",
    "szombaton": "szombat",
    "szombatot": "szombat",
    "szombatra": "szombat",
    "szombattól": "szombat",
    "szomjamat": "szomj",
    "szomjasak": "szomjas",
    "szomorkodtak": "szomorkodik",
    "szomorkásak": "szomorkás",
    "szomorodott": "szomorodik",
    "szomorúan": "szomorú",
    "szomorúságfélét": "szomorúságféle",
    "szomorúsággal": "szomorúság",
    "szomorúságának": "szomorúság",
    "szomszédasszonyuk": "szomszédasszony",
    "szomszédba": "szomszéd",
    "szomszédban": "szomszéd",
    "szomszédból": "szomszéd",
    "szomszédja": "szomszéd",
    "szomszédjukban": "szomszéd",
    "szomszédjával": "szomszéd",
    "szomszédnak": "szomszéd",
    "szomszédok": "szomszéd",
    "szomszédokkal": "szomszéd",
    "szomszédokra": "szomszéd",
    "szomszédoktól": "szomszéd",
    "szomszédot": "szomszéd",
    "szomszédsága": "szomszédság",
    "szomszédságában": "szomszédság",
    "szomszédságából": "szomszédság",
    "szondáztatta": "szondáztat",
    "szopott": "szopik",
    "szoptatása": "szoptatás",
    "szoptatásával": "szoptatás",
    "szorgalma": "szorgalom",
    "szorgalmasan": "szorgalmas",
    "szorgalmaznia": "szorgalmaz",
    "szorgalmazott": "szorgalmaz",
    "szorgalmazta": "szorgalmaz",
    "szorgalmazza": "szorgalmaz",
    "szorgalmazója": "szorgalmazó",
    "szorgalmazók": "szorgalmazó",
    "szorgosan": "szorgos",
    "szorongassuk": "szorongat",
    "szorongatta": "szorongat",
    "szorongattatásából": "szorongattatás",
    "szorongatták": "szorongat",
    "szorongott": "szorong",
    "szorongtam": "szorong",
    "szorongáson": "szorongás",
    "szorongását": "szorongás",
    "szorongón": "szorongó",
    "szorosabb": "szoros",
    "szorosabban": "szoros",
    "szorosan": "szoros",
    "szorosával": "szoros",
    "szortyogtatták": "szortyogtat",
    "szorulnak": "szorul",
    "szorult": "szorul",
    "szorultságából": "szorultság",
    "szorulásig": "szorulás",
    "szorítani": "szorít",
    "szorítja": "szorít",
    "szorítják": "szorít",
    "szorított": "szorít",
    "szorította": "szorít",
    "szorítottuk": "szorít",
    "szorították": "szorít",
    "szovjet-bűntettek": "szovjet-bűntett",
    "szovjetek": "szovjet",
    "szovjetunióban": "szovjetunió",
    "szponzora": "szponzor",
    "szponzorok": "szponzor",
    "sztratoszférába": "sztratoszféra",
    "sztrádán": "sztráda",
    "sztrájkba": "sztrájk",
    "sztrájkból": "sztrájk",
    "sztrájktól": "sztrájk",
    "sztárja": "sztár",
    "sztárok": "sztár",
    "sztárokért": "sztár",
    "sztárvendégek": "sztárvendég",
    "szuggesztivitással": "szuggesztivitás",
    "szuggesztívnek": "szuggesztív",
    "szunyókált": "szunyókál",
    "szupersztárrá": "szupersztár",
    "szuperállam": "szuperáll",
    "szuperállamban": "szuperállam",
    "szuperállamok": "szuperállam",
    "szuperállamra": "szuperállam",
    "szuronyai": "szurony",
    "szuronyaikat": "szurony",
    "szuronyait": "szurony",
    "szuronyok": "szurony",
    "szuronyokat": "szurony",
    "szuverenitásának": "szuverenitás",
    "szád": "száj",
    "szádból": "száj",
    "szádából": "száda",
    "száguldottak": "száguldott",
    "szája": "száj",
    "szájaskodóknak": "szájaskodó",
    "szájat": "száj",
    "szájizmaik": "szájizom",
    "szájjal": "száj",
    "szájjá": "száj",
    "szájra": "száj",
    "szájról": "száj",
    "szájszéllel": "szájszél",
    "szájuk": "száj",
    "szájukba": "száj",
    "szájukból": "száj",
    "szájába": "száj",
    "szájában": "száj",
    "szájából": "száj",
    "szájához": "száj",
    "száján": "száj",
    "szájának": "száj",
    "szájára": "száj",
    "száját": "száj",
    "szájával": "száj",
    "szájízt": "szájíz",
    "szákháza": "szákház",
    "szálak": "szál",
    "szálakat": "szál",
    "szálast": "szálas",
    "szálat": "szál",
    "szállhasson": "szállhat",
    "szállingózott": "szállingózik",
    "szállj": "száll",
    "szálljunk": "száll",
    "szállna": "száll",
    "szállni": "száll",
    "szállodaláncban": "szállodalánc",
    "szállodába": "szálloda",
    "szállodában": "szálloda",
    "szállodája": "szálloda",
    "szállodájában": "szálloda",
    "szállodáját": "szálloda",
    "szállodák": "szálloda",
    "szállodára": "szálloda",
    "szállodát": "szálloda",
    "szállongtak": "szállong",
    "szállottak": "szállott",
    "szállt": "száll",
    "szálltak": "szállt",
    "szálltunk": "szállt",
    "szállunk": "száll",
    "szálláshelyüket": "szálláshely",
    "szállásoltak": "szállásolt",
    "szállásról": "szállás",
    "szállást": "szállás",
    "szállítanak": "szállít",
    "szállíthattak": "szállíthat",
    "szállítja": "szállít",
    "szállítják": "szállít",
    "szállítmányból": "szállítmány",
    "szállítmányok": "szállítmány",
    "szállítmányt": "szállítmány",
    "szállított": "szállít",
    "szállította": "szállít",
    "szállítsanak": "szállít",
    "szállítása": "szállítás",
    "szállítást": "szállítás",
    "szállítására": "szállítás",
    "szállításáról": "szállítás",
    "szállítását": "szállítás",
    "szállítóeszközöket": "szállítóeszköz",
    "szállítógépek": "szállítógép",
    "szállítói": "szállító",
    "szállítójárművek": "szállítójármű",
    "szállítók": "szállító",
    "szállítóknak": "szállító",
    "szállítóvevényeket": "szállítóvevény",
    "szállóhelyére": "szállóhely",
    "szállóigéjük": "szállóige",
    "szálon": "szál",
    "szám": "száj",
    "száma": "szám",
    "számadatait": "számadat",
    "számadatok": "számadat",
    "számadásuk": "számadás",
    "számait": "szám",
    "számaival": "szám",
    "számarányuk": "számarány",
    "számat": "száj",
    "számba": "szám",
    "számban": "szám",
    "számjegye": "számjegy",
    "számjegyzéket": "számjegyzék",
    "számjegyük": "számjegy",
    "számlapok": "számlap",
    "számlapokat": "számlap",
    "számlapon": "számlap",
    "számlapra": "számlap",
    "számlapról": "számlap",
    "számlista-bogarászást": "számlista-bogarászás",
    "számláin": "számla",
    "számláit": "számla",
    "számlája": "számla",
    "számláján": "számla",
    "számlájára": "számla",
    "számláját": "számla",
    "számlák": "számla",
    "számlákat": "számla",
    "számlákon": "számla",
    "számlákra": "számla",
    "számlán": "számla",
    "számlára": "számla",
    "számlát": "számla",
    "számlázott": "számláz",
    "számmal": "szám",
    "számodra": "számodor",
    "számok": "szám",
    "számok-at": "szám",
    "számokat": "szám",
    "számokban": "szám",
    "számokkal": "szám",
    "számoknál": "szám",
    "számolgatják": "számolgat",
    "számolhatott": "számolhat",
    "számolja": "számol",
    "számolnak": "számol",
    "számolni": "számol",
    "számolnia": "számol",
    "számolt": "számol",
    "számolta": "számol",
    "számoltak": "számolt",
    "számolunk": "számol",
    "számolásába": "számolás",
    "számológépekről": "számológép",
    "számomra": "szám",
    "számon": "szám",
    "számot": "szám",
    "számotokra": "szám",
    "számszerűen": "számszerű",
    "számszerűsödtek": "számszerűsöd",
    "számtalanszor": "számtalan",
    "számuk": "szám",
    "számukra": "szám",
    "számunkat": "szám",
    "számunkban": "szám",
    "számunkra": "szám",
    "számvevője": "számvevő",
    "számába": "szám",
    "számában": "szám",
    "számából": "szám",
    "számának": "szám",
    "számára": "szám",
    "számát": "szám",
    "számítana": "számít",
    "számítanak": "számít",
    "számítani": "számít",
    "számíthatnak": "számíthat",
    "számíthatott": "számíthat",
    "számított": "számít",
    "számította": "számít",
    "számítottak": "számított",
    "számítottam": "számított",
    "számítottatok": "számított",
    "számították": "számít",
    "számíts": "számít",
    "számítása": "számítás",
    "számításai": "számítás",
    "számításba": "számítás",
    "számítások": "számítás",
    "számításokat": "számítás",
    "számításokra": "számítás",
    "számításunk": "számítás",
    "számítógép-kezelést": "számítógép-kezelés",
    "számítógépben": "számítógép",
    "számítógépcsaládot": "számítógépcsalád",
    "számítógépek": "számítógép",
    "számítógépre": "számítógép",
    "számítógépén": "számítógép",
    "számúak": "számú",
    "száműzetésbe": "száműzetés",
    "száműzte": "száműz",
    "száműzött": "száműz",
    "szánalmat": "szánalom",
    "szándéka": "szándék",
    "szándékai": "szándék",
    "szándékaik": "szándék",
    "szándékainak": "szándék",
    "szándékairól": "szándék",
    "szándékait": "szándék",
    "szándékból": "szándék",
    "szándékkal": "szándék",
    "szándéknyilatkozatot": "szándéknyilatkozat",
    "szándékok": "szándék",
    "szándékosan": "szándékos",
    "szándékoznak": "szándékozik",
    "szándékoztak": "szándékozik",
    "szándékukat": "szándék",
    "szándékát": "szándék",
    "szándékától": "szándék",
    "szánja": "szán",
    "szánják": "szán",
    "szánna": "szán",
    "szánnak": "szán",
    "szánt": "szán",
    "szánta": "szánt",
    "szánta-bánta": "szán-bán",
    "szántani": "szánt",
    "szántszándékkal": "szántszándék",
    "szánták": "szánta",
    "szántás-vetéshez": "szántás-vetés",
    "szántás-vetést": "szántás-vetés",
    "szántásokon": "szántás",
    "szántáson": "szántás",
    "szántóföldeket": "szántóföld",
    "szára": "szár",
    "száradjon": "szárad",
    "száradt": "szárad",
    "szárai": "szár",
    "szárazabb": "száraz",
    "szárazak": "száraz",
    "szárazföldtől": "szárazföld",
    "szárazon": "száraz",
    "szárazra": "száraz",
    "származnak": "származik",
    "származott": "származik",
    "származtak": "származik",
    "származásúak": "származású",
    "származékai": "származék",
    "szárnya": "szárny",
    "szárnyai": "szárny",
    "szárnyain": "szárny",
    "szárnyait": "szárny",
    "szárnyrebbenésekre": "szárnyrebbenés",
    "szárnyának": "szárny",
    "szárnyát": "szárny",
    "szárán": "szár",
    "szárát": "szár",
    "szárította": "szárít",
    "szárítópadlást": "szárítópadlás",
    "század": "száz",
    "századairól": "század",
    "században": "század",
    "századból": "század",
    "századik": "századi",
    "századokban": "század",
    "századosnál": "százados",
    "századunk": "század",
    "századának": "század",
    "századát": "század",
    "százainak": "száz",
    "százait": "száz",
    "százak": "száz",
    "százaléka": "százalék",
    "százalékban": "százalék",
    "százalékig": "százalék",
    "százalékkal": "százalék",
    "százalékon": "százalék",
    "százalékot": "százalék",
    "százalékponttal": "százalékpont",
    "százalékra": "százalék",
    "százalékról": "százalék",
    "százalékuk": "százalék",
    "százalékának": "százalék",
    "százalékára": "százalék",
    "százalékát": "százalék",
    "százalékért": "százalék",
    "százezrei": "százezer",
    "százezreit": "százezer",
    "százféleképpen": "százféle",
    "százharmincat": "százharminc",
    "százig": "száz",
    "százszor": "száz",
    "százszorosan": "százszoros",
    "százzal": "száz",
    "százával": "száz",
    "százévnyire": "százévnyi",
    "szédíteni": "szédít",
    "szédült": "szédül",
    "szégyelli": "szégyell",
    "szégyellte": "szégyell",
    "szégyenben": "szégyen",
    "szégyenkezéséből": "szégyenkezés",
    "szégyenletesen": "szégyenletes",
    "szégyenlősségével": "szégyenlősség",
    "szégyentelenül": "szégyentelen",
    "szégyentől": "szégyen",
    "szégyenében": "szégyen",
    "szégyenéhez": "szégyen",
    "széjjelhullott": "széjjelhullik",
    "széjjelmérni": "széjjelmér",
    "széjjelnézni": "széjjelnéz",
    "széjjelnéztem": "széjjelnéz",
    "széjjelnéztünk": "széjjelnéz",
    "széjjelnézünk": "széjjelnéz",
    "széjjelszóródtunk": "széjjelszóródik",
    "székbe": "szék",
    "székben": "szék",
    "székből": "szék",
    "széke": "szék",
    "székek": "szék",
    "székekben": "szék",
    "székeket": "szék",
    "székelt": "székel",
    "székelyek": "székely",
    "székelyeket": "székely",
    "székelyhídnak": "székelyhíd",
    "székelyhídon": "székelyhíd",
    "székelyhídra": "székelyhíd",
    "székelyhídról": "székelyhíd",
    "széken": "szék",
    "székesegyházaiban": "székesegyház",
    "székesegyházát": "székesegyház",
    "széket": "szék",
    "székhelye": "székhely",
    "székhelyén": "székhely",
    "székhelyük": "székhely",
    "székházba": "székház",
    "székházában": "székház",
    "székházát": "székház",
    "székre": "szék",
    "székébe": "szék",
    "székében": "szék",
    "székéből": "szék",
    "székén": "szék",
    "székét": "szék",
    "széküket": "szék",
    "székünk": "szék",
    "szélben": "szél",
    "széle": "szél",
    "széleit": "szél",
    "szélesebb": "széles",
    "szélesebben": "széles",
    "szélességben": "szélesség",
    "szélesítésébe": "szélesítés",
    "szélfogóban": "szélfogó",
    "szélhez": "szél",
    "szélhámosnak": "szélhámos",
    "széljárást": "széljárás",
    "széllökések": "széllökés",
    "szélnek": "szél",
    "szélsebesen": "szélsebes",
    "szélsőjobboldallal": "szélsőjobboldal",
    "szélsőségesekkel": "szélsőséges",
    "széltől": "szél",
    "szélvészkönnyedséggel": "szélvészkönnyedség",
    "szélébe": "szél",
    "széléig": "szél",
    "szélén": "szél",
    "szélére": "szél",
    "szélörvények": "szélörvény",
    "szélükön": "szél",
    "szén-monoxidot": "szén-monoxid",
    "szénatartóba": "szénatartó",
    "szénaágyat": "szénaágy",
    "szénbányákban": "szénbánya",
    "szénkupacai": "szénkupac",
    "szénájának": "széna",
    "szénát": "széna",
    "szépasszonynak": "szépasszony",
    "szépek": "szép",
    "szépen": "szép",
    "széplelkek": "széplélek",
    "szépművészetek": "szépművészet",
    "szépnek": "szép",
    "szépsége": "szépség",
    "szépségeihez": "szépség",
    "szépségeire": "szépség",
    "szépségek": "szépség",
    "szépségre": "szépség",
    "szépségversenyeit": "szépségverseny",
    "szépségének": "szépség",
    "szépségét": "szépség",
    "szépségüket": "szépség",
    "szépítettek": "szépített",
    "szépítsem": "szépít",
    "szépítőszert": "szépítőszer",
    "szétbontott": "szétbont",
    "szétcibálják": "szétcibál",
    "szétestek": "szétesik",
    "szétesése": "szétesés",
    "szétfolyt": "szétfolyik",
    "szétforgatta": "szétforgat",
    "széthajtogatnia": "széthajtogat",
    "széthányt": "széthány",
    "széthúzta": "széthúz",
    "szétlőtték": "szétlő",
    "szétmenne": "szétmegy",
    "szétment": "szétmegy",
    "szétnyílt": "szétnyílik",
    "szétnézett": "szétnéz",
    "szétnéznek": "szétnéz",
    "szétnézésében": "szétnézés",
    "szétomlott": "szétomlik",
    "szétosztani": "szétoszt",
    "szétosztottam": "szétosztott",
    "szétosztották": "szétoszt",
    "szétrebbentek": "szétrebbent",
    "szétrepedt": "szétreped",
    "szétrombolják": "szétrombol",
    "szétrombolt": "szétrombol",
    "szétrázódott": "szétrázódik",
    "szétszakadt": "szétszakad",
    "szétszedték": "szétszed",
    "szétszedésükhöz": "szétszedés",
    "szétszerelt": "szétszerel",
    "szétszélednek": "szétszéled",
    "szétszéledtek": "szétszéledt",
    "szétszórt": "szétszór",
    "szétszórta": "szétszór",
    "szétszóródnak": "szétszóródik",
    "szétterjedt": "szétterjed",
    "szétterülne": "szétterül",
    "szétterült": "szétterül",
    "széttépett": "széttép",
    "széttúrták": "széttúr",
    "szétveri": "szétver",
    "szétverte": "szétver",
    "szétválasztotta": "szétválaszt",
    "szétvált": "szétválik",
    "szétváltak": "szétvált",
    "szétválását": "szétválás",
    "szétzilált": "szétzilál",
    "szétzilálták": "szétzilál",
    "szétzúzták": "szétzúz",
    "szíjait": "szíj",
    "szíjat": "szíj",
    "szíjra": "szíj",
    "szín-szalonnát": "szín-szalonna",
    "színdarabokat": "színdarab",
    "színdarabokkal": "színdarab",
    "színe": "szín",
    "színeikkel": "szín",
    "színeivel": "szín",
    "színek": "szín",
    "színekben": "szín",
    "színeket": "szín",
    "színezete": "színezet",
    "színezett": "színez",
    "színezetének": "színezet",
    "színezetét": "színezet",
    "színezetük": "színezet",
    "színezetüktől": "színezet",
    "színfalak": "színfal",
    "színhelyre": "színhely",
    "színhelyén": "színhely",
    "színházak": "színház",
    "színházat": "színház",
    "színházba": "színház",
    "színházban": "színház",
    "színháznak": "színház",
    "színházra": "színház",
    "színháztól": "színház",
    "színházzal": "színház",
    "színig": "szín",
    "színjátékok": "színjáték",
    "színjátékát": "színjáték",
    "színlelni": "színlel",
    "színlelt": "színlel",
    "színlelte": "színlel",
    "színlelésből": "színlelés",
    "színművészetet": "színművészet",
    "színpadon": "színpad",
    "színpadra": "színpad",
    "színpadán": "színpad",
    "színre": "szín",
    "színt": "szín",
    "színtere": "színtér",
    "színteréül": "színtér",
    "színvonala": "színvonal",
    "színvonalasak": "színvonalas",
    "színvonalat": "színvonal",
    "színvonallal": "színvonal",
    "színvonalon": "színvonal",
    "színvonalra": "színvonal",
    "színvonalról": "színvonal",
    "színvonalán": "színvonal",
    "színvonalának": "színvonal",
    "színvonalát": "színvonal",
    "színéhez": "szín",
    "színének": "szín",
    "színére": "szín",
    "színészeinek": "színész",
    "színészek": "színész",
    "színészeket": "színész",
    "színészekkel": "színész",
    "színészgárdájával": "színészgárda",
    "színésznő-felesége": "színésznő-feleség",
    "színésznőt": "színésznő",
    "színészt": "színész",
    "színésztársulata": "színésztársulat",
    "színét": "szín",
    "színével": "szín",
    "színük": "szín",
    "színültig": "színült",
    "színűvé": "színű",
    "szíriaiak": "szíriai",
    "szítták": "szítta",
    "szívből": "szív",
    "szíve": "szív",
    "szíved": "szív",
    "szívekben": "szív",
    "szívem": "szív",
    "szívemet": "szív",
    "szíven": "szív",
    "szívesebben": "szíves",
    "szívesen": "szíves",
    "szívességből": "szívesség",
    "szívességük": "szívesség",
    "szívhangokkal": "szívhang",
    "szívinfarktuson": "szívinfarktus",
    "szívja": "szív",
    "szívni": "szív",
    "szívott": "szív",
    "szívre": "szív",
    "szívvel": "szív",
    "szívében": "szív",
    "szívélyesen": "szívélyes",
    "szívélyességet": "szívélyesség",
    "szívét": "szív",
    "szívükben": "szív",
    "szívükről": "szív",
    "szívünk": "szív",
    "szívünkhöz": "szív",
    "szóalakokat": "szóalak",
    "szóba": "szó",
    "szóban": "szó",
    "szóból": "szó",
    "szófajok": "szófaj",
    "szófiába": "szófia",
    "szóhasználatukat": "szóhasználat",
    "szóhoz": "szó",
    "szókimondóan": "szókimondó",
    "szókimondóbb": "szókimondó",
    "szókincsbe": "szókincs",
    "szókincsben": "szókincs",
    "szókincse": "szókincs",
    "szókincset": "szókincs",
    "szókincsnek": "szókincs",
    "szókincsre": "szókincs",
    "szókincsének": "szókincs",
    "szókészletével": "szókészlet",
    "szólalni": "szólal",
    "szólalt": "szólal",
    "szólaltatja": "szólaltat",
    "szólaltatunk": "szólaltat",
    "szólama": "szólam",
    "szólamot": "szólam",
    "szólistaként": "szólista",
    "szólisták": "szólista",
    "szóljanak": "szól",
    "szólna": "szól",
    "szólnak": "szól",
    "szólni": "szól",
    "szólnának": "szól",
    "szólok": "szól",
    "szólott": "szól",
    "szólsz": "szól",
    "szólt": "szól",
    "szóltak": "szólt",
    "szóltunk": "szólt",
    "szóltál": "szól",
    "szólásra": "szólás",
    "szólásszabadságot": "szólásszabadság",
    "szólásszabadságról": "szólásszabadság",
    "szólítanak": "szólít",
    "szólítani": "szólít",
    "szólítania": "szólít",
    "szólítanod": "szólít",
    "szólított": "szólít",
    "szólította": "szólít",
    "szólították": "szólít",
    "szólóestet": "szólóest",
    "szólóhoz": "szóló",
    "szólószonátája": "szólószonáta",
    "szón": "szó",
    "szónak": "szó",
    "szónoka": "szónok",
    "szónoklata": "szónoklat",
    "szónoklatok": "szónoklat",
    "szónoklatokkal": "szónoklat",
    "szónoklatot": "szónoklat",
    "szónokolni": "szónokol",
    "szónokolt": "szónokol",
    "szónokot": "szónok",
    "szónoktól": "szónok",
    "szónokáról": "szónok",
    "szóra": "szó",
    "szórakozhatnak": "szórakozhat",
    "szórakozott": "szórakozik",
    "szórakozottan": "szórakozott",
    "szórakoztak": "szórakozik",
    "szórakoztatást": "szórakoztatás",
    "szórakoztatásával": "szórakoztatás",
    "szórakozzék": "szórakozik",
    "szórakozása": "szórakozás",
    "szórakozásait": "szórakozás",
    "szórakozásban": "szórakozás",
    "szórakozásra": "szórakozás",
    "szórakozásról": "szórakozás",
    "szórakozóhelyeket": "szórakozóhely",
    "szórja": "szór",
    "szórt": "szór",
    "szórta": "szór",
    "szórtunk": "szórt",
    "szórták": "szór",
    "szórványosan": "szórványos",
    "szórásával": "szórás",
    "szórészletből": "szórészlet",
    "szóródtak": "szóródik",
    "szóról": "szó",
    "szósorozatokat": "szósorozat",
    "szószólója": "szószóló",
    "szószólójaként": "szószóló",
    "szószólójuk": "szószóló",
    "szót": "szó",
    "szótagba": "szótag",
    "szótlanul": "szótlan",
    "szótára": "szótár",
    "szótárban": "szótár",
    "szótárral": "szótár",
    "szótárt": "szótár",
    "szótáráig": "szótára",
    "szótárának": "szótára",
    "szótárát": "szótára",
    "szótövekből": "szótő",
    "szóval": "szó",
    "szóvivője": "szóvivő",
    "szóvivőjük": "szóvivő",
    "szóvá": "szó",
    "szóválasztéknak": "szóválaszték",
    "szóáradattal": "szóáradat",
    "szögben": "szög",
    "szögből": "szög",
    "szöge": "szög",
    "szöget": "szög",
    "szögezte": "szögez",
    "szögletben": "szöglet",
    "szögletében": "szöglet",
    "szökdösnek": "szökdös",
    "szökdösni": "szökdös",
    "szökdöstek": "szökdös",
    "szökevényt": "szökevény",
    "szökhessen": "szökhet",
    "szöknek": "szökik",
    "szökni": "szökik",
    "szöknie": "szökik",
    "szöktek": "szökik",
    "szöktem": "szökik",
    "szöktünk": "szökik",
    "szökésen": "szökés",
    "szökéshez": "szökés",
    "szökésre": "szökés",
    "szökést": "szökés",
    "szökésünket": "szökés",
    "szökött": "szökik",
    "szöszmötölt": "szöszmötöl",
    "szövedéke": "szövedék",
    "szöveg-nek": "szöveg",
    "szövegbe": "szöveg",
    "szövegben": "szöveg",
    "szövege": "szöveg",
    "szövegekben": "szöveg",
    "szövegemet": "szöveg",
    "szöveget": "szöveg",
    "szöveggyűjteményéből": "szöveggyűjtemény",
    "szövegkörnyezetéből": "szövegkörnyezet",
    "szövegnek": "szöveg",
    "szövegében": "szöveg",
    "szövegének": "szöveg",
    "szövegét": "szöveg",
    "szövegüket": "szöveg",
    "szövete": "szövet",
    "szövetekből": "szövet",
    "szövetkezeteiket": "szövetkezet",
    "szövetkezetek": "szövetkezet",
    "szövetkezeti": "szövetkezet",
    "szövetkezetteket": "szövetkezett",
    "szövetkezni": "szövetkezik",
    "szövetségbe": "szövetség",
    "szövetségben": "szövetség",
    "szövetségből": "szövetség",
    "szövetsége": "szövetség",
    "szövetségekkel": "szövetség",
    "szövetségest": "szövetséges",
    "szövetségesük": "szövetséges",
    "szövetséget": "szövetség",
    "szövetséghez": "szövetség",
    "szövetségnek": "szövetség",
    "szövetségre": "szövetség",
    "szövetségről": "szövetség",
    "szövetségtől": "szövetség",
    "szövetségébe": "szövetség",
    "szövetségében": "szövetség",
    "szövetségéből": "szövetség",
    "szövetségének": "szövetség",
    "szövetségénél": "szövetség",
    "szövetébe": "szövet",
    "szövögeti": "szövöget",
    "szövődnek-fonódnak": "szövődik-fonódik",
    "szövődött": "szövődik",
    "szúnyogok": "szúnyog",
    "szúrd": "szúr",
    "szúrja": "szúr",
    "szúrják": "szúr",
    "szúrta": "szúr",
    "szúrtak": "szúrt",
    "szüksége": "szükség",
    "szükséged": "szükség",
    "szükségeltetett": "szükségeltet",
    "szükségen": "szükség",
    "szükségesebbre": "szükséges",
    "szükségesek": "szükséges",
    "szükségeseket": "szükséges",
    "szükségesnek": "szükséges",
    "szükségessé": "szükséges",
    "szükségessége": "szükségesség",
    "szükségességéről": "szükségesség",
    "szükségességét": "szükségesség",
    "szükségletein": "szükséglet",
    "szükségleteinek": "szükséglet",
    "szükségleteit": "szükséglet",
    "szükségleteivé": "szükséglet",
    "szükségletekhez": "szükséglet",
    "szükségletnek": "szükséglet",
    "szükségletté": "szükséglet",
    "szükségletét": "szükséglet",
    "szükségletük": "szükséglet",
    "szükségszerűen": "szükségszerű",
    "szükségtelenek": "szükségtelen",
    "szükségét": "szükség",
    "szükségük": "szükség",
    "szükségünk": "szükség",
    "szülei": "szülő",
    "szüleihez": "szülő",
    "szüleik": "szülő",
    "szüleikhez": "szülő",
    "szüleikkel": "szülő",
    "szüleiknek": "szülő",
    "szüleiknél": "szülő",
    "szüleiktől": "szülő",
    "szüleim": "szülő",
    "szüleinek": "szülő",
    "szüleinél": "szülő",
    "szüleit": "szülő",
    "szüleménye": "szülemény",
    "szüleményei": "szülemény",
    "született": "születik",
    "születettnek": "született",
    "születnek": "születik",
    "születnie": "születik",
    "születtek": "születik",
    "születése": "születés",
    "születések": "születés",
    "születésnapja": "születésnap",
    "születésnapját": "születésnap",
    "születésétől": "születés",
    "születésüktől": "születés",
    "szülhetett": "szülhet",
    "szülne": "szül",
    "szülnek": "szül",
    "szülni": "szül",
    "szült": "szül",
    "szülte": "szül",
    "szültem": "szül",
    "szültél": "szül",
    "szülése": "szülés",
    "szülésről": "szülés",
    "szülést": "szülés",
    "szüléséről": "szülés",
    "szülőföldem": "szülőföld",
    "szülői": "szülő",
    "szülők": "szülő",
    "szülőknek": "szülő",
    "szülőkre": "szülő",
    "szülőktől": "szülő",
    "szülővárosának": "szülőváros",
    "szünetben": "szünet",
    "szünetekben": "szünet",
    "szünetelnek": "szünetel",
    "szünetelt": "szünetel",
    "szüneteltetésével": "szüneteltetés",
    "szüneteltetőket": "szüneteltető",
    "szüneteltetőkkel": "szüneteltető",
    "szünetet": "szünet",
    "szünetre": "szünet",
    "szüntelenül": "szüntelen",
    "szüntesd": "szüntet",
    "szüntetjük": "szüntet",
    "szüntetni": "szüntet",
    "szüretelnek": "szüretel",
    "szürkeségét": "szürkeség",
    "szürkéllett": "szürkéllik",
    "szürkén": "szürke",
    "szőlőbe": "szőlő",
    "szőlőjében": "szőlő",
    "szőlők": "szőlő",
    "szőlőkbe": "szőlő",
    "szőlőkben": "szőlő",
    "szőlőn": "szőlő",
    "szőnyegeinkbe": "szőnyeg",
    "szőnyegen": "szőnyeg",
    "szőnyegre": "szőnyeg",
    "szőnyegével": "szőnyeg",
    "szőrcsomók": "szőrcsomó",
    "szőre": "szőr",
    "szőrrel": "szőr",
    "szőrt": "szőr",
    "szőrtarisznyám": "szőrtarisznya",
    "szőrzete": "szőrzet",
    "szőrzetűek": "szőrzetű",
    "szőréért": "szőr",
    "szőrükből": "szőr",
    "szőtt": "sző",
    "szőttem": "szőtt",
    "szőttesei": "szőttes",
    "szőttesekben": "szőttes",
    "szűken": "szűk",
    "szűkíteni": "szűkít",
    "szűkítse": "szűkít",
    "szűkítsük": "szűkít",
    "szűkítése": "szűkítés",
    "szűkölködéstől": "szűkölködés",
    "szűkült": "szűkül",
    "szűnjék": "szűnik",
    "szűnnek": "szűnik",
    "szűnni": "szűnik",
    "szűnt": "szűnik",
    "szűntek": "szűnik",
    "szűri": "szűr",
    "szűrni": "szűr",
    "szűrről": "szűr",
    "szűrt": "szűr",
    "szűrében": "szűr",
    "szűrét": "szűr",
    "szűrőin": "szűrő",
    "szűrőket": "szűrő",
    "szűrőállomásokon": "szűrőállomás",
    "szűziesen": "szűzies",
    "sáfránybokrokat": "sáfránybokor",
    "sáfránybokron": "sáfránybokor",
    "sáljáról": "sál",
    "sálját": "sál",
    "sántítást": "sántítás",
    "sápadnak": "sápad",
    "sápadt": "sápad",
    "sápadtabb": "sápadt",
    "sápadtan": "sápadt",
    "sárban": "sár",
    "sárgán": "sárga",
    "sárlepényekre": "sárlepény",
    "sárra": "sár",
    "sátortetők": "sátortető",
    "sátrak": "sátor",
    "sátrat": "sátor",
    "sátruk": "sátor",
    "sátrában": "sátor",
    "sátán-ügyben": "sátán-ügy",
    "sátánnál": "sátán",
    "sátánt": "sátán",
    "sávban": "sáv",
    "sávot": "sáv",
    "sérelmeiket": "sérelem",
    "sérelmek": "sérelem",
    "sérelmet": "sérelem",
    "sérelmezett": "sérelmez",
    "sérelmezte": "sérelmez",
    "sérelmezték": "sérelmez",
    "sértetlenek": "sértetlen",
    "sértetlenül": "sértetlen",
    "sértett": "sért",
    "sértette": "sért",
    "sértettek": "sértett",
    "sérthetetlenségbe": "sérthetetlenség",
    "sérthetetlenül": "sérthetetlen",
    "sérti": "sért",
    "sértik": "sért",
    "sértéseket": "sértés",
    "sértődött": "sértődik",
    "sértődöttségét": "sértődöttség",
    "sértőn": "sértő",
    "sértőnek": "sértő",
    "sérült": "sérül",
    "sérüléseket": "sérülés",
    "sérülésektől": "sérülés",
    "sérülésem": "sérülés",
    "sérülést": "sérülés",
    "sétakocsikázást": "sétakocsikázás",
    "sétatérre": "sétatér",
    "sétáinkon": "séta",
    "sétájuknak": "séta",
    "sétákat": "séta",
    "sétálgasson": "sétálgat",
    "sétálhatna": "sétálhat",
    "sétálhatnék": "sétálhat",
    "sétálni": "sétál",
    "sétált": "sétál",
    "sétáltak": "sétált",
    "sétáltunk": "sétált",
    "sétálóutcákon": "sétálóutca",
    "sétálóutcává": "sétálóutca",
    "sétán": "séta",
    "sétára": "séta",
    "sétát": "séta",
    "síkján": "sík",
    "síkon": "sík",
    "síkságain": "síkság",
    "síkvidékiek": "síkvidéki",
    "síneket": "sín",
    "sínekhez": "sín",
    "sínekre": "sín",
    "sínpáron": "sínpár",
    "sínylődnek": "sínylődik",
    "sírba": "sír",
    "sírban": "sír",
    "sírbeszédek": "sírbeszéd",
    "sírdombok": "sírdomb",
    "síremlékhez": "síremlék",
    "sírfelirata": "sírfelirat",
    "sírjukhoz": "sír",
    "sírkövek": "sírkő",
    "sírnak": "sír",
    "sírni": "sír",
    "síron": "sír",
    "sírsz": "sír",
    "sírt": "sír",
    "sírtak": "sírt",
    "sírásban": "sírás",
    "sírásokat": "sírás",
    "sírással": "sírás",
    "sírást": "sírás",
    "sírógörccsel": "sírógörcs",
    "sírógörcsbe": "sírógörcs",
    "sírógörcsben": "sírógörcs",
    "sóbányákba": "sóbánya",
    "sódert": "sóder",
    "sógora": "sógor",
    "sógorai": "sógor",
    "sógornőm": "sógornő",
    "sóhajjal": "sóhaj",
    "sóhajokban": "sóhaj",
    "sóhajt": "sóhaj",
    "sóhajtott": "sóhajt",
    "sóhajtottak": "sóhajtott",
    "sóhajtást": "sóhajtás",
    "sósan": "sós",
    "sót": "só",
    "sóval": "só",
    "sózták": "sóz",
    "sózzák": "sóz",
    "sózása": "sózás",
    "söntésnél": "söntés",
    "söntésre": "söntés",
    "söntésről": "söntés",
    "söpörni": "söpör",
    "sörnek": "sör",
    "sörrel": "sör",
    "sört": "sör",
    "sörének": "sör",
    "sörét": "sör",
    "sötétbe": "sötét",
    "sötétben": "sötét",
    "sötétebb": "sötét",
    "sötétebbnek": "sötét",
    "sötétje": "sötét",
    "sötétlett": "sötétlik",
    "sötétségben": "sötétség",
    "sötétségből": "sötétség",
    "sötétségen": "sötétség",
    "sötétséget": "sötétség",
    "sötétséggel": "sötétség",
    "sötéttel": "sötét",
    "sövényei": "sövény",
    "súgott": "súg",
    "súgta": "súg",
    "súgásából": "súgás",
    "sújtja": "sújt",
    "sújtotta": "sújt",
    "sújtották": "sújt",
    "súlya": "súly",
    "súlyosabb": "súlyos",
    "súlyosabbá": "súlyos",
    "súlyosan": "súlyos",
    "súlyosbítja": "súlyosbít",
    "súlyt": "súly",
    "súlyuk": "súly",
    "súlyát": "súly",
    "súlyától": "súly",
    "súrolja": "súrol",
    "súrolt": "súrol",
    "súrolta": "súrol",
    "süldőfiúk": "süldőfiú",
    "süldőket": "süldő",
    "süldőkkel": "süldő",
    "süldőkocát": "süldőkoca",
    "süldőlányok": "süldőlány",
    "süllyedt": "süllyed",
    "süllyedtek": "süllyedt",
    "süllyesszük": "süllyeszt",
    "süllyesztette": "süllyeszt",
    "sülni": "sül",
    "sült": "sül",
    "sülttengerit": "sülttengeri",
    "süppedt": "süpped",
    "sürgetett": "sürget",
    "sürgeti": "sürget",
    "sürgetik": "sürget",
    "sürgette": "sürget",
    "sürgés-forgása": "sürgés-forgás",
    "sürgés-forgásukban": "sürgés-forgás",
    "sürgönyben": "sürgöny",
    "sürgőssé": "sürgős",
    "sürgőssége": "sürgősség",
    "süteményről": "sütemény",
    "sütnek": "süt",
    "sütnek-főznek": "süt-főz",
    "sütni": "süt",
    "sütés-főzésnek": "sütés-főzés",
    "sütéshez": "sütés",
    "sütéséből": "sütés",
    "sütött": "süt",
    "sütöttük": "sütött",
    "süvített": "süvít",
    "sűríteni": "sűrít",
    "sűrűbben": "sűrű",
    "sűrűjébe": "sűrű",
    "sűrűn": "sűrű",
    "sűrűre": "sűrű",
    "sűrűsödik": "sűrűsöd",
    "t.-plakátba": "t.-plakát",
    "tabellán": "tabella",
    "tablettát": "tabletta",
    "tagadd": "tagad",
    "tagadhatatlanul": "tagadhatatlan",
    "tagadja": "tagad",
    "tagadjuk": "tagad",
    "tagadják": "tagad",
    "tagadnak": "tagad",
    "tagadni": "tagad",
    "tagadom": "tagad",
    "tagadott": "tagad",
    "tagadta": "tagad",
    "tagadtam": "tagad",
    "tagadásáról": "tagadás",
    "tagadásával": "tagadás",
    "tagadóvá": "tagadó",
    "tagban": "tag",
    "tagból": "tag",
    "tagja": "tag",
    "tagjai": "tag",
    "tagjaiból": "tag",
    "tagjaihoz": "tag",
    "tagjaikat": "tag",
    "tagjain": "tag",
    "tagjainak": "tag",
    "tagjaink": "tag",
    "tagjainkon": "tag",
    "tagjait": "tag",
    "tagjaitól": "tag",
    "tagjaival": "tag",
    "tagjaként": "tag",
    "tagjában": "tag",
    "tagjának": "tag",
    "tagjára": "tag",
    "tagjáról": "tag",
    "tagját": "tag",
    "tagjától": "tag",
    "tagjává": "tag",
    "tagként": "tag",
    "taglétszáma": "taglétszám",
    "tagnak": "tag",
    "tagok": "tag",
    "tagolatlanul": "tagolatlan",
    "tagországnak": "tagország",
    "tagot": "tag",
    "tagozatra": "tagozat",
    "tagozatán": "tagozat",
    "tagozódott": "tagozódik",
    "tagozódáshoz": "tagozódás",
    "tagsága": "tagság",
    "tagságának": "tagság",
    "tagságát": "tagság",
    "tagállam": "tagáll",
    "tagállamainak": "tagállam",
    "tagállamok": "tagállam",
    "tagállamoknak": "tagállam",
    "tajtékot": "tajték",
    "takard": "takar",
    "takargatta": "takargat",
    "takarmánybúzához": "takarmánybúza",
    "takarmányt": "takarmány",
    "takarékban": "takarék",
    "takarékbetétekre": "takarékbetét",
    "takarékbetétkönyvek": "takarékbetétkönyv",
    "takarékkönyvetek": "takarékkönyv",
    "takaréknoteszetek": "takaréknotesz",
    "takarékosan": "takarékos",
    "takarékossággal": "takarékosság",
    "takarékosságnak": "takarékosság",
    "takarítani": "takarít",
    "takarított": "takarít",
    "takarítottuk": "takarít",
    "takarót": "takaró",
    "takaróztunk": "takaróz",
    "taktikája": "taktika",
    "taktikát": "taktika",
    "taktikával": "taktika",
    "talajvizet": "talajvíz",
    "talajvízforrások": "talajvízforrás",
    "talapzatukat": "talapzat",
    "talapzatán": "talapzat",
    "talapzatánál": "talapzat",
    "talapzatát": "talapzat",
    "taligazörgést": "taligazörgés",
    "taligán": "taliga",
    "talmudot": "talmud",
    "talpra": "talp",
    "talpukhoz": "talp",
    "talpukon": "talp",
    "talpán": "talp",
    "talpára": "talp",
    "talpát": "talp",
    "találgatni": "találgat",
    "találgattuk": "találgat",
    "találgatások": "találgatás",
    "találhatja": "találhat",
    "találhatnak": "találhat",
    "találhatná": "találhat",
    "találhatsz": "találhat",
    "találhatta": "találhat",
    "találhatók": "található",
    "találja": "talál",
    "találjon": "talál",
    "találjuk": "talál",
    "találjunk": "talál",
    "találják": "talál",
    "találkozhassanak": "találkozhat",
    "találkozhatna": "találkozhat",
    "találkozhatnak": "találkozhat",
    "találkozhatnánk": "találkozhat",
    "találkozhatom": "találkozhat",
    "találkozhatott": "találkozhat",
    "találkozhattak": "találkozhat",
    "találkozhatunk": "találkozhat",
    "találkoznak": "találkozik",
    "találkozni": "találkozik",
    "találkozniuk": "találkozik",
    "találkoznánk": "találkozik",
    "találkoznék": "találkozik",
    "találkozott": "találkozik",
    "találkoztak": "találkozik",
    "találkoztam": "találkozik",
    "találkoztunk": "találkozik",
    "találkozunk": "találkozik",
    "találkozzam": "találkozik",
    "találkozzanak": "találkozik",
    "találkozzon": "találkozik",
    "találkozása": "találkozás",
    "találkozásaik": "találkozás",
    "találkozásból": "találkozás",
    "találkozásnak": "találkozás",
    "találkozást": "találkozás",
    "találkozásuk": "találkozás",
    "találkozásukra": "találkozás",
    "találkozásánál": "találkozás",
    "találkozóban": "találkozó",
    "találkozóin": "találkozó",
    "találkozójuk": "találkozó",
    "találkozójukon": "találkozó",
    "találkozóján": "találkozó",
    "találkozójától": "találkozó",
    "találkozójával": "találkozó",
    "találkozók": "találkozó",
    "találkozón": "találkozó",
    "találkozóra": "találkozó",
    "találkozóról": "találkozó",
    "találkozót": "találkozó",
    "találkánkat": "találka",
    "találmányok": "találmány",
    "találmányt": "találmány",
    "találna": "talál",
    "találnak": "talál",
    "találni": "talál",
    "találod": "talál",
    "találok": "talál",
    "talált": "talál",
    "találta": "talál",
    "találtad": "talált",
    "találtak": "talált",
    "találtam": "talált",
    "találtunk": "talált",
    "találták": "talál",
    "találtál": "talál",
    "találunk": "talál",
    "találóan": "találó",
    "talányosabbá": "talányos",
    "tamtamok": "tamtam",
    "tamáskodók": "tamáskodó",
    "tamástól": "tamás",
    "tanborából": "tanbor",
    "tandíjhátraléka": "tandíjhátralék",
    "tanfolyamok": "tanfolyam",
    "tanfolyamon": "tanfolyam",
    "tanfolyamot": "tanfolyam",
    "tanhoz": "tan",
    "tanintézetekkel": "tanintézet",
    "tankjaival": "tank",
    "tankjuk": "tank",
    "tankkönyvbe": "tankkönyv",
    "tankok": "tank",
    "tankon": "tank",
    "tankönyvbe": "tankönyv",
    "tankönyveket": "tankönyv",
    "tankönyvhöz": "tankönyv",
    "tannak": "tan",
    "tanok": "tan",
    "tanokat": "tan",
    "tanszékére": "tanszék",
    "tantermekben": "tanterem",
    "tantárgyak": "tantárgy",
    "tanul": "tan",
    "tanulhassanak": "tanulhat",
    "tanulhattak": "tanulhat",
    "tanulja": "tanul",
    "tanuljátok": "tanul",
    "tanulmánya": "tanulmány",
    "tanulmányai": "tanulmány",
    "tanulmányaim": "tanulmány",
    "tanulmányait": "tanulmány",
    "tanulmányban": "tanulmány",
    "tanulmányokat": "tanulmány",
    "tanulmányoknál": "tanulmány",
    "tanulmányokra": "tanulmány",
    "tanulmányozni": "tanulmányoz",
    "tanulmányozta": "tanulmányoz",
    "tanulmányozza": "tanulmányoz",
    "tanulmányozása": "tanulmányozás",
    "tanulmányozásakor": "tanulmányozás",
    "tanulmányozásába": "tanulmányozás",
    "tanulmányt": "tanulmány",
    "tanulmányutat": "tanulmányút",
    "tanulmányában": "tanulmány",
    "tanulmányútra": "tanulmányút",
    "tanulnak": "tanul",
    "tanulni": "tanul",
    "tanulnia": "tanul",
    "tanulniuk": "tanul",
    "tanulnivalók": "tanulnivaló",
    "tanulnod": "tanul",
    "tanulsz": "tanul",
    "tanulságait": "tanulság",
    "tanulsággal": "tanulság",
    "tanulságokat": "tanulság",
    "tanult": "tanul",
    "tanulta": "tanul",
    "tanultak": "tanult",
    "tanultam": "tanult",
    "tanultunk": "tanult",
    "tanuláshoz": "tanulás",
    "tanulékonyságuk": "tanulékonyság",
    "tanulócsoportok": "tanulócsoport",
    "tanulók": "tanuló",
    "tanulókat": "tanuló",
    "tanulóknak": "tanuló",
    "tanyabetörés-sorozaton": "tanyabetörés-sorozat",
    "tanyagazdával": "tanyagazda",
    "tanyahelyen": "tanyahely",
    "tanyahelyhez": "tanyahely",
    "tanyahelyre": "tanyahely",
    "tanyaiak": "tanyai",
    "tanyaiakat": "tanyai",
    "tanyaiaknak": "tanyai",
    "tanyaiakért": "tanyai",
    "tanyait": "tanyai",
    "tanyatulajdonosok": "tanyatulajdonos",
    "tanyába": "tanya",
    "tanyában": "tanya",
    "tanyából": "tanya",
    "tanyái": "tanya",
    "tanyájából": "tanya",
    "tanyáján": "tanya",
    "tanyájánál": "tanya",
    "tanyájára": "tanya",
    "tanyák": "tanya",
    "tanyákat": "tanya",
    "tanyákba": "tanya",
    "tanyákkal": "tanya",
    "tanyáknak": "tanya",
    "tanyákon": "tanya",
    "tanyákra": "tanya",
    "tanyákról": "tanya",
    "tanyán": "tanya",
    "tanyára": "tanya",
    "tanyáról": "tanya",
    "tanyásunknak": "tanyás",
    "tanyát": "tanya",
    "tanyával": "tanya",
    "tanyázgattunk": "tanyázgat",
    "tanyázni": "tanyázik",
    "tanyázott": "tanyázik",
    "tanyáztunk": "tanyázik",
    "tanácsa": "tanács",
    "tanácsadást": "tanácsadás",
    "tanácsadói": "tanácsadó",
    "tanácsadója": "tanácsadó",
    "tanácsadók": "tanácsadó",
    "tanácsba": "tanács",
    "tanácsban": "tanács",
    "tanácskozott": "tanácskozik",
    "tanácskoztak": "tanácskozik",
    "tanácskoztunk": "tanácskozik",
    "tanácskozása": "tanácskozás",
    "tanácskozáson": "tanácskozás",
    "tanácskozásra": "tanácskozás",
    "tanácskozást": "tanácskozás",
    "tanácskozásán": "tanácskozás",
    "tanácskozására": "tanácskozás",
    "tanácskozásáról": "tanácskozás",
    "tanácskozását": "tanácskozás",
    "tanácsnak": "tanács",
    "tanácsok": "tanács",
    "tanácsokat": "tanács",
    "tanácsolta": "tanácsol",
    "tanácsolták": "tanácsol",
    "tanácsot": "tanács",
    "tanácstagok": "tanácstag",
    "tanácstagot": "tanácstag",
    "tanácstalanságot": "tanácstalanság",
    "tanácstalanságát": "tanácstalanság",
    "tanácstalanul": "tanácstalan",
    "tanácstermébe": "tanácsterem",
    "tanácstól": "tanács",
    "tanácsának": "tanács",
    "tanácsát": "tanács",
    "tanácsülése": "tanácsülés",
    "tanára": "tanár",
    "tanárban": "tanár",
    "tanárjára": "tanár",
    "tanárnak": "tanár",
    "tanárok": "tanár",
    "tanárokhoz": "tanár",
    "tanároknak": "tanár",
    "tanárom": "tanár",
    "tanárra": "tanár",
    "tanárral": "tanár",
    "tanárt": "tanár",
    "tanáruk": "tanáru",
    "tanárát": "tanár",
    "tanárért": "tanár",
    "tanévben": "tanév",
    "tanítani": "tanít",
    "tanítja": "tanít",
    "tanítom": "tanít",
    "tanított": "tanít",
    "tanította": "tanít",
    "tanítottak": "tanított",
    "tanították": "tanít",
    "taníttassam": "taníttat",
    "taníttathatnánk": "taníttathat",
    "taníttatják": "taníttat",
    "taníttatni": "taníttat",
    "taníttattok": "taníttat",
    "taníttatását": "taníttatás",
    "tanítványai": "tanítvány",
    "tanítványainak": "tanítvány",
    "tanítványának": "tanítvány",
    "tanítványától": "tanítvány",
    "tanítványával": "tanítvány",
    "tanítása": "tanítás",
    "tanításai": "tanítás",
    "tanításaiból": "tanítás",
    "tanításomra": "tanítás",
    "tanítást": "tanítás",
    "tanításából": "tanítás",
    "tanítója": "tanító",
    "tanítók": "tanító",
    "tanítókból": "tanító",
    "tanítókhoz": "tanító",
    "tanítóm": "tanító",
    "tanítómestereinek": "tanítómester",
    "tanítón": "tanító",
    "tanítónak": "tanító",
    "tanítóé": "tanító",
    "tanúi": "tanú",
    "tanúja": "tanú",
    "tanúját": "tanú",
    "tanúkkal": "tanú",
    "tanúskodnak": "tanúskodik",
    "tanúskodni": "tanúskodik",
    "tanúskodott": "tanúskodik",
    "tanúsága": "tanúság",
    "tanúságképp": "tanúság",
    "tanúságot": "tanúság",
    "tanúsítják": "tanúsít",
    "tanúsított": "tanúsít",
    "tanúsította": "tanúsít",
    "tanúvallomásaikkal": "tanúvallomás",
    "tapadt": "tapad",
    "tapadtak": "tapadt",
    "tapasztalata": "tapasztalat",
    "tapasztalatai": "tapasztalat",
    "tapasztalatait": "tapasztalat",
    "tapasztalatból": "tapasztalat",
    "tapasztalatok": "tapasztalat",
    "tapasztalatokon": "tapasztalat",
    "tapasztalatom": "tapasztalat",
    "tapasztalattal": "tapasztalat",
    "tapasztalatuk": "tapasztalat",
    "tapasztalatára": "tapasztalat",
    "tapasztalatát": "tapasztalat",
    "tapasztalniuk": "tapasztal",
    "tapasztalom": "tapasztal",
    "tapasztalt": "tapasztal",
    "tapasztalta": "tapasztal",
    "tapasztaltabb": "tapasztalt",
    "tapasztaltam": "tapasztalt",
    "tapasztaltuk": "tapasztal",
    "tapasztalást": "tapasztalás",
    "tapasztotta": "tapaszt",
    "tapintani": "tapint",
    "tapintatosan": "tapintatos",
    "tapintása": "tapintás",
    "tapogatták": "tapogat",
    "tapogatózott": "tapogatóz",
    "taposhatják": "taposhat",
    "taposni": "tapos",
    "taposott": "tapos",
    "tapostak": "tapos",
    "taposták": "tapos",
    "taposunk": "tapos",
    "taposómalomról": "taposómalom",
    "tappert": "tapper",
    "tapétából": "tapéta",
    "tapétájával": "tapéta",
    "tapétázata": "tapétázat",
    "tarajokat": "taraj",
    "tarhonyát": "tarhonya",
    "tarifaemelések": "tarifaemelés",
    "tarifaemeléssel": "tarifaemelés",
    "tarifamegosztásban": "tarifamegosztás",
    "tarifatáblázatából": "tarifatáblázat",
    "tarifája": "tarifa",
    "tarifák": "tarifa",
    "tarifákat": "tarifa",
    "tarisznyába": "tarisznya",
    "tarisznyáját": "tarisznya",
    "tarisznyák": "tarisznya",
    "tarisznyám": "tarisznya",
    "tarisznyát": "tarisznya",
    "tarisznyával": "tarisznya",
    "tarkított": "tarkít",
    "tarkóján": "tarkó",
    "tarkón": "tarkó",
    "tarlókra": "tarló",
    "tarlón": "tarló",
    "tarlóra": "tarló",
    "tarlóról": "tarló",
    "taroltak": "tarolt",
    "tart": "tar",
    "tartalak": "tart",
    "tartalma": "tartalom",
    "tartalmat": "tartalom",
    "tartalmazna": "tartalmaz",
    "tartalmaznak": "tartalmaz",
    "tartalmaznia": "tartalmaz",
    "tartalmazott": "tartalmaz",
    "tartalmazta": "tartalmaz",
    "tartalmaztak": "tartalmaz",
    "tartalmazták": "tartalmaz",
    "tartalmazza": "tartalmaz",
    "tartalmazzák": "tartalmaz",
    "tartalmának": "tartalom",
    "tartalmát": "tartalom",
    "tartalommal": "tartalom",
    "tartalék-üzemanyagnak": "tartalék-üzemanyag",
    "tartalékalapjaiból": "tartalékalap",
    "tartalékalapjából": "tartalékalap",
    "tartalékban": "tartalék",
    "tartalékok": "tartalék",
    "tartana": "tartan",
    "tartanak": "tart",
    "tartani": "tart",
    "tartania": "tart",
    "tartanom": "tartan",
    "tartanunk": "tartan",
    "tartaná": "tart",
    "tartanák": "tart",
    "tarthassa": "tarthat",
    "tarthasson": "tarthat",
    "tarthassák": "tarthat",
    "tarthatatlansága": "tarthatatlanság",
    "tarthatja": "tarthat",
    "tarthatnak": "tarthat",
    "tarthatná": "tarthat",
    "tarthatod": "tarthat",
    "tarthatott": "tarthat",
    "tarthatta": "tarthat",
    "tartja": "tart",
    "tartjuk": "tart",
    "tartják": "tart",
    "tartod": "tart",
    "tartogatja": "tartogat",
    "tartogatott": "tartogat",
    "tartok": "tart",
    "tartom": "tart",
    "tartományai": "tartomány",
    "tartományaik": "tartomány",
    "tartományok": "tartomány",
    "tartott": "tart",
    "tartotta": "tart",
    "tartottad": "tartott",
    "tartottak": "tartott",
    "tartottam": "tartott",
    "tartottuk": "tart",
    "tartottunk": "tartott",
    "tartották": "tart",
    "tartozhatott": "tartozhat",
    "tartoznak": "tartozik",
    "tartozol": "tartozik",
    "tartozom": "tartozik",
    "tartozott": "tartozik",
    "tartoztak": "tartozik",
    "tartozunk": "tartozik",
    "tartozzék": "tartozik",
    "tartozása": "tartozás",
    "tartozásait": "tartozás",
    "tartozások": "tartozás",
    "tartozást": "tartozás",
    "tartozásának": "tartozás",
    "tartozását": "tartozás",
    "tartozéka": "tartozék",
    "tartozékot": "tartozék",
    "tartozók": "tartozó",
    "tartsa": "tart",
    "tartsam": "tart",
    "tartsanak": "tart",
    "tartson": "tart",
    "tartsuk": "tart",
    "tartsák": "tart",
    "tartunk": "tart",
    "tartálykocsiból": "tartálykocsi",
    "tartása": "tartás",
    "tartásban": "tartás",
    "tartásához": "tartás",
    "tartására": "tartás",
    "tartását": "tartás",
    "tartóoszlopa": "tartóoszlop",
    "tartópillérévé": "tartópillérév",
    "tartósaknak": "tartós",
    "tartósan": "tartós",
    "tartóssá": "tartós",
    "tartósítani": "tartósít",
    "tartózkodnak": "tartózkodik",
    "tartózkodnának": "tartózkodik",
    "tartózkodnék": "tartózkodik",
    "tartózkodott": "tartózkodik",
    "tartózkodtam": "tartózkodik",
    "tartózkodással": "tartózkodás",
    "tartózkodásért": "tartózkodás",
    "tartózkodóak": "tartózkodó",
    "tartózkodóan": "tartózkodó",
    "tartóztathassák": "tartóztathat",
    "tartóztatott": "tartóztat",
    "taszítani": "taszít",
    "taszított": "taszít",
    "tatabányán": "tatabánya",
    "tatuskám": "tatuska",
    "tatármosolyába": "tatármosoly",
    "tavalyinál": "tavalyi",
    "tavasszal": "tavasz",
    "tavaszian": "tavaszi",
    "tavaszig": "tavasz",
    "tavaszon": "tavasz",
    "tavaszra": "tavasz",
    "tavasztól": "tavasz",
    "tavaszán": "tavasz",
    "taván": "tó",
    "taxiján": "taxi",
    "taxisok": "taxis",
    "teakészítésnél": "teakészítés",
    "teamaradékot": "teamaradék",
    "tearózsacsokorra": "tearózsacsokor",
    "technikusokból": "technikus",
    "technikából": "technika",
    "technikájával": "technika",
    "technikák": "technika",
    "technológiák": "technológia",
    "technológiával": "technológia",
    "tedd": "tesz",
    "teendővé": "teendő",
    "tegnapra": "tegnap",
    "tegnaptól": "tegnap",
    "tegye": "tesz",
    "tegyek": "tesz",
    "tegyen": "tesz",
    "tegyenek": "tesz",
    "tegyék": "tesz",
    "tegyük": "tesz",
    "tegyünk": "tesz",
    "teheneket": "tehén",
    "tehenekre": "tehén",
    "tehenet": "tehén",
    "tehenével": "tehén",
    "teherautók": "teherautó",
    "teherautókra": "teherautó",
    "teherautóra": "teherautó",
    "teherautósofőrnek": "teherautósofőr",
    "teherbíró-képességét": "teherbíró-képesség",
    "teherhajót": "teherhajó",
    "teherkocsik": "teherkocsi",
    "teherkocsikat": "teherkocsi",
    "teherrel": "teher",
    "teherszállítók": "teherszállító",
    "tehervonathoz": "tehervonat",
    "tehesse": "tehet",
    "tehessen": "tehet",
    "teheted": "tehet",
    "tehetek": "tehet",
    "tehetem": "tehet",
    "tehetetlenek": "tehetetlen",
    "tehetetlennek": "tehetetlen",
    "tehetetlenné": "tehetetlen",
    "tehetetlenségbe": "tehetetlenség",
    "tehetetlensége": "tehetetlenség",
    "tehetetlenséget": "tehetetlenség",
    "tehetetlenül": "tehetetlen",
    "tehetett": "tehet",
    "tehetik": "tehet",
    "tehetnek": "tehet",
    "tehetném": "tehet",
    "tehetnének": "tehet",
    "tehetségeinek": "tehetség",
    "tehetségeit": "tehetség",
    "tehetségek": "tehetség",
    "tehetségekben": "tehetség",
    "tehetségesnek": "tehetséges",
    "tehetséget": "tehetség",
    "tehetségét": "tehetség",
    "tehette": "tehet",
    "tehettek": "tehet",
    "tehették": "tehet",
    "tehettétek": "tehet",
    "tehettünk": "tehet",
    "tehetünk": "tehet",
    "tehetők": "tehető",
    "tehetősebb": "tehetős",
    "tehéncsordának": "tehéncsorda",
    "tehénről": "tehén",
    "tejbekásához": "tejbekása",
    "tejbekását": "tejbekása",
    "tejből": "tej",
    "tejesítéséhez": "tejesítés",
    "tejet": "tej",
    "tejfölért": "tejföl",
    "tejjel": "tej",
    "tejnek": "tej",
    "tejsárgába": "tejsárga",
    "tekintem": "tekint",
    "tekintenek": "tekint",
    "tekinteni": "tekint",
    "tekintenie": "tekint",
    "tekintetben": "tekintet",
    "tekintete": "tekintet",
    "tekintetek": "tekintet",
    "tekintett": "tekint",
    "tekintette": "tekint",
    "tekintettek": "tekintett",
    "tekintettel": "tekintett",
    "tekintették": "tekintet",
    "tekintetébe": "tekintet",
    "tekintetében": "tekintet",
    "tekintetét": "tekintet",
    "tekintetével": "tekintet",
    "tekintetük": "tekintet",
    "tekinthetett": "tekinthet",
    "tekinthetik": "tekinthet",
    "tekinthetjük": "tekinthet",
    "tekinthetők": "tekinthető",
    "tekinti": "tekint",
    "tekintik": "tekint",
    "tekintjük": "tekint",
    "tekintsék": "tekint",
    "tekintélyek": "tekintély",
    "tekintélyhez": "tekintély",
    "tekintélynek": "tekintély",
    "tekintélyrombolást": "tekintélyrombolás",
    "tekintélyük": "tekintély",
    "tekintünk": "tekint",
    "teknőcöt": "teknőc",
    "tele": "tél",
    "telefonbeszélgetésünk": "telefonbeszélgetés",
    "telefonhoz": "telefon",
    "telefonkártyájukért": "telefonkártya",
    "telefonkönyvet": "telefonkönyv",
    "telefonodon": "telefon",
    "telefonok": "telefon",
    "telefonon": "telefon",
    "telefonszámot": "telefonszám",
    "telefontársaságok": "telefontársaság",
    "telefonálhatnak": "telefonálhat",
    "telefonálj": "telefonál",
    "telefonálni": "telefonál",
    "telehozza": "telehoz",
    "telehányta": "telehány",
    "telek": "telik",
    "telekapportja": "telekapport",
    "telekre": "telek",
    "telektulajdonosokat": "telektulajdonos",
    "telektől": "telek",
    "telekvásárlásra": "telekvásárlás",
    "teleképben": "telekép",
    "teleképből": "telekép",
    "teleképek": "telekép",
    "teleképekből": "telekép",
    "teleképeken": "telekép",
    "teleképekhez": "telekép",
    "teleképekkel": "telekép",
    "teleképen": "telekép",
    "teleképet": "telekép",
    "teleképhez": "telekép",
    "teleképműsorokat": "teleképműsor",
    "teleképműsorokkal": "teleképműsor",
    "teleképnek": "telekép",
    "teleképpel": "telekép",
    "teleképre": "telekép",
    "teleképtől": "telekép",
    "telelődözni": "telelődöz",
    "telepeken": "telep",
    "telepeket": "telep",
    "telepen": "telep",
    "telepet": "telep",
    "telepén": "telep",
    "telepére": "telep",
    "telepíteni": "telepít",
    "telepített": "telepít",
    "telepítik": "telepít",
    "telepítései": "telepítés",
    "települések": "település",
    "településeken": "település",
    "településeket": "település",
    "településeknek": "település",
    "településektől": "település",
    "településen": "település",
    "településre": "település",
    "településrendezésben": "településrendezés",
    "településről": "település",
    "településének": "település",
    "telerakták": "telerak",
    "teleszívta": "teleszív",
    "telet": "tél",
    "teletexttel": "teletext",
    "teletömi": "teletöm",
    "teletömött": "teletöm",
    "televegye": "televesz",
    "televiszik": "televisz",
    "televízióban": "televízió",
    "televíziók": "televízió",
    "televízióval": "televízió",
    "telezsúfolt": "telezsúfol",
    "telhetett": "telhet",
    "telhettek": "telhet",
    "teli": "telik",
    "telik": "teli",
    "teliszurkálni": "teliszurkál",
    "teliszórt": "teliszór",
    "teljesen": "teljes",
    "teljességben": "teljesség",
    "teljességgel": "teljesség",
    "teljesíteni": "teljesít",
    "teljesíteniük": "teljesít",
    "teljesített": "teljesít",
    "teljesítette": "teljesít",
    "teljesítették": "teljesítet",
    "teljesítik": "teljesít",
    "teljesítménye": "teljesítmény",
    "teljesítményeinek": "teljesítmény",
    "teljesítményeivel": "teljesítmény",
    "teljesítményre": "teljesítmény",
    "teljesítményt": "teljesítmény",
    "teljesítménytől": "teljesítmény",
    "teljesítményét": "teljesítmény",
    "teljesítményük": "teljesítmény",
    "teljesítse": "teljesít",
    "teljesítések": "teljesítés",
    "teljesítésre": "teljesítés",
    "teljesítésére": "teljesítés",
    "teljesítéséről": "teljesítés",
    "teljesítését": "teljesítés",
    "teljesülne": "teljesül",
    "teljesülnek": "teljesül",
    "teljesült": "teljesül",
    "teljében": "telje",
    "telkeinek": "telek",
    "telkek": "telek",
    "telkekben": "telek",
    "telkeket": "telek",
    "telkekhez": "telek",
    "telken": "telek",
    "telket": "telek",
    "telkét": "telek",
    "tellett": "telik",
    "telnek": "telik",
    "telnének": "telik",
    "telosz-nak": "telosz",
    "telt": "telik",
    "teltek": "telt",
    "telített": "telít",
    "temeti": "temet",
    "temette": "temet",
    "temetésből": "temetés",
    "temetésen": "temetés",
    "temetésén": "temetés",
    "temetésének": "temetés",
    "temetésére": "temetés",
    "temetésükön": "temetés",
    "templomnévből": "templomnév",
    "templomok": "templom",
    "templomot": "templom",
    "templompadokat": "templompad",
    "templomtornyok": "templomtorony",
    "templomtoronyban": "templomtorony",
    "templomában": "templom",
    "templomának": "templom",
    "templomát": "templom",
    "tempójának": "tempó",
    "tempóját": "tempó",
    "tendenciája": "tendencia",
    "tendenciák": "tendencia",
    "tendenciákkal": "tendencia",
    "tenderek": "tender",
    "tenderen": "tender",
    "tendertárgyalásokra": "tendertárgyalás",
    "tengelyt": "tengely",
    "tengelyébe": "tengely",
    "tengeralattjáró-bázisaik": "tengeralattjáró-bázis",
    "tengerbe": "tenger",
    "tengeren": "tenger",
    "tengeribe": "tengeri",
    "tengeridarát": "tengeridara",
    "tengeriföldet": "tengeriföld",
    "tengeriföldosztáskor": "tengeriföldosztás",
    "tengerit": "tengeri",
    "tengernagyának": "tengernagy",
    "tengerpartra": "tengerpart",
    "tengertől": "tenger",
    "tengervizet": "tengervíz",
    "tengerárak": "tengerár",
    "tengerészei": "tengerész",
    "tengerészeit": "tengerész",
    "tengett": "teng",
    "teniszbajnokságon": "teniszbajnokság",
    "teniszezett": "teniszezik",
    "teniszezők": "teniszező",
    "teniszjátékosoknak": "teniszjátékos",
    "teniszpályát": "teniszpálya",
    "teniszre": "tenisz",
    "teniszstadiont": "teniszstadion",
    "teniszt": "tenisz",
    "teniszviadalon": "teniszviadal",
    "tenne": "tesz",
    "tenned": "tesz",
    "tennem": "tesz",
    "tenni": "tesz",
    "tennie": "tesz",
    "tennivalójuk": "tennivaló",
    "tenné": "tesz",
    "tennék": "tesz",
    "tennél": "tesz",
    "tennének": "tesz",
    "tenyerem": "tenyér",
    "tenyeret": "tenyér",
    "tenyerébe": "tenyér",
    "tenyerén": "tenyér",
    "tenyerének": "tenyér",
    "tenyerét": "tenyér",
    "tenyérlenyomatát": "tenyérlenyomat",
    "tenyérrel": "tenyér",
    "tenyésztésbe": "tenyésztés",
    "tenyésztők": "tenyésztő",
    "tepsije": "tepsi",
    "tepsijeikkel": "tepsi",
    "tepsit": "tepsi",
    "tere": "tér",
    "teregetett": "tereget",
    "teregethetné": "teregethet",
    "terei": "tér",
    "tereli": "terel",
    "terelni": "terel",
    "terem": "tér",
    "terembe": "terem",
    "teremben": "terem",
    "terembérlete": "terembérlet",
    "teremnek": "terem",
    "teremtene": "teremt",
    "teremteni": "teremt",
    "teremtené": "teremt",
    "teremtetett": "teremtetik",
    "teremtett": "teremt",
    "teremtettek": "teremtett",
    "teremtettem": "teremtett",
    "teremtheti": "teremthet",
    "teremthetnek": "teremthet",
    "teremti": "teremt",
    "teremtmények": "teremtmény",
    "teremtsen": "teremt",
    "teremtsenek": "teremt",
    "teremtések": "teremtés",
    "teremtésére": "teremtés",
    "teremtünk": "teremt",
    "teremtője": "teremtő",
    "terepen": "terep",
    "terepet": "terep",
    "terepjáróból": "terepjáró",
    "terepjáróval": "terepjáró",
    "terepviszonyok": "terepviszony",
    "teret": "tér",
    "terhedre": "teher",
    "terhei": "teher",
    "terheit": "teher",
    "terheket": "teher",
    "terheli": "terhel",
    "terhelje": "terhel",
    "terheljem": "terhel",
    "terhelné": "terhel",
    "terhelte": "terhel",
    "terheltek": "terhelt",
    "terhelése": "terhelés",
    "terhelésre": "terhelés",
    "terhelést": "terhelés",
    "terhet": "teher",
    "terhére": "teher",
    "terhét": "teher",
    "terhükre": "teher",
    "terjedelmében": "terjedelem",
    "terjednek": "terjed",
    "terjedt": "terjed",
    "terjedtek": "terjedt",
    "terjengett": "terjeng",
    "terjengtek": "terjeng",
    "terjesszem": "terjeszt",
    "terjeszkedne": "terjeszkedik",
    "terjeszteni": "terjeszt",
    "terjesztett": "terjeszt",
    "terjesztették": "terjesztet",
    "terjeszthetjük": "terjeszthet",
    "terjeszti": "terjeszt",
    "terjesztjük": "terjeszt",
    "terjesztését": "terjesztés",
    "terjesztői": "terjesztő",
    "termeiből": "terem",
    "termeljen": "termel",
    "termelni": "termel",
    "termelnie": "termel",
    "termelnénk": "termel",
    "termelt": "termel",
    "termelte": "termel",
    "termeltek": "termelt",
    "termeltetni": "termeltet",
    "termelvényeiket": "termelvény",
    "termelésből": "termelés",
    "termelése": "termelés",
    "termeléskiesése": "termeléskiesés",
    "termelésről": "termelés",
    "termelést": "termelés",
    "termelésének": "termelés",
    "termeléséről": "termelés",
    "termelését": "termelés",
    "termelői": "termelő",
    "termelőjeként": "termelő",
    "termelők": "termelő",
    "termelőket": "termelő",
    "termelőszövetkezettel": "termelőszövetkezet",
    "termen": "terem",
    "termet": "terem",
    "termett": "terem",
    "terminológiánkkal": "terminológia",
    "termében": "terem",
    "termékdíjjal": "termékdíj",
    "termékei": "termék",
    "termékeinek": "termék",
    "termékeit": "termék",
    "termékek": "termék",
    "termékeken": "termék",
    "termékeket": "termék",
    "terméket": "termék",
    "terméketlenné": "terméketlen",
    "termékről": "termék",
    "termékét": "termék",
    "termésnek": "termés",
    "termést": "termés",
    "természete": "természet",
    "természetemből": "természet",
    "természetesebbnek": "természetes",
    "természetesen": "természetes",
    "természetesnek": "természetes",
    "természetet": "természet",
    "természetrombolásnak": "természetrombolás",
    "természettudománnyal": "természettudomány",
    "természettől": "természet",
    "természetében": "természet",
    "természeténél": "természet",
    "természetéről": "természet",
    "természetét": "természet",
    "természetével": "természet",
    "természetűek": "természetű",
    "termését": "termés",
    "terrorakcióktól": "terrorakció",
    "terrorcselekményeinek": "terrorcselekmény",
    "terrorcselekmények": "terrorcselekmény",
    "terrorhullám": "terrorhulla",
    "terrorhullámnak": "terrorhullám",
    "terrorhírek": "terrorhír",
    "terroristaként": "terrorista",
    "terroristái": "terrorista",
    "terroristák": "terrorista",
    "terroristákat": "terrorista",
    "terroristákkal": "terrorista",
    "terroristákról": "terrorista",
    "terrortámadástól": "terrortámadás",
    "terve": "terv",
    "tervei": "terv",
    "terveik": "terv",
    "terveinek": "terv",
    "terveinél": "terv",
    "terveit": "terv",
    "terveivel": "terv",
    "tervek": "terv",
    "tervekben": "terv",
    "terveken": "terv",
    "terveket": "terv",
    "tervekhez": "terv",
    "tervekkel": "terv",
    "terveknek": "terv",
    "tervekről": "terv",
    "tervekért": "terv",
    "tervelik": "tervel",
    "tervet": "terv",
    "tervezetbe": "tervezet",
    "tervezetben": "tervezet",
    "tervezete": "tervezet",
    "tervezetet": "tervezet",
    "tervezetnél": "tervezet",
    "tervezett": "tervez",
    "tervezettnél": "tervezett",
    "tervezetét": "tervezet",
    "tervezgetéseiben": "tervezgetés",
    "tervezik": "tervez",
    "terveznek": "tervez",
    "tervezte": "tervez",
    "terveztek": "tervez",
    "tervezték": "tervez",
    "terveztük": "tervez",
    "tervezzük": "tervez",
    "tervezésénél": "tervezés",
    "tervezői": "tervező",
    "tervgazdálkodást": "tervgazdálkodás",
    "tervnél": "terv",
    "tervrajzokat": "tervrajz",
    "tervre": "terv",
    "tervszerűen": "tervszerű",
    "tervvel": "terv",
    "tervéről": "terv",
    "tervét": "terv",
    "tervével": "terv",
    "tervünket": "terv",
    "terén": "tér",
    "terének": "tér",
    "terített": "terít",
    "terítette": "terít",
    "terítették": "terítet",
    "teríti": "terít",
    "terítéken": "teríték",
    "terítékre": "teríték",
    "terítők": "terítő",
    "területe": "terület",
    "területek": "terület",
    "területeken": "terület",
    "területeket": "terület",
    "területekkel": "terület",
    "területekre": "terület",
    "területekről": "terület",
    "területen": "terület",
    "területet": "terület",
    "területkiegyenlítést": "területkiegyenlítés",
    "területnek": "terület",
    "területre": "terület",
    "területrészek": "területrész",
    "területről": "terület",
    "területté": "terület",
    "területéhez": "terület",
    "területén": "terület",
    "területére": "terület",
    "területét": "terület",
    "terültek": "terül",
    "tespedjünk": "tesped",
    "tesszük": "tetszik",
    "teste": "test",
    "tested": "test",
    "testeden": "test",
    "testek": "test",
    "testem": "test",
    "testessége": "testesség",
    "testesítette": "testesít",
    "testet": "test",
    "testhez": "test",
    "testidomot": "testidom",
    "testmozdulatait": "testmozdulat",
    "testre": "test",
    "testrészekről": "testrész",
    "testrészt": "testrész",
    "testről": "test",
    "testsúlyt": "testsúly",
    "testtartásukból": "testtartás",
    "testtel": "test",
    "testvér-fejért": "testvér-fej",
    "testvér-portréknál": "testvér-portré",
    "testvére": "testvér",
    "testvérei": "testvér",
    "testvérekkel": "testvér",
    "testvérinek": "testvéri",
    "testvériségbe": "testvériség",
    "testvériséget": "testvériség",
    "testvériséggel": "testvériség",
    "testvériségnek": "testvériség",
    "testvériségről": "testvériség",
    "testvérnek": "testvér",
    "testvérre": "testvér",
    "testvérrel": "testvér",
    "testvérről": "testvér",
    "testvért": "testvér",
    "testvérért": "testvér",
    "testvérét": "testvér",
    "testébe": "test",
    "testében": "test",
    "testéhez": "test",
    "testén": "test",
    "testének": "test",
    "testére": "test",
    "testét": "test",
    "testével": "test",
    "testük": "test",
    "testükből": "test",
    "testükhöz": "test",
    "testületbe": "testület",
    "testületeinek": "testület",
    "testületet": "testület",
    "testületnél": "testület",
    "testületének": "testület",
    "testünkbe": "test",
    "teszed": "tesz",
    "teszel": "tesz",
    "teszi": "tesz",
    "teszik": "tesz",
    "tesznek": "tesz",
    "teszteltem": "tesztelt",
    "tesztelésének": "tesztelés",
    "tesztet": "teszt",
    "tesztsorozatot": "tesztsorozat",
    "teteje": "tető",
    "tetejéig": "tető",
    "tetején": "tető",
    "tetejére": "tető",
    "tetejéről": "tető",
    "tetejét": "tető",
    "tetejük": "tető",
    "tetejükkel": "tető",
    "tetemesebb": "tetemes",
    "tetszelegtek": "tetszeleg",
    "tetszene": "tetszik",
    "tetszett": "tetszik",
    "tetszettek": "tetszik",
    "tetszetősen": "tetszetős",
    "tetszésüket": "tetszés",
    "tett": "tesz",
    "tette": "tett",
    "tettei": "tett",
    "tetteiket": "tett",
    "tetteit": "tett",
    "tettek": "tett",
    "tetteket": "tett",
    "tettekig": "tett",
    "tettem": "tett",
    "tetten": "tett",
    "tetteseit": "tettes",
    "tettesek": "tettes",
    "tettest": "tettes",
    "tetteted": "tettet",
    "tettetett": "tettet",
    "tetteti": "tettet",
    "tettetik": "tettet",
    "tettetnie": "tettet",
    "tettette": "tettet",
    "tettették": "tettet",
    "tettként": "tett",
    "tették": "tesz",
    "tettél": "tesz",
    "tettét": "tett",
    "tettétek": "tesz",
    "tettétől": "tett",
    "tettéért": "tett",
    "tettük": "tett",
    "tettünk": "tett",
    "tetvek": "tetű",
    "tetvészkedtek": "tetvészkedik",
    "tetézi": "tetéz",
    "tetézni": "tetéz",
    "tetőbeszakadásokról": "tetőbeszakadás",
    "tetőfokára": "tetőfok",
    "tetők": "tető",
    "tetőkertek": "tetőkert",
    "tetőket": "tető",
    "tetőkön": "tető",
    "tetőpontján": "tetőpont",
    "tetőről": "tető",
    "tetőterek": "tetőtér",
    "tetűm": "tetű",
    "tetűtől": "tetű",
    "tetűvel": "tetű",
    "teutánad": "teután",
    "tevékenyebb": "tevékeny",
    "tevékenykedett": "tevékenykedik",
    "tevékenykedhetett": "tevékenykedhet",
    "tevékenykedtek": "tevékenykedik",
    "tevékenykedők": "tevékenykedő",
    "tevékenységbe": "tevékenység",
    "tevékenysége": "tevékenység",
    "tevékenységeket": "tevékenység",
    "tevékenységet": "tevékenység",
    "tevékenységnek": "tevékenység",
    "tevékenységről": "tevékenység",
    "tevékenységét": "tevékenység",
    "tevékenységével": "tevékenység",
    "tevékenységéért": "tevékenység",
    "tevékenységükben": "tevékenység",
    "tevékenységüket": "tevékenység",
    "tevékenységüknek": "tevékenység",
    "textilművészek": "textilművész",
    "teához": "tea",
    "teájuk": "tea",
    "teákra": "tea",
    "teám": "tea",
    "teáscsészék": "teáscsésze",
    "teáscsészényit": "teáscsészényi",
    "teáskannát": "teáskanna",
    "teáskészletet": "teáskészlet",
    "teát": "tea",
    "teátrumok": "teátrum",
    "teától": "tea",
    "teázásaiknál": "teázás",
    "tibetiek": "tibeti",
    "tied": "te",
    "tigriskölykök": "tigriskölyök",
    "tilalma": "tilalom",
    "tilalmaival": "tilalom",
    "tilalmak": "tilalom",
    "tilalmáról": "tilalom",
    "tilalommal": "tilalom",
    "tiltakozna": "tiltakozik",
    "tiltakoznak": "tiltakozik",
    "tiltakozni": "tiltakozik",
    "tiltakozom": "tiltakozik",
    "tiltakozott": "tiltakozik",
    "tiltakoztak": "tiltakozik",
    "tiltakozása": "tiltakozás",
    "tiltakozások": "tiltakozás",
    "tiltakozással": "tiltakozás",
    "tiltakozásszerűen": "tiltakozásszerű",
    "tiltakozást": "tiltakozás",
    "tiltakozásuk": "tiltakozás",
    "tiltakozásul": "tiltakozás",
    "tiltakozók": "tiltakozó",
    "tilthatja": "tilthat",
    "tiltja": "tilt",
    "tiltják": "tilt",
    "tiltott": "tilt",
    "tiltotta": "tilt",
    "tiltottak": "tiltott",
    "tiltották": "tilt",
    "tiltson": "tilt",
    "tiltsák": "tilt",
    "tiltást": "tiltás",
    "tiltására": "tiltás",
    "tiltófeliratok": "tiltófelirat",
    "tintaceruzájának": "tintaceruza",
    "tintaceruzával": "tintaceruza",
    "tintába": "tinta",
    "tintásüveget": "tintásüveg",
    "tintát": "tinta",
    "tinédzserek": "tinédzser",
    "tinéktek": "ti",
    "tipográfussal": "tipográfus",
    "tirpákok": "tirpák",
    "tiszavirág-életűnek": "tiszavirág-életű",
    "tisztaságnak": "tisztaság",
    "tisztaságnál": "tisztaság",
    "tisztaságot": "tisztaság",
    "tisztaságunk": "tisztaság",
    "tisztaságának": "tisztaság",
    "tisztaságát": "tisztaság",
    "tisztaságával": "tisztaság",
    "tisztaságért": "tisztaság",
    "tisztek": "tiszt",
    "tiszteletadást": "tiszteletadás",
    "tiszteletben": "tisztelet",
    "tiszteletből": "tisztelet",
    "tisztelete": "tisztelet",
    "tiszteletet": "tisztelet",
    "tiszteletnek": "tisztelet",
    "tiszteletre": "tisztelet",
    "tisztelettel": "tisztelet",
    "tiszteletteljesen": "tiszteletteljes",
    "tiszteletére": "tisztelet",
    "tisztelgőre": "tisztelgő",
    "tisztelte": "tisztel",
    "tisztem": "tiszt",
    "tisztességesen": "tisztességes",
    "tiszthelyettesek": "tiszthelyettes",
    "tiszthelyettesnek": "tiszthelyettes",
    "tisztjeiknek": "tiszt",
    "tisztjelöltek": "tisztjelölt",
    "tisztjének": "tiszt",
    "tisztnek": "tiszt",
    "tisztogatásai": "tisztogatás",
    "tisztogatások": "tisztogatás",
    "tisztogatásokat": "tisztogatás",
    "tisztogatásokban": "tisztogatás",
    "tisztre": "tiszt",
    "tisztségek": "tisztség",
    "tisztségeket": "tisztség",
    "tisztséget": "tisztség",
    "tisztségviselőinek": "tisztségviselői",
    "tisztségviselőire": "tisztségviselői",
    "tisztségviselőivel": "tisztségviselői",
    "tisztségében": "tisztség",
    "tisztségükben": "tisztség",
    "tiszttől": "tiszt",
    "tisztult": "tisztul",
    "tisztviselői": "tisztviselő",
    "tisztviselőit": "tisztviselői",
    "tisztviselők": "tisztviselő",
    "tisztviselőt": "tisztviselő",
    "tisztába": "tiszta",
    "tisztában": "tiszta",
    "tisztább": "tiszta",
    "tiszták": "tiszta",
    "tisztán": "tiszta",
    "tisztának": "tiszta",
    "tisztára": "tiszta",
    "tisztáson": "tisztás",
    "tisztásra": "tisztás",
    "tisztásról": "tisztás",
    "tisztást": "tisztás",
    "tisztátalanul": "tisztátalan",
    "tisztázni": "tisztáz",
    "tisztáznia": "tisztáz",
    "tisztázniuk": "tisztáz",
    "tisztázta": "tisztáz",
    "tisztázása": "tisztázás",
    "tisztázásra": "tisztázás",
    "tisztázását": "tisztázás",
    "tisztázódnak": "tisztázódik",
    "tisztéből": "tiszt",
    "tisztéről": "tiszt",
    "tisztéért": "tiszt",
    "tisztítja": "tisztít",
    "tisztították": "tisztít",
    "tisztítására": "tisztítás",
    "tisztújításnak": "tisztújítás",
    "titeket": "ti",
    "titka": "titok",
    "titkai": "titok",
    "titkok": "titok",
    "titkokat": "titok",
    "titkolni": "titkol",
    "titkolnia": "titkol",
    "titkolt": "titkol",
    "titkolta": "titkol",
    "titkon": "titok",
    "titkosszolgálatok": "titkosszolgálat",
    "titkosszolgálattal": "titkosszolgálat",
    "titkot": "titok",
    "titkukat": "titok",
    "titkára": "titok",
    "titkárnője": "titkárnő",
    "titkárnőjével": "titkárnő",
    "titkárnők": "titkárnő",
    "titkárra": "titkár",
    "titokban": "titok",
    "titokhoz": "titok",
    "titulálni": "titulál",
    "tizeddel": "tized",
    "tizedekkel": "tized",
    "tizediknek": "tizedik",
    "tizenegyet": "tizenegy",
    "tizenegyre": "tizenegy",
    "tizenhármat": "tizenhárom",
    "tizenkettőre": "tizenkettő",
    "tizenkettőt": "tizenkettő",
    "tizenkilencben": "tizenkilenc",
    "tizenkilenckor": "tizenkilenc",
    "tizennegyedszer": "tizennegyed",
    "tizennyolcat": "tizennyolc",
    "tizenöt-tizenhatodán": "tizenöt-tizenhatod",
    "tizenötből": "tizenöt",
    "tizenötöt": "tizenöt",
    "tiéd": "te",
    "toalettpapírba": "toalettpapír",
    "toborzott": "toboroz",
    "tojásban": "tojás",
    "tojásokat": "tojás",
    "tojással": "tojás",
    "tojásért": "tojás",
    "tokján": "tok",
    "tokokba": "tok",
    "tolakodott": "tolakodik",
    "tolakodással": "tolakodás",
    "tolakodástól": "tolakodás",
    "tolakodónak": "tolakodó",
    "tolatásokra": "tolatás",
    "toldalékolnak": "toldalékol",
    "tolja": "tol",
    "tolják": "tol",
    "tolla": "toll",
    "tollal": "toll",
    "tollat": "toll",
    "tollköpönyegében": "tollköpönyeg",
    "tollszárat": "tollszár",
    "tollszárba": "tollszár",
    "tollával": "toll",
    "tolmácsnak": "tolmács",
    "tolmácsolásában": "tolmácsolás",
    "tolna": "tol",
    "tolnak": "tol",
    "tologatott": "tologat",
    "tologatták": "tologat",
    "toloncügyosztályon": "toloncügyosztály",
    "tolongani": "tolong",
    "tolongott": "tolong",
    "tolongtak": "tolong",
    "tolongásban": "tolongás",
    "tolta": "tol",
    "toltam": "tolt",
    "tolták": "tol",
    "tolvajait": "tolvaj",
    "tolvajlásokért": "tolvajlás",
    "tolvajnak": "tolvaj",
    "tolvajnyelven": "tolvajnyelv",
    "tolvajok": "tolvaj",
    "tolvajokat": "tolvaj",
    "tolvajságuk": "tolvajság",
    "tomporok": "tompor",
    "tompán": "tompa",
    "tompítása": "tompítás",
    "topogása": "topogás",
    "toporgott": "toporog",
    "toporgását": "toporgás",
    "toporogni": "toporog",
    "torkolata": "torkolat",
    "torkolataiban": "torkolat",
    "torkollott": "torkollik",
    "torkolták": "torkol",
    "torkom": "torok",
    "torkuk": "torok",
    "torkukat": "torok",
    "torkunkra": "torok",
    "torkába": "torok",
    "torkából": "torok",
    "torkán": "torok",
    "torkára": "torok",
    "torkát": "torok",
    "tornacipőbe": "tornacipő",
    "tornacipői": "tornacipő",
    "tornadíjat": "tornadíj",
    "tornateremben": "tornaterem",
    "tornyai": "torony",
    "tornyosodott": "tornyosodik",
    "tornyosult": "tornyosul",
    "tornáca": "tornác",
    "tornácon": "tornác",
    "tornán": "torna",
    "tornát": "torna",
    "tornázni": "tornázik",
    "torok": "tor",
    "torokban": "torok",
    "torokból": "torok",
    "toronnyal": "torony",
    "torontói": "torontó",
    "toronylépcsőn": "toronylépcső",
    "torpanni": "torpan",
    "torpedózza": "torpedóz",
    "torzképei": "torzkép",
    "torzsa": "torzs",
    "torzult": "torzul",
    "torzított": "torzít",
    "torzítók": "torzító",
    "totalitáriusnak": "totalitárius",
    "totószelvények": "totószelvény",
    "továbbadjuk": "továbbad",
    "továbbadják": "továbbad",
    "továbbfejlesszük": "továbbfejleszt",
    "továbbfejleszteni": "továbbfejleszt",
    "továbbiakban": "további",
    "továbbjutott": "továbbjut",
    "továbbjutáshoz": "továbbjutás",
    "továbbjutásra": "továbbjutás",
    "továbbjutást": "továbbjutás",
    "továbbképzést": "továbbképzés",
    "továbbmenni": "továbbmegy",
    "továbbment": "továbbmegy",
    "továbbmentek": "továbbment",
    "továbbpillantott": "továbbpillant",
    "továbbtanulni": "továbbtanul",
    "továbbtanulást": "továbbtanulás",
    "továbbtanulók": "továbbtanuló",
    "továbbtaníttatnátok": "továbbtaníttat",
    "továbbálltak": "továbbállt",
    "továbbálltam": "továbbállt",
    "továbbélése": "továbbélés",
    "továbbítaniuk": "továbbít",
    "továbbítja": "továbbít",
    "továbbítják": "továbbít",
    "továbbítsák": "továbbít",
    "tradícióhiányt": "tradícióhiány",
    "tradíciót": "tradíció",
    "tragikusnak": "tragikus",
    "tragédiájának": "tragédia",
    "tragédiáját": "tragédia",
    "tragédiák": "tragédia",
    "traktálják": "traktál",
    "transzformátorházat": "transzformátorház",
    "transzparensek": "transzparens",
    "transzponálhatóvá": "transzponálható",
    "transzport": "transzpor",
    "tranzakcióhoz": "tranzakció",
    "tranzakcióra": "tranzakció",
    "tranzakcióval": "tranzakció",
    "trappolása": "trappolás",
    "trikóját": "trikó",
    "trombitaszóval": "trombitaszó",
    "trágyadombbá": "trágyadomb",
    "trágyahordáshoz": "trágyahordás",
    "trágyát": "trágya",
    "trágyává": "trágya",
    "trágárságot": "trágárság",
    "tréfaként": "tréfa",
    "tréfálkozásait": "tréfálkozás",
    "tréfálkozásra": "tréfálkozás",
    "tréfált": "tréfál",
    "tréfára": "tréfa",
    "tréfásan": "tréfás",
    "tréfát": "tréfa",
    "trófeái": "trófea",
    "trófeák": "trófea",
    "trófeát": "trófea",
    "trónról": "trón",
    "trükkel": "trükk",
    "trükkfilmekben": "trükkfilm",
    "trükkök": "trükk",
    "trükköt": "trükk",
    "tucatjait": "tucat",
    "tucatszor": "tucat",
    "tudakozódott": "tudakozódik",
    "tudata": "tudat",
    "tudatalattin": "tudatalatti",
    "tudatba": "tudat",
    "tudatban": "tudat",
    "tudatlanságnak": "tudatlanság",
    "tudatlanságot": "tudatlanság",
    "tudatlanságra": "tudatlanság",
    "tudatomban": "tudat",
    "tudaton": "tudat",
    "tudatosan": "tudatos",
    "tudatosnak": "tudatos",
    "tudatosságra": "tudatosság",
    "tudatosuljon": "tudatosul",
    "tudatosította": "tudatosít",
    "tudatta": "tudat",
    "tudattal": "tudat",
    "tudattalanságot": "tudattalanság",
    "tudattól": "tudat",
    "tudatukban": "tudat",
    "tudatunk": "tudat",
    "tudatunkban": "tudat",
    "tudatunkon": "tudat",
    "tudatába": "tudat",
    "tudatában": "tudat",
    "tudatából": "tudat",
    "tudatára": "tudat",
    "tudatát": "tudat",
    "tudatától": "tudat",
    "tudhassák": "tudhat",
    "tudhatja": "tudhat",
    "tudhatjuk": "tudhat",
    "tudhatná": "tudhat",
    "tudhatnák": "tudhat",
    "tudhatod": "tudhat",
    "tudhatom": "tudhat",
    "tudhatta": "tudhat",
    "tudhattok": "tudhat",
    "tudhattunk": "tudhat",
    "tudhatták": "tudhat",
    "tudja": "tud",
    "tudjak": "tud",
    "tudjam": "tud",
    "tudjanak": "tud",
    "tudjon": "tud",
    "tudjuk": "tud",
    "tudják": "tud",
    "tudjátok": "tud",
    "tudna": "tud",
    "tudnak": "tud",
    "tudni": "tud",
    "tudnia": "tud",
    "tudniuk": "tud",
    "tudnod": "tud",
    "tudnunk": "tud",
    "tudná": "tud",
    "tudnád": "tud",
    "tudnák": "tud",
    "tudnál": "tud",
    "tudnálak": "tud",
    "tudnám": "tud",
    "tudnának": "tud",
    "tudnánk": "tud",
    "tudnátok": "tud",
    "tudnék": "tud",
    "tudod": "tud",
    "tudok": "tud",
    "tudom": "tud",
    "tudománya": "tudomány",
    "tudománynak": "tudomány",
    "tudományok": "tudomány",
    "tudományosan": "tudományos",
    "tudományosnak": "tudományos",
    "tudományra": "tudomány",
    "tudományt": "tudomány",
    "tudományágban": "tudományág",
    "tudomása": "tudomás",
    "tudomásomra": "tudomás",
    "tudomást": "tudomás",
    "tudomásul": "tudomás",
    "tudomására": "tudomás",
    "tudott": "tud",
    "tudsz": "tud",
    "tudta": "tud",
    "tudtad": "tud",
    "tudtak": "tud",
    "tudtam": "tud",
    "tudtok": "tud",
    "tudtommal": "tudta",
    "tudtuk": "tudta",
    "tudtunk": "tudta",
    "tudták": "tudta",
    "tudtál": "tud",
    "tudtára": "tudta",
    "tudunk": "tud",
    "tudása": "tudás",
    "tudásnak": "tudás",
    "tudásom": "tudás",
    "tudással": "tudás",
    "tudásunk": "tudás",
    "tudásunkat": "tudás",
    "tudásának": "tudás",
    "tudásáról": "tudás",
    "tudását": "tudás",
    "tudók": "tudó",
    "tudósa": "tudós",
    "tudósai": "tudós",
    "tudósok": "tudós",
    "tudósokból": "tudós",
    "tudósokra": "tudós",
    "tudóst": "tudós",
    "tudóstársai": "tudóstárs",
    "tudósításoknál": "tudósítás",
    "tudósítást": "tudósítás",
    "tudósítója": "tudósító",
    "tudósítójának": "tudósító",
    "tudósítók": "tudósító",
    "tudósítónk": "tudósító",
    "tulajdonba": "tulajdon",
    "tulajdonban": "tulajdon",
    "tulajdonformák": "tulajdonformá",
    "tulajdonhoz": "tulajdon",
    "tulajdonjoga": "tulajdonjog",
    "tulajdonjogát": "tulajdonjog",
    "tulajdonképp": "tulajdon",
    "tulajdonképpen": "tulajdon",
    "tulajdonnal": "tulajdon",
    "tulajdonok": "tulajdon",
    "tulajdonokat": "tulajdon",
    "tulajdonosa": "tulajdonos",
    "tulajdonosai": "tulajdonos",
    "tulajdonosaik": "tulajdonos",
    "tulajdonosaira": "tulajdonos",
    "tulajdonosakkal": "tulajdonos",
    "tulajdonosaként": "tulajdonos",
    "tulajdonoshoz": "tulajdonos",
    "tulajdonosként": "tulajdonos",
    "tulajdonosnál": "tulajdonos",
    "tulajdonosok": "tulajdonos",
    "tulajdonosokat": "tulajdonos",
    "tulajdonosoknak": "tulajdonos",
    "tulajdonost": "tulajdonos",
    "tulajdonosának": "tulajdonos",
    "tulajdonosát": "tulajdonos",
    "tulajdonosával": "tulajdonos",
    "tulajdonra": "tulajdon",
    "tulajdonrésszel": "tulajdonrész",
    "tulajdonrészeket": "tulajdonrész",
    "tulajdonrészhez": "tulajdonrész",
    "tulajdonrészért": "tulajdonrész",
    "tulajdonrészétől": "tulajdonrész",
    "tulajdonságai": "tulajdonság",
    "tulajdonságokat": "tulajdonság",
    "tulajdonságára": "tulajdonság",
    "tulajdonságát": "tulajdonság",
    "tulajdont": "tulajdon",
    "tulajdonukban": "tulajdon",
    "tulajdonviszonyának": "tulajdonviszony",
    "tulajdonába": "tulajdon",
    "tulajdonában": "tulajdon",
    "tulajdonának": "tulajdon",
    "tulajdonát": "tulajdon",
    "tulajdonítanak": "tulajdonít",
    "tulajdonítani": "tulajdonít",
    "tulajdonított": "tulajdonít",
    "tulkot": "tulok",
    "turisták": "turista",
    "turistáknak": "turista",
    "turizmusból": "turizmus",
    "turizmust": "turizmus",
    "turnusba": "turnus",
    "turnézik": "turnéz",
    "tusa": "tus",
    "tusakodók": "tusakodó",
    "tussal": "tus",
    "tuszkolt": "tuszkol",
    "tuszkolunk": "tuszkol",
    "tutajon": "tutaj",
    "tv-ben": "tv",
    "tv-operatőrt": "tv-operatőr",
    "tyúkfejet": "tyúkfej",
    "tyúkjai": "tyúk",
    "tyúkot": "tyúk",
    "tyúktól": "tyúk",
    "tyúkólban": "tyúkól",
    "táblabírákat": "táblabíró",
    "táblába": "tábla",
    "táblából": "tábla",
    "táblácskák": "táblácská",
    "táblák": "tábla",
    "táblákat": "tábla",
    "táblákon": "tábla",
    "táblán": "tábla",
    "táblának": "tábla",
    "táblára": "tábla",
    "tábláról": "tábla",
    "táblát": "tábla",
    "táblázattal": "táblázat",
    "táborba": "tábor",
    "táborban": "tábor",
    "táborból": "tábor",
    "táborhelyet": "táborhely",
    "tábornoknak": "tábornok",
    "táborokban": "tábor",
    "táborozott": "táborozik",
    "táborozások": "táborozás",
    "táborra": "tábor",
    "tábort": "tábor",
    "tábortüzet": "tábortűz",
    "táborát": "tábor",
    "táborával": "tábor",
    "tágabb": "tág",
    "tágassága": "tágasság",
    "tágasságáért": "tágasság",
    "tágra": "tág",
    "tágult": "tágul",
    "tágultak": "tágult",
    "tágított": "tágít",
    "tájak": "táj",
    "tájat": "táj",
    "tájba": "táj",
    "tájban": "táj",
    "tájegységére": "tájegység",
    "tájképek": "tájkép",
    "táján": "táj",
    "tájáról": "táj",
    "tájékozatlansága": "tájékozatlanság",
    "tájékozatlanságát": "tájékozatlanság",
    "tájékozatta": "tájékozat",
    "tájékozott": "tájékoz",
    "tájékozottak": "tájékozott",
    "tájékozottsággal": "tájékozottság",
    "tájékoztatják": "tájékoztat",
    "tájékoztatnak": "tájékoztat",
    "tájékoztatta": "tájékoztat",
    "tájékoztatása": "tájékoztatás",
    "tájékoztatások": "tájékoztatás",
    "tájékoztatást": "tájékoztatás",
    "tájékoztatója": "tájékoztató",
    "tájékoztatóján": "tájékoztató",
    "tájékoztatón": "tájékoztató",
    "tájékoztatót": "tájékoztató",
    "tájékozódhassam": "tájékozódhat",
    "tájékozódjanak": "tájékozódik",
    "tájékozódni": "tájékozódik",
    "tájékozódniuk": "tájékozódik",
    "tájékozódtam": "tájékozódik",
    "tájékozódásra": "tájékozódás",
    "tálacskák": "tálacská",
    "tálain": "tál",
    "tálalja": "tálalj",
    "tálalnak": "tálal",
    "tálalt": "tálal",
    "tálcaoszlopról": "tálcaoszlop",
    "tálcáikat": "tálca",
    "tálcája": "tálca",
    "tálcájához": "tálca",
    "tálcájáról": "tálca",
    "tálcáját": "tálca",
    "tálcák": "tálca",
    "tálcával": "tálca",
    "tálkáját": "tálka",
    "tálkákat": "tálka",
    "támadhatnának": "támadhat",
    "támadhatókká": "támadható",
    "támadja": "támad",
    "támadjon": "támad",
    "támadják": "támad",
    "támadni": "támad",
    "támadt": "támad",
    "támadtak": "támadt",
    "támadták": "támad",
    "támadása": "támadás",
    "támadásai": "támadás",
    "támadásba": "támadás",
    "támadásnak": "támadás",
    "támadásokat": "támadás",
    "támadásokhoz": "támadás",
    "támadásra": "támadás",
    "támadásról": "támadás",
    "támadást": "támadás",
    "támadásából": "támadás",
    "támadók": "támadó",
    "támaszkodhassanak": "támaszkodhat",
    "támaszkodni": "támaszkodik",
    "támaszkodott": "támaszkodik",
    "támaszpontot": "támaszpont",
    "támasztaná": "támaszt",
    "támaszthatnak": "támaszthat",
    "támaszthatta": "támaszthat",
    "támasztja": "támaszt",
    "támasztott": "támaszt",
    "támasztotta": "támaszt",
    "támasztották": "támaszt",
    "támlájára": "támla",
    "támogatja": "támogat",
    "támogatják": "támogat",
    "támogatni": "támogat",
    "támogatniuk": "támogat",
    "támogatnák": "támogat",
    "támogatott": "támogat",
    "támogatottak": "támogatott",
    "támogatottjai": "támogatott",
    "támogatottsága": "támogatottság",
    "támogatta": "támogat",
    "támogattak": "támogat",
    "támogattuk": "támogat",
    "támogatták": "támogat",
    "támogatása": "támogatás",
    "támogatásból": "támogatás",
    "támogatáscsökkentést": "támogatáscsökkentés",
    "támogatásnak": "támogatás",
    "támogatások": "támogatás",
    "támogatásokat": "támogatás",
    "támogatásokból": "támogatás",
    "támogatást": "támogatás",
    "támogatásában": "támogatás",
    "támogatásának": "támogatás",
    "támogatására": "támogatás",
    "támogatását": "támogatás",
    "támogatásával": "támogatás",
    "támogatója": "támogató",
    "támpontot": "támpont",
    "táncba": "tánc",
    "táncféléhez": "táncféle",
    "táncnál": "tánc",
    "táncoljon": "táncol",
    "táncolni": "táncol",
    "táncosa": "táncos",
    "táncot": "tánc",
    "táncra": "tánc",
    "tántoríthatja": "tántoríthat",
    "tántorította": "tántorít",
    "tántorították": "tántorít",
    "tányérján": "tányér",
    "tányérjáról": "tányér",
    "tányérnyalói": "tányérnyaló",
    "tányéromba": "tányér",
    "tányérral": "tányér",
    "tányért": "tányér",
    "táplálhatnának": "táplálhat",
    "táplálkozni": "táplálkozik",
    "táplálkozott": "táplálkozik",
    "táplálkozásának": "táplálkozás",
    "táplálni": "táplál",
    "táplált": "táplál",
    "táplálták": "táplál",
    "tápláléka": "táplálék",
    "táplálékom": "táplálék",
    "táplálékot": "táplálék",
    "tápászkodott": "tápászkodik",
    "tápászkodásnak": "tápászkodás",
    "tárcsázhatott": "tárcsázhat",
    "tárcsázta": "tárcsáz",
    "tárcája": "tárca",
    "tárcámban": "tárca",
    "tárcánál": "tárca",
    "tárggyal": "tárgy",
    "tárgya": "tárgy",
    "tárgyai": "tárgy",
    "tárgyait": "tárgy",
    "tárgyak": "tárgy",
    "tárgyakat": "tárgy",
    "tárgyakban": "tárgy",
    "tárgyakból": "tárgy",
    "tárgyaknak": "tárgy",
    "tárgyakra": "tárgy",
    "tárgyalja": "tárgyalj",
    "tárgyaljanak": "tárgyal",
    "tárgyaljon": "tárgyalj",
    "tárgyaljuk": "tárgyalj",
    "tárgyalják": "tárgyal",
    "tárgyalnak": "tárgyal",
    "tárgyalni": "tárgyal",
    "tárgyalnia": "tárgyal",
    "tárgyalnának": "tárgyal",
    "tárgyalt": "tárgyal",
    "tárgyalta": "tárgyal",
    "tárgyaltak": "tárgyalt",
    "tárgyaltam": "tárgyalt",
    "tárgyalása": "tárgyalás",
    "tárgyalásairól": "tárgyalás",
    "tárgyalásait": "tárgyalás",
    "tárgyalások": "tárgyalás",
    "tárgyalásokat": "tárgyalás",
    "tárgyalásokba": "tárgyalás",
    "tárgyalásokkal": "tárgyalás",
    "tárgyalásokon": "tárgyalás",
    "tárgyalásokra": "tárgyalás",
    "tárgyalásoktól": "tárgyalás",
    "tárgyaláson": "tárgyalás",
    "tárgyalásra": "tárgyalás",
    "tárgyalást": "tárgyalás",
    "tárgyalásuk": "tárgyalás",
    "tárgyalásának": "tárgyalás",
    "tárgyalók": "tárgyaló",
    "tárgyalópartnerei": "tárgyalópartner",
    "tárgyalópartnereinkét": "tárgyalópartner",
    "tárgyalópartnerénél": "tárgyalópartner",
    "tárgyalóteremben": "tárgyalóterem",
    "tárgyalótermek": "tárgyalóterem",
    "tárgyat": "tárgy",
    "tárgyban": "tárgy",
    "tárgyból": "tárgy",
    "tárgyilagosabban": "tárgyilagos",
    "tárgyilagosan": "tárgyilagos",
    "tárgykörét": "tárgykör",
    "tárgynak": "tárgy",
    "tárgynál": "tárgy",
    "tárgyra": "tárgy",
    "tárgyról": "tárgy",
    "tárgytól": "tárgy",
    "tárgyuk": "tárgy",
    "tárgyukat": "tárgy",
    "tárgyával": "tárgy",
    "tárgyává": "tárgy",
    "tárja": "tár",
    "tárlata": "tárlat",
    "tárlatból": "tárlat",
    "tárlatodat": "tárlat",
    "tárlatot": "tárlat",
    "tárlatról": "tárlat",
    "tárlattól": "tárlat",
    "tárlatuk": "tárlat",
    "tárlatukról": "tárlat",
    "tárlatán": "tárlat",
    "tárlatának": "tárlat",
    "tárlatért": "tárlat",
    "tárnában": "tárna",
    "tárolnak": "tárol",
    "tárolt": "tárol",
    "tároltak": "tárolt",
    "tárolták": "tárol",
    "tárolón": "tároló",
    "társadalmak": "társadalom",
    "társadalmat": "társadalom",
    "társadalmunk": "társadalom",
    "társadalmunkban": "társadalom",
    "társadalomban": "társadalom",
    "társadalombiztosításnak": "társadalombiztosítás",
    "társadalombiztosítást": "társadalombiztosítás",
    "társadalommal": "társadalom",
    "társadalomnak": "társadalom",
    "társadalomról": "társadalom",
    "társadalomtudományok": "társadalomtudomány",
    "társaikat": "társ",
    "társaiktól": "társ",
    "társaim": "társ",
    "társainak": "társ",
    "társaink": "társ",
    "társait": "társ",
    "társakkal": "társakk",
    "társalgott": "társalog",
    "társalgásban": "társalgás",
    "társalgáshoz": "társalgás",
    "társalgást": "társalgás",
    "társalogtak": "társalog",
    "társasházakat": "társasház",
    "társasága": "társaság",
    "társaságban": "társaság",
    "társaságból": "társaság",
    "társasággal": "társaság",
    "társaságnak": "társaság",
    "társaságok": "társaság",
    "társaságokat": "társaság",
    "társaságokban": "társaság",
    "társaságoknak": "társaság",
    "társaságoknál": "társaság",
    "társaságot": "társaság",
    "társaságában": "társaság",
    "társaságára": "társaság",
    "társelnök-vezérigazgatója": "társelnök-vezérigazgató",
    "társelnökei": "társelnök",
    "társigazgatóját": "társigazgató",
    "társnak": "társ",
    "társszakszervezetek": "társszakszervezet",
    "társszerzője": "társszerző",
    "társtulajdonosaként": "társtulajdonos",
    "társulata": "társulat",
    "társulatai": "társulat",
    "társulatnak": "társulat",
    "társulatnál": "társulat",
    "társulatok": "társulat",
    "társulatokkal": "társulat",
    "társulatunk": "társulat",
    "társulatát": "társulat",
    "társulásban": "társulás",
    "tárt": "tár",
    "tárta": "tár",
    "tártak": "tárt",
    "tárulnak": "tárul",
    "táskában": "táska",
    "táskák": "táska",
    "táskát": "táska",
    "táv-sajtókonferenciát": "táv-sajtókonferencia",
    "távfűtésről": "távfűtés",
    "távfűtéstől": "távfűtés",
    "távfűtését": "távfűtés",
    "távfűtők": "távfűtő",
    "távfűtőművek": "távfűtőmű",
    "távfűtőműveknek": "távfűtőmű",
    "távfűtőrendszerről": "távfűtőrendszer",
    "távhőszolgáltatásra": "távhőszolgáltatás",
    "távhőszolgáltatásról": "távhőszolgáltatás",
    "táviratban": "távirat",
    "távlatban": "távlat",
    "távlatot": "távlat",
    "távlatában": "távlat",
    "távlatából": "távlat",
    "távolabb": "távol",
    "távolabbról": "távol",
    "távolban": "távol",
    "távolból": "távol",
    "távoliak": "távoli",
    "távolian": "távoli",
    "távolit": "távoli",
    "távolléte": "távollét",
    "távollétemben": "távollét",
    "távollétük": "távollét",
    "távolmaradásuk": "távolmaradás",
    "távolról": "távol",
    "távolságban": "távolság",
    "távolságból": "távolság",
    "távolságokba": "távolság",
    "távolságra": "távolság",
    "távolságáról": "távolság",
    "távolította": "távolít",
    "távon": "táv",
    "távot": "táv",
    "távozik": "távoz",
    "távoznak": "távozik",
    "távozni": "távozik",
    "távoznod": "távozik",
    "távoznotok": "távozik",
    "távozol": "távozik",
    "távozott": "távozik",
    "távozz": "távozik",
    "távozzon": "távozik",
    "távozzék": "távozik",
    "távozása": "távozás",
    "távozásával": "távozás",
    "távra": "táv",
    "tébolyodott": "tébolyodik",
    "téged": "te",
    "téglafalai": "téglafal",
    "téglafalaival": "téglafal",
    "téglalapját": "téglalap",
    "téglaszínűek": "téglaszínű",
    "téglából": "tégla",
    "téglák": "tégla",
    "télben": "tél",
    "télen": "tél",
    "télidőben": "télidő",
    "télikabátosan": "télikabátos",
    "télikertből": "télikert",
    "témaköreit": "témakör",
    "témába": "téma",
    "témában": "téma",
    "témához": "téma",
    "témája": "téma",
    "témákat": "téma",
    "témáktól": "téma",
    "témánkban": "téma",
    "témáról": "téma",
    "témát": "téma",
    "témával": "téma",
    "témává": "téma",
    "ténnyel": "tény",
    "ténye": "tény",
    "tények": "tény",
    "tényeket": "tény",
    "tényeknek": "tény",
    "tényekre": "tény",
    "tényekről": "tény",
    "tényezői": "tényező",
    "tényezők": "tényező",
    "tényezőnek": "tényező",
    "tényezőre": "tényező",
    "tényezőt": "tényező",
    "tényezővé": "tényező",
    "ténykedése": "ténykedés",
    "ténylegesen": "tényleges",
    "tényre": "tény",
    "tényt": "tény",
    "ténytől": "tény",
    "tényén": "tény",
    "tényének": "tény",
    "tépdesték": "tépdes",
    "tépett": "tép",
    "tépjék": "tép",
    "tépjük": "tép",
    "tépnek": "tép",
    "tépni": "tép",
    "tépte": "tép",
    "tépték": "tép",
    "térbe": "tér",
    "térben": "tér",
    "térde": "térd",
    "térdei": "térd",
    "térdeket": "térd",
    "térdelt": "térdel",
    "térdeltek": "térdelt",
    "térdem": "térd",
    "térden": "térd",
    "térdig": "térd",
    "térdre": "térd",
    "térdén": "térd",
    "térdének": "térd",
    "térdénél": "térd",
    "térdére": "térd",
    "térdéről": "térd",
    "térdét": "térd",
    "térdükön": "térd",
    "téren": "tér",
    "térfogatába": "térfogat",
    "térhetett": "térhet",
    "térhettünk": "térhet",
    "térhetünk": "térhét",
    "téri": "tér",
    "tériszonya": "tériszony",
    "térjen": "tér",
    "térjünk": "tér",
    "térképe": "térkép",
    "térképen": "térkép",
    "térképet": "térkép",
    "térképezte": "térképez",
    "térképre": "térkép",
    "térképén": "térkép",
    "térképét": "térkép",
    "térnek": "tér",
    "térni": "tér",
    "térnyerését": "térnyerés",
    "térre": "tér",
    "térsz": "tér",
    "térségbe": "térség",
    "térségben": "térség",
    "térségből": "térség",
    "térségei": "térség",
    "térségeivel": "térség",
    "térségekben": "térség",
    "térséget": "térség",
    "térségre": "térség",
    "térségében": "térség",
    "térségén": "térség",
    "térségének": "térség",
    "tért": "tér",
    "tértek": "tért",
    "térítenie": "térít",
    "térítette": "térít",
    "térítéskötelessé": "térítésköteles",
    "térüljünk": "térül",
    "térültek": "térül",
    "tésztacsináláshoz": "tésztacsinálás",
    "tésztalevest": "tésztaleves",
    "tésztában": "tészta",
    "tésztából": "tészta",
    "tésztát": "tészta",
    "tételben": "tétel",
    "tétele": "tétel",
    "tételei": "tétel",
    "tételek": "tétel",
    "tételeket": "tétel",
    "tételekre": "tétel",
    "tételekről": "tétel",
    "tételezte": "tételez",
    "tételkönyvbe": "tételkönyv",
    "tételt": "tétel",
    "tételének": "tétel",
    "tételét": "tétel",
    "tételével": "tétel",
    "tétje": "tét",
    "tétlenül": "tétlen",
    "tétmérkőzésre": "tétmérkőzés",
    "tétován": "tétova",
    "tétovázott": "tétovázik",
    "tétováztunk": "tétovázik",
    "tévedett": "téved",
    "tévedhetne": "tévedhet",
    "tévedsz": "téved",
    "tévedt": "téved",
    "tévedtem": "tévedt",
    "tévedtünk": "tévedt",
    "tévedéseiből": "tévedés",
    "tévedéseket": "tévedés",
    "tévedésekre": "tévedés",
    "tévedésemnek": "tévedés",
    "tévedésre": "tévedés",
    "tévedést": "tévedés",
    "tévesek": "téves",
    "tévesen": "téves",
    "tévessze": "téveszt",
    "tévesszenek": "téveszt",
    "tévesztették": "tévesztet",
    "tévében": "tévé",
    "tévéelnökkel": "tévéelnök",
    "tévéjátékot": "tévéjáték",
    "tévénézők": "tévénéző",
    "tévéstábok": "tévéstáb",
    "tévét": "tévé",
    "típusa": "típus",
    "típusai": "típus",
    "típusait": "típus",
    "típusok": "típus",
    "típusokat": "típus",
    "típust": "típus",
    "típusát": "típus",
    "típusúak": "típusú",
    "tízen": "tíz",
    "tízezredszer": "tízezred",
    "tízezrével": "tízezer",
    "tízkor": "tíz",
    "tízméternyire": "tízméternyi",
    "tízszeresen": "tízszeres",
    "tízszeresének": "tízszeres",
    "tízzel": "tíz",
    "tízóraira": "tízórai",
    "tócsákat": "tócsa",
    "tócsákba": "tócsa",
    "tódult": "tódul",
    "tódultak": "tódult",
    "tónusa": "tónus",
    "tónusainak": "tónus",
    "tónusban": "tónus",
    "tónusokkal": "tónus",
    "tórészlete": "tórészlet",
    "többe": "több",
    "többek": "több",
    "többektől": "több",
    "többel": "több",
    "többen": "több",
    "többese": "többes",
    "többet": "több",
    "többiek": "többi",
    "többieken": "többi",
    "többieket": "többi",
    "többiekkel": "többi",
    "többieknek": "többi",
    "többieké": "többi",
    "többinek": "többi",
    "többinél": "többi",
    "többire": "többi",
    "többiről": "többi",
    "többit": "többi",
    "többitől": "többi",
    "többivel": "többi",
    "többié": "többi",
    "többlete": "többlet",
    "többletköltségeit": "többletköltség",
    "többletköltségeket": "többletköltség",
    "többlettámogatást": "többlettámogatás",
    "többnyire": "többnyi",
    "többre": "több",
    "többszörösét": "többszörös",
    "többsége": "többség",
    "többséget": "többség",
    "többséggel": "többség",
    "többséghez": "többség",
    "többségében": "többség",
    "többségének": "többség",
    "többségét": "többség",
    "többségéé": "többség",
    "többségük": "többség",
    "többségükben": "többség",
    "többségüket": "többség",
    "többé": "több",
    "tökmaghéjjal": "tökmaghéj",
    "tökéletesebb": "tökéletes",
    "tökéletesebben": "tökéletes",
    "tökéletesen": "tökéletes",
    "tökéletessé": "tökéletes",
    "tökéletességükbe": "tökéletesség",
    "tökéletlenül": "tökéletlen",
    "tökélyre": "tökély",
    "tölcsérrel": "tölcsér",
    "töltenek": "tölt",
    "tölteni": "tölt",
    "töltenie": "tölt",
    "töltetekkel": "töltet",
    "töltetett": "töltet",
    "tölthetett": "tölthet",
    "tölti": "tölt",
    "töltsék": "tölt",
    "töltésen": "töltés",
    "töltésig": "töltés",
    "töltésről": "töltés",
    "töltök": "tölt",
    "töltött": "tölt",
    "töltötte": "tölt",
    "töltöttek": "töltött",
    "töltötték": "tölt",
    "töltöttük": "töltött",
    "töltöttünk": "töltött",
    "töltőtolla": "töltőtoll",
    "töltőtollaikat": "töltőtoll",
    "töltőtollat": "töltőtoll",
    "tömbben": "tömb",
    "tömbtelkeken": "tömbtelek",
    "tömbön": "tömb",
    "tömbönként": "tömb",
    "tömegben": "tömeg",
    "tömegbúzája": "tömegbúza",
    "tömegből": "tömeg",
    "tömege": "tömeg",
    "tömegei": "tömeg",
    "tömegeinek": "tömeg",
    "tömegek": "tömeg",
    "tömegeket": "tömeg",
    "tömegeknek": "tömeg",
    "tömegekéhez": "tömegeke",
    "tömegemberek": "tömegember",
    "tömegen": "tömeg",
    "tömeget": "tömeg",
    "tömeggel": "tömeg",
    "tömeggyilkosságok": "tömeggyilkosság",
    "tömeggyűlésen": "tömeggyűlés",
    "tömeggé": "tömeg",
    "tömegközlekedéssel": "tömegközlekedés",
    "tömegmészárlásra": "tömegmészárlás",
    "tömegnek": "tömeg",
    "tömegsírjait": "tömegsír",
    "tömegsírok": "tömegsír",
    "tömegsírokat": "tömegsír",
    "tömegsírokra": "tömegsír",
    "tömegéhez": "tömeg",
    "tömegén": "tömeg",
    "tömegét": "tömeg",
    "tömegétől": "tömeg",
    "tömegével": "tömeg",
    "tömjénszagában": "tömjénszag",
    "tömte": "töm",
    "tömtek": "töm",
    "töményen": "tömény",
    "tömöríteni": "tömörít",
    "tömöttek": "tömött",
    "tönkre": "tönk",
    "tönkrement": "tönkremegy",
    "tönkreteheti": "tönkretehet",
    "tönkreteszi": "tönkretesz",
    "tönkretették": "tönkretesz",
    "tönkretétele": "tönkretétel",
    "tönkrezúzhatja": "tönkrezúzhat",
    "töprengene": "töpreng",
    "töprengeni": "töpreng",
    "töprengett": "töpreng",
    "töprengtem": "töpreng",
    "töprengtünk": "töpreng",
    "töprengéseit": "töprengés",
    "töprengések": "töprengés",
    "töprengésre": "töprengés",
    "törd": "törik",
    "töredezett": "töredezik",
    "töredéke": "töredék",
    "töredékei": "töredék",
    "töredékeit": "töredék",
    "töredékek": "töredék",
    "töredéket": "töredék",
    "töredékére": "töredék",
    "töredékét": "töredék",
    "törekednek": "törekedik",
    "törekedni": "törekedik",
    "törekedtem": "törekedik",
    "töreket": "törek",
    "törekvéseit": "törekvés",
    "törekvéshez": "törekvés",
    "törekvéssel": "törekvés",
    "törekvését": "törekvés",
    "törhetetlenek": "törhetetlen",
    "törheti": "törhet",
    "törhetnék": "törhet",
    "töri": "törik",
    "törik": "tör",
    "törjön": "törik",
    "törjük": "törik",
    "törlendők": "törlendő",
    "törleszteni": "törleszt",
    "törlesztenie": "törleszt",
    "törleszteniük": "törleszt",
    "törlesztette": "törlesztet",
    "törlesztik": "törleszt",
    "törlesztéseként": "törlesztés",
    "törlesztésére": "törlesztés",
    "törlik": "töröl",
    "törléshez": "törlés",
    "törlést": "törlés",
    "törlésére": "törlés",
    "törmelékkel": "törmelék",
    "törni": "törik",
    "törnie": "törik",
    "tört": "törik",
    "törte": "törik",
    "törtek": "tört",
    "törtetett": "törtet",
    "törtetnek": "törtet",
    "törtettek": "törtet",
    "történelembe": "történelem",
    "történelemben": "történelem",
    "történelemből": "történelem",
    "történelemkönyve": "történelemkönyv",
    "történelemkönyvek": "történelemkönyv",
    "történelemkönyvekben": "történelemkönyv",
    "történelemkönyvet": "történelemkönyv",
    "történelemkönyvnek": "történelemkönyv",
    "történelmen": "történelem",
    "történelmet": "történelem",
    "történelmében": "történelem",
    "történelmének": "történelem",
    "története": "történet",
    "történetei": "történet",
    "történeteket": "történet",
    "történetesen": "történetes",
    "történetet": "történet",
    "történetnek": "történet",
    "történetre": "történet",
    "történetében": "történet",
    "történetéhez": "történet",
    "történetének": "történet",
    "történetéről": "történet",
    "történetét": "történet",
    "történetével": "történet",
    "történetírók": "történetíró",
    "történetük": "történet",
    "történetünk": "történet",
    "történhetett": "történhet",
    "történhetik": "történhet",
    "történhetne": "történhet",
    "történhetnek": "történhet",
    "történhettek": "történhet",
    "történjen": "történik",
    "történjenek": "történik",
    "történjék": "történik",
    "történnek": "történik",
    "történni": "történik",
    "történnie": "történik",
    "történt": "történik",
    "történtek": "történt",
    "történteket": "történtek",
    "történtekről": "történtek",
    "történtekért": "történtek",
    "történtté": "történt",
    "történéseivel": "történés",
    "történésnek": "történés",
    "történőben": "történő",
    "törtük": "törik",
    "törtünk": "tört",
    "törvénnyel": "törvény",
    "törvényalkotáskor": "törvényalkotás",
    "törvényalkotók": "törvényalkotó",
    "törvénybe": "törvény",
    "törvényben": "törvény",
    "törvénye": "törvény",
    "törvényei": "törvény",
    "törvényeiket": "törvény",
    "törvényeit": "törvény",
    "törvények": "törvény",
    "törvényeket": "törvény",
    "törvényekhez": "törvény",
    "törvényellenesnek": "törvényellenes",
    "törvényen": "törvény",
    "törvényesen": "törvényes",
    "törvényessége": "törvényesség",
    "törvényességen": "törvényesség",
    "törvényességéről": "törvényesség",
    "törvényhozók": "törvényhozó",
    "törvényhozókat": "törvényhozó",
    "törvényjavaslatban": "törvényjavaslat",
    "törvényjavaslatot": "törvényjavaslat",
    "törvényjavaslatról": "törvényjavaslat",
    "törvénykeresőket": "törvénykereső",
    "törvényként": "törvény",
    "törvényre": "törvény",
    "törvényről": "törvény",
    "törvényszerűen": "törvényszerű",
    "törvénysértőnek": "törvénysértő",
    "törvényt": "törvény",
    "törvénytől": "törvény",
    "törvényének": "törvény",
    "törvényét": "törvény",
    "törvényünk": "törvény",
    "törzse": "törzs",
    "törzsrészvényét": "törzsrészvény",
    "törzsállományának": "törzsállomány",
    "törzsétől": "törzs",
    "török": "törik",
    "törökpincéknek": "törökpince",
    "törökül": "török",
    "törölhették": "törölhet",
    "törölni": "töröl",
    "törölnie": "töröl",
    "törölnünk": "töröl",
    "törölték": "töröl",
    "törött": "törik",
    "töröttek": "törött",
    "töröttnek": "törött",
    "törülközőkkel": "törülköző",
    "törülközőt": "törülköző",
    "törődhetek": "törődhet",
    "törődnek": "törődik",
    "törődni": "törődik",
    "törődnötök": "törődik",
    "törődtek": "törődik",
    "törődtünk": "törődik",
    "törődöm": "törődik",
    "törődött": "törődik",
    "törődünk": "törődik",
    "törők": "törő",
    "tövig": "tő",
    "tövisben": "tövis",
    "tövébe": "tő",
    "tövében": "tő",
    "tövén": "tő",
    "túlcsordult": "túlcsordul",
    "túlestek": "túlesik",
    "túlestem": "túlesik",
    "túlestünk": "túlesik",
    "túlfejlett": "túlfejlik",
    "túlfinanszírozni": "túlfinanszíroz",
    "túlfűtött": "túlfűt",
    "túlhajtott": "túlhajt",
    "túlhaladunk": "túlhalad",
    "túlharsogja": "túlharsog",
    "túljegyzik": "túljegyez",
    "túljutottam": "túljutott",
    "túllépni": "túllép",
    "túlmennek": "túlmegy",
    "túlmenően": "túlmenő",
    "túlméretezettnek": "túlméretezett",
    "túlméretezettségének": "túlméretezettség",
    "túlméreteznénk": "túlméretez",
    "túlnyomórészt": "túlnyomórész",
    "túlnépesedésnek": "túlnépesedés",
    "túloldalon": "túloldal",
    "túloldalára": "túloldal",
    "túlozta": "túloz",
    "túloztak": "túloz",
    "túlozza": "túloz",
    "túlságosan": "túlságos",
    "túlsúlyban": "túlsúly",
    "túlsúlyt": "túlsúly",
    "túlteljesítették": "túlteljesítet",
    "túlteljesítéséről": "túlteljesítés",
    "túlterhelt": "túlterhel",
    "túlterveznek": "túltervez",
    "túltett": "túltesz",
    "túltettem": "túltett",
    "túlzott": "túloz",
    "túlzottan": "túlzott",
    "túlzottnak": "túlzott",
    "túlzással": "túlzás",
    "túláradásának": "túláradás",
    "túlélni": "túlél",
    "túlélte": "túlél",
    "túléltem": "túlélt",
    "túlélésért": "túlélés",
    "túléléséért": "túlélés",
    "túlélők": "túlélő",
    "túlérett": "túlérik",
    "túlórázott": "túlórázik",
    "túlüvöltötték": "túlüvölt",
    "túrjon": "túr",
    "túrónak": "túró",
    "túrót": "túró",
    "túszként": "túsz",
    "túszok": "túsz",
    "túszokat": "túsz",
    "túszokkal": "túsz",
    "túszt": "túsz",
    "túszul": "túsz",
    "tüdejében": "tüdő",
    "tüdejét": "tüdő",
    "tüdődet": "tüdő",
    "tüdőgyulladásosnak": "tüdőgyulladásos",
    "tükre": "tükör",
    "tükrei": "tükör",
    "tükrein": "tükör",
    "tükrében": "tükör",
    "tükrén": "tükör",
    "tükrözi": "tükrözik",
    "tükrözni": "tükrözik",
    "tükröződni": "tükröződik",
    "tükröződnék": "tükröződik",
    "tükröződött": "tükröződik",
    "tükörbe": "tükör",
    "tükörben": "tükör",
    "tükörből": "tükör",
    "tükörhöz": "tükör",
    "tükörképe": "tükörkép",
    "tükörnek": "tükör",
    "tülekedett": "tülekedik",
    "tüllé": "tüll",
    "tündérek": "tündér",
    "tünedeztek": "tünedezik",
    "tünete": "tünet",
    "tüneteit": "tünet",
    "tüneteket": "tünet",
    "tünetté": "tünet",
    "tünteti": "tüntet",
    "tüntetik": "tüntet",
    "tüntetni": "tüntet",
    "tüntette": "tüntet",
    "tüntettek": "tüntet",
    "tüntették": "tüntet",
    "tüntetésben": "tüntetés",
    "tüntetések": "tüntetés",
    "türelemben": "türelem",
    "türelemmel": "türelem",
    "türelemre": "türelem",
    "türelmesen": "türelmes",
    "türelmetlenkedj": "türelmetlenkedik",
    "türelmetlenné": "türelmetlen",
    "türelmetlenségről": "türelmetlenség",
    "türelmetlenségével": "türelmetlenség",
    "türelmetlenül": "türelmetlen",
    "türelmük": "türelem",
    "türelmüket": "türelem",
    "tüskék": "tüske",
    "tüsszögnie": "tüsszög",
    "tüzelni": "tüzel",
    "tüzeltünk": "tüzelt",
    "tüzelőt": "tüzelő",
    "tüzet": "tűz",
    "tüzérek": "tüzér",
    "tüzérséggel": "tüzérség",
    "tüzétől": "tűz",
    "tőkebefektetések": "tőkebefektetés",
    "tőkeberuházásokat": "tőkeberuházás",
    "tőkeimportnak": "tőkeimport",
    "tőkeinjekciót": "tőkeinjekció",
    "tőkerendezésére": "tőkerendezés",
    "tőkések": "tőkés",
    "tőkéseket": "tőkés",
    "tőkésosztályt": "tőkésosztály",
    "tőkésíthetik": "tőkésíthet",
    "tőkét": "tőke",
    "tőkével": "tőke",
    "tőle": "ő",
    "tőled": "te",
    "tőlem": "én",
    "tőlük": "ők",
    "tőlünk": "mi",
    "tőről": "tő",
    "tőszomszédságában": "tőszomszédság",
    "tőzeg-ganéjt": "tőzeg-ganéj",
    "tőzsdefelügyelethez": "tőzsdefelügyelet",
    "tőzsdenapinál": "tőzsdenapi",
    "tőzsdetagságát": "tőzsdetagság",
    "tőzsdén": "tőzsde",
    "tűhányója": "tűhányó",
    "tűje": "tű",
    "tűnjek": "tűnik",
    "tűnjenek": "tűnik",
    "tűnjék": "tűnik",
    "tűnnek": "tűnik",
    "tűnniük": "tűnik",
    "tűnt": "tűnik",
    "tűntek": "tűnik",
    "tűnődni": "tűnődik",
    "tűnődött": "tűnődik",
    "tűrhetem": "tűrhet",
    "tűrhetetlennek": "tűrhetetlen",
    "tűrhette": "tűrhet",
    "tűrhetően": "tűrhető",
    "tűri": "tűr",
    "tűrik": "tűr",
    "tűrnie": "tűr",
    "tűrt": "tűr",
    "tűrtek": "tűr",
    "tűrték": "tűr",
    "tűrést": "tűrés",
    "tűt": "tű",
    "tűvel": "tű",
    "tűvé": "tű",
    "tűzbe": "tűz",
    "tűzdarabkák": "tűzdarabka",
    "tűzdelt": "tűzdel",
    "tűzdelte": "tűzdel",
    "tűzgömbök": "tűzgömb",
    "tűzhelyen": "tűzhely",
    "tűzre": "tűz",
    "tűzrevalóhoz": "tűzrevaló",
    "tűzrevalója": "tűzrevaló",
    "tűzrevalót": "tűzrevaló",
    "tűzrevalóért": "tűzrevaló",
    "tűzről": "tűz",
    "tűzték": "tűz",
    "tűzzük": "tűz",
    "tűzött": "tűz",
    "uborkásüvegek": "uborkásüveg",
    "udvarban": "udvar",
    "udvarhelyre": "udvarhely",
    "udvariasak": "udvarias",
    "udvariasan": "udvarias",
    "udvarnak": "udvar",
    "udvarok": "udvar",
    "udvarolni": "udvarol",
    "udvaron": "udvar",
    "udvarra": "udvar",
    "udvarán": "udvar",
    "ugranak": "ugrik",
    "ugrani": "ugrik",
    "ugratni": "ugrat",
    "ugratta": "ugrat",
    "ugratásba": "ugratás",
    "ugratást": "ugratás",
    "ugrott": "ugrik",
    "ugrottak": "ugrott",
    "ugrottunk": "ugrott",
    "ugrálhattam": "ugrálhat",
    "ugrálok": "ugrál",
    "ugrált": "ugrál",
    "ugráltak": "ugrált",
    "ugráltatja": "ugráltat",
    "ugrándozással": "ugrándozás",
    "ugrásnál": "ugrás",
    "ugrásokkal": "ugrás",
    "ugyanabban": "ugyanaz",
    "ugyanabból": "ugyanaz",
    "ugyanakkor": "ugyanaz",
    "ugyanannál": "ugyanaz",
    "ugyanarra": "ugyanaz",
    "ugyanarról": "ugyanaz",
    "ugyanazok": "ugyanaz",
    "ugyanazokat": "ugyanaz",
    "ugyanazokból": "ugyanaz",
    "ugyanazokkal": "ugyanaz",
    "ugyanazt": "ugyanaz",
    "ugyanazzal": "ugyanaz",
    "ugyanazért": "ugyanaz",
    "ugyanebben": "ugyanez",
    "ugyanennek": "ugyanez",
    "ugyanennyire": "ugyanennyi",
    "ugyanerre": "ugyanez",
    "ugyanezek": "ugyanez",
    "ugyanezt": "ugyanez",
    "ugyanezért": "ugyanez",
    "ugyanilyen": "ugyanily",
    "ujja": "ujj",
    "ujjai": "ujj",
    "ujjaiba": "ujj",
    "ujjaikkal": "ujj",
    "ujjaimat": "ujj",
    "ujjainak": "ujj",
    "ujjairól": "ujj",
    "ujjait": "ujj",
    "ujjak": "ujj",
    "ujjakat": "ujj",
    "ujjakkal": "ujj",
    "ujjam": "ujj",
    "ujjamat": "ujj",
    "ujjasban": "ujjas",
    "ujjasában": "ujjas",
    "ujjat": "ujj",
    "ujjmozdulattal": "ujjmozdulat",
    "ujjon": "ujj",
    "ujjongani": "ujjong",
    "ujjukra": "ujj",
    "ujján": "ujj",
    "ujját": "ujj",
    "ujjával": "ujj",
    "ukránok": "ukrán",
    "ukránokkal": "ukrán",
    "ultimátumát": "ultimátum",
    "unalmamban": "unalom",
    "unalmasak": "unalmas",
    "unalmát": "unalom",
    "unalomból": "unalom",
    "unatkozni": "unatkozik",
    "unatkozott": "unatkozik",
    "unciában": "uncia",
    "undora": "undor",
    "undorral": "undor",
    "undorítóan": "undorító",
    "uniformizált": "uniformizál",
    "uniója": "unió",
    "unióval": "unió",
    "unokái": "unoka",
    "unokáira": "unoka",
    "unokája": "unoka",
    "unokájának": "unoka",
    "unokáját": "unoka",
    "unt": "un",
    "ura": "úr",
    "uradalmakba": "uradalom",
    "uradalmakban": "uradalom",
    "uradalomban": "uradalom",
    "uradalomnak": "uradalom",
    "urai": "úr",
    "uraik": "úr",
    "uraim": "úr",
    "urak": "úr",
    "urakat": "úr",
    "urakhoz": "úr",
    "urakkal": "úr",
    "uraktól": "úr",
    "uralhatjátok": "uralhat",
    "uralja": "ural",
    "uraljuk": "ural",
    "uralkodnak": "uralkodik",
    "uralkodni": "uralkodik",
    "uralkodott": "uralkodik",
    "uralkodtok": "uralkodik",
    "uralkodunk": "uralkodik",
    "uralkodásuk": "uralkodás",
    "uralkodói": "uralkodó",
    "uralma": "uralom",
    "uralmát": "uralom",
    "uralnak": "ural",
    "uralom": "ural",
    "uralomról": "uralom",
    "uraltad": "uralt",
    "uraltátok": "ural",
    "uralunk": "ural",
    "uram": "úr",
    "uram-nak": "uram",
    "uraságnak": "uraság",
    "uraságnál": "uraság",
    "uraságok": "uraság",
    "uraságé": "uraság",
    "urat": "úr",
    "urizált": "urizál",
    "urnája": "urna",
    "urnákhoz": "urna",
    "urnát": "urna",
    "urának": "úr",
    "urára": "úr",
    "urával": "úr",
    "uszodák": "uszoda",
    "utad": "út",
    "utak": "út",
    "utakat": "út",
    "utakban": "út",
    "utakon": "út",
    "utakra": "út",
    "utalja": "utal",
    "utalnak": "utal",
    "utalni": "utal",
    "utalnák": "utal",
    "utalt": "utal",
    "utaltak": "utalt",
    "utalták": "utal",
    "utalvánnyal": "utalvány",
    "utalványokkal": "utalvány",
    "utalványon": "utalvány",
    "utalványra": "utalvány",
    "utalványt": "utalvány",
    "utalásaiból": "utalás",
    "utalások": "utalás",
    "utamon": "út",
    "utasa": "utas",
    "utasai": "utas",
    "utasok": "utas",
    "utasokat": "utas",
    "utasoknak": "utas",
    "utasoktól": "utas",
    "utasítania": "utasít",
    "utasíthatta": "utasíthat",
    "utasított": "utasít",
    "utasította": "utasít",
    "utasítottak": "utasított",
    "utasítások": "utasítás",
    "utasításokat": "utasítás",
    "utasításoktól": "utasítás",
    "utasításom": "utasítás",
    "utasítást": "utasítás",
    "utasítására": "utasítás",
    "utat": "út",
    "utazni": "utazik",
    "utaznál": "utazik",
    "utazott": "utazik",
    "utaztak": "utazik",
    "utaztattak": "utaztat",
    "utazunk": "utazik",
    "utazzál": "utazik",
    "utazzék": "utazik",
    "utazások": "utazás",
    "utazást": "utazás",
    "utazásuk": "utazás",
    "utazásából": "utazás",
    "utcaajtón": "utcaajtó",
    "utcabútorokkal": "utcabútor",
    "utcakereszteződést": "utcakereszteződés",
    "utcakövezetre": "utcakövezet",
    "utcaneveket": "utcanév",
    "utcarajzain": "utcarajz",
    "utcasarkokon": "utcasarok",
    "utcában": "utca",
    "utcából": "utca",
    "utcáig": "utca",
    "utcáin": "utca",
    "utcáink": "utca",
    "utcájában": "utca",
    "utcájának": "utca",
    "utcák": "utca",
    "utcákat": "utca",
    "utcákban": "utca",
    "utcákon": "utca",
    "utcán": "utca",
    "utcánál": "utca",
    "utcára": "utca",
    "utcáról": "utca",
    "utcát": "utca",
    "utoljára": "utolja",
    "utolsóknak": "utolsó",
    "utolsóként": "utolsó",
    "utolsónak": "utolsó",
    "utolsósorban": "utolsósor",
    "utolérjük": "utolér",
    "utolérné": "utolér",
    "utunk": "út",
    "utálatról": "utálat",
    "utálja": "utál",
    "utáljuk": "utál",
    "utálkozásaink": "utálkozás",
    "utálkozással": "utálkozás",
    "utálnia": "utál",
    "utálta": "utál",
    "utáltuk": "utál",
    "utána": "után",
    "utánad": "után",
    "utánafordítani": "utánafordít",
    "utánam": "után",
    "utánament": "utánamegy",
    "utánanézzen": "utánanéz",
    "utánjárást": "utánjárás",
    "utánoznak": "utánoz",
    "utánozni": "utánoz",
    "utánozta": "utánoz",
    "utánoztak": "utánoz",
    "utánozzák": "utánoz",
    "utánpótlásból": "utánpótlás",
    "utánuk": "után",
    "utánunk": "után",
    "utánzásában": "utánzás",
    "utánérzései": "utánérzés",
    "utászok": "utász",
    "utóbbiak": "utóbbi",
    "utóbbiakból": "utóbbi",
    "utóbbiaktól": "utóbbi",
    "utóbbira": "utóbbi",
    "utóbbit": "utóbbi",
    "utóbbival": "utóbbi",
    "utóda": "utód",
    "utódainknak": "utód",
    "utódja": "utód",
    "utódjának": "utód",
    "utódállamban": "utódállam",
    "utódállambelieket": "utódállambeli",
    "utódállamok": "utódállam",
    "utódát": "utód",
    "utógondolatként": "utógondolat",
    "utókor": "utó",
    "utókornak": "utókor",
    "utópizmusával": "utópizmus",
    "utópiáknak": "utópia",
    "utóízt": "utóíz",
    "vackában": "vacok",
    "vacogjon": "vacog",
    "vacogtak": "vacog",
    "vacokba": "vacok",
    "vacokból": "vacok",
    "vacokra": "vacok",
    "vacsorája": "vacsora",
    "vacsoráját": "vacsora",
    "vacsorájául": "vacsora",
    "vacsorálni": "vacsorál",
    "vacsorán": "vacsora",
    "vacsoránál": "vacsora",
    "vacsorára": "vacsora",
    "vacsorát": "vacsora",
    "vadakká": "vad",
    "vadat": "vad",
    "vaddisznótejet": "vaddisznótej",
    "vadonatújan": "vadonatúj",
    "vadul": "vad",
    "vadállat": "vadáll",
    "vadállatnak": "vadállat",
    "vadállatok": "vadállat",
    "vadászgépeket": "vadászgép",
    "vadászgépet": "vadászgép",
    "vadászkalandjait": "vadászkaland",
    "vadásznak": "vadászik",
    "vadászom": "vadászik",
    "vadászrepülőgépek": "vadászrepülőgép",
    "vadásztak": "vadászik",
    "vadászvásznakat": "vadászvászon",
    "vagy": "van",
    "vagyok": "van",
    "vagyona": "vagyon",
    "vagyonból": "vagyon",
    "vagyonfelhasználói": "vagyonfelhasználó",
    "vagyonjuttatásra": "vagyonjuttatás",
    "vagyonkezelőnek": "vagyonkezelő",
    "vagyonnal": "vagyon",
    "vagyonom": "vagyon",
    "vagyonra": "vagyon",
    "vagyont": "vagyon",
    "vagyonából": "vagyon",
    "vagyonát": "vagyon",
    "vagyonátadást": "vagyonátadás",
    "vagyonért": "vagyon",
    "vagytok": "van",
    "vagyunk": "van",
    "vajat": "vaj",
    "vajcsinálásnál": "vajcsinálás",
    "vajon": "vaj",
    "vajért": "vaj",
    "vakarcsot": "vakarcs",
    "vakarhatjuk": "vakarhat",
    "vakartak": "vakart",
    "vakfoltot": "vakfolt",
    "vakkantotta": "vakkant",
    "vakok": "vak",
    "vakolatot": "vakolat",
    "vakon": "vak",
    "vakondtúrásokkal": "vakondtúrás",
    "vaksin": "vaksi",
    "vaksötétben": "vaksötét",
    "vakuljon": "vakul",
    "vakítja": "vakít",
    "valakibe": "valaki",
    "valakik": "valaki",
    "valakinek": "valaki",
    "valakit": "valaki",
    "valakivel": "valaki",
    "valamelyikéből": "valamelyik",
    "valamelyikén": "valamelyik",
    "valamelyikük": "valamelyik",
    "valamennyien": "valamennyi",
    "valamennyinél": "valamennyi",
    "valamennyire": "valamennyi",
    "valamennyit": "valamennyi",
    "valamiben": "valami",
    "valamicskét": "valamicské",
    "valamid": "valami",
    "valamikor": "valami",
    "valamiképp": "valami",
    "valamiképpen": "valami",
    "valamilyen": "valamily",
    "valamin": "valami",
    "valaminek": "valami",
    "valamire": "valami",
    "valamiről": "valami",
    "valamit": "valami",
    "valamitől": "valami",
    "valamivel": "valami",
    "valamiért": "valami",
    "vallana": "vall",
    "vallani": "vall",
    "vallania": "vall",
    "vallanék": "vall",
    "vallatják": "vallat",
    "vallattak": "vallat",
    "vallattassam": "vallattas",
    "vallatták": "vallat",
    "vallatáson": "vallatás",
    "vallatással": "vallatás",
    "vallatást": "vallatás",
    "vallatástól": "vallatás",
    "vallatásukban": "vallatás",
    "vallatásának": "vallatás",
    "vallatói": "vallató",
    "vallatóinak": "vallatóín",
    "valld": "vall",
    "vallja": "vall",
    "valljanak": "vall",
    "valljon": "vall",
    "vallják": "vall",
    "vallok": "vall",
    "vallomása": "vallomás",
    "vallomásaiban": "vallomás",
    "vallomásaik": "vallomás",
    "vallomásairól": "vallomás",
    "vallomásait": "vallomás",
    "vallomásaként": "vallomás",
    "vallomásnak": "vallomás",
    "vallomások": "vallomás",
    "vallomásokat": "vallomás",
    "vallomást": "vallomás",
    "vallomásuk": "vallomás",
    "vallomására": "vallomás",
    "vallott": "vall",
    "vallotta": "vall",
    "vallottak": "vallott",
    "vallották": "vall",
    "vallásban": "vallás",
    "vallásgyakorlásról": "vallásgyakorlás",
    "vallásszabadságot": "vallásszabadság",
    "vallásszabadságról": "vallásszabadság",
    "vallást": "vallás",
    "vallásüldözéseiről": "vallásüldözés",
    "vallók": "valló",
    "valutaalapnak": "valutaalap",
    "valutatulajdonosok": "valutatulajdonos",
    "valutának": "valuta",
    "valóban": "való",
    "valódit": "valódi",
    "valója": "való",
    "valójában": "való",
    "valók": "való",
    "valónak": "való",
    "valóra": "való",
    "valószerűen": "valószerű",
    "valószínűbb": "valószínű",
    "valószínűnek": "valószínű",
    "valószínűsége": "valószínűség",
    "valószínűséggel": "valószínűség",
    "valószínűsítették": "valószínűsítet",
    "valószínűsíti": "valószínűsít",
    "valószínűtlennek": "valószínűtlen",
    "valóság-magjuk": "valóság-mag",
    "valóságban": "valóság",
    "valósággal": "valóság",
    "valósággá": "valóság",
    "valósághoz": "valóság",
    "valóságnak": "valóság",
    "valóságon": "valóság",
    "valóságosan": "valóságos",
    "valóságosnál": "valóságos",
    "valóságot": "valóság",
    "valóságról": "valóság",
    "valóságszabályozásnak": "valóságszabályozás",
    "valósítsák": "valósít",
    "valót": "való",
    "valótlanságokat": "valótlanság",
    "valótlanságot": "valótlanság",
    "valóvá": "való",
    "vannak": "van",
    "varainkat": "var",
    "varietéműsorban": "varietéműsor",
    "varietéműsorok": "varietéműsor",
    "variációban": "variáció",
    "varrni": "varr",
    "varrt": "varr",
    "varrtak": "varrt",
    "varrást": "varrás",
    "varázsa": "varázs",
    "varázslója": "varázsló",
    "varázslót": "varázsló",
    "varázsolni": "varázsol",
    "varázsolták": "varázsol",
    "varázsához": "varázs",
    "vasaltak": "vasalt",
    "vasaltatni": "vasaltat",
    "vasastól": "vasas",
    "vasat": "vas",
    "vasban": "vas",
    "vaskarzatok": "vaskarzat",
    "vaskályhájáról": "vaskályha",
    "vaslábak": "vasláb",
    "vaslépcsők": "vaslépcső",
    "vasművet": "vasmű",
    "vasrudakat": "vasrúd",
    "vasrúdról": "vasrúd",
    "vassal": "vas",
    "vasszékre": "vasszék",
    "vastagabb": "vastag",
    "vastagabbak": "vastag",
    "vastagon": "vastag",
    "vastagát": "vastag",
    "vasutak": "vasút",
    "vasutasnak": "vasutas",
    "vasvillával": "vasvilla",
    "vasárnak": "vasár",
    "vasárnapot": "vasárnap",
    "vasút": "vasú",
    "vasútnál": "vasút",
    "vasútoldalon": "vasútoldal",
    "vasúton": "vasút",
    "vasútvonalakon": "vasútvonal",
    "vasútállomások": "vasútállomás",
    "vasútállomásra": "vasútállomás",
    "vasútállomására": "vasútállomás",
    "vattacsomókkal": "vattacsomó",
    "vattacsomót": "vattacsomó",
    "vb-döntőjének": "vb-döntő",
    "vb-győztest": "vb-győztes",
    "vedret": "veder",
    "vegye": "vesz",
    "vegyen": "vesz",
    "vegyeskereskedésbe": "vegyeskereskedés",
    "vegyest": "vegyes",
    "vegytanban": "vegytan",
    "vegyék": "vesz",
    "vegyük": "vesz",
    "vegyült": "vegyül",
    "vegyünk": "vesz",
    "vehessünk": "vehet",
    "vehetett": "vehet",
    "veheti": "vehet",
    "vehetik": "vehet",
    "vehetjük": "vehet",
    "vehetnek": "vehet",
    "vehetné": "vehet",
    "vehetnék": "vehet",
    "vehette": "vehet",
    "vehettek": "vehet",
    "veje": "vő",
    "vejem": "vej",
    "vejemmel": "vej",
    "vejüknek": "vő",
    "vele": "ő",
    "velejéig": "velő",
    "velem": "én",
    "veletek": "ti",
    "velük": "ők",
    "velünk": "mi",
    "velőmig": "velő",
    "vendége": "vendég",
    "vendégei": "vendég",
    "vendégek": "vendég",
    "vendégeket": "vendég",
    "vendégekkel": "vendég",
    "vendégekre": "vendég",
    "vendégem": "vendég",
    "vendéget": "vendég",
    "vendégjátéka": "vendégjáték",
    "vendégjátékáról": "vendégjáték",
    "vendégkiállítása": "vendégkiállítás",
    "vendégként": "vendég",
    "vendéglátók": "vendéglátó",
    "vendéglősök": "vendéglős",
    "vendégprofesszora": "vendégprofesszor",
    "vendégre": "vendég",
    "vendégről": "vendég",
    "vendégszerepelt": "vendégszerepel",
    "vendégszeretetből": "vendégszeretet",
    "vendégszeretettel": "vendégszeretett",
    "vendégének": "vendég",
    "vendégére": "vendég",
    "vendégükre": "vendég",
    "vendégül": "vendég",
    "venne": "vesz",
    "venned": "vesz",
    "vennem": "vesz",
    "vennetek": "vesz",
    "venni": "vesz",
    "vennie": "vesz",
    "venniük": "vesz",
    "venné": "vesz",
    "vennünk": "vesz",
    "verandaajtón": "verandaajtó",
    "verandaasztalnál": "verandaasztal",
    "verandaasztalon": "verandaasztal",
    "verandaasztalra": "verandaasztal",
    "verandája": "veranda",
    "verandán": "veranda",
    "verandára": "veranda",
    "verbuválni": "verbuvál",
    "verd": "ver",
    "verebeit": "veréb",
    "verebek": "veréb",
    "vereshagymát": "vereshagyma",
    "veress": "veres",
    "veresége": "vereség",
    "vereséget": "vereség",
    "vereséggel": "vereség",
    "vereségtől": "vereség",
    "vereségérzettel": "vereségérzett",
    "vereségét": "vereség",
    "vereségükért": "vereség",
    "veretlenül": "veretlen",
    "vergődnek": "vergődik",
    "vergődése": "vergődés",
    "veri": "ver",
    "verik": "ver",
    "verje": "ver",
    "vernek": "ver",
    "verni": "ver",
    "vernének": "ver",
    "versbe": "vers",
    "verscsináló-nak": "verscsináló",
    "verscsinálónak": "verscsináló",
    "verseimet": "vers",
    "verseit": "vers",
    "versek": "vers",
    "verseket": "vers",
    "versekre": "vers",
    "versengenek": "verseng",
    "versengjenek": "verseng",
    "versenyben": "verseny",
    "versenybizottsága": "versenybizottság",
    "versenyeit": "verseny",
    "versenyek": "verseny",
    "versenyeket": "verseny",
    "versenyeljárásban": "versenyeljárás",
    "versenyezhetnek": "versenyezhet",
    "versenyeznek": "versenyez",
    "versenyeztek": "versenyez",
    "versenyeztetése": "versenyeztetés",
    "versenyfóruma": "versenyfórum",
    "versenyhivatalok": "versenyhivatal",
    "versenykiírásnak": "versenykiírás",
    "versenyként": "verseny",
    "versenyműve": "versenymű",
    "versenyművében": "versenymű",
    "versenynek": "verseny",
    "versenypályákban": "versenypálya",
    "versenyre": "verseny",
    "versenyt": "verseny",
    "versenytanácsa": "versenytanács",
    "versenytársai": "versenytárs",
    "versenytársaik": "versenytárs",
    "versenytársainak": "versenytárs",
    "versenytársak": "versenytárs",
    "versenytársaknak": "versenytárs",
    "versenytörvényben": "versenytörvény",
    "versenyzek": "versenyez",
    "versenyzett": "versenyez",
    "versenyzést": "versenyzés",
    "versenyzője": "versenyző",
    "versenyzőket": "versenyző",
    "verset": "vers",
    "versformába": "versformá",
    "versgyűjteményekben": "versgyűjtemény",
    "versikére": "versike",
    "versre": "vers",
    "verssel": "vers",
    "versének": "vers",
    "versére": "vers",
    "vert": "ver",
    "verte": "ver",
    "vertek": "vert",
    "verték": "ver",
    "verzióját": "verzió",
    "verések": "verés",
    "veréstől": "verés",
    "vesd": "vet",
    "vesekövek": "vesekő",
    "vesse": "vet",
    "vessen": "vet",
    "vessenek": "vet",
    "vesszük": "veszt",
    "vesszőket": "vessző",
    "vesszőparipája": "vesszőparipa",
    "vessék": "vet",
    "veszed": "veszik",
    "veszedelme": "veszedelem",
    "veszedelmekkel": "veszedelem",
    "veszedelmesebb": "veszedelmes",
    "veszedelmesen": "veszedelmes",
    "veszedelmessé": "veszedelmes",
    "veszedelmet": "veszedelem",
    "veszek": "veszik",
    "veszekedjünk": "veszekedik",
    "veszekednek": "veszekedik",
    "veszekedtek": "veszekedik",
    "veszekedtünk": "veszekedik",
    "veszekedések": "veszekedés",
    "veszekedésekben": "veszekedés",
    "veszekedésektől": "veszekedés",
    "veszekedésre": "veszekedés",
    "veszekedéssel": "veszekedés",
    "veszem": "veszik",
    "veszett": "veszik",
    "veszi": "veszik",
    "veszik": "vesz",
    "vesznek": "veszik",
    "vesztegetni": "veszteget",
    "vesztek": "veszt",
    "veszteni": "veszt",
    "vesztesen": "vesztes",
    "vesztesége": "veszteség",
    "veszteségei": "veszteség",
    "veszteségeit": "veszteség",
    "veszteségek": "veszteség",
    "veszteségeket": "veszteség",
    "veszteséget": "veszteség",
    "veszteséggel": "veszteség",
    "veszteségre": "veszteség",
    "veszteségről": "veszteség",
    "veszteségének": "veszteség",
    "veszteségét": "veszteség",
    "vesztesének": "vesztes",
    "vesztett": "veszt",
    "vesztette": "veszt",
    "vesztették": "vesztet",
    "vesztetőn": "vesztető",
    "vesztik": "veszt",
    "vesztét": "veszte",
    "veszéllyel": "veszély",
    "veszélybe": "veszély",
    "veszélyben": "veszély",
    "veszélye": "veszély",
    "veszélyek": "veszély",
    "veszélyesebb": "veszélyes",
    "veszélyesen": "veszélyes",
    "veszélyesnek": "veszélyes",
    "veszélyessé": "veszélyes",
    "veszélyeztetett": "veszélyeztet",
    "veszélyeztetheti": "veszélyeztethet",
    "veszélyezteti": "veszélyeztet",
    "veszélyeztetik": "veszélyeztet",
    "veszélyeztetné": "veszélyeztet",
    "veszélyforrástól": "veszélyforrás",
    "veszélyt": "veszély",
    "veszélytelenül": "veszélytelen",
    "veszélyére": "veszély",
    "veszélyét": "veszély",
    "veszítenek": "veszít",
    "veszített": "veszít",
    "veszítettek": "veszített",
    "veszíti": "veszít",
    "veszítse": "veszít",
    "veszítsenek": "veszít",
    "veszítsetek": "veszít",
    "veszünk": "veszik",
    "vesékig": "vese",
    "vesémbe": "vese",
    "vetemedett": "vetemedik",
    "vetemedtek": "vetemedik",
    "vetett": "vet",
    "vetette": "vet",
    "vetettek": "vetett",
    "vetettem": "vetett",
    "vetették": "vetet",
    "vethetett": "vethet",
    "vethettek": "vethet",
    "veti": "vet",
    "vetik": "vet",
    "vetkőzött": "vetkőzik",
    "vetnek": "vet",
    "vetni": "vet",
    "vetnie": "vet",
    "vetnénk": "vet",
    "vett": "vesz",
    "vette": "vesz",
    "vettek": "vett",
    "vettem": "vett",
    "vették": "vesz",
    "vettük": "vett",
    "vettünk": "vett",
    "vetélkedtek": "vetélkedik",
    "vetélkedőre": "vetélkedő",
    "vetélytársa": "vetélytárs",
    "vetélytárssal": "vetélytárs",
    "vetése": "vetés",
    "vetíteni": "vetít",
    "vetítették": "vetítet",
    "vetíti": "vetít",
    "vevői": "vevő",
    "vevők": "vevő",
    "vevőket": "vevő",
    "vevőknek": "vevő",
    "vevőre": "vevő",
    "vezesse": "vezet",
    "vezetett": "vezet",
    "vezethette": "vezethet",
    "vezethetők": "vezethető",
    "vezeti": "vezet",
    "vezetne": "vezet",
    "vezetnek": "vezet",
    "vezetni": "vezet",
    "vezette": "vezet",
    "vezettek": "vezet",
    "vezették": "vezet",
    "vezetékek": "vezeték",
    "vezetéken": "vezeték",
    "vezetéknevét": "vezetéknév",
    "vezetékének": "vezeték",
    "vezetésből": "vezetés",
    "vezetése": "vezetés",
    "vezetésnek": "vezetés",
    "vezetéssel": "vezetés",
    "vezetést": "vezetés",
    "vezetésébe": "vezetés",
    "vezetésében": "vezetés",
    "vezetésének": "vezetés",
    "vezetését": "vezetés",
    "vezetésével": "vezetés",
    "vezetésük": "vezetés",
    "vezetői": "vezető",
    "vezetőihez": "vezetői",
    "vezetőinek": "vezetői",
    "vezetőink": "vezető",
    "vezetőit": "vezetői",
    "vezetőitől": "vezetői",
    "vezetőivel": "vezetői",
    "vezetője": "vezető",
    "vezetőjéhez": "vezető",
    "vezetőjét": "vezető",
    "vezetőjétől": "vezető",
    "vezetőjévé": "vezető",
    "vezetőjüket": "vezető",
    "vezetők": "vezető",
    "vezetőket": "vezető",
    "vezetőkre": "vezető",
    "vezetőnek": "vezető",
    "vezetősége": "vezetőség",
    "vezetőségének": "vezetőség",
    "vezetőségét": "vezetőség",
    "vezetővel": "vezető",
    "vezényelnének": "vezényel",
    "vezényelt": "vezényel",
    "vezényletével": "vezénylet",
    "vezényli": "vezényel",
    "vezércikkből": "vezércikk",
    "vezércikkeinek": "vezércikk",
    "vezércikkeit": "vezércikk",
    "vezére": "vezér",
    "vezérek": "vezér",
    "vezéreket": "vezér",
    "vezérelt": "vezérel",
    "vezérfonalának": "vezérfonál",
    "vezérigazgatói": "vezérigazgató",
    "vezérigazgatója": "vezérigazgató",
    "vezérigazgatóját": "vezérigazgató",
    "vezérimádattá": "vezérimádat",
    "vezérsége": "vezérség",
    "vezért": "vezér",
    "vezérét": "vezér",
    "vezérünkre": "vezér",
    "viadalon": "viadal",
    "viadalán": "viadal",
    "viaskodnak": "viaskodik",
    "viaskodtunk": "viaskodik",
    "viasszal": "viasz",
    "viaszfigura-kiállításokat": "viaszfigura-kiállítás",
    "viaszfigura-kiállításokkal": "viaszfigura-kiállítás",
    "viaszfigurákból": "viaszfigura",
    "vibráltak": "vibrált",
    "vibrálását": "vibrálás",
    "vicceket": "vicc",
    "viccelnek": "viccel",
    "viccnek": "vicc",
    "vicsorogni": "vicsorog",
    "vidd": "visz",
    "videofilmet": "videofilm",
    "videokazettáról": "videokazetta",
    "vidámabb": "vidám",
    "vidáman": "vidám",
    "vidámságot": "vidámság",
    "vidékeken": "vidék",
    "vidékekről": "vidék",
    "vidéken": "vidék",
    "vidéket": "vidék",
    "vidéknek": "vidék",
    "vidékre": "vidék",
    "vidékének": "vidék",
    "vidékünket": "vidék",
    "vigadnak": "vigad",
    "vigadóban": "vigadó",
    "vigasztalta": "vigasztal",
    "vigasztalóbb": "vigasztaló",
    "vigasztalódhatott": "vigasztalódhat",
    "vigye": "visz",
    "vigyem": "visz",
    "vigyetek": "visz",
    "vigyorogtak": "vigyorog",
    "vigyorral": "vigyor",
    "vigyorával": "vigyor",
    "vigyázatlanná": "vigyázatlan",
    "vigyázatlanul": "vigyázatlan",
    "vigyázna": "vigyáz",
    "vigyázni": "vigyáz",
    "vigyáznia": "vigyáz",
    "vigyázott": "vigyáz",
    "vigyáztak": "vigyáz",
    "vigyázz": "vigyáz",
    "vigyázzatok": "vigyáz",
    "vigyázzba": "vigyázz",
    "vigyázzon": "vigyáz",
    "vigyázzt": "vigyázz",
    "vigyázzál": "vigyáz",
    "vigyázzállásba": "vigyázzállás",
    "vigyék": "visz",
    "vigyétek": "visz",
    "viharban": "vihar",
    "viharként": "vihar",
    "viharok": "vihar",
    "vihart": "vihar",
    "vihartól": "vihar",
    "vihessenek": "vihet",
    "viheti": "vihet",
    "vihetnénk": "vihet",
    "vihette": "vihet",
    "villamossággal": "villamosság",
    "villannak": "villan",
    "villant": "villan",
    "villantak": "villant",
    "villanykábelek": "villanykábel",
    "villanykörtékből": "villanykörte",
    "villanylámpák": "villanylámpa",
    "villanymotort": "villanymotor",
    "villanyrészvények": "villanyrészvény",
    "villanyszámlát": "villanyszámla",
    "villanyt": "villany",
    "villanyvezetékei": "villanyvezeték",
    "villanyégőit": "villanyégői",
    "villanások": "villanás",
    "villába": "villa",
    "villáiban": "villa",
    "villájuk": "villa",
    "villámcsapásszerűen": "villámcsapásszerű",
    "villámgyorsan": "villámgyors",
    "villámlástól": "villámlás",
    "villámok": "villám",
    "villázgatta": "villázgat",
    "világa": "világ",
    "világba": "világ",
    "világbajnoknője": "világbajnoknő",
    "világbajnokságon": "világbajnokság",
    "világbajnokságot": "világbajnokság",
    "világban": "világ",
    "világbanknak": "világbank",
    "világbotrányt": "világbotrány",
    "világból": "világ",
    "világcsúcsot": "világcsúcs",
    "világcégek": "világcég",
    "világegyetemben": "világegyetem",
    "világegyetemet": "világegyetem",
    "világfelfogásuk": "világfelfogás",
    "világgal": "világ",
    "világgazdaságnak": "világgazdaság",
    "világhatalommal": "világhatalom",
    "világháborút": "világháború",
    "világhálóval": "világháló",
    "világhírességekkel": "világhíresség",
    "világhírre": "világhír",
    "világkongresszuson": "világkongresszus",
    "világkupa-győztes": "világ-kupagyőztes",
    "világnak": "világ",
    "világnézete": "világnézet",
    "világnézetet": "világnézet",
    "világnézetnek": "világnézet",
    "világon": "világ",
    "világosabb": "világos",
    "világosabban": "világos",
    "világosak": "világos",
    "világosan": "világos",
    "világosodni": "világosodik",
    "világossá": "világos",
    "világosságban": "világosság",
    "világosságnál": "világosság",
    "világosságon": "világosság",
    "világosságot": "világosság",
    "világosságra": "világosság",
    "világot": "világ",
    "világra": "világ",
    "világranglistájának": "világranglista",
    "világranglistáját": "világranglista",
    "világszínvonalat": "világszínvonal",
    "világszövetsége": "világszövetség",
    "világturnékon": "világturné",
    "világunk": "világ",
    "világunkat": "világ",
    "világunkban": "világ",
    "világunkról": "világ",
    "világversenyeken": "világverseny",
    "világába": "világ",
    "világában": "világ",
    "világáig": "világ",
    "világának": "világ",
    "világát": "világ",
    "világával": "világ",
    "világért": "világ",
    "világítanak": "világít",
    "világítanám": "világít",
    "világítja": "világít",
    "világított": "világít",
    "világítottak": "világított",
    "világítása": "világítás",
    "világításában": "világítás",
    "világítótestekhez": "világítótest",
    "világörökség-listájára": "világörökség-lista",
    "világútlevelet": "világútlevél",
    "világűrben": "világűr",
    "világűrből": "világűr",
    "vinned": "visz",
    "vinni": "visz",
    "vinnéd": "visz",
    "vinnének": "visz",
    "vinnünk": "visz",
    "vircsaftban": "vircsaft",
    "virradni": "virrad",
    "virradóra": "virradó",
    "virágai": "virág",
    "virágból": "virág",
    "virágcsokrok": "virágcsokor",
    "virággal": "virág",
    "virágnál": "virág",
    "virágok": "virág",
    "virágokat": "virág",
    "virágokkal": "virág",
    "virágot": "virág",
    "virágozni": "virágoz",
    "virágszedést": "virágszedés",
    "virágszedőket": "virágszedő",
    "virágzott": "virágzik",
    "virágzásnak": "virágzás",
    "virágzásuk": "virágzás",
    "virágzását": "virágzás",
    "viseletek": "viselet",
    "viselik": "visel",
    "viseljék": "visel",
    "viselkedett": "viselkedik",
    "viselkedhettek": "viselkedhet",
    "viselkedj": "viselkedik",
    "viselkednek": "viselkedik",
    "viselkedni": "viselkedik",
    "viselkedtek": "viselkedik",
    "viselkedtem": "viselkedik",
    "viselkedésben": "viselkedés",
    "viselkedése": "viselkedés",
    "viselkedésében": "viselkedés",
    "viselkedését": "viselkedés",
    "viselnek": "visel",
    "viselni": "visel",
    "viselnének": "visel",
    "viselt": "visel",
    "viselte": "visel",
    "viseltek": "viselt",
    "viseltem": "viselt",
    "viseltünk": "viselt",
    "viselését": "viselés",
    "visszaadja": "visszaad",
    "visszaadna": "visszaad",
    "visszaadni": "visszaad",
    "visszaadom": "visszaad",
    "visszaadott": "visszaad",
    "visszaadása": "visszaadás",
    "visszaadásakor": "visszaadás",
    "visszaadásának": "visszaadás",
    "visszaadására": "visszaadás",
    "visszaadásáról": "visszaadás",
    "visszabeszélt": "visszabeszél",
    "visszabotorkált": "visszabotorkál",
    "visszabújni": "visszabújik",
    "visszacsúsztak": "visszacsúszik",
    "visszadugta": "visszadug",
    "visszadőlt": "visszadől",
    "visszaemlékezett": "visszaemlékezik",
    "visszaemlékeznek": "visszaemlékezik",
    "visszaemlékezni": "visszaemlékezik",
    "visszaemlékezések": "visszaemlékezés",
    "visszaemlékezünk": "visszaemlékezik",
    "visszaemlékezők": "visszaemlékező",
    "visszaemlékszel": "visszaemlékszik",
    "visszaengedte": "visszaenged",
    "visszaesett": "visszaesik",
    "visszaesése": "visszaesés",
    "visszafejlődött": "visszafejlődik",
    "visszafeküdt": "visszafekszik",
    "visszafeküdtünk": "visszafeküdt",
    "visszafizetik": "visszafizet",
    "visszafizetésre": "visszafizetés",
    "visszafizetéssel": "visszafizetés",
    "visszafizetésére": "visszafizetés",
    "visszafizetését": "visszafizetés",
    "visszafogadják": "visszafogad",
    "visszafoglalja": "visszafoglal",
    "visszafogott": "visszafog",
    "visszafogottabb": "visszafogott",
    "visszafogottan": "visszafogott",
    "visszafordulni": "visszafordul",
    "visszafordult": "visszafordul",
    "visszafordultak": "visszafordult",
    "visszafordítunk": "visszafordít",
    "visszaforgatni": "visszaforgat",
    "visszahozhatta": "visszahozhat",
    "visszahozta": "visszahoz",
    "visszahoztak": "visszahoz",
    "visszahozták": "visszahoz",
    "visszahozzon": "visszahoz",
    "visszahozzák": "visszahoz",
    "visszahívta": "visszahív",
    "visszahívták": "visszahív",
    "visszahúzza": "visszahúz",
    "visszahőkölt": "visszahőköl",
    "visszaidézni": "visszaidéz",
    "visszaigazította": "visszaigazít",
    "visszajuttatniuk": "visszajuttat",
    "visszajuttatását": "visszajuttatás",
    "visszajátssza": "visszajátszik",
    "visszajött": "visszajön",
    "visszajöttem": "visszajön",
    "visszajövünk": "visszajön",
    "visszakanyarodott": "visszakanyarodik",
    "visszakapaszkodott": "visszakapaszkodik",
    "visszakapja": "visszakap",
    "visszakapná": "visszakap",
    "visszakapta": "visszakap",
    "visszakapták": "visszakap",
    "visszakerülnek": "visszakerül",
    "visszakerülni": "visszakerül",
    "visszakerült": "visszakerül",
    "visszakiabálnak": "visszakiabál",
    "visszaküldjék": "visszaküld",
    "visszaküldtük": "visszaküld",
    "visszalapozott": "visszalapoz",
    "visszalépett": "visszalép",
    "visszalépni": "visszalép",
    "visszaléptem": "visszalép",
    "visszamaradottnak": "visszamaradott",
    "visszamaradtunk": "visszamaradt",
    "visszamegyek": "visszamegy",
    "visszamenni": "visszamegy",
    "visszament": "visszamegy",
    "visszamentek": "visszament",
    "visszamentünk": "visszament",
    "visszanyerte": "visszanyer",
    "visszanézett": "visszanéz",
    "visszanéztem": "visszanéz",
    "visszanéztünk": "visszanéz",
    "visszapattant": "visszapattan",
    "visszarendelik": "visszarendel",
    "visszarettentek": "visszarettent",
    "visszariadtam": "visszariadt",
    "visszariasztott": "visszariaszt",
    "visszaszerezni": "visszaszerez",
    "visszaszerezze": "visszaszerez",
    "visszasírni": "visszasír",
    "visszatartanak": "visszatart",
    "visszatartani": "visszatart",
    "visszatartott": "visszatart",
    "visszatartotta": "visszatart",
    "visszatartották": "visszatart",
    "visszatartásokat": "visszatartás",
    "visszataszítják": "visszataszít",
    "visszataszítóbb": "visszataszító",
    "visszatehette": "visszatehet",
    "visszatetszést": "visszatetszés",
    "visszatette": "visszatesz",
    "visszatették": "visszatesz",
    "visszatuszkolják": "visszatuszkol",
    "visszatérek": "visszatér",
    "visszatérhetnek": "visszatérhet",
    "visszatérjen": "visszatér",
    "visszatérnek": "visszatér",
    "visszatérni": "visszatér",
    "visszatérnie": "visszatér",
    "visszatérsz": "visszatér",
    "visszatért": "visszatér",
    "visszatértek": "visszatért",
    "visszatértél": "visszatér",
    "visszatértünk": "visszatért",
    "visszatérése": "visszatérés",
    "visszatérésre": "visszatérés",
    "visszatérésének": "visszatérés",
    "visszatéréséről": "visszatérés",
    "visszatérését": "visszatérés",
    "visszatérítésből": "visszatérítés",
    "visszatérítésére": "visszatérítés",
    "visszautalásához": "visszautalás",
    "visszautasítani": "visszautasít",
    "visszautasított": "visszautasít",
    "visszautasította": "visszautasít",
    "visszautasítsa": "visszautasít",
    "visszautat": "visszaút",
    "visszautazom": "visszautazik",
    "visszavarrta": "visszavarr",
    "visszavenni": "visszavesz",
    "visszaverjenek": "visszaver",
    "visszaveti": "visszavet",
    "visszavetik": "visszavet",
    "visszavették": "visszavesz",
    "visszavitték": "visszavisz",
    "visszavonta": "visszavon",
    "visszavonult": "visszavonul",
    "visszavonultak": "visszavonult",
    "visszavonulását": "visszavonulás",
    "visszavonzotta": "visszavonz",
    "visszavonásáról": "visszavonás",
    "visszavágott": "visszavág",
    "visszavágóit": "visszavágói",
    "visszavágón": "visszavágó",
    "visszavándorlásának": "visszavándorlás",
    "visszaállt": "visszaáll",
    "visszaélt": "visszaél",
    "visszaélések": "visszaélés",
    "visszaéléseket": "visszaélés",
    "visszaélésekre": "visszaélés",
    "visszfényében": "visszfény",
    "visszfényét": "visszfény",
    "visszhangja": "visszhang",
    "visszhangot": "visszhang",
    "visszhangozta": "visszhangoz",
    "visszhangtalanságért": "visszhangtalanság",
    "visszhangzott": "visszhangzik",
    "visszértágulásom": "visszértágulás",
    "viszek": "visz",
    "viszem": "visz",
    "viszi": "visz",
    "viszik": "visz",
    "viszketni": "viszket",
    "viszketése": "viszketés",
    "viszketésig": "viszketés",
    "visznek": "visz",
    "viszolygással": "viszolygás",
    "viszolyogna": "viszolyog",
    "viszonnyal": "viszony",
    "viszontagságai": "viszontagság",
    "viszontszereted": "viszontszeret",
    "viszontszerethesse": "viszontszerethet",
    "viszonyait": "viszony",
    "viszonyban": "viszony",
    "viszonylagossá": "viszonylagos",
    "viszonylatok": "viszonylat",
    "viszonyok": "viszony",
    "viszonyokat": "viszony",
    "viszonyokról": "viszony",
    "viszonyra": "viszony",
    "viszonyszámok": "viszonyszám",
    "viszonyt": "viszony",
    "viszonyuk": "viszony",
    "viszonyult": "viszonyul",
    "viszonyulások": "viszonyulás",
    "viszonyunk": "viszony",
    "viszonyában": "viszony",
    "viszonyán": "viszony",
    "viszonyára": "viszony",
    "viszonyáról": "viszony",
    "viszonyát": "viszony",
    "viszonyított": "viszonyít",
    "viszályok": "viszály",
    "visítottak": "visított",
    "vitaanyagban": "vitaanyag",
    "vitaanyagot": "vitaanyag",
    "vitathatatlanul": "vitathatatlan",
    "vitatja": "vitat",
    "vitatják": "vitat",
    "vitatkozni": "vitatkozik",
    "vitatkozott": "vitatkozik",
    "vitatkoztak": "vitatkozik",
    "vitatkozzunk": "vitatkozik",
    "vitatni": "vitat",
    "vitatott": "vitat",
    "vitatta": "vitat",
    "vitatájában": "vitatáj",
    "viteldíjat": "viteldíj",
    "vitetett": "vitet",
    "vitetni": "vitet",
    "vitorlából": "vitorla",
    "vitrinben": "vitrin",
    "vitrint": "vitrin",
    "vitriolt": "vitriol",
    "vitt": "visz",
    "vitte": "visz",
    "vittek": "vitt",
    "vittem": "vitt",
    "vitték": "visz",
    "vittük": "vitt",
    "vittünk": "vitt",
    "vitába": "vita",
    "vitáik": "vita",
    "vitájuk": "vita",
    "viták": "vita",
    "vitákat": "vita",
    "vitákban": "vita",
    "vitákhoz": "vita",
    "vitákkal": "vita",
    "vitáktól": "vita",
    "vitának": "vita",
    "vitára": "vita",
    "vitát": "vita",
    "vitáznak": "vitázik",
    "vitázott": "vitázik",
    "vitázunk": "vitázik",
    "vitézül": "vitéz",
    "vizei": "víz",
    "vizeinkről": "víz",
    "vizek": "víz",
    "vizekről": "víz",
    "vizeldébe": "vizelde",
    "vizeldék": "vizelde",
    "vizeletéből": "vizelet",
    "vizelni": "vizel",
    "vizelnie": "vizel",
    "vizelt": "vizel",
    "vizeskancsójából": "vizeskancsó",
    "vizet": "víz",
    "viziteltek": "vizitelt",
    "vizsgaelőadásán": "vizsgaelőadás",
    "vizsgaelőadásának": "vizsgaelőadás",
    "vizsgaelőadására": "vizsgaelőadás",
    "vizsgaidőpontokat": "vizsgaidőpont",
    "vizsgaként": "vizsga",
    "vizsgakövetelmények": "vizsgakövetelmény",
    "vizsgához": "vizsga",
    "vizsgájáról": "vizsga",
    "vizsgák": "vizsga",
    "vizsgákat": "vizsga",
    "vizsgálata": "vizsgálat",
    "vizsgálatai": "vizsgálat",
    "vizsgálatiban": "vizsgálati",
    "vizsgálatnak": "vizsgálat",
    "vizsgálatok": "vizsgálat",
    "vizsgálatokat": "vizsgálat",
    "vizsgálatokkal": "vizsgálat",
    "vizsgálatokra": "vizsgálat",
    "vizsgálatot": "vizsgálat",
    "vizsgálatra": "vizsgálat",
    "vizsgálgatni": "vizsgálgat",
    "vizsgálhatjuk": "vizsgálhat",
    "vizsgálja": "vizsgál",
    "vizsgálják": "vizsgál",
    "vizsgálni": "vizsgál",
    "vizsgált": "vizsgál",
    "vizsgálta": "vizsgál",
    "vizsgálták": "vizsgál",
    "vizsgálóasztalon": "vizsgálóasztal",
    "vizsgálóbizottságok": "vizsgálóbizottság",
    "vizsgálódhatnak": "vizsgálódhat",
    "vizsgálódóknak": "vizsgálódó",
    "vizsgára": "vizsga",
    "vizsgát": "vizsga",
    "vizsgázgatásra": "vizsgázgatás",
    "vizsgáznak": "vizsgázik",
    "vizében": "víz",
    "vizéből": "víz",
    "voksolt": "voksol",
    "voksolásnál": "voksolás",
    "voksát": "voks",
    "volna": "van",
    "volnának": "van",
    "volnánk": "van",
    "volnék": "van",
    "volt": "van",
    "voltak": "volt",
    "voltaképen": "voltakép",
    "voltaképp": "volta",
    "voltaképpen": "volta",
    "voltam": "volt",
    "voltatok": "volt",
    "voltuk": "van",
    "voltunk": "volt",
    "voltál": "van",
    "voltát": "volta",
    "volumenben": "volumen",
    "volumene": "volumen",
    "volumenének": "volumen",
    "vonakodott": "vonakodik",
    "vonakodásban": "vonakodás",
    "vonakodását": "vonakodás",
    "vonalai": "vonal",
    "vonalaikat": "vonal",
    "vonalaikban": "vonal",
    "vonalak": "vonal",
    "vonalakat": "vonal",
    "vonalakhoz": "vonal",
    "vonalakkal": "vonal",
    "vonalat": "vonal",
    "vonalban": "vonal",
    "vonalmentesen": "vonalmentes",
    "vonalon": "vonal",
    "vonalról": "vonal",
    "vonalszámot": "vonalszám",
    "vonalvezetésben": "vonalvezetés",
    "vonalában": "vonal",
    "vonalának": "vonal",
    "vonalát": "vonal",
    "vonatban": "vonat",
    "vonatkoznak": "vonatkozik",
    "vonatkozott": "vonatkozik",
    "vonatkoztak": "vonatkozik",
    "vonatkozásban": "vonatkozás",
    "vonatkozásuk": "vonatkozás",
    "vonatkozásában": "vonatkozás",
    "vonatkozóan": "vonatkozó",
    "vonatnak": "vonat",
    "vonatok": "vonat",
    "vonaton": "vonat",
    "vonatot": "vonat",
    "vonatra": "vonat",
    "vonatról": "vonat",
    "vonatszerelvénnyel": "vonatszerelvény",
    "vonja": "von",
    "vonják": "von",
    "vonni": "von",
    "vonszolta": "vonszol",
    "vont": "von",
    "vonta": "von",
    "vontak": "vont",
    "vontatottan": "vontatott",
    "vontatta": "vontat",
    "vontatókat": "vontató",
    "vonták": "von",
    "vonuljatok": "vonul",
    "vonulnak": "vonul",
    "vonulni": "vonul",
    "vonult": "vonul",
    "vonultak": "vonult",
    "vonzalmat": "vonzalom",
    "vonzerejének": "vonzerő",
    "vonzhatja": "vonzhat",
    "vonzott": "vonz",
    "vonzotta": "vonz",
    "vonzzák": "vonz",
    "vonzása": "vonzás",
    "vonzódnak": "vonzódik",
    "vonzódott": "vonzódik",
    "vonzódása": "vonzódás",
    "vonzónak": "vonzó",
    "vonása": "vonás",
    "vonások": "vonás",
    "vonított": "vonít",
    "vonósnégyest": "vonósnégyes",
    "vonósnégyesének": "vonósnégyes",
    "vulkánjaiból": "vulkán",
    "vádak": "vád",
    "vádakat": "vád",
    "vádaknak": "vád",
    "vádat": "vád",
    "vádja": "vád",
    "vádjaink": "vád",
    "vádjait": "vád",
    "vádját": "vád",
    "vádlott-társuk": "vádlott-társ",
    "vádlottak": "vádlott",
    "vádolhattak": "vádolhat",
    "vádolja": "vádol",
    "vádolják": "vádol",
    "vádollak": "vádol",
    "vádolnak": "vádol",
    "vádolni": "vádol",
    "vádolt": "vádol",
    "vádoltassunk": "vádoltas",
    "vádolták": "vádol",
    "vádpontok": "vádpont",
    "vágatta": "vágat",
    "vággyal": "vágy",
    "vághatják": "vághat",
    "vághatjátok": "vághat",
    "vágja": "vág",
    "vágjak": "vág",
    "vágjon": "vág",
    "vágjunk": "vág",
    "vágják": "vág",
    "vágnak": "vág",
    "vágni": "vág",
    "vágnának": "vág",
    "vágott": "vág",
    "vágta": "vág",
    "vágtak": "vág",
    "vágták": "vágta",
    "vágya": "vágy",
    "vágyai": "vágy",
    "vágyaiknak": "vágy",
    "vágyaink": "vágy",
    "vágyait": "vágy",
    "vágyakozzál": "vágyakozik",
    "vágyat": "vágy",
    "vágyban": "vágy",
    "vágyból": "vágy",
    "vágyjanak": "vágyik",
    "vágyom": "vágyik",
    "vágyott": "vágyik",
    "vágytam": "vágyik",
    "vágytól": "vágy",
    "vágyának": "vágy",
    "vágyára": "vágy",
    "vágyódott": "vágyódik",
    "vágyódásunkat": "vágyódás",
    "vágányain": "vágány",
    "vágányról": "vágány",
    "vágást": "vágás",
    "vágódni": "vágódik",
    "vágódott": "vágódik",
    "vágóhidak": "vágóhíd",
    "vágóhídon": "vágóhíd",
    "vágóhídra": "vágóhíd",
    "vágóhídról": "vágóhíd",
    "vájja": "váj",
    "vákuumba": "vákuum",
    "válasszam": "választ",
    "válasszon": "választ",
    "válasszák": "választ",
    "válasza": "válasz",
    "válaszfalon": "válaszfal",
    "válaszként": "válasz",
    "válaszok": "válasz",
    "válaszokat": "válasz",
    "válaszolni": "válaszol",
    "válaszolt": "válaszol",
    "válaszolta": "válaszol",
    "válaszoltam": "válaszolt",
    "válaszra": "válasz",
    "választ": "válasz",
    "választanak": "választ",
    "választani": "választ",
    "választania": "választ",
    "választhatnál": "választhat",
    "választhatta": "választhat",
    "választhatunk": "választhat",
    "választja": "választ",
    "választják": "választ",
    "választmánya": "választmány",
    "választmányt": "választmány",
    "választmányának": "választmány",
    "választott": "választ",
    "választotta": "választ",
    "választottak": "választott",
    "választották": "választ",
    "választunk": "választ",
    "választása": "választás",
    "választáskor": "választás",
    "választások": "választás",
    "választásokat": "választás",
    "választásokhoz": "választás",
    "választásokig": "választás",
    "választásokon": "választás",
    "választásokra": "választás",
    "választáson": "választás",
    "választásra": "választás",
    "választással": "választás",
    "választásuk": "választás",
    "választásában": "választás",
    "választásával": "választás",
    "választékának": "választéka",
    "választékát": "választéka",
    "választói": "választó",
    "választóik": "választói",
    "választók": "választó",
    "választókerületből": "választókerület",
    "választóknak": "választó",
    "választópolgárokat": "választópolgár",
    "válaszul": "válasz",
    "válaszát": "válasz",
    "válhatna": "válhat",
    "válhatnának": "válhat",
    "váljanak": "válik",
    "váljék": "válik",
    "válla": "váll",
    "válladat": "váll",
    "vállak": "váll",
    "vállakkal": "váll",
    "vállal": "váll",
    "vállalata": "vállalat",
    "vállalatok": "vállalat",
    "vállalatokkal": "vállalat",
    "vállalatoknak": "vállalat",
    "vállalhatja": "vállalhat",
    "vállalhatna": "vállalhat",
    "vállalhatnak": "vállalhat",
    "vállalhatta": "vállalhat",
    "vállalja": "vállalj",
    "vállaljanak": "vállal",
    "vállaljon": "vállalj",
    "vállaljuk": "vállalj",
    "vállalják": "vállal",
    "vállaljátok": "vállal",
    "vállalkoznak": "vállalkozik",
    "vállalkozni": "vállalkozik",
    "vállalkoztak": "vállalkozik",
    "vállalkoztam": "vállalkozik",
    "vállalkozása": "vállalkozás",
    "vállalkozásba": "vállalkozás",
    "vállalkozások": "vállalkozás",
    "vállalkozással": "vállalkozás",
    "vállalkozástól": "vállalkozás",
    "vállalkozásunk": "vállalkozás",
    "vállalkozásának": "vállalkozás",
    "vállalkozásáért": "vállalkozás",
    "vállalkozóból": "vállalkozó",
    "vállalkozói": "vállalkozó",
    "vállalkozók": "vállalkozó",
    "vállalkozóknak": "vállalkozó",
    "vállalkozóknál": "vállalkozó",
    "vállalkozót": "vállalkozó",
    "vállalna": "vállal",
    "vállalnak": "vállal",
    "vállalni": "vállal",
    "vállalnunk": "vállal",
    "vállalná": "vállal",
    "vállalnék": "vállal",
    "vállalok": "vállal",
    "vállalom": "vállal",
    "vállalt": "vállal",
    "vállalta": "vállal",
    "vállaltad": "vállalt",
    "vállaltak": "vállalt",
    "vállaltam": "vállalt",
    "vállaltatok": "vállaltat",
    "vállalták": "vállal",
    "vállalása": "vállalás",
    "vállat": "váll",
    "vállon": "váll",
    "válluk": "váll",
    "vállunkra": "váll",
    "vállán": "váll",
    "vállánál": "váll",
    "vállára": "váll",
    "vállát": "váll",
    "válna": "válik",
    "válnak": "válik",
    "válni": "válik",
    "válnunk": "válik",
    "válogathatnak": "válogathat",
    "válogatni": "válogat",
    "válogatott": "válogat",
    "válogatottal": "válogatott",
    "válogatottat": "válogatott",
    "válogatottjai": "válogatott",
    "válogatta": "válogat",
    "válogattak": "válogat",
    "válogatták": "válogat",
    "válogatósak": "válogatós",
    "válsz": "válik",
    "válságai": "válság",
    "válságban": "válság",
    "válságköltségvetést": "válságköltségvetés",
    "válságosabb": "válságos",
    "válságosra": "válságos",
    "válságot": "válság",
    "válságáról": "válság",
    "válságát": "válság",
    "válságövezetnek": "válságövezet",
    "vált": "válik",
    "váltak": "vált",
    "váltani": "vált",
    "váltaniuk": "vált",
    "váltanom": "vált",
    "válthassanak": "válthat",
    "válthatna": "válthat",
    "válthatnak": "válthat",
    "válthatott": "válthat",
    "váltja": "vált",
    "váltják": "vált",
    "váltogatta": "váltogat",
    "váltok": "vált",
    "váltott": "vált",
    "váltotta": "vált",
    "váltottak": "váltott",
    "váltottam": "váltott",
    "váltottunk": "váltott",
    "változata": "változat",
    "változatai": "változat",
    "változatait": "változat",
    "változatban": "változat",
    "változatként": "változat",
    "változatlanok": "változatlan",
    "változatlanul": "változatlan",
    "változatok": "változat",
    "változatokban": "változat",
    "változatosabb": "változatos",
    "változatot": "változat",
    "változattal": "változat",
    "változatában": "változat",
    "változatát": "változat",
    "változnak": "változik",
    "változnának": "változik",
    "változom": "változik",
    "változott": "változik",
    "változtak": "változik",
    "változtassa": "változtat",
    "változtassanak": "változtat",
    "változtathatják": "változtathat",
    "változtathatnának": "változtathat",
    "változtathatunk": "változtathat",
    "változtathatósága": "változtathatóság",
    "változtatni": "változtat",
    "változtatott": "változtat",
    "változtatták": "változtat",
    "változtatunk": "változtat",
    "változtatásakor": "változtatás",
    "változtatások": "változtatás",
    "változtatásokat": "változtatás",
    "változtatást": "változtatás",
    "változtatásának": "változtatás",
    "változtatását": "változtatás",
    "változzék": "változik",
    "változása": "változás",
    "változáshoz": "változás",
    "változásnak": "változás",
    "változások": "változás",
    "változásokat": "változás",
    "változásokból": "változás",
    "változásokon": "változás",
    "változásra": "változás",
    "változásról": "változás",
    "változásának": "változás",
    "változására": "változás",
    "változását": "változás",
    "válts": "vált",
    "váltsa": "vált",
    "váltsák": "vált",
    "váltásában": "váltás",
    "vályoggödrök": "vályoggödör",
    "válást": "válás",
    "válásának": "válás",
    "vámházaknál": "vámház",
    "vámját": "vám",
    "vámkezelt": "vámkezel",
    "vámkezelést": "vámkezelés",
    "vámmal": "vám",
    "vámolják": "vámol",
    "vámszervek": "vámszerv",
    "vámtisztviselőhöz": "vámtisztviselő",
    "vámáruraktárban": "vámáruraktár",
    "vándorlásuk": "vándorlás",
    "vándormadarak": "vándormadár",
    "vándoroljanak": "vándorol",
    "vándorolni": "vándorol",
    "vándorolt": "vándorol",
    "vánszorogni": "vánszorog",
    "váradon": "vár",
    "váradra": "vár",
    "váradról": "vár",
    "váradtól": "vár",
    "várakozniuk": "várakozik",
    "várakozott": "várakozik",
    "várakoztak": "várakozik",
    "várakoztunk": "várakozik",
    "várakozásai": "várakozás",
    "várakozásnak": "várakozás",
    "várakozások": "várakozás",
    "várakozásokat": "várakozás",
    "várakozásokkal": "várakozás",
    "várakozásoknak": "várakozás",
    "várakozásra": "várakozás",
    "várakozással": "várakozás",
    "várakozástól": "várakozás",
    "várat": "vár",
    "váratlanul": "váratlan",
    "várba": "vár",
    "várban": "vár",
    "várhatja": "várhat",
    "várhatjuk": "várhat",
    "várhatnak": "várhat",
    "várhatóan": "várható",
    "várhatók": "várható",
    "várj": "vár",
    "várja": "vár",
    "várjam": "vár",
    "várjon": "vár",
    "várjuk": "vár",
    "várjunk": "vár",
    "várják": "vár",
    "várnak": "vár",
    "várni": "vár",
    "várnia": "vár",
    "várná": "vár",
    "várod": "vár",
    "vároldalban": "vároldal",
    "várom": "vár",
    "városa": "város",
    "városba": "város",
    "városban": "város",
    "városból": "város",
    "városhatártól": "városhatár",
    "városháza": "városház",
    "városiak": "városi",
    "városkáját": "városka",
    "városközpontot": "városközpont",
    "városmajorban": "városmajor",
    "városnak": "város",
    "városnegyedbe": "városnegyed",
    "városnegyedben": "városnegyed",
    "városok": "város",
    "városokat": "város",
    "városokban": "város",
    "városomban": "város",
    "városon": "város",
    "városra": "város",
    "városrészben": "városrész",
    "városrészekben": "városrész",
    "városrészektől": "városrész",
    "városrészt": "városrész",
    "várost": "város",
    "várostervezők": "várostervező",
    "várostól": "város",
    "városuk": "város",
    "városukba": "város",
    "városunk": "város",
    "városállam": "városáll",
    "városának": "város",
    "városát": "város",
    "városé": "város",
    "városét": "város",
    "vársz": "vár",
    "várt": "vár",
    "várta": "vár",
    "vártak": "várt",
    "vártam": "várt",
    "vártnál": "várt",
    "vártuk": "vár",
    "vártunk": "várt",
    "várták": "várta",
    "várukban": "vár",
    "várunk": "vár",
    "várójául": "váró",
    "várók": "váró",
    "vászna": "vászon",
    "vásznait": "vászon",
    "vásznakat": "vászon",
    "vásznakkal": "vászon",
    "vásznat": "vászon",
    "vásznunk": "vászon",
    "vásznát": "vászon",
    "vászonból": "vászon",
    "vászonra": "vászon",
    "vásárlása": "vásárlás",
    "vásárlásnál": "vásárlás",
    "vásárlások": "vásárlás",
    "vásárlásokat": "vásárlás",
    "vásárlásra": "vásárlás",
    "vásárlásról": "vásárlás",
    "vásárlásában": "vásárlás",
    "vásárlásánál": "vásárlás",
    "vásárlására": "vásárlás",
    "vásárlók": "vásárló",
    "vásárlóknak": "vásárló",
    "vásárlókra": "vásárló",
    "vásárlóktól": "vásárló",
    "vásárlót": "vásárló",
    "vásárlóértéke": "vásárlóérték",
    "vásárolhatja": "vásárolhat",
    "vásárolhatják": "vásárolhat",
    "vásárolj": "vásárol",
    "vásárolja": "vásárol",
    "vásárolják": "vásárol",
    "vásárolni": "vásárol",
    "vásárolt": "vásárol",
    "vásárolta": "vásárol",
    "vásároltak": "vásárolt",
    "vásárolták": "vásárol",
    "vásárra": "vásár",
    "vásárvárosban": "vásárváros",
    "vázból": "váz",
    "vázlatai": "vázlat",
    "vázolt": "vázol",
    "vázolta": "vázol",
    "vécében": "vécé",
    "vécék": "vécé",
    "vécét": "vécé",
    "védekezne": "védekezik",
    "védekezni": "védekezik",
    "védekezésből": "védekezés",
    "védelemre": "védelem",
    "védelme": "védelem",
    "védelmem": "védelem",
    "védelmemre": "védelem",
    "védelmet": "védelem",
    "védelmezi": "védelmez",
    "védelmezték": "védelmez",
    "védelmezője": "védelmező",
    "védelmébe": "védelem",
    "védelmében": "védelem",
    "védelmére": "védelem",
    "védelméről": "védelem",
    "védelmét": "védelem",
    "védelmükre": "védelem",
    "védenceik": "védenc",
    "védenceiknek": "védenc",
    "védenem": "véd",
    "védeni": "véd",
    "védett": "véd",
    "védetté": "védett",
    "védhetők": "védhető",
    "védi": "véd",
    "védik": "véd",
    "védte": "véd",
    "védtelenek": "védtelen",
    "védték": "véd",
    "védőbeszédek": "védőbeszéd",
    "védőernyőnek": "védőernyő",
    "védőernyőt": "védőernyő",
    "védői": "védő",
    "védőlemezeket": "védőlemez",
    "védőnővel": "védőnő",
    "védőről": "védő",
    "védőövezetéhez": "védőövezet",
    "végbe": "vég",
    "végbemennie": "végbemegy",
    "végbement": "végbemegy",
    "végbevitt": "végbevisz",
    "vége": "vég",
    "végeredményben": "végeredmény",
    "végeredményen": "végeredmény",
    "véget": "vég",
    "végezetül": "végezet",
    "végeznek": "végez",
    "végezni": "végez",
    "végezniük": "végez",
    "végezte": "végez",
    "végeztek": "végez",
    "végeztem": "végez",
    "végeztetnek": "végeztet",
    "végeztetni": "végeztet",
    "végezték": "végezte",
    "végeztével": "végezte",
    "végeztünk": "végez",
    "végezze": "végez",
    "végezzenek": "végez",
    "végezzük": "végez",
    "véghez": "vég",
    "végiben": "végi",
    "végig": "vég",
    "végigbizsergette": "végigbizserget",
    "végigböngéssze": "végigböngész",
    "végigcsinálni": "végigcsinál",
    "végigcsinálunk": "végigcsinál",
    "végigcsóvázták": "végigcsóváz",
    "végigfolyt": "végigfolyik",
    "végigfosztogatták": "végigfosztogat",
    "végigfürkészte": "végigfürkész",
    "végiggondolt": "végiggondol",
    "végiggondolta": "végiggondol",
    "végiggondoltam": "végiggondolt",
    "végiggondolása": "végiggondolás",
    "végiggurult": "végiggurul",
    "végiggurították": "végiggurít",
    "végighazudta": "végighazudik",
    "végigheveredett": "végigheveredik",
    "végighúztak": "végighúz",
    "végigjárja": "végigjár",
    "végigjártatta": "végigjártat",
    "végigkutatták": "végigkutat",
    "végiglátogatta": "végiglátogat",
    "végigment": "végigmegy",
    "végigmondta": "végigmond",
    "végignézem": "végignéz",
    "végignézett": "végignéz",
    "végignézni": "végignéz",
    "végigolvasta": "végigolvas",
    "végigpillantott": "végigpillant",
    "végigpróbált": "végigpróbál",
    "végigszaladt": "végigszalad",
    "végigszenvedniük": "végigszenved",
    "végigtapogatta": "végigtapogat",
    "végigtekinthetnek": "végigtekinthet",
    "végigvezette": "végigvezet",
    "végigvágta": "végigvág",
    "végigvágódott": "végigvágódik",
    "végigálmodta": "végigálmodik",
    "végire": "végi",
    "végjátékba": "végjáték",
    "végkielégítések": "végkielégítés",
    "végkielégítést": "végkielégítés",
    "végképp": "vég",
    "véglegesen": "végleges",
    "véglegesnek": "végleges",
    "véglegesítik": "véglegesít",
    "véglegesítése": "véglegesítés",
    "véglegesítéséhez": "véglegesítés",
    "végre": "vég",
    "végrehajtani": "végrehajt",
    "végrehajtott": "végrehajt",
    "végrehajtotta": "végrehajt",
    "végrehajtottak": "végrehajtott",
    "végrehajtották": "végrehajt",
    "végrehajtása": "végrehajtás",
    "végrehajtásra": "végrehajtás",
    "végrehajtást": "végrehajtás",
    "végrehajtástól": "végrehajtás",
    "végrehajtásuk": "végrehajtás",
    "végrehajtásának": "végrehajtás",
    "végrehajtását": "végrehajtás",
    "végtagok": "végtag",
    "végtelenbe": "végtelen",
    "végtelenségig": "végtelenség",
    "végtelenül": "végtelen",
    "végzek": "végez",
    "végzett": "végez",
    "végzettséggel": "végzettség",
    "végzettségük": "végzettség",
    "végzettségűek": "végzettségű",
    "végzetét": "végzet",
    "végzi": "végez",
    "végzik": "végez",
    "végződjék": "végződik",
    "végződnek": "végződik",
    "végződnie": "végződik",
    "végződött": "végződik",
    "végzőknek": "végző",
    "végállomáson": "végállomás",
    "végében": "vég",
    "végéhez": "vég",
    "végéig": "vég",
    "végén": "vég",
    "végénél": "vég",
    "végére": "vég",
    "végérvényesen": "végérvényes",
    "végéről": "vég",
    "végét": "vég",
    "végétől": "vég",
    "végórája": "végóra",
    "végül": "vég",
    "vékonyabb": "vékony",
    "vékát": "véka",
    "vékázzuk": "vékáz",
    "vélekedett": "vélekedik",
    "vélekedhetünk": "vélekedhet",
    "vélekedése": "vélekedés",
    "vélelme": "vélelem",
    "vélelmezett": "vélelmez",
    "vélem": "vél",
    "véleménnyel": "vélemény",
    "véleménye": "vélemény",
    "véleményed": "vélemény",
    "véleményedet": "vélemény",
    "véleményeik": "vélemény",
    "vélemények": "vélemény",
    "véleményeket": "vélemény",
    "véleményem": "vélemény",
    "véleményen": "vélemény",
    "véleményetek": "vélemény",
    "véleményhez": "vélemény",
    "véleménykülönbsége": "véleménykülönbség",
    "véleménykülönbségek": "véleménykülönbség",
    "véleményt": "vélemény",
    "véleményét": "vélemény",
    "véleményével": "vélemény",
    "véleményük": "vélemény",
    "véleményüket": "vélemény",
    "véletlenek": "véletlen",
    "véletlenszerűen": "véletlenszerű",
    "véletlenül": "véletlen",
    "vélhetően": "vélhető",
    "véli": "vél",
    "vélik": "vél",
    "vélnek": "vél",
    "vélt": "vél",
    "vélte": "vél",
    "véltem": "vélt",
    "véradások": "véradás",
    "véradással": "véradás",
    "véradástól": "véradás",
    "véradók": "véradó",
    "vérbajeseteket": "vérbajeset",
    "vérbajosok": "vérbajos",
    "vérbajt": "vérbaj",
    "vérbe": "vér",
    "vérből": "vér",
    "vércseréje": "vércsere",
    "vércsoportban": "vércsoport",
    "vércsoportból": "vércsoport",
    "vércsoportonként": "vércsoport",
    "vére": "vér",
    "véredben": "vér",
    "vérellátók": "vérellátó",
    "vérem": "vér",
    "véremnek": "vér",
    "véresen": "véres",
    "vérkeringésébe": "vérkeringés",
    "vérkészlete": "vérkészlet",
    "vérkészletek": "vérkészlet",
    "vérkészítmények": "vérkészítmény",
    "vérmérsékletét": "vérmérséklet",
    "vérnyomásmérővel": "vérnyomásmérő",
    "vérre": "vér",
    "vérrel": "vér",
    "vérszomjassá": "vérszomjas",
    "vért": "vér",
    "vértanúkat": "vértanú",
    "vértanúkká": "vértanú",
    "vértől": "vér",
    "vérének": "vér",
    "vérünknek": "vér",
    "véste": "vés",
    "vészharangot": "vészharang",
    "vésők": "véső",
    "vétele": "vétel",
    "vételárat": "vételár",
    "vételáron": "vételár",
    "vételárának": "vételár",
    "vétetne": "vétet",
    "vétett": "vét",
    "vétkeseket": "vétkes",
    "vétket": "vétek",
    "vétsége": "vétség",
    "vétségeket": "vétség",
    "vétséget": "vétség",
    "vígan": "víg",
    "víruskutatók": "víruskutató",
    "vírusokkal": "vírus",
    "vívmányként": "vívmány",
    "vívnak": "vív",
    "vívott": "vív",
    "vívónőtől": "vívónő",
    "vízbe": "víz",
    "vízbe-jégbe": "víz-jég",
    "vízben": "víz",
    "vízbázist": "vízbázis",
    "vízből": "víz",
    "vízcsövek": "vízcső",
    "vízdíjak": "vízdíj",
    "vízellátásában": "vízellátás",
    "vízen": "víz",
    "vízfelülettel": "vízfelület",
    "vízhúzást": "vízhúzás",
    "vízigényeket": "vízigény",
    "vízigénynek": "vízigény",
    "vízigényének": "vízigény",
    "vízimadarak": "vízimadár",
    "víziója": "vízió",
    "víziójától": "vízió",
    "vízióként": "vízió",
    "vízlépcsőről": "vízlépcső",
    "vízművek": "vízmű",
    "vízszintesen": "vízszintes",
    "vízszinteshez": "vízszintes",
    "víztározót": "víztározó",
    "víztócsák": "víztócsa",
    "víztömegen": "víztömeg",
    "víztől": "víz",
    "vízumlottóra": "vízumlottó",
    "vízumokat": "vízum",
    "vízvezetékcsövek": "vízvezetékcső",
    "vízviszonyok": "vízviszony",
    "vízzel": "víz",
    "vízzé": "víz",
    "vízálláskor": "vízállás",
    "vízállásokon": "vízállás",
    "vízért": "víz",
    "vóna": "van",
    "vödörben": "vödör",
    "völgyei": "völgy",
    "völgyvidékbe": "völgyvidék",
    "vörösek": "vörös",
    "vöröskatonák": "vöröskatona",
    "vöröskatonákat": "vöröskatona",
    "vöröskereszttől": "vöröskereszt",
    "vöröslött": "vöröslik",
    "vörösöket": "vörös",
    "vörösöknek": "vörös",
    "vőnek": "vő",
    "whiskysüvegek": "whiskysüveg",
    "x-szel": "x",
    "zabolátlan-szabadon": "zabolátlan-szabad",
    "zabtarlón": "zabtarló",
    "zacskókkal": "zacskó",
    "zacskót": "zacskó",
    "zagyvaságaikat": "zagyvaság",
    "zagyvaságok": "zagyvaság",
    "zagyvaságokkal": "zagyvaság",
    "zagyvaságot": "zagyvaság",
    "zagyvaságra": "zagyvaság",
    "zagyvaságáradat": "zagyvaságár",
    "zagyvaságért": "zagyvaság",
    "zaja": "zaj",
    "zajjal": "zaj",
    "zajlott": "zajlik",
    "zajlottak": "zajlott",
    "zajok": "zaj",
    "zajt": "zaj",
    "zajtalanul": "zajtalan",
    "zajtól": "zaj",
    "zajában": "zaj",
    "zavara": "zavar",
    "zavarba": "zavar",
    "zavarban": "zavar",
    "zavarják": "zavar",
    "zavarnak": "zavar",
    "zavarodjon": "zavarodik",
    "zavarodottan": "zavarodott",
    "zavarok": "zavar",
    "zavart": "zavar",
    "zavarta": "zavar",
    "zavartabb": "zavart",
    "zavartalanságát": "zavartalanság",
    "zavartan": "zavart",
    "zavartatásra": "zavartatás",
    "zavarták": "zavar",
    "zendített": "zendít",
    "zeneesztétikára": "zeneesztétika",
    "zenehallgatásra": "zenehallgatás",
    "zenekarai": "zenekar",
    "zenekart": "zenekar",
    "zenekarát": "zenekar",
    "zeneköltőt": "zeneköltő",
    "zeneművekre": "zenemű",
    "zeneszerszámok": "zeneszerszám",
    "zengett": "zeng",
    "zengi": "zeng",
    "zenében": "zene",
    "zenéjéért": "zene",
    "zenélésbe": "zenélés",
    "zenére": "zene",
    "zenéről": "zene",
    "zenészeket": "zenész",
    "zenét": "zene",
    "zenével": "zene",
    "zihált": "zihál",
    "zihálásba": "zihálás",
    "zilált": "zilál",
    "ziláltságával": "ziláltság",
    "zivatartól": "zivatar",
    "zoknikat": "zokni",
    "zokogta": "zokog",
    "zongoraleckéjéről": "zongoralecke",
    "zongorát": "zongora",
    "zsargonjában": "zsargon",
    "zsarnoksága": "zsarnokság",
    "zsarnokságok": "zsarnokság",
    "zsarnokságot": "zsarnokság",
    "zsarnokságukat": "zsarnokság",
    "zsarolnak": "zsarol",
    "zsarolni": "zsarol",
    "zsebbel": "zseb",
    "zsebből": "zseb",
    "zsebeimet": "zseb",
    "zsebeket": "zseb",
    "zsebkések": "zsebkés",
    "zsebpénzről": "zsebpénz",
    "zsebre": "zseb",
    "zsebébe": "zseb",
    "zsebében": "zseb",
    "zsebéből": "zseb",
    "zsebére": "zseb",
    "zsebét": "zseb",
    "zsebük": "zseb",
    "zsebünkben": "zseb",
    "zsellérgyerekeket": "zsellérgyerek",
    "zsellérgyereket": "zsellérgyerek",
    "zsemledarabot": "zsemledarab",
    "zsemléből": "zsemle",
    "zseniálisan": "zseniális",
    "zsibogóban": "zsibogó",
    "zsibvásárban": "zsibvásár",
    "zsidóhoz": "zsidó",
    "zsidók": "zsidó",
    "zsidókat": "zsidó",
    "zsidókra": "zsidó",
    "zsidókról": "zsidó",
    "zsidónak": "zsidó",
    "zsidónál": "zsidó",
    "zsidóságon": "zsidóság",
    "zsidóságával": "zsidóság",
    "zsidót": "zsidó",
    "zsidótörvények": "zsidótörvény",
    "zsidóéhoz": "zsidó",
    "zsinatolhattak": "zsinatolhat",
    "zsinegdarabot": "zsinegdarab",
    "zsoldon": "zsold",
    "zsoldot": "zsold",
    "zsongott": "zsong",
    "zsugoriak": "zsugori",
    "zsugoriakkal": "zsugori",
    "zsugorinak": "zsugorín",
    "zsugorodni": "zsugorodik",
    "zsákba": "zsák",
    "zsákban": "zsák",
    "zsákból": "zsák",
    "zsákdarabba": "zsákdarab",
    "zsákdarabbal": "zsákdarab",
    "zsákjába": "zsák",
    "zsákját": "zsák",
    "zsákkal": "zsák",
    "zsákmányolni": "zsákmányol",
    "zsákmányról": "zsákmány",
    "zsákok": "zsák",
    "zsákolnak": "zsákol",
    "zsákolni": "zsákol",
    "zsákot": "zsák",
    "zsákszámra": "zsákszám",
    "zsírban": "zsír",
    "zsírját": "zsír",
    "zsírnak": "zsír",
    "zsírpárnák": "zsírpárna",
    "zsírról": "zsír",
    "zsírsertést": "zsírsertés",
    "zsírt": "zsír",
    "zsúfolják": "zsúfol",
    "zsúfolt": "zsúfol",
    "zsúfoltabbak": "zsúfolt",
    "zsúfoltak": "zsúfolt",
    "zsúfolták": "zsúfol",
    "zsúfolásig": "zsúfolás",
    "zsúfolódott": "zsúfolódik",
    "zubogjon": "zubog",
    "zubogott": "zubog",
    "zugaiból": "zug",
    "zugárusok": "zugárus",
    "zuhanjon": "zuhan",
    "zuhanjunk": "zuhan",
    "zuhannak": "zuhan",
    "zuhanni": "zuhan",
    "zuhansz": "zuhan",
    "zuhant": "zuhan",
    "zuhantak": "zuhant",
    "zuhanása": "zuhanás",
    "zuhataga": "zuhatag",
    "zupások": "zupás",
    "zálogba": "zálog",
    "zálogként": "zálog",
    "zálogosításával": "zálogosítás",
    "zálogpiacon": "zálogpiac",
    "zálogtevékenységgel": "zálogtevékenység",
    "zálogának": "zálog",
    "záporoztak": "záporoz",
    "zárak": "zár",
    "zárd": "zár",
    "zárja": "zár",
    "zárjegyek": "zárjegy",
    "zárjának": "zár",
    "zárkába": "zárka",
    "zárkában": "zárka",
    "zárkózott": "zárkózik",
    "zárkózottságuk": "zárkózottság",
    "zárlatot": "zárlat",
    "zárnak": "zár",
    "zárni": "zár",
    "zárnia": "zár",
    "zárt": "zár",
    "zárta": "zár",
    "zártak": "zárt",
    "zárták": "zárta",
    "zárul": "zár",
    "zárult": "zárul",
    "zárásaként": "zárás",
    "záráskor": "zárás",
    "záróakkordjaként": "záróakkord",
    "zárójelen": "zárójel",
    "záróráig": "záróra",
    "záróünnepélyen": "záróünnepély",
    "zászlai": "zászló",
    "zászlaja": "zászló",
    "zászlódísze": "zászlódísz",
    "zászlójához": "zászló",
    "zászlók": "zászló",
    "zászlókat": "zászló",
    "zászlókkal": "zászló",
    "zászlókról": "zászló",
    "zászlóként": "zászló",
    "zászlórudakat": "zászlórúd",
    "zászlót": "zászló",
    "zátonyra": "zátony",
    "zónahatárt": "zónahatár",
    "zónában": "zóna",
    "zónából": "zóna",
    "zónának": "zóna",
    "zökkennek": "zökken",
    "zökkent": "zökken",
    "zökkenői": "zökkenő",
    "zöldben": "zöld",
    "zöldek": "zöld",
    "zöldet": "zöld",
    "zöldfelületek": "zöldfelület",
    "zöldje": "zöld",
    "zöldjét": "zöld",
    "zöldre": "zöld",
    "zöldségféléket": "zöldségféle",
    "zöldáradásokra": "zöldáradás",
    "zöme": "zöm",
    "zömében": "zöm",
    "zömök": "zöm",
    "zöngéssel": "zöngés",
    "zöngést": "zöngés",
    "zörgött": "zörög",
    "zörrent": "zörren",
    "zöttyent": "zöttyen",
    "zúdítják": "zúdít",
    "zúgolódott": "zúgolódik",
    "zúgott": "zúg",
    "zúgtak": "zúg",
    "zúgásban": "zúgás",
    "zúzni": "zúz",
    "zúzott": "zúz",
    "zúzta": "zúz",
    "zúzódnának": "zúzódik",
    "züllést": "züllés",
    "zümmögtek": "zümmög",
    "zümmögött": "zümmög",
    "zűrzavara": "zűrzavar",
    "zűrzavarban": "zűrzavar",
    "zűrzavarából": "zűrzavar",
    "Árpádtól": "Árpád",
    "Égei-tengerben": "Égei-tenger",
    "Élysée-palotát": "Élysée-palota",
    "Érden": "Érd",
    "Észak-Afrikában": "Észak-Afrika",
    "Észak-Amerikában": "Észak-Amerika",
    "Észak-Kaukázusban": "Észak-Kaukázus",
    "Észak-Írországban": "Észak-Írország",
    "Északi-sarkért": "Északi-sarok",
    "Óbudán": "Óbuda",
    "Óceániá-t": "Óceánia",
    "Óceániában": "Óceánia",
    "Óceánián": "Óceánia",
    "Óceániának": "Óceánia",
    "Óceániát": "Óceánia",
    "Ózdon": "Ózd",
    "ÚESZ-t": "ÚESZ",
    "ábrándjuk": "ábránd",
    "ábrándképeinek": "ábrándkép",
    "ábrándképeket": "ábrándkép",
    "ábrándok": "ábránd",
    "ábrándokat": "ábránd",
    "ábrándozni": "ábrándozik",
    "ábrándoztak": "ábrándozik",
    "ábrándoztam": "ábrándozik",
    "ábrándozásaimban": "ábrándozás",
    "ábrándozóvá": "ábrándozó",
    "ábránkon": "ábra",
    "ábrázatát": "ábrázat",
    "ábrázol": "ábráz",
    "ábrázolni": "ábrázol",
    "ábécére": "ábécé",
    "ácsolt": "ácsol",
    "ácsorgott": "ácsorog",
    "ácsorogjunk": "ácsorog",
    "ácsorogna": "ácsorog",
    "ácsorogni": "ácsorog",
    "ácsorogtak": "ácsorog",
    "ácsorogtunk": "ácsorog",
    "ádámcsutkája": "ádámcsutka",
    "ága": "ág",
    "ágait": "ág",
    "ágaival": "ág",
    "ágak": "ág",
    "ágazatai": "ágazat",
    "ágazatban": "ágazat",
    "ágazatának": "ágazat",
    "ággyal": "ágy",
    "ágra": "ág",
    "ágya": "ágy",
    "ágyad": "ágy",
    "ágyain": "ágy",
    "ágyak": "ágy",
    "ágyakból": "ágy",
    "ágyakkal": "ágy",
    "ágyakon": "ágy",
    "ágyanként": "ágy",
    "ágyat": "ágy",
    "ágyazták": "ágyaz",
    "ágyba": "ágy",
    "ágyban": "ágy",
    "ágyból": "ágy",
    "ágyfejének": "ágyfej",
    "ágyhoz": "ágy",
    "ágyhuzatával": "ágyhuzat",
    "ágynak": "ágy",
    "ágyneműnél": "ágynemű",
    "ágyneműt": "ágynemű",
    "ágyon": "ágy",
    "ágyra": "ágy",
    "ágyról": "ágy",
    "ágytól": "ágy",
    "ágyuk": "ágy",
    "ágyukban": "ágy",
    "ágyában": "ágy",
    "ágyához": "ágy",
    "ágyáig": "ágy",
    "ágyának": "ágy",
    "ágyára": "ágy",
    "ágyékokból": "ágyék",
    "ágyúk": "ágyú",
    "ágyút": "ágyú",
    "ágába": "ág",
    "ágára": "ág",
    "áhított": "áhít",
    "álarca": "álarc",
    "álarcot": "álarc",
    "álcázott": "álcáz",
    "áldomást": "áldomás",
    "áldozata": "áldozat",
    "áldozatai": "áldozat",
    "áldozataikat": "áldozat",
    "áldozatok": "áldozat",
    "áldozatokról": "áldozat",
    "áldozatokéval": "áldozat",
    "áldozatot": "áldozat",
    "áldozatról": "áldozat",
    "áldozatukká": "áldozat",
    "áldozatul": "áldozat",
    "áldozatvállalásra": "áldozatvállalás",
    "áldozatául": "áldozat",
    "áldozaté": "áldozat",
    "áldoznak": "áldozik",
    "áldozni": "áldozik",
    "áldozok": "áldozik",
    "áldozta": "áldozik",
    "áldozza": "áldozik",
    "áldozzon": "áldozik",
    "áldást": "áldás",
    "áldását": "áldás",
    "álhíreket": "álhír",
    "álla": "áll",
    "állaga": "állag",
    "állagmegóvására": "állagmegóvás",
    "állagmegőrzésében": "állagmegőrzés",
    "állam": "áll",
    "államadósságunkat": "államadósság",
    "államai": "állam",
    "államalakulatnak": "államalakulat",
    "államalakulatok": "államalakulat",
    "államba": "állam",
    "államban": "állam",
    "államból": "állam",
    "államformakérdésnek": "államformakérdés",
    "államformavitában": "államformavita",
    "államformája": "államformá",
    "államformájának": "államformá",
    "államformájáról": "államformá",
    "államformáját": "államformá",
    "államformáról": "államformá",
    "államformát": "államformá",
    "államférfiak": "államférfi",
    "államférfihez": "államférfi",
    "államfői": "államfő",
    "államfőket": "államfő",
    "államfőnek": "államfő",
    "államfőt": "államfő",
    "államfővel": "államfő",
    "államkötvényjegyzések": "államkötvényjegyzés",
    "állammal": "állam",
    "államminisztere": "államminiszter",
    "állammá": "állam",
    "államnak": "állam",
    "államnyelvtörvénnyel": "államnyelvtörvény",
    "államok": "állam",
    "államokat": "állam",
    "államokban": "állam",
    "államoknak": "állam",
    "államon": "állam",
    "államot": "állam",
    "állampolgárainak": "állampolgár",
    "állampolgárok": "állampolgár",
    "állampolgárral": "állampolgár",
    "állampolgárt": "állampolgár",
    "államrészek": "államrész",
    "államtitkár-helyettesnek": "államtitkár-helyettes",
    "államtitkára": "államtitok",
    "államtitkárral": "államtitkár",
    "államtitkárának": "államtitkár",
    "államtitkárát": "államtitkár",
    "államtitkárától": "államtitkár",
    "államtól": "állam",
    "államuk": "állam",
    "államvasutak": "államvasút",
    "államához": "állam",
    "állandóan": "állandó",
    "állandóbb": "állandó",
    "állandósult": "állandósul",
    "állandósulásának": "állandósulás",
    "állandósítása": "állandósítás",
    "állandóvá": "állandó",
    "állani": "áll",
    "állapodott": "állapodik",
    "állapodtak": "állapodik",
    "állapodtunk": "állapodik",
    "állapot": "állap",
    "állapota": "állapot",
    "állapotba": "állapot",
    "állapotban": "állapot",
    "állapotnak": "állapot",
    "állapotok": "állapot",
    "állapotokat": "állapot",
    "állapotokhoz": "állapot",
    "állapotokért": "állapot",
    "állapottól": "állapot",
    "állapotuk": "állapot",
    "állapotában": "állapot",
    "állapotán": "állapot",
    "állapotát": "állapot",
    "állapítani": "állapít",
    "állapítania": "állapít",
    "állapítaná": "állapít",
    "állapítják": "állapít",
    "állapította": "állapít",
    "állapítottak": "állapított",
    "állapítottuk": "állapít",
    "állapítsa": "állapít",
    "állat": "áll",
    "állataikkal": "állat",
    "állatfajok": "állatfaj",
    "állatfajokat": "állatfaj",
    "állatfajták": "állatfajtá",
    "állatfajtának": "állatfajtá",
    "állatgyilkosságok": "állatgyilkosság",
    "állatkertbe": "állatkert",
    "állatkertből": "állatkert",
    "állatkertért": "állatkert",
    "állatként": "állat",
    "állatok": "állat",
    "állatokat": "állat",
    "állatokon": "állat",
    "állatországban": "állatország",
    "állattenyésztői": "állattenyésztő",
    "állattrófeát": "állattrófea",
    "állatvilágát": "állatvilág",
    "állatért": "állat",
    "álldogálnia": "álldogál",
    "álldogáltak": "álldogált",
    "állhatatosan": "állhatatos",
    "állhatja": "állhat",
    "állhatta": "állhat",
    "állj": "áll",
    "állja": "áll",
    "álljak": "áll",
    "álljon": "áll",
    "álljunk": "áll",
    "állják": "áll",
    "állkapcsot": "állkapocs",
    "állkapcsába": "állkapocs",
    "állna": "áll",
    "állnak": "áll",
    "állni": "áll",
    "állnia": "áll",
    "állniuk": "áll",
    "állnának": "áll",
    "állok": "áll",
    "állománynak": "állomány",
    "állomásaira": "állomás",
    "állomásig": "állomás",
    "állomásnak": "állomás",
    "állomásokat": "állomás",
    "állomásokon": "állomás",
    "állomáson": "állomás",
    "állomásozik": "állomásoz",
    "állomásoztatásának": "állomásoztatás",
    "állomásra": "állomás",
    "állomásról": "állomás",
    "állomására": "állomás",
    "állomását": "állomás",
    "állott": "áll",
    "állottak": "állott",
    "állottam": "állott",
    "állottunk": "állott",
    "állsz": "áll",
    "állt": "áll",
    "állta": "áll",
    "álltak": "állt",
    "álltam": "állt",
    "álltunk": "állt",
    "állták": "állta",
    "álltál": "áll",
    "állunk": "áll",
    "állványokon": "állvány",
    "állában": "áll",
    "állása": "állás",
    "állásaiban": "állás",
    "állásba": "állás",
    "állásban": "állás",
    "állásfoglalása": "állásfoglalás",
    "állásfoglalások": "állásfoglalás",
    "állásfoglalással": "állásfoglalás",
    "állásfoglalást": "állásfoglalás",
    "állásfoglalásuk": "állásfoglalás",
    "állásfoglalásában": "állásfoglalás",
    "állásfoglalásához": "állásfoglalás",
    "álláshoz": "állás",
    "álláskereséssel": "álláskeresés",
    "álláspontja": "álláspont",
    "álláspontjukat": "álláspont",
    "álláspontjában": "álláspont",
    "álláspontjának": "álláspont",
    "álláspontját": "álláspont",
    "álláspontjával": "álláspont",
    "álláspontok": "álláspont",
    "álláspontokban": "álláspont",
    "álláspontot": "álláspont",
    "állást": "állás",
    "állástalannak": "állástalan",
    "állástalanok": "állástalan",
    "állástalanokhoz": "állástalan",
    "állástalanról": "állástalan",
    "állástalanságnak": "állástalanság",
    "állástalanságot": "állástalanság",
    "állásuk": "állás",
    "állásából": "állás",
    "állását": "állás",
    "állásával": "állás",
    "állát": "áll",
    "állítanak": "állít",
    "állítani": "állít",
    "állítanunk": "állít",
    "állíthatja": "állíthat",
    "állítja": "állít",
    "állítjuk": "állít",
    "állítják": "állít",
    "állítod": "állít",
    "állított": "állít",
    "állította": "állít",
    "állítottak": "állított",
    "állítottam": "állított",
    "állítottunk": "állított",
    "állították": "állít",
    "állítsak": "állít",
    "állítsanak": "állít",
    "állítsd": "állít",
    "állítson": "állít",
    "állítása": "állítás",
    "állításait": "állítás",
    "állításnak": "állítás",
    "állítások": "állítás",
    "állításokat": "állítás",
    "állítást": "állítás",
    "állításuk": "állítás",
    "állításának": "állítás",
    "állításával": "állítás",
    "állók": "álló",
    "állókból": "álló",
    "állóknak": "álló",
    "állólámpájának": "állólámpa",
    "állónak": "álló",
    "állóvizét": "állóvíz",
    "állóvízében": "állóvíz",
    "álma": "álom",
    "álmai": "álom",
    "álmaiban": "álom",
    "álmaiból": "álom",
    "álmaim": "álom",
    "álmatlanságban": "álmatlanság",
    "álmatlansággal": "álmatlanság",
    "álmatlanságtól": "álmatlanság",
    "álmatlanságától": "álmatlanság",
    "álmennyezetnek": "álmennyezet",
    "álmodban": "álom",
    "álmodból": "álom",
    "álmodnia": "álmodik",
    "álmodott": "álmodik",
    "álmodozott": "álmodozik",
    "álmodozásba": "álmodozás",
    "álmodozásokba": "álmodozás",
    "álmodozóvá": "álmodozó",
    "álmodta": "álmodik",
    "álmodtam": "álmodik",
    "álmok": "álom",
    "álmokat": "álom",
    "álmom": "álom",
    "álmomba": "álom",
    "álmomban": "álom",
    "álmosak": "álmos",
    "álmosan": "álmos",
    "álmot": "álom",
    "álmukból": "álom",
    "álmában": "álom",
    "álmából": "álom",
    "álmához": "álom",
    "álmának": "álom",
    "álmát": "álom",
    "álmélkodott": "álmélkodik",
    "álnokságát": "álnokság",
    "álomba": "álom",
    "álomban": "álom",
    "álomból": "álom",
    "álomhatárt": "álomhatár",
    "álommagyarázata": "álommagyarázat",
    "álomra": "álom",
    "álruhába": "álruha",
    "álruhában": "álruha",
    "általa": "által",
    "általuk": "által",
    "általunk": "által",
    "általánosan": "általános",
    "általánossá": "általános",
    "általánosságban": "általánosság",
    "általánosságokat": "általánosság",
    "általánosságokon": "általánosság",
    "álvámostól": "álvámos",
    "álöltözetben": "álöltözet",
    "ámítja": "ámít",
    "ámítjuk": "ámít",
    "ángyaink": "ángy",
    "ápolják": "ápol",
    "ápolt": "ápol",
    "ápolása": "ápolás",
    "ápolásra": "ápolás",
    "ápolást": "ápolás",
    "ápolók": "ápoló",
    "áporodott": "áporodik",
    "áprilisban": "április",
    "áprilistól": "április",
    "áprilisában": "április",
    "áprilisára": "április",
    "ára": "ár",
    "árad": "ár",
    "áradat": "ár",
    "áradata": "áradat",
    "áradatot": "áradat",
    "áradattól": "áradat",
    "áradni": "árad",
    "áradt": "árad",
    "áradtak": "áradt",
    "áradása": "áradás",
    "árai": "ár",
    "áraikból": "ár",
    "árait": "ár",
    "árajánlatot": "árajánlat",
    "árak": "ár",
    "árakat": "ár",
    "árakon": "ár",
    "áram": "ár",
    "áramellátásának": "áramellátás",
    "áramlata": "áramlat",
    "áramlatok": "áramlat",
    "áramlott": "áramlik",
    "áramlásával": "áramlás",
    "áramszolgáltatók": "áramszolgáltató",
    "áramtakarékosságra": "áramtakarékosság",
    "áramtermelőből": "áramtermelő",
    "árarányok": "árarány",
    "árasztott": "áraszt",
    "árasztotta": "áraszt",
    "árasztották": "áraszt",
    "árat": "ár",
    "árazta": "áraz",
    "árban": "ár",
    "árbevétele": "árbevétel",
    "árbevételhez": "árbevétel",
    "árbevétellel": "árbevétel",
    "árbevételt": "árbevétel",
    "árbevételét": "árbevétel",
    "árbevételük": "árbevétel",
    "árbizottságuk": "árbizottság",
    "árból": "ár",
    "árcsökkentést": "árcsökkentés",
    "árcsökkentését": "árcsökkentés",
    "árcsökkentően": "árcsökkentő",
    "árcsökkenését": "árcsökkenés",
    "árcéduláival": "árcédula",
    "áremelkedést": "áremelkedés",
    "áremelések": "áremelés",
    "áresésnek": "áresés",
    "árfolyama": "árfolyam",
    "árfolyamok": "árfolyam",
    "árfolyamokat": "árfolyam",
    "árfolyamon": "árfolyam",
    "árfolyamot": "árfolyam",
    "árfolyamának": "árfolyam",
    "árfolyamát": "árfolyam",
    "árfolyamértéken": "árfolyamérték",
    "árhullám": "árhulla",
    "árka": "árok",
    "árkiegészítést": "árkiegészítés",
    "árkokban": "árok",
    "árkot": "árok",
    "árkában": "árok",
    "árnyak": "árny",
    "árnyakat": "árnyak",
    "árnyalakjáról": "árnyalak",
    "árnyalattal": "árnyalat",
    "árnyalt": "árnyal",
    "árnyat": "árny",
    "árnyéka": "árnyék",
    "árnyékban": "árnyék",
    "árnyékfoltokkal": "árnyékfolt",
    "árnyékhadseregnek": "árnyékhadsereg",
    "árnyékkockákon": "árnyékkocka",
    "árnyékokkal": "árnyék",
    "árnyékot": "árnyék",
    "árnyékszerűen": "árnyékszerű",
    "árnyékszékre": "árnyékszék",
    "árnyékukat": "árnyék",
    "árnyékvilágba": "árnyékvilág",
    "árnyékában": "árnyék",
    "árokba": "árok",
    "árokban": "árok",
    "árokparton": "árokpart",
    "áron": "ár",
    "árpatarlóra": "árpatarló",
    "árpád": "árpa",
    "árpádtól": "árpa",
    "árral": "ár",
    "árszinteken": "árszint",
    "árszinthez": "árszint",
    "árszintje": "árszint",
    "ártalmatlanná": "ártalmatlan",
    "ártalmatlanításáról": "ártalmatlanítás",
    "ártani": "árt",
    "ártatlannak": "ártatlan",
    "ártatlanok": "ártatlan",
    "ártatlansága": "ártatlanság",
    "ártatlanságod": "ártatlanság",
    "ártatlanságtokban": "ártatlanságtok",
    "ártatlanságuk": "ártatlanság",
    "ártatlanságukat": "ártatlanság",
    "ártatlanságában": "ártatlanság",
    "ártatlanságát": "ártatlanság",
    "ártatlanul": "ártatlan",
    "ártott": "árt",
    "árualapot": "árualap",
    "áruba": "áru",
    "áruból": "áru",
    "áruexportból": "áruexport",
    "áruházak": "áruház",
    "áruházban": "áruház",
    "áruházra": "áruház",
    "áruja": "áru",
    "árujukat": "áru",
    "áruk": "áru",
    "árukészletével": "árukészlet",
    "árul": "ár",
    "árulja": "árul",
    "áruljuk": "árul",
    "árulkodtak": "árulkodik",
    "árulna": "árul",
    "árulnak": "árul",
    "árulni": "árul",
    "árulnia": "árul",
    "árult": "árul",
    "árulta": "árul",
    "árultad": "árult",
    "árultak": "árult",
    "árultam": "árult",
    "árulták": "árul",
    "árulástól": "árulás",
    "árulásért": "árulás",
    "árulójától": "áruló",
    "árulójává": "áruló",
    "árulók": "áruló",
    "árulókat": "áruló",
    "árulókra": "áruló",
    "árulót": "áruló",
    "áruról": "áru",
    "árusok": "árus",
    "árusítják": "árusít",
    "árusítottak": "árusított",
    "árusítását": "árusítás",
    "árut": "áru",
    "árutőzsdén": "árutőzsde",
    "árvaházak": "árvaház",
    "árvaházakba": "árvaház",
    "árvaházakban": "árvaház",
    "árvaházban": "árvaház",
    "árvaházról": "árvaház",
    "árvaságában": "árvaság",
    "árvák": "árva",
    "árvákat": "árva",
    "árváknak": "árva",
    "árváltozások": "árváltozás",
    "árában": "ár",
    "árából": "ár",
    "árán": "ár",
    "árának": "ár",
    "áráról": "ár",
    "árát": "ár",
    "árától": "ár",
    "árával": "ár",
    "árért": "ár",
    "ásatni": "ásat",
    "ásatták": "ásat",
    "ásatásakor": "ásatás",
    "ásnak": "ás",
    "ásni": "ás",
    "ásott": "ás",
    "ástuk": "ás",
    "ásvánnyal": "ásvány",
    "ásványai": "ásvány",
    "ásványaitól": "ásvány",
    "ásványgyűjteménye": "ásványgyűjtemény",
    "ásványgyűjteményem": "ásványgyűjtemény",
    "ásványkincsek": "ásványkincs",
    "ásványok": "ásvány",
    "ásványokat": "ásvány",
    "ásványvizet": "ásványvíz",
    "ásványvizéből": "ásványvíz",
    "ászt": "ász",
    "átadhatom": "átadhat",
    "átadja": "átad",
    "átadni": "átad",
    "átadom": "átad",
    "átadott": "átad",
    "átadta": "átad",
    "átadtak": "átad",
    "átadtam": "átad",
    "átadták": "átad",
    "átadása": "átadás",
    "átadásakor": "átadás",
    "átadást": "átadás",
    "átadására": "átadás",
    "átadásáról": "átadás",
    "átalakulni": "átalakul",
    "átalakult": "átalakul",
    "átalakultak": "átalakult",
    "átalakulása": "átalakulás",
    "átalakuláson": "átalakulás",
    "átalakulást": "átalakulás",
    "átalakulásából": "átalakulás",
    "átalakulásával": "átalakulás",
    "átalakulóban": "átalakuló",
    "átalakíthatja": "átalakíthat",
    "átalakíthatta": "átalakíthat",
    "átalakított": "átalakít",
    "átalakították": "átalakít",
    "átalakítása": "átalakítás",
    "átalakításhoz": "átalakítás",
    "átalakításnak": "átalakítás",
    "átalakítások": "átalakítás",
    "átalakítással": "átalakítás",
    "átalakítást": "átalakítás",
    "átalakításában": "átalakítás",
    "átalakításának": "átalakítás",
    "átalakítását": "átalakítás",
    "átalakításával": "átalakítás",
    "átalánydíjak": "átalánydíj",
    "átcsapja": "átcsap",
    "átcsapáson": "átcsapás",
    "átcsempésztem": "átcsempész",
    "átcsábította": "átcsábít",
    "átcsúszni": "átcsúszik",
    "átejteni": "átejt",
    "átellenben": "átellen",
    "átengedni": "átenged",
    "átengedték": "átenged",
    "áteresztenek": "átereszt",
    "átesett": "átesik",
    "átesnie": "átesik",
    "átestek": "átesik",
    "átfogalmazták": "átfogalmaz",
    "átfogom": "átfog",
    "átfogott": "átfog",
    "átfogta": "átfog",
    "átfuthassunk": "átfuthat",
    "átfutott": "átfut",
    "átfütyült": "átfütyül",
    "átgondolnia": "átgondol",
    "átgondoltam": "átgondolt",
    "áthaladjon": "áthalad",
    "áthaladásért": "áthaladás",
    "áthallatszott": "áthallatszik",
    "áthatolhatatlanabb": "áthatolhatatlan",
    "áthatolni": "áthatol",
    "áthatóan": "átható",
    "áthatóbb": "átható",
    "áthelyezéséhez": "áthelyezés",
    "áthelyezésének": "áthelyezés",
    "áthidalja": "áthidal",
    "áthágni": "áthág",
    "áthágásának": "áthágás",
    "átháríthatja": "átháríthat",
    "áthárításának": "áthárítás",
    "áthívták": "áthív",
    "áthúzott": "áthúz",
    "áthúzza": "áthúz",
    "áthúzzák": "áthúz",
    "áthúzódott": "áthúzódik",
    "átiratok": "átirat",
    "átirányítania": "átirányít",
    "átitatta": "átitat",
    "átjavítja": "átjavít",
    "átjárják": "átjár",
    "átjártunk": "átjárt",
    "átjáróba": "átjáró",
    "átjáróban": "átjáró",
    "átjárók": "átjáró",
    "átjönni": "átjön",
    "átjött": "átjön",
    "átjöttek": "átjön",
    "átkarolt": "átkarol",
    "átkarolta": "átkarol",
    "átkarolták": "átkarol",
    "átkelőhelyein": "átkelőhely",
    "átkerülnének": "átkerül",
    "átkokat": "átok",
    "átkozott": "átkoz",
    "átkozottul": "átkozott",
    "átkozódjék": "átkozódik",
    "átkozódnak": "átkozódik",
    "átkozódtak": "átkozódik",
    "átkozódással": "átkozódás",
    "átkutatni": "átkutat",
    "átkutatnia": "átkutat",
    "átkutatása": "átkutatás",
    "átképzésekkel": "átképzés",
    "átkísértek": "átkísért",
    "átküldhetek": "átküldhet",
    "átlagembereknek": "átlagember",
    "átlagembernek": "átlagember",
    "átlagköltsége": "átlagköltség",
    "átlagod": "átlag",
    "átlagosan": "átlagos",
    "átlagosnál": "átlagos",
    "átlagpolgára": "átlagpolgár",
    "átlagpolgárnak": "átlagpolgár",
    "átlagszínvonala": "átlagszínvonal",
    "átlagától": "átlag",
    "átláthatott": "átláthat",
    "átlátott": "átlát",
    "átlátszóbb": "átlátszó",
    "átláttam": "átlát",
    "átlépte": "átlép",
    "átlőttek": "átlőtt",
    "átmehetünk": "átmehet",
    "átmelegedhetett": "átmelegedhet",
    "átmenne": "átmegy",
    "átmenni": "átmegy",
    "átment": "átmegy",
    "átmentem": "átment",
    "átminősülnek": "átminősül",
    "átmozgatást": "átmozgatás",
    "átmásolásához": "átmásolás",
    "átmérője": "átmérő",
    "átnedvesedett": "átnedvesedik",
    "átnevelje": "átnevel",
    "átnyújtott": "átnyújt",
    "átnyújtotta": "átnyújt",
    "átnyújtottak": "átnyújtott",
    "átnézegették": "átnézeget",
    "átnézett": "átnéz",
    "átnézni": "átnéz",
    "átolvastak": "átolvas",
    "átruházta": "átruház",
    "átsodródott": "átsodródik",
    "átsuhant": "átsuhan",
    "átsurranni": "átsurran",
    "átszaladtak": "átszaladt",
    "átszellemült": "átszellemül",
    "átszervezték": "átszervez",
    "átszervezése": "átszervezés",
    "átszervezéseket": "átszervezés",
    "átszervezéséről": "átszervezés",
    "átszökdösnének": "átszökdös",
    "átszöknénk": "átszökik",
    "átszökök": "átszökik",
    "átszökött": "átszökik",
    "áttenném": "áttesz",
    "átterelni": "átterel",
    "átterjednek": "átterjed",
    "átteszik": "áttesz",
    "áttetszene": "áttetszik",
    "áttetszőnek": "áttetsző",
    "áttérnek": "áttér",
    "áttörhesse": "áttörhet",
    "áttörhetetlennek": "áttörhetetlen",
    "áttöri": "áttörik",
    "áttörni": "áttörik",
    "áttörnie": "áttörik",
    "áttörést": "áttörés",
    "áttűnt": "áttűnik",
    "átutalt": "átutal",
    "átvenni": "átvesz",
    "átvetette": "átvetet",
    "átvette": "átvesz",
    "átvették": "átvesz",
    "átvezetne": "átvezet",
    "átvezetéssel": "átvezetés",
    "átvillanni": "átvillan",
    "átvillant": "átvillan",
    "átvitele": "átvitel",
    "átvitt": "átvisz",
    "átvitte": "átvisz",
    "átvitték": "átvisz",
    "átvizsgáltam": "átvizsgált",
    "átvágtam": "átvág",
    "átvállalja": "átvállal",
    "átvállalni": "átvállal",
    "átvétele": "átvétel",
    "átvételéről": "átvétel",
    "átállt": "átáll",
    "átállása": "átállás",
    "átélt": "átél",
    "átélése": "átélés",
    "átépítették": "átépítet",
    "átépítésre": "átépítés",
    "átértünk": "átért",
    "átérzéssel": "átérzés",
    "átíratott": "átíratik",
    "átírni": "átír",
    "átírta": "átír",
    "átírták": "átír",
    "átírásáról": "átírás",
    "átölelte": "átölel",
    "átöltöznek": "átöltözik",
    "átöntött": "átönt",
    "átültethetők": "átültethető",
    "átültetni": "átültet",
    "átültetése": "átültetés",
    "átültetésnek": "átültetés",
    "áznak": "ázik",
    "ázott": "ázik",
    "áztatja": "áztat",
    "ázzak": "ázik",
    "ázzon": "ázik",
    "éberebb": "éber",
    "éberen": "éber",
    "ébersége": "éberség",
    "ébredhetnek": "ébredhet",
    "ébredhetnének": "ébredhet",
    "ébrednek": "ébred",
    "ébredni": "ébred",
    "ébredt": "ébred",
    "ébredtek": "ébredt",
    "ébredtünk": "ébredt",
    "ébredését": "ébredés",
    "ébredünk": "ébred",
    "ébren": "éber",
    "ébrenlétemben": "ébrenlét",
    "ébresztett": "ébreszt",
    "ébresztette": "ébreszt",
    "édesanyja": "édesanya",
    "édesanyjuk": "édesanya",
    "édesanyád": "édesanya",
    "édesanyám": "édesanya",
    "édesanyára": "édesanya",
    "édesanyát": "édesanya",
    "édesapjuk": "édesapa",
    "édesapjukból": "édesapa",
    "édessége": "édesség",
    "égboltja": "égbolt",
    "égboltot": "égbolt",
    "égből": "ég",
    "égen": "ég",
    "égetni": "éget",
    "égett": "ég",
    "égetőnek": "égető",
    "égetőre": "égető",
    "égetőt": "égető",
    "éghajlatot": "éghajlat",
    "éghettek": "éghet",
    "égi": "ég",
    "égisze": "égisz",
    "égne": "ég",
    "égnek": "ég",
    "égni": "ég",
    "égre": "ég",
    "égvilágon": "égvilág",
    "égőt": "égő",
    "éhen": "éh",
    "éhesebbek": "éhes",
    "éhesek": "éhes",
    "éhezhetik": "éhezhet",
    "éheznek": "éhezik",
    "éheztek": "éhezik",
    "éheztem": "éhezik",
    "éheztethettek": "éheztethet",
    "éheztették": "éheztet",
    "éheztetéssel": "éheztetés",
    "éheztünk": "éhezik",
    "éhezéshez": "éhezés",
    "éhezést": "éhezés",
    "éhgyomorra": "éhgyomor",
    "éhséget": "éhség",
    "éhségről": "éhség",
    "éhségsztrájkba": "éhségsztrájk",
    "éhségtől": "éhség",
    "éhségét": "éhség",
    "éhségüknek": "éhség",
    "éhükben": "éh",
    "éjfélig": "éjfél",
    "éjfélkor": "éjfél",
    "éjféltájban": "éjféltáj",
    "éjjel": "éj",
    "éjszaka": "éjszak",
    "éjszakai": "éjszak",
    "éjszakában": "éjszaka",
    "éjszakájukon": "éjszaka",
    "éjszakáján": "éjszaka",
    "éjszakák": "éjszaka",
    "éjszakán": "éjszaka",
    "éjszakánként": "éjszaka",
    "éjszakára": "éjszaka",
    "éjszakát": "éjszaka",
    "ékelnie": "ékel",
    "ékesített": "ékesít",
    "ékszakáin": "ékszaka",
    "ékszerdobozra": "ékszerdoboz",
    "ékszereit": "ékszer",
    "éktelenül": "éktelen",
    "élcelődésbe": "élcelődés",
    "élcsoportjának": "élcsoport",
    "élek": "él",
    "élelemgyűjtésben": "élelemgyűjtés",
    "élelemraktárt": "élelemraktár",
    "élelmesebbek": "élelmes",
    "élelmet": "élelem",
    "élelmezésünkben": "élelmezés",
    "élelmiszerboltot": "élelmiszerbolt",
    "élelmiszerek": "élelmiszer",
    "élelmiszerekben": "élelmiszer",
    "élelmiszereket": "élelmiszer",
    "élelmiszerekről": "élelmiszer",
    "élelmiszerhez": "élelmiszer",
    "élelmiszert": "élelmiszer",
    "élelmiszerért": "élelmiszer",
    "élelmük": "élelem",
    "élen": "él",
    "élesek": "éles",
    "élesen": "éles",
    "éleset": "éles",
    "élességüket": "élesség",
    "élesztette": "éleszt",
    "élet": "él",
    "életbe": "élet",
    "életben": "élet",
    "életből": "élet",
    "élete": "élet",
    "életed": "élet",
    "életeké": "élet",
    "életem": "élet",
    "életemben": "élet",
    "életemet": "élet",
    "életen": "élet",
    "életereje": "életerő",
    "életerejéből": "életerő",
    "életerőt": "életerő",
    "életet": "élet",
    "életetek": "élet",
    "életeteket": "élet",
    "életfelfogásával": "életfelfogás",
    "életfilozófiáját": "életfilozófia",
    "életfordulatának": "életfordulat",
    "élethez": "élet",
    "élethűen": "élethű",
    "élethűségtől": "élethűség",
    "életismeretét": "életismeret",
    "életjáradékra": "életjáradék",
    "életkoruk": "életkor",
    "életképességét": "életképesség",
    "életképtelennek": "életképtelen",
    "életkörülményeinek": "életkörülmény",
    "életkörülményeiről": "életkörülmény",
    "életkörülményeit": "életkörülmény",
    "életkörülmények": "életkörülmény",
    "életmódban": "életmód",
    "életmóddal": "életmód",
    "életmódhoz": "életmód",
    "életmódja": "életmód",
    "életmódjában": "életmód",
    "életmódnak": "életmód",
    "életművének": "életmű",
    "életművét": "életmű",
    "életnagyságnál": "életnagyság",
    "életnek": "élet",
    "életrajzáról": "életrajz",
    "életrajzát": "életrajz",
    "életre": "élet",
    "életritmust": "életritmus",
    "életről": "élet",
    "életszínvonalát": "életszínvonal",
    "élettartamát": "élettartam",
    "élettel": "élet",
    "élettelenek": "élettelen",
    "élettársa": "élettárs",
    "élettársat": "élettárs",
    "élettársán": "élettárs",
    "élettől": "élet",
    "életveszélybe": "életveszély",
    "életvezetését": "életvezetés",
    "életvágya": "életvágy",
    "életébe": "élet",
    "életében": "élet",
    "életéből": "élet",
    "életén": "élet",
    "életének": "élet",
    "életért": "élet",
    "életéről": "élet",
    "életét": "élet",
    "életével": "élet",
    "életútjáról": "életút",
    "életük": "élet",
    "életükben": "élet",
    "életükből": "élet",
    "életüket": "élet",
    "életükön": "élet",
    "életünk": "élet",
    "életünkbe": "élet",
    "életünkben": "élet",
    "életünkből": "élet",
    "életünket": "élet",
    "életűek": "életű",
    "élharcosává": "élharcos",
    "élhessenek": "élhet",
    "élhetett": "élhet",
    "élhetik": "élhet",
    "élhetnek": "élhet",
    "élhetsz": "élhet",
    "élhettek": "élhet",
    "élhetünk": "élhet",
    "éli": "él",
    "élitek": "él",
    "éljen": "él",
    "éljenek": "éljen",
    "éljenzett": "éljenez",
    "éljetek": "él",
    "éllel": "él",
    "élmezőnyben": "élmezőny",
    "élmezőnyében": "élmezőny",
    "élmunkásban": "élmunkás",
    "élményanyagaként": "élményanyag",
    "élményanyagát": "élményanyag",
    "élményeiket": "élmény",
    "élményem": "élmény",
    "élményre": "élmény",
    "élne": "él",
    "élnek": "él",
    "élni": "él",
    "élnie": "él",
    "élniük": "él",
    "élnél": "él",
    "élsz": "él",
    "élt": "él",
    "élte": "él",
    "élted": "élt",
    "éltek": "élt",
    "éltem": "élt",
    "éltetné": "éltet",
    "éltette": "éltet",
    "élték": "él",
    "éltél": "él",
    "éltünk": "élt",
    "élve": "élv",
    "élversenyzői": "élversenyző",
    "élvezetektől": "élvezet",
    "élvezetesebb": "élvezetes",
    "élvezetesebbé": "élvezetes",
    "élvezetet": "élvezet",
    "élvezeti": "élvezet",
    "élvezetnek": "élvezet",
    "élvezett": "élvez",
    "élvezettel": "élvezett",
    "élvezettől": "élvezett",
    "élvezetük": "élvezet",
    "élvezi": "élvez",
    "élveznek": "élvez",
    "élvezni": "élvez",
    "élvezte": "élvez",
    "élén": "él",
    "élénkebben": "élénk",
    "élénken": "élénk",
    "élére": "él",
    "éléről": "él",
    "élünk": "él",
    "élőben": "élő",
    "élők": "élő",
    "élőket": "élő",
    "élőknek": "élő",
    "élőlények": "élőlény",
    "élőre": "élő",
    "élősködtek": "élősködik",
    "élőszóban": "élőszó",
    "élőzenét": "élőzene",
    "émelyedéssel": "émelyedés",
    "émelyen": "émely",
    "émelygést": "émelygés",
    "émelygősek": "émelygős",
    "énbelőlem": "énbelől",
    "énbennem": "én",
    "ének": "én",
    "ének-zenéből": "ének-zene",
    "énekbe": "ének",
    "éneke": "ének",
    "énekeket": "ének",
    "énekelhetne": "énekelhet",
    "énekelnek": "énekel",
    "énekelni": "énekel",
    "énekelnivalójuk": "énekelnivaló",
    "énekelt": "énekel",
    "énekelte": "énekel",
    "énekelték": "énekel",
    "énekeltük": "énekel",
    "énekhangot": "énekhang",
    "énekkart": "énekkar",
    "énekszámok": "énekszám",
    "énekszóval": "énekszó",
    "énekét": "ének",
    "énhozzám": "én",
    "énmellém": "énmellé",
    "énnekem": "én",
    "énrajtam": "énrajt",
    "énvelem": "én",
    "énértem": "én",
    "épelméjűségedben": "épelméjűség",
    "épelméjűvé": "épelméjű",
    "éppannyit": "éppannyi",
    "építenek": "épít",
    "építeni": "épít",
    "épített": "épít",
    "építettek": "épített",
    "építették": "építet",
    "építgették": "építget",
    "építhetik": "építhet",
    "építhettek": "építhet",
    "építhetők": "építhető",
    "építi": "épít",
    "építkezzenek": "építkezik",
    "építkezések": "építkezés",
    "építkezésen": "építkezés",
    "építményben": "építmény",
    "építménye": "építmény",
    "építmények": "építmény",
    "építtetheti": "építtethet",
    "építtetők": "építtető",
    "építése": "építés",
    "építészek": "építész",
    "építésének": "építés",
    "építésére": "építés",
    "építését": "építés",
    "építünk": "épít",
    "építőmunkásról": "építőmunkás",
    "épületbe": "épület",
    "épületben": "épület",
    "épületből": "épület",
    "épületegyüttesével": "épületegyüttes",
    "épületeinek": "épület",
    "épületek": "épület",
    "épületekben": "épület",
    "épületekkel": "épület",
    "épületekről": "épület",
    "épületen": "épület",
    "épületet": "épület",
    "épületkárokról": "épületkár",
    "épületről": "épület",
    "épülettől": "épület",
    "épületében": "épület",
    "épületéből": "épület",
    "épületének": "épület",
    "épületét": "épület",
    "épületéért": "épület",
    "épülhetne": "épülhet",
    "épülne": "épül",
    "épülnek": "épül",
    "épülni": "épül",
    "épülnének": "épül",
    "épült": "épül",
    "épültek": "épül",
    "épülésének": "épülés",
    "érccel": "érc",
    "ércesen": "érces",
    "érdaganata": "érdaganat",
    "érdeke": "érdek",
    "érdekei": "érdek",
    "érdekeiket": "érdek",
    "érdekeinek": "érdek",
    "érdekeink": "érdek",
    "érdekeit": "érdek",
    "érdekek": "érdek",
    "érdekeket": "érdek",
    "érdekelne": "érdekel",
    "érdekelnek": "érdekel",
    "érdekelni": "érdekel",
    "érdekelt": "érdekel",
    "érdekelte": "érdekel",
    "érdekeltek": "érdekelt",
    "érdekeltségeik": "érdekeltség",
    "érdekeltségek": "érdekeltség",
    "érdekeltséggel": "érdekeltség",
    "érdekeltségébe": "érdekeltség",
    "érdekeltté": "érdekelt",
    "érdekelték": "érdekel",
    "érdekesek": "érdekes",
    "érdekesen": "érdekes",
    "érdekesnek": "érdekes",
    "érdekessége": "érdekesség",
    "érdekli": "érdekel",
    "érdeklik": "érdekel",
    "érdeklődnek": "érdeklődik",
    "érdeklődni": "érdeklődik",
    "érdeklődsz": "érdeklődik",
    "érdeklődtem": "érdeklődik",
    "érdeklődtünk": "érdeklődik",
    "érdeklődése": "érdeklődés",
    "érdeklődéssel": "érdeklődés",
    "érdeklődést": "érdeklődés",
    "érdeklődésének": "érdeklődés",
    "érdeklődésére": "érdeklődés",
    "érdeklődésüket": "érdeklődés",
    "érdeklődésünkre": "érdeklődés",
    "érdeklődött": "érdeklődik",
    "érdeklődők": "érdeklődő",
    "érdeklődőket": "érdeklődő",
    "érdeklődőkkel": "érdeklődő",
    "érdekmúlásra": "érdekmúlás",
    "érdekmúlást": "érdekmúlás",
    "érdekszférájában": "érdekszféra",
    "érdektelennek": "érdektelen",
    "érdekében": "érdek",
    "érdekük": "érdek",
    "érdekükben": "érdek",
    "érdekünkben": "érdek",
    "érdemben": "érdem",
    "érdeme": "érdem",
    "érdemeiket": "érdem",
    "érdemeként": "érdem",
    "érdemelték": "érdemel",
    "érdemeltük": "érdemel",
    "érdemesített": "érdemesít",
    "érdemnek": "érdem",
    "érdemrenddel": "érdemrend",
    "érek": "érik",
    "érett": "érik",
    "érettségihez": "érettségi",
    "érettségije": "érettségi",
    "érettségin": "érettségi",
    "érettségireform-elképzeléseivel": "érettségireform-elképzelés",
    "érettségit": "érettségi",
    "érettségivel": "érettségi",
    "érettségizett": "érettségizik",
    "érettségizettek": "érettségizett",
    "érettségizik": "érettségiz",
    "érettségünk": "érettség",
    "érezhesse": "érezhet",
    "érezhetik": "érezhet",
    "érezhetné": "érezhet",
    "érezhette": "érezhet",
    "érezhették": "érezhet",
    "érezhetőbb": "érezhető",
    "érezhetően": "érezhető",
    "érezhetővé": "érezhető",
    "éreznek": "érez",
    "érezni": "érez",
    "éreznie": "érez",
    "érezné": "érez",
    "éreznék": "érez",
    "érezte": "érez",
    "éreztek": "érez",
    "éreztem": "érez",
    "éreztesse": "éreztet",
    "éreztetik": "éreztet",
    "érezték": "érez",
    "érezzenek": "érez",
    "érezzük": "érez",
    "érhesse": "érhet",
    "érhetik": "érhet",
    "érhették": "érhet",
    "éri": "érik",
    "érik": "ér",
    "érintené": "érint",
    "érintetlenül": "érintetlen",
    "érintett": "érint",
    "érintette": "érint",
    "érintettek": "érintett",
    "érintetteket": "érintett",
    "érintetteknek": "érintett",
    "érintettekre": "érintett",
    "érintettet": "érintett",
    "érintettnek": "érintett",
    "érintették": "érintet",
    "érinthetetlenek": "érinthetetlen",
    "érinti": "érint",
    "érintik": "érint",
    "érintkezhetne": "érintkezhet",
    "érintkeznek": "érintkezik",
    "érintkezni": "érintkezik",
    "érintkezésbe": "érintkezés",
    "érintkezésben": "érintkezés",
    "érintkezést": "érintkezés",
    "érintkezéstől": "érintkezés",
    "érintkezésében": "érintkezés",
    "érintkezésük": "érintkezés",
    "érintése": "érintés",
    "érintést": "érintés",
    "érintésére": "érintés",
    "érintését": "érintés",
    "érintésétől": "érintés",
    "érintésével": "érintés",
    "érjek": "érik",
    "érkezett": "érkezik",
    "érkezettek": "érkezett",
    "érkezhetett": "érkezhet",
    "érkeznek": "érkezik",
    "érkezni": "érkezik",
    "érkeztek": "érkezik",
    "érkeztem": "érkezik",
    "érkeztünk": "érkezik",
    "érkezzék": "érkezik",
    "érkezése": "érkezés",
    "érkezésére": "érkezés",
    "érkezésével": "érkezés",
    "érkezésük": "érkezés",
    "érlelődni": "érlelődik",
    "érlelődött": "érlelődik",
    "érne": "érik",
    "érnek": "érik",
    "érni": "érik",
    "érné": "érik",
    "ért": "érik",
    "érte": "ő",
    "érted": "te",
    "értek": "ért",
    "értekezlete": "értekezlet",
    "értekezleten": "értekezlet",
    "értekezletére": "értekezlet",
    "értekezni": "értekezik",
    "értekezésekig": "értekezés",
    "értelem": "értél",
    "értelemben": "értelem",
    "értelemmel": "értelem",
    "értelemnek": "értelem",
    "értelemről": "értelem",
    "értelemében": "értelem",
    "értelme": "értelem",
    "értelmesnek": "értelmes",
    "értelmet": "értelem",
    "értelmetlennek": "értelmetlen",
    "értelmetlenséget": "értelmetlenség",
    "értelmetlenségként": "értelmetlenség",
    "értelmetlenül": "értelmetlen",
    "értelmezett": "értelmez",
    "értelmezték": "értelmez",
    "értelmezésben": "értelmezés",
    "értelmezést": "értelmezés",
    "értelmezésével": "értelmezés",
    "értelmiséget": "értelmiség",
    "értelmiségieket": "értelmiségi",
    "értelmében": "értelem",
    "értelmére": "értelem",
    "értelmét": "értelem",
    "értelmük": "értelem",
    "értelműeket": "értelmű",
    "értem": "ért",
    "értened": "ért",
    "értenek": "ért",
    "értenetek": "ért",
    "érteni": "ért",
    "értenie": "ért",
    "értenék": "ért",
    "értesz": "ért",
    "értesíteni": "értesít",
    "értesített": "értesít",
    "értesítette": "értesít",
    "értesítették": "értesítet",
    "értesítse": "értesít",
    "értesítést": "értesítés",
    "értesítőben": "értesítő",
    "értesítőt": "értesítő",
    "értesült": "értesül",
    "értesültek": "értesül",
    "értesülése": "értesülés",
    "értesülései": "értesülés",
    "értesüléseink": "értesülés",
    "értesülések": "értesülés",
    "értesüléstől": "értesülés",
    "értetlenül": "értetlen",
    "értetni": "értet",
    "értett": "ért",
    "értette": "értet",
    "értettek": "értett",
    "értettem": "értett",
    "értették": "értet",
    "értetődően": "értetődő",
    "értetődőnek": "értetődő",
    "érthetem": "érthet",
    "érthetetlenek": "érthetetlen",
    "érthetetlennek": "érthetetlen",
    "érthetetlenül": "érthetetlen",
    "értheti": "érthet",
    "érthetik": "érthet",
    "érthette": "érthet",
    "érthetően": "érthető",
    "érti": "ért",
    "értik": "ért",
    "értjük": "ért",
    "értsd": "ért",
    "értse": "ért",
    "értsen": "ért",
    "értsétek": "ért",
    "érték": "érik",
    "értékben": "érték",
    "értékcsökkenésére": "értékcsökkenés",
    "értéke": "érték",
    "értékei": "érték",
    "értékeik": "érték",
    "értékeiket": "érték",
    "értékeit": "érték",
    "értékek": "érték",
    "értékekben": "érték",
    "értékeket": "érték",
    "értékeled": "értékel",
    "értékeli": "értékel",
    "értékelik": "értékel",
    "értékelje": "értékel",
    "értékelte": "értékel",
    "értékelték": "értékel",
    "értékelése": "értékelés",
    "értékelések": "értékelés",
    "értékelésekor": "értékelés",
    "értékelésében": "értékelés",
    "értékeléséről": "értékelés",
    "értéken": "érték",
    "értékesíted": "értékesít",
    "értékesítenek": "értékesít",
    "értékesített": "értékesít",
    "értékesítettek": "értékesített",
    "értékesítették": "értékesítet",
    "értékesíti": "értékesít",
    "értékesítik": "értékesít",
    "értékesítése": "értékesítés",
    "értékesítésen": "értékesítés",
    "értékesítéshez": "értékesítés",
    "értékesítésnél": "értékesítés",
    "értékesítésre": "értékesítés",
    "értékesítést": "értékesítés",
    "értékesítésében": "értékesítés",
    "értékesítését": "értékesítés",
    "értéket": "érték",
    "értékhez": "érték",
    "értékkel": "érték",
    "értékmentők": "értékmentő",
    "értéknek": "érték",
    "értéknél": "érték",
    "értékpapírjainak": "értékpapír",
    "értékpapírjait": "értékpapír",
    "értékpapírok": "értékpapír",
    "értékrendet": "értékrend",
    "értékrendjének": "értékrend",
    "értékrendjére": "értékrend",
    "értéktelenné": "értéktelen",
    "értéktárgyak": "értéktárgy",
    "értéktőzsdén": "értéktőzsde",
    "értékvesztése": "értékvesztés",
    "értékvesztését": "értékvesztés",
    "értékvédelemmel": "értékvédelem",
    "értékének": "érték",
    "értékét": "érték",
    "értékével": "érték",
    "értékítéletének": "értékítélet",
    "értékük": "érték",
    "értéküket": "érték",
    "értük": "ők",
    "értünk": "mi",
    "érvei": "érv",
    "érveimet": "érv",
    "érvek": "érv",
    "érveket": "érv",
    "érvekre": "érv",
    "érvelése": "érvelés",
    "érvelésre": "érvelés",
    "érveléssel": "érvelés",
    "érvelésük": "érvelés",
    "érvelésüket": "érvelés",
    "érvet": "érv",
    "érvágásra": "érvágás",
    "érvénnyel": "érvény",
    "érvényben": "érvény",
    "érvényesek": "érvényes",
    "érvényességét": "érvényesség",
    "érvényesíteni": "érvényesít",
    "érvényesítené": "érvényesít",
    "érvényesíti": "érvényesít",
    "érvényesítése": "érvényesítés",
    "érvényesítésében": "érvényesítés",
    "érvényesítésén": "érvényesítés",
    "érvényesülhetnek": "érvényesülhet",
    "érvényesülne": "érvényesül",
    "érvényesült": "érvényesül",
    "érvényre": "érvény",
    "érvényt": "érvény",
    "érvénytelennek": "érvénytelen",
    "érvét": "érv",
    "érzek": "érez",
    "érzel": "érez",
    "érzelegni": "érzeleg",
    "érzelemrétegek": "érzelemréteg",
    "érzelgősek": "érzelgős",
    "érzelgősen": "érzelgős",
    "érzelmei": "érzelem",
    "érzelmeiket": "érzelem",
    "érzelmeinket": "érzelem",
    "érzelmeire": "érzelem",
    "érzelmek": "érzelem",
    "érzelmeket": "érzelem",
    "érzelmekkel": "érzelem",
    "érzelmeknek": "érzelem",
    "érzelmekre": "érzelem",
    "érzelmektől": "érzelem",
    "érzelmet": "érzelem",
    "érzelmiséget": "érzelmiség",
    "érzelmit": "érzelmi",
    "érzem": "érez",
    "érzett": "érez",
    "érzi": "érez",
    "érzik": "érez",
    "érzéke": "érzék",
    "érzékei": "érzék",
    "érzékelik": "érzékel",
    "érzékelni": "érzékel",
    "érzékelt": "érzékel",
    "érzékeltetni": "érzékeltet",
    "érzékem": "érzék",
    "érzékenyen": "érzékeny",
    "érzékenységből": "érzékenység",
    "érzékenységének": "érzékenység",
    "érzékenységével": "érzékenység",
    "érzéketek": "érzék",
    "érzéketlenné": "érzéketlen",
    "érzékkel": "érzék",
    "érzékletesen": "érzékletes",
    "érzékére": "érzék",
    "érzékük": "érzék",
    "érzése": "érzés",
    "érzései": "érzés",
    "érzéseiben": "érzés",
    "érzéseidet": "érzés",
    "érzéseik": "érzés",
    "érzésein": "érzés",
    "érzések": "érzés",
    "érzéseket": "érzés",
    "érzésnek": "érzés",
    "érzéssel": "érzés",
    "érzést": "érzés",
    "érzéséből": "érzés",
    "érzését": "érzés",
    "érzésük": "érzés",
    "érzésünk": "érzés",
    "ésszerűen": "ésszerű",
    "ésszerűtlenül": "ésszerűtlen",
    "észak-budapesti": "északbudapesti",
    "észak-dunántúli": "északdunántúli",
    "északkeletre": "északkelet",
    "északra": "észak",
    "észbe": "ész",
    "észben": "ész",
    "észen": "ész",
    "észjárásnak": "észjárás",
    "észjárásában": "észjárás",
    "észlelt": "észlel",
    "észlelte": "észlel",
    "észleltek": "észlelt",
    "észre": "ész",
    "észrevehette": "észrevehet",
    "észrevehetően": "észrevehető",
    "észrevenni": "észrevesz",
    "észrevennék": "észrevesz",
    "észreveszi": "észrevesz",
    "észreveszik": "észrevesz",
    "észrevett": "észrevesz",
    "észrevette": "észrevesz",
    "észrevettek": "észrevett",
    "észrevettem": "észrevett",
    "észrevették": "észrevesz",
    "észrevettük": "észrevett",
    "észrevételbe": "észrevétel",
    "észrevételeket": "észrevétel",
    "észt": "ész",
    "ételek": "étel",
    "ételeken": "étel",
    "ételeket": "étel",
    "ételeknek": "étel",
    "ételmaradékért": "ételmaradék",
    "ételnek": "étel",
    "ételnél": "étel",
    "ételre": "étel",
    "ételt": "étel",
    "ételébe": "étel",
    "ételének": "étel",
    "étkezett": "étkezik",
    "étkezések": "étkezés",
    "étkezéskor": "étkezés",
    "étkezéstől": "étkezés",
    "étkezésük": "étkezés",
    "étlapjaikat": "étlap",
    "étlapon": "étlap",
    "étterem": "éttér",
    "étteremben": "étterem",
    "éttermeket": "étterem",
    "éttermet": "étterem",
    "éttermébe": "étterem",
    "éttermében": "étterem",
    "étvágycsinálót": "étvágycsináló",
    "évben": "év",
    "éve": "év",
    "évei": "év",
    "éveiben": "év",
    "éveit": "év",
    "évek": "év",
    "években": "év",
    "éveken": "év",
    "éveket": "év",
    "évekig": "év",
    "évekkel": "év",
    "éveknél": "év",
    "évekénél": "éveke",
    "éven": "év",
    "évenként": "év",
    "évesek": "éves",
    "évesen": "éves",
    "évet": "év",
    "évezredeken": "évezred",
    "évezredekig": "évezred",
    "évezreden": "évezred",
    "évfolyamait": "évfolyam",
    "évfolyamokat": "évfolyam",
    "évfordulóján": "évforduló",
    "évfordulókról": "évforduló",
    "évfordulóra": "évforduló",
    "évhez": "év",
    "évig": "év",
    "évihez": "évi",
    "évinek": "évi",
    "évinél": "évi",
    "évit": "évi",
    "évmilliókig": "évmillió",
    "évnek": "év",
    "évnél": "év",
    "évre": "év",
    "évről": "év",
    "évszámok": "évszám",
    "évszázada": "évszázad",
    "évszázaddal": "évszázad",
    "évszázadokig": "évszázad",
    "évszázadokkal": "évszázad",
    "évszázadokra": "évszázad",
    "évszázadra": "évszázad",
    "évszázadról": "évszázad",
    "évtizeddel": "évtized",
    "évtizede": "évtized",
    "évtizedei": "évtized",
    "évtizedeiben": "évtized",
    "évtizedek": "évtized",
    "évtizedekben": "évtized",
    "évtizedekig": "évtized",
    "évtizedekkel": "évtized",
    "évtizeden": "évtized",
    "évtizedére": "évtized",
    "évtizedétől": "évtized",
    "évtől": "év",
    "évvel": "év",
    "évében": "év",
    "évét": "év",
    "évünk": "év",
    "évődést": "évődés",
    "ígéreteket": "ígéret",
    "ígéretekkel": "ígéret",
    "ígéreteknek": "ígéret",
    "ígéretesen": "ígéretes",
    "ígéretet": "ígéret",
    "ígéretre": "ígéret",
    "ígérkezett": "ígérkezik",
    "ígérkezne": "ígérkezik",
    "ígérnek": "ígér",
    "ígért": "ígér",
    "ígérte": "ígér",
    "ígértem": "ígért",
    "ígérték": "ígér",
    "ígértél": "ígér",
    "ígértünk": "ígért",
    "ínye": "íny",
    "íratnak": "íratik",
    "íratták": "íratik",
    "írd": "ír",
    "írja": "ír",
    "írjanak": "ír",
    "írjuk": "ír",
    "írják": "ír",
    "írnak": "ír",
    "írni": "ír",
    "írni-olvasni": "ír-olvas",
    "írnia": "ír",
    "írnoka": "írnok",
    "írnokhoz": "írnok",
    "írnoknak": "írnok",
    "írnokok": "írnok",
    "írnokokat": "írnok",
    "írnának": "ír",
    "írok": "ír",
    "írom": "ír",
    "írsz": "ír",
    "írt": "ír",
    "írta": "ír",
    "írtad": "írt",
    "írtak": "írt",
    "írtam": "írt",
    "írtuk": "ír",
    "írtunk": "írt",
    "írták": "ír",
    "írtál": "ír",
    "írásaik": "írás",
    "írásaim": "írás",
    "írásban": "írás",
    "írásbelit": "írásbeli",
    "íráshoz": "írás",
    "írásjelek": "írásjel",
    "írások": "írás",
    "írásokat": "írás",
    "írással": "írás",
    "írást": "írás",
    "írásában": "írás",
    "írásán": "írás",
    "íróasztala": "íróasztal",
    "íróasztalfiókjában": "íróasztalfiók",
    "íróasztalhoz": "íróasztal",
    "íróasztalon": "íróasztal",
    "íróasztalt": "íróasztal",
    "íróasztalán": "íróasztal",
    "íróasztalánál": "íróasztal",
    "írógépeikből": "írógép",
    "írói": "író",
    "íróikról": "írói",
    "írójuk": "író",
    "írójának": "író",
    "írók": "író",
    "írókat": "író",
    "írókhoz": "író",
    "írókkal": "író",
    "írókultuszt": "írókultusz",
    "írómappáját": "írómappa",
    "írón": "író",
    "írónak": "író",
    "írópályák": "írópálya",
    "íróra": "író",
    "írót": "író",
    "íróval": "író",
    "ítélem": "ítél",
    "ítéleteit": "ítélet",
    "ítéletek": "ítélet",
    "ítéletet": "ítélet",
    "ítéletét": "ítélet",
    "ítélhetik": "ítélhet",
    "ítéli": "ítél",
    "ítélik": "ítél",
    "ítéljetek": "ítél",
    "ítélkeznek": "ítélkezik",
    "ítélkezni": "ítélkezik",
    "ítélni": "ítél",
    "ítélt": "ítél",
    "ítélte": "ítél",
    "ítéltek": "ítélt",
    "ítéltetett": "ítéltet",
    "ítélték": "ítél",
    "ítélőképessége": "ítélőképesség",
    "ívben": "ív",
    "íve": "ív",
    "ívet": "ív",
    "ízben": "íz",
    "íze": "íz",
    "ízetlenebb": "ízetlen",
    "ízleltük": "ízlel",
    "ízlésről": "ízlés",
    "ízléstelenségnek": "ízléstelenség",
    "ízlését": "ízlés",
    "ízlésével": "ízlés",
    "ízt": "íz",
    "ízénél": "íz",
    "ízét": "íz",
    "ízük": "íz",
    "ízületei": "ízület",
    "ízületével": "ízület",
    "óbestere": "óbester",
    "óbeszélre": "óbeszél",
    "óbeszélt": "óbeszél",
    "óbeszélül": "óbeszél",
    "óceánokon": "óceán",
    "óceánon": "óceán",
    "ócskaságát": "ócskaság",
    "ógondolók": "ógondoló",
    "óhaja": "óhaj",
    "óhajod": "óhaj",
    "óhajtják": "óhajt",
    "óhajtott": "óhajt",
    "óhajtotta": "óhajt",
    "óhatatlanul": "óhatatlan",
    "ólat": "ól",
    "ólomkatonák": "ólomkatona",
    "óntepsiket": "óntepsi",
    "óra": "ó",
    "órakor": "óra",
    "óraszáma": "óraszám",
    "óraszámok": "óraszám",
    "óraszámokat": "óraszám",
    "óraszámának": "óraszám",
    "óriásinak": "óriásín",
    "óriáskígyók": "óriáskígyó",
    "óriásnak": "óriás",
    "óriássá": "óriás",
    "óriásával": "óriás",
    "órában": "óra",
    "óráiban": "óra",
    "óráig": "óra",
    "óráin": "óra",
    "óráit": "óra",
    "órája": "óra",
    "órájuk": "óra",
    "órájában": "óra",
    "órájának": "óra",
    "órájára": "óra",
    "órák": "óra",
    "órákat": "óra",
    "órákban": "óra",
    "órákig": "óra",
    "órákon": "óra",
    "órákra": "óra",
    "órán": "óra",
    "órának": "óra",
    "óránk": "óra",
    "óránként": "óra",
    "órára": "óra",
    "órásnál": "órás",
    "órát": "óra",
    "órától": "óra",
    "órával": "óra",
    "óvatosabban": "óvatos",
    "óvatosan": "óvatos",
    "óvatosságból": "óvatosság",
    "óvatosságától": "óvatosság",
    "óvintézkedéseknek": "óvintézkedés",
    "óvodában": "óvoda",
    "óvodájába": "óvoda",
    "óvodák": "óvoda",
    "óvta": "óv",
    "óvásokat": "óvás",
    "óvást": "óvás",
    "óvók": "óvó",
    "öblének": "öböl",
    "öblöket": "öböl",
    "öccse": "öcs",
    "öklei": "ököl",
    "öklét": "ököl",
    "öklöt": "ököl",
    "ökre": "ökör",
    "ökrök": "ökör",
    "ökrökkel": "ökör",
    "ökölcsapásokat": "ökölcsapás",
    "ököllel": "ököl",
    "ökölre": "ököl",
    "ökölrázásokkal": "ökölrázás",
    "ökörnek": "ökör",
    "öldöklésnél": "öldöklés",
    "ölelik": "ölel",
    "ölelje": "ölel",
    "ölelt": "ölel",
    "ölelte": "ölel",
    "ölelésből": "ölelés",
    "ölelésnek": "ölelés",
    "ölelésre": "ölelés",
    "ölelésük": "ölelés",
    "öllel": "öl",
    "ölni": "öl",
    "ölnének": "öl",
    "ölte": "öl",
    "ölted": "öl",
    "öltek": "öl",
    "öltem": "öl",
    "ölték": "öl",
    "öltésekkel": "öltés",
    "öltött": "ölt",
    "öltözetemről": "öltözet",
    "öltözködni": "öltözködik",
    "öltözködésben": "öltözködés",
    "öltözteti": "öltöztet",
    "öltözött": "öltözik",
    "ölébe": "öl",
    "ölünkbe": "öl",
    "ömlött": "ömlik",
    "ömlöttek": "ömlött",
    "önakaratánál": "önakarat",
    "önbecsülésük": "önbecsülés",
    "önbizalmat": "önbizalom",
    "önbizalmát": "önbizalom",
    "önből": "ön",
    "öncsonkításról": "öncsonkítás",
    "öncélúan": "öncélú",
    "önelégültséggel": "önelégültség",
    "önerőből": "önerő",
    "önfegyelemből": "önfegyelem",
    "önfegyelemre": "önfegyelem",
    "önfegyelmet": "önfegyelem",
    "önfeláldozással": "önfeláldozás",
    "öngyilkosságnál": "öngyilkosság",
    "öngyilkosságok": "öngyilkosság",
    "öngyilkosságot": "öngyilkosság",
    "öngyilkosságra": "öngyilkosság",
    "öngyilkosságról": "öngyilkosság",
    "öngyilkosságáról": "öngyilkosság",
    "öngóljával": "öngól",
    "önhibájukból": "önhiba",
    "önhibájából": "önhiba",
    "önhibát": "önhiba",
    "önhipnózisról": "önhipnózis",
    "önkezével": "önkéz",
    "önkorlátozásra": "önkorlátozás",
    "önkormányzata": "önkormányzat",
    "önkormányzatai": "önkormányzat",
    "önkormányzatnak": "önkormányzat",
    "önkormányzatnál": "önkormányzat",
    "önkormányzatok": "önkormányzat",
    "önkormányzatokat": "önkormányzat",
    "önkormányzatoknak": "önkormányzat",
    "önkormányzatoknál": "önkormányzat",
    "önkormányzatokra": "önkormányzat",
    "önkormányzatoktól": "önkormányzat",
    "önkormányzatra": "önkormányzat",
    "önkormányzattól": "önkormányzat",
    "önkormányzatát": "önkormányzat",
    "önként": "ön",
    "önkéntelenül": "önkéntelen",
    "önkéntesekből": "önkéntes",
    "önkéntességre": "önkéntesség",
    "önkényesek": "önkényes",
    "önkényurak": "önkényúr",
    "önköltségei": "önköltség",
    "önköltségek": "önköltség",
    "önköltségnél": "önköltség",
    "önmagukat": "önmaguk",
    "önmagukba": "önmaguk",
    "önmagukban": "önmaguk",
    "önmagunk": "önmaga",
    "önmagunkkal": "önmagunk",
    "önmagába": "önmaga",
    "önmagában": "önmaga",
    "önmagán": "önmaga",
    "önmagának": "önmaga",
    "önmagáról": "önmaga",
    "önmagát": "önmaga",
    "önmagától": "önmaga",
    "önmagával": "önmaga",
    "önmagává": "önmaga",
    "önmagáért": "önmaga",
    "önmegaláztatásról": "önmegaláztatás",
    "önmetaforái": "önmetafora",
    "önmérsékletre": "önmérséklet",
    "önműveléshez": "önművelés",
    "önnek": "ön",
    "önnel": "ön",
    "önre": "ön",
    "önrongálását": "önrongálás",
    "önről": "ön",
    "önszántukból": "önszánt",
    "önszántából": "önszánta",
    "önt": "ön",
    "öntenek": "önt",
    "önteni": "önt",
    "öntessenek": "öntet",
    "önthették": "önthet",
    "öntik": "önt",
    "öntjük": "önt",
    "öntse": "önt",
    "öntudatlannak": "öntudatlan",
    "öntudatlanul": "öntudatlan",
    "öntudatra": "öntudat",
    "öntudattal": "öntudat",
    "öntudattá": "öntudat",
    "öntudatát": "öntudat",
    "öntött": "önt",
    "öntötte": "önt",
    "öntöttvasról": "öntöttvas",
    "öntöttvastermeléssel": "öntöttvastermelés",
    "öntötték": "önt",
    "öntözésre": "öntözés",
    "öntözését": "öntözés",
    "önuralma": "önuralom",
    "önuralommal": "önuralom",
    "önvédelemből": "önvédelem",
    "önzetlenül": "önzetlen",
    "önzése": "önzés",
    "önzők": "önző",
    "önállóan": "önálló",
    "önállósága": "önállóság",
    "önállósággal": "önállóság",
    "önállóvá": "önálló",
    "önérzetet": "önérzet",
    "önérzetének": "önérzet",
    "önérzetét": "önérzet",
    "önítéletek": "önítélet",
    "önök": "ön",
    "önöknél": "ön",
    "ördögbe": "ördög",
    "ördögfiókám": "ördögfióka",
    "ördögien": "ördögi",
    "ördöginek": "ördögi",
    "ördögnek": "ördög",
    "ördögök": "ördög",
    "ördögöt": "ördög",
    "öreganyád": "öreganya",
    "öregapád": "öregapa",
    "öregapáikat": "öregapa",
    "öregasszonynak": "öregasszony",
    "öregasszonyok": "öregasszony",
    "öregasszonyokat": "öregasszony",
    "öregebb": "öreg",
    "öregebbek": "öreg",
    "öregebbnek": "öreg",
    "öregek": "öreg",
    "öregekből": "öreg",
    "öregemberre": "öregember",
    "öregemberrel": "öregember",
    "öregembert": "öregember",
    "öreget": "öreg",
    "öreggel": "öreg",
    "öregnek": "öreg",
    "öregségnek": "öregség",
    "örvendezett": "örvendezik",
    "örvendhessen": "örvendhet",
    "örökké": "örök",
    "örökkévalóvá": "örökkévaló",
    "örökletessé": "örökletes",
    "öröklik": "örököl",
    "öröklött": "örököl",
    "örökre": "örök",
    "örökségképp": "örökség",
    "örökségét": "örökség",
    "örökíthették": "örökíthet",
    "örökölt": "örököl",
    "örökölte": "örököl",
    "örököse": "örökös",
    "örökösei": "örökös",
    "örököseit": "örökös",
    "örökösen": "örökös",
    "örökösét": "örökös",
    "örökösök": "örökös",
    "örömbe": "öröm",
    "örömben": "öröm",
    "öröme": "öröm",
    "örömet": "öröm",
    "örömmel": "öröm",
    "örömnyilvánításokra": "örömnyilvánítás",
    "örömtől": "öröm",
    "örömében": "öröm",
    "öröméből": "öröm",
    "örömére": "öröm",
    "örömét": "öröm",
    "örömével": "öröm",
    "örömömre": "öröm",
    "örömöt": "öröm",
    "örömük": "öröm",
    "örömüket": "öröm",
    "örülhetett": "örülhet",
    "örülnek": "örül",
    "örülni": "örül",
    "örülnének": "örül",
    "örült": "örül",
    "örülök": "örül",
    "örülünk": "örül",
    "összeadtuk": "összead",
    "összeaszalódott": "összeaszalódik",
    "összebarátkoztak": "összebarátkozik",
    "összebarátkoztunk": "összebarátkozik",
    "összebékítésével": "összebékítés",
    "összecsapta": "összecsap",
    "összecsapása": "összecsapás",
    "összecsapásoktól": "összecsapás",
    "összecsatolta": "összecsatol",
    "összecsuklott": "összecsuklik",
    "összecsukása": "összecsukás",
    "összecsíptetett": "összecsíptet",
    "összeegyeztethetetlenek": "összeegyeztethetetlen",
    "összeegyeztetni": "összeegyeztet",
    "összeesküvésekbe": "összeesküvés",
    "összeesküvéseket": "összeesküvés",
    "összeesküvésnek": "összeesküvés",
    "összeesküvésre": "összeesküvés",
    "összeesküvésről": "összeesküvés",
    "összeesküvők": "összeesküvő",
    "összefoglalni": "összefoglal",
    "összefogott": "összefog",
    "összefogottan": "összefogott",
    "összefoltozásán": "összefoltozás",
    "összefolyt": "összefolyik",
    "összefonódtak": "összefonódik",
    "összefonódását": "összefonódás",
    "összeférhetetlenséget": "összeférhetetlenség",
    "összeférhetetlenségre": "összeférhetetlenség",
    "összeférhetetlenségét": "összeférhetetlenség",
    "összefüggésben": "összefüggés",
    "összefüggéseket": "összefüggés",
    "összefüggésfélében": "összefüggésféle",
    "összefüggéstelenül": "összefüggéstelen",
    "összefüggőbbek": "összefüggő",
    "összefüggően": "összefüggő",
    "összegben": "összeg",
    "összege": "összeg",
    "összegek": "összeg",
    "összegeken": "összeg",
    "összegeket": "összeg",
    "összegekkel": "összeg",
    "összegeknek": "összeg",
    "összegekre": "összeg",
    "összegen": "összeg",
    "összeget": "összeg",
    "összegezte": "összegez",
    "összegezzük": "összegez",
    "összeggel": "összeg",
    "összeghez": "összeg",
    "összegyülekezett": "összegyülekezik",
    "összegyűjtik": "összegyűjt",
    "összegyűjtsék": "összegyűjt",
    "összegyűjtése": "összegyűjtés",
    "összegyűjtött": "összegyűjt",
    "összegyűlt": "összegyűlik",
    "összegyűltek": "összegyűlik",
    "összegyűrte": "összegyűr",
    "összegért": "összeg",
    "összegöngyölte": "összegöngyöl",
    "összehajtogatott": "összehajtogat",
    "összehajtogatta": "összehajtogat",
    "összehangolt": "összehangol",
    "összehangolták": "összehangol",
    "összehangolásában": "összehangolás",
    "összehasogatták": "összehasogat",
    "összehasonlítani": "összehasonlít",
    "összehasonlítania": "összehasonlít",
    "összehasonlításhoz": "összehasonlítás",
    "összehasonlításokat": "összehasonlítás",
    "összehasonlítással": "összehasonlítás",
    "összehasonlításul": "összehasonlítás",
    "összehordani": "összehord",
    "összehordott": "összehord",
    "összehozhatja": "összehozhat",
    "összehozni": "összehoz",
    "összehozott": "összehoz",
    "összehozzák": "összehoz",
    "összeházasodniuk": "összeházasodik",
    "összeházasodásuk": "összeházasodás",
    "összehívhatja": "összehívhat",
    "összehívja": "összehív",
    "összehívott": "összehív",
    "összehívására": "összehívás",
    "összeijedt": "összeijed",
    "összejöhessenek": "összejöhet",
    "összejöjjenek": "összejön",
    "összejöttünk": "összejött",
    "összejövetelnél": "összejövetel",
    "összejövetelre": "összejövetel",
    "összejövetelt": "összejövetel",
    "összekapcsolhatjuk": "összekapcsolhat",
    "összekapcsolása": "összekapcsolás",
    "összekaristolták": "összekaristol",
    "összekeveredett": "összekeveredik",
    "összekeveredjenek": "összekeveredik",
    "összekeveri": "összekever",
    "összekeveréstől": "összekeverés",
    "összekoccantja": "összekoccant",
    "összekulcsolni": "összekulcsol",
    "összekulcsolt": "összekulcsol",
    "összekulcsolta": "összekulcsol",
    "összekuszált": "összekuszál",
    "összeköti": "összeköt",
    "összekötik": "összeköt",
    "összeköttetésben": "összeköttetés",
    "összeköttetései": "összeköttetés",
    "összeköttetést": "összeköttetés",
    "összeköttetését": "összeköttetés",
    "összekötőknek": "összekötő",
    "összelőtték": "összelő",
    "összemázolni": "összemázol",
    "összeomlott": "összeomlik",
    "összeomlást": "összeomlás",
    "összepakoltuk": "összepakol",
    "összepréselték": "összeprésel",
    "összeragasztott": "összeragaszt",
    "összeredményét": "összeredmény",
    "összerombolt": "összerombol",
    "összeroppantotta": "összeroppant",
    "összerágta": "összerág",
    "összeráncolt": "összeráncol",
    "összerándult": "összerándul",
    "összeröhögnek": "összeröhög",
    "összesen": "összes",
    "összesepert": "összeseper",
    "összesereglett": "összesereglik",
    "összessége": "összesség",
    "összességében": "összesség",
    "összeszaladt": "összeszalad",
    "összeszedett": "összeszed",
    "összeszedették": "összeszedet",
    "összeszedni": "összeszed",
    "összeszedte": "összeszed",
    "összeszedték": "összeszed",
    "összeszerelését": "összeszerelés",
    "összeszidja": "összeszid",
    "összeszokottabb": "összeszokott",
    "összeszorult": "összeszorul",
    "összeszorított": "összeszorít",
    "összeszorította": "összeszorít",
    "összeszorítottam": "összeszorított",
    "összeszűkült": "összeszűkül",
    "összesített": "összesít",
    "összesíthetnek": "összesíthet",
    "összesítése": "összesítés",
    "összetalálkoztak": "összetalálkozik",
    "összetaposták": "összetapos",
    "összetartani": "összetart",
    "összetartott": "összetart",
    "összetartoztak": "összetartozik",
    "összetartozásból": "összetartozás",
    "összetartozásuk": "összetartozás",
    "összetartást": "összetartás",
    "összetett": "összetesz",
    "összetételben": "összetétel",
    "összetétele": "összetétel",
    "összetöri": "összetörik",
    "összetörik": "összetör",
    "összetörjük": "összetörik",
    "összetört": "összetörik",
    "összetörte": "összetörik",
    "összetörtnek": "összetört",
    "összetörték": "összetörik",
    "összevegyüléstől": "összevegyülés",
    "összeverődnek": "összeverődik",
    "összeverődtek": "összeverődik",
    "összeveszett": "összeveszik",
    "összeveszhetek": "összeveszhet",
    "összevesztek": "összeveszt",
    "összevetésével": "összevetés",
    "összevonják": "összevon",
    "összevont": "összevon",
    "összevontak": "összevont",
    "összevonása": "összevonás",
    "összevonások": "összevonás",
    "összevágott": "összevág",
    "összevéreznének": "összevérez",
    "összezavarja": "összezavar",
    "összezsugorodott": "összezsugorodik",
    "összezárunk": "összezár",
    "összezúzni": "összezúz",
    "összezúzott": "összezúz",
    "összezúzták": "összezúz",
    "összeállt": "összeáll",
    "összeállított": "összeállít",
    "összeállították": "összeállít",
    "összeállítsák": "összeállít",
    "összeállítása": "összeállítás",
    "összeállításához": "összeállítás",
    "összeégett": "összeég",
    "összeérnek": "összeérik",
    "összeért": "összeérik",
    "összeöntötték": "összeönt",
    "összeülnek": "összeül",
    "összeült": "összeül",
    "összeültek": "összeül",
    "összeütközhetett": "összeütközhet",
    "összeütközése": "összeütközés",
    "összeütközött": "összeütközik",
    "összforgalmon": "összforgalom",
    "összhangba": "összhang",
    "összhangban": "összhang",
    "összhanghoz": "összhang",
    "összhangját": "összhang",
    "összlakosságon": "összlakosság",
    "összpontosult": "összpontosul",
    "összpontosítani": "összpontosít",
    "összpontosítottak": "összpontosított",
    "összpontosítsa": "összpontosít",
    "összértéke": "összérték",
    "ösvényeit": "ösvény",
    "ösvények": "ösvény",
    "ösvényen": "ösvény",
    "ösvényre": "ösvény",
    "ösztökéli": "ösztökél",
    "ösztökélt": "ösztökél",
    "ösztöndíjat": "ösztöndíj",
    "ösztöndíjából": "ösztöndíj",
    "ösztöne": "ösztön",
    "ösztönei": "ösztön",
    "ösztönné": "ösztön",
    "ösztönszerűen": "ösztönszerű",
    "ösztönszerűvé": "ösztönszerű",
    "ösztönt": "ösztön",
    "ösztönzi": "ösztönöz",
    "ösztönzik": "ösztönöz",
    "ösztönzésről": "ösztönzés",
    "ösztönzést": "ösztönzés",
    "ösztönével": "ösztön",
    "ösztönévé": "ösztönév",
    "ösztönök": "ösztön",
    "ösztönökből": "ösztön",
    "ösztönömet": "ösztön",
    "ösztönösen": "ösztönös",
    "ösztönösnek": "ösztönös",
    "ösztönözni": "ösztönöz",
    "ösztönöznie": "ösztönöz",
    "ösztönözte": "ösztönöz",
    "ösztönözze": "ösztönöz",
    "öthatoda": "öthatod",
    "ötkor": "öt",
    "ötletbe": "ötlet",
    "ötlete": "ötlet",
    "ötleteket": "ötlet",
    "ötletekkel": "ötlet",
    "ötletet": "ötlet",
    "ötlethez": "ötlet",
    "ötlettel": "ötlet",
    "ötlött": "ötlik",
    "ötméternyire": "ötméternyi",
    "ötnek": "öt",
    "ötre": "öt",
    "ötszázezresnek": "ötszázezres",
    "ötször": "öt",
    "ötszörösére": "ötszörös",
    "ötvenből": "ötven",
    "ötvenen": "ötven",
    "ötvenhétmillióra": "ötvenhétmillió",
    "ötvenért": "ötven",
    "ötvenötre": "ötvenöt",
    "ötvényét": "ötvény",
    "ötvöződnek": "ötvöződik",
    "ötöd": "öt",
    "ötöde": "ötöd",
    "ötödére": "ötöd",
    "ötöt": "öt",
    "övek": "öv",
    "övet": "öv",
    "övezetben": "övezet",
    "övezetből": "övezet",
    "övezeteiben": "övezet",
    "övezetek": "övezet",
    "övezetté": "övezett",
    "övezetében": "övezet",
    "övezik": "övez",
    "övezte": "övez",
    "övvel": "öv",
    "övé": "öv",
    "övébe": "öv",
    "övéhez": "öv",
    "övéi": "öv",
    "övéikkel": "ők",
    "övék": "ők",
    "övékbe": "ők",
    "övéké": "ők",
    "övének": "öv",
    "övére": "öv",
    "övét": "öv",
    "övétől": "öv",
    "özvegyének": "özvegy",
    "özönlött": "özönlik",
    "újabb": "új",
    "újabbak": "új",
    "újabban": "új",
    "újabbat": "új",
    "újak": "új",
    "újat": "új",
    "újbeszélben": "újbeszél",
    "újbeszélnek": "újbeszél",
    "újbeszélre": "újbeszél",
    "újbeszélül": "újbeszél",
    "újból": "új",
    "újdonságnak": "újdonság",
    "újdonságot": "újdonság",
    "újdonsült": "újdonsül",
    "újig": "új",
    "újjá": "új",
    "újjáalakítjuk": "újjáalakít",
    "újjáalakítása": "újjáalakítás",
    "újjáéled": "újjáél",
    "újjáépítésre": "újjáépítés",
    "újjáépítésére": "újjáépítés",
    "újkerten": "újkert",
    "újkrumplival": "újkrumpli",
    "újnak": "új",
    "újpesten": "újpest",
    "újra": "új",
    "újracsoportosulások": "újracsoportosulás",
    "újrafelosztását": "újrafelosztás",
    "újrafestettek": "újrafestett",
    "újragondolását": "újragondolás",
    "újraindulása": "újraindulás",
    "újraindítása": "újraindítás",
    "újrakereszteltek": "újrakeresztelt",
    "újrakezdik": "újrakezd",
    "újrakezdésének": "újrakezdés",
    "újrakezdődött": "újrakezdődik",
    "újranyomtatták": "újranyomtat",
    "újraolvassa": "újraolvas",
    "újraolvasása": "újraolvasás",
    "újratanulni": "újratanul",
    "újratemetését": "újratemetés",
    "újratárgyalja": "újratárgyal",
    "újraválasztotta": "újraválaszt",
    "újraválasztása": "újraválasztás",
    "újraírják": "újraír",
    "újraírt": "újraír",
    "újraírta": "újraír",
    "újraírtak": "újraírt",
    "újraírták": "újraír",
    "újszülöttek": "újszülött",
    "újságban": "újság",
    "újságcikkek": "újságcikk",
    "újságcikkeket": "újságcikk",
    "újságfoszlányokért": "újságfoszlány",
    "újsággal": "újság",
    "újsághoz": "újság",
    "újságjai": "újság",
    "újságkivágásokat": "újságkivágás",
    "újságok": "újság",
    "újságokat": "újság",
    "újságokban": "újság",
    "újságokból": "újság",
    "újságokkal": "újság",
    "újságoldalon": "újságoldal",
    "újságot": "újság",
    "újságpéldányokat": "újságpéldány",
    "újságszeletekkel": "újságszelet",
    "újságírásban": "újságírás",
    "újságírói": "újságíró",
    "újságírók": "újságíró",
    "újságírókat": "újságíró",
    "újságírókból": "újságíró",
    "újságíróknak": "újságíró",
    "újságírónak": "újságíró",
    "újságírót": "újságíró",
    "újvilágiak": "újvilági",
    "újvárosiak": "újvárosi",
    "újítják": "újít",
    "újítása": "újítás",
    "újítók": "újító",
    "úrhatnámságra": "úrhatnámság",
    "úrhoz": "úr",
    "úriemberrel": "úriember",
    "úrilányok": "úrilány",
    "úrnak": "úr",
    "úrra": "úr",
    "úrral": "úr",
    "úrtól": "úr",
    "úszkálnak": "úszkál",
    "úszkáltak": "úszkált",
    "úszott": "úszik",
    "úsztak": "úszik",
    "úsztuk": "úszik",
    "úszókotrót": "úszókotró",
    "útakadályokról": "útakadály",
    "útalap-hozzájárulást": "útalap-hozzájárulás",
    "útalapot": "útalap",
    "útalapról": "útalap",
    "útba": "út",
    "útbaigazítást": "útbaigazítás",
    "útban": "út",
    "útellenőrzésen": "útellenőrzés",
    "útfélen": "útfél",
    "úthasználatért": "úthasználat",
    "útiak": "úti",
    "útig": "út",
    "útirányt": "útirány",
    "útitársaink": "útitárs",
    "útitársunk": "útitárs",
    "útja": "út",
    "útjain": "út",
    "útjait": "útjai",
    "útjában": "út",
    "útján": "út",
    "útjára": "út",
    "útjáról": "út",
    "útját": "út",
    "útközben": "útköz",
    "útlevelet": "útlevél",
    "útlevélkérelmeink": "útlevélkérelem",
    "útmutatása": "útmutatás",
    "útmutatásait": "útmutatás",
    "útnak": "út",
    "úton": "út",
    "útonállók": "útonálló",
    "útonállóé": "útonálló",
    "útra": "út",
    "útravalót": "útravaló",
    "útravalóval": "útravaló",
    "útról": "út",
    "útszakaszon": "útszakasz",
    "útszűkületet": "útszűkület",
    "útszűkületre": "útszűkület",
    "útsüllyedések": "útsüllyedés",
    "úttól": "út",
    "úttörőiről": "úttörői",
    "útvesztőiben": "útvesztői",
    "útvesztők": "útvesztő",
    "útvonala": "útvonal",
    "útvonalak": "útvonal",
    "útvonalaként": "útvonal",
    "útvonalat": "útvonal",
    "útvonallal": "útvonal",
    "útvonalon": "útvonal",
    "üdesége": "üdeség",
    "üdvözli": "üdvözöl",
    "üdvözölte": "üdvözöl",
    "üdítőn": "üdítő",
    "üdüléseket": "üdülés",
    "üdülőiben": "üdülői",
    "üdülőkörzetekben": "üdülőkörzet",
    "üdülőterületként": "üdülőterület",
    "üggyé": "ügy",
    "ügybe": "ügy",
    "ügyben": "ügy",
    "ügybuzgók": "ügybuzgó",
    "ügye": "ügy",
    "ügyeit": "ügy",
    "ügyeivel": "ügy",
    "ügyek": "ügy",
    "ügyekben": "ügy",
    "ügyeket": "ügy",
    "ügyeknek": "ügy",
    "ügyekért": "ügy",
    "ügyeletesétől": "ügyeletes",
    "ügyelni": "ügyel",
    "ügyelnie": "ügyel",
    "ügyelt": "ügyel",
    "ügyeltek": "ügyelt",
    "ügyeltünk": "ügyelt",
    "ügyem": "ügy",
    "ügyesek": "ügyes",
    "ügyesen": "ügyes",
    "ügyesnek": "ügyes",
    "ügyességét": "ügyesség",
    "ügyet": "ügy",
    "ügyetlenül": "ügyetlen",
    "ügyfele": "ügyfél",
    "ügyfelei": "ügyfél",
    "ügyfeleinek": "ügyfél",
    "ügyfeleknek": "ügyfél",
    "ügyfelet": "ügyfél",
    "ügyfelével": "ügyfele",
    "ügyintézőkből": "ügyintéző",
    "ügyletekről": "ügylet",
    "ügyletet": "ügylet",
    "ügynöke": "ügynök",
    "ügynökeikkel": "ügynök",
    "ügynökeinek": "ügynök",
    "ügynökeivel": "ügynök",
    "ügynökök": "ügynök",
    "ügyről": "ügy",
    "ügyvezetése": "ügyvezetés",
    "ügyvezetőjétől": "ügyvezető",
    "ügyvivőket": "ügyvivő",
    "ügyvéddel": "ügyvéd",
    "ügyvédei": "ügyvéd",
    "ügyvédeket": "ügyvéd",
    "ügyvédet": "ügyvéd",
    "ügyvédje": "ügyvéd",
    "ügyvédkedjék": "ügyvédkedik",
    "ügyébe": "ügy",
    "ügyében": "ügy",
    "ügyéből": "ügy",
    "ügyészségen": "ügyészség",
    "ügyét": "ügy",
    "ügyön": "ügy",
    "ügyüket": "ügy",
    "ügyünk": "ügy",
    "ügyünket": "ügy",
    "ügyünkhöz": "ügy",
    "üldögélni": "üldögél",
    "üldögélt": "üldögél",
    "üldögélte": "üldögél",
    "üldögéltek": "üldögélt",
    "üldözi": "üldöz",
    "üldözik": "üldöz",
    "üldöznek": "üldöz",
    "üldözték": "üldöz",
    "üldözze": "üldöz",
    "üldözzék": "üldöz",
    "üldözött": "üldöz",
    "üldözőbe": "üldöző",
    "ülepedett": "ülepedik",
    "ülepedjetek": "ülepedik",
    "ülepében": "ülep",
    "ülhessen": "ülhet",
    "ülhetett": "ülhet",
    "üljenek": "ül",
    "üljön": "ül",
    "üljünk": "ül",
    "üllőjük": "üllő",
    "üllőt": "üllő",
    "ülne": "ül",
    "ülnek": "ül",
    "ülni": "ül",
    "ülnie": "ül",
    "ült": "ül",
    "ültek": "ül",
    "ültem": "ül",
    "ülteti": "ültet",
    "ültette": "ültet",
    "ültében": "ülte",
    "ültőhelyében": "ültőhely",
    "ülése": "ülés",
    "üléseit": "ülés",
    "ülésen": "ülés",
    "ülésig": "ülés",
    "ülésszaka": "ülésszak",
    "ülésszakon": "ülésszak",
    "ülést": "ülés",
    "ülésén": "ülés",
    "ülésének": "ülés",
    "ülését": "ülés",
    "ülésével": "ülés",
    "ülésükön": "ülés",
    "ülök": "ül",
    "ülünk": "ül",
    "ülőfürdőbe": "ülőfürdő",
    "ülőhelyein": "ülőhely",
    "ülőhelyet": "ülőhely",
    "ülők": "ülő",
    "ünnepe": "ünnep",
    "ünnepelje": "ünnepel",
    "ünnepelni": "ünnepel",
    "ünnepelt": "ünnepel",
    "ünnepelte": "ünnepel",
    "ünnepen": "ünnep",
    "ünnepli": "ünnepel",
    "ünneplik": "ünnepel",
    "ünneppé": "ünnep",
    "ünnepségek": "ünnepség",
    "ünnepségeket": "ünnepség",
    "ünnepségekre": "ünnepség",
    "ünnepségen": "ünnepség",
    "ünnepséget": "ünnepség",
    "ünnepélyesebbé": "ünnepélyes",
    "ünnepélyessé": "ünnepélyes",
    "ünnepélyességet": "ünnepélyesség",
    "ünnepélyességgel": "ünnepélyesség",
    "üregeit": "üreg",
    "üregek": "üreg",
    "üreget": "üreg",
    "üresek": "üres",
    "üresen": "üres",
    "üresre": "üres",
    "üressége": "üresség",
    "ürgék": "ürge",
    "ürgével": "ürge",
    "ürített": "ürít",
    "ürüggyel": "ürügy",
    "ürügye": "ürügy",
    "ürügyeiül": "ürügy",
    "ürügyekkel": "ürügy",
    "ürügyet": "ürügy",
    "ürügyként": "ürügy",
    "ürügyén": "ürügy",
    "ürügyül": "ürügy",
    "üssük": "üt",
    "üstökben": "üstök",
    "üstökösből": "üstökös",
    "üstökösnek": "üstökös",
    "üstökösről": "üstökös",
    "üszköt": "üszök",
    "ütemben": "ütem",
    "ütemesen": "ütemes",
    "ütemig": "ütem",
    "ütemére": "ütem",
    "ütemét": "ütem",
    "ütemével": "ütem",
    "üti-vágja": "üt-vág",
    "ütik": "üt",
    "ütköznek": "ütközik",
    "ütközni": "ütközik",
    "ütközzön": "ütközik",
    "ütközések": "ütközés",
    "ütközött": "ütközik",
    "ütni": "üt",
    "ütése": "ütés",
    "ütéseit": "ütés",
    "ütések": "ütés",
    "ütésekre": "ütés",
    "ütésre": "ütés",
    "ütéssel": "ütés",
    "ütést": "ütés",
    "ütött": "üt",
    "ütötte": "üt",
    "ütötte-verte": "üt-ver",
    "ütöttek": "ütött",
    "ütötték": "üt",
    "ütöttünk": "ütött",
    "ütődött": "ütődik",
    "üvegablakai": "üvegablak",
    "üvegablakok": "üvegablak",
    "üvegajtajukon": "üvegajtó",
    "üvegajtaján": "üvegajtó",
    "üvegajtók": "üvegajtó",
    "üvegben": "üveg",
    "üvegburája": "üvegbura",
    "üvegbúra": "üvegbú",
    "üvegből": "üveg",
    "üvegcserepek": "üvegcserép",
    "üvegen": "üveg",
    "üveget": "üveg",
    "üveggel": "üveg",
    "üveghez": "üveg",
    "üvegnek": "üveg",
    "üvegszekrények": "üvegszekrény",
    "üvegszilánk": "üvegszila",
    "üvegtetőn": "üvegtető",
    "üvegtörmeléke": "üvegtörmelék",
    "üvegvázát": "üvegváza",
    "üvölteni": "üvölt",
    "üvöltenie": "üvölt",
    "üvöltik": "üvölt",
    "üvöltsön": "üvölt",
    "üvöltése": "üvöltés",
    "üvöltések": "üvöltés",
    "üvöltött": "üvölt",
    "üvöltötte": "üvölt",
    "üvöltözik": "üvöltöz",
    "üvöltöztek": "üvöltöz",
    "üvöltözték": "üvöltöz",
    "üvöltözése": "üvöltözés",
    "üvöltözéssel": "üvöltözés",
    "üvöltözött": "üvöltöz",
    "üzemanyag-tartalékát": "üzemanyag-tartalék",
    "üzemanyagot": "üzemanyag",
    "üzemanyagának": "üzemanyag",
    "üzembe": "üzem",
    "üzemben": "üzem",
    "üzemcsarnokot": "üzemcsarnok",
    "üzemek": "üzem",
    "üzemeltetett": "üzemeltet",
    "üzemeltetni": "üzemeltet",
    "üzemeltetése": "üzemeltetés",
    "üzemeltetést": "üzemeltetés",
    "üzemeltetéséhez": "üzemeltetés",
    "üzemeltetőnek": "üzemeltető",
    "üzemelése": "üzemelés",
    "üzemelésre": "üzemelés",
    "üzemet": "üzem",
    "üzemzavarok": "üzemzavar",
    "üzeneteire": "üzenet",
    "üzenetek": "üzenet",
    "üzeneteket": "üzenet",
    "üzenetem": "üzenet",
    "üzenetet": "üzenet",
    "üzenetkézbesítésnek": "üzenetkézbesítés",
    "üzenetnek": "üzenet",
    "üzenettel": "üzenet",
    "üzenetében": "üzenet",
    "üzenetét": "üzenet",
    "üzent": "üzen",
    "üzente": "üzen",
    "üzletbe": "üzlet",
    "üzletben": "üzlet",
    "üzlete": "üzlet",
    "üzletei": "üzlet",
    "üzletek": "üzlet",
    "üzletekben": "üzlet",
    "üzleteken": "üzlet",
    "üzleteket": "üzlet",
    "üzletelni": "üzletel",
    "üzleteltek": "üzletelt",
    "üzletelésnek": "üzletelés",
    "üzletembereket": "üzletember",
    "üzletemberrel": "üzletember",
    "üzletesek": "üzletes",
    "üzletet": "üzlet",
    "üzletfelek": "üzletfél",
    "üzlethelyiségekbe": "üzlethelyiség",
    "üzletház-beruházásban": "üzletház-beruházás",
    "üzletkötések": "üzletkötés",
    "üzletkötéseket": "üzletkötés",
    "üzletkötést": "üzletkötés",
    "üzletközpontokat": "üzletközpont",
    "üzletpolitikával": "üzletpolitika",
    "üzletrésze": "üzletrész",
    "üzletágait": "üzletág",
    "üzletágak": "üzletág",
    "üzletágaktól": "üzletág",
    "üzletágat": "üzletág",
    "üzletét": "üzlet",
    "őbelőle": "őbelől",
    "őket": "ők",
    "őneki": "ő",
    "őnekik": "ők",
    "őre": "őr",
    "őreá": "ő",
    "őrházai": "őrház",
    "őrházban": "őrház",
    "őrháznál": "őrház",
    "őrizetbe": "őrizet",
    "őrizkednem": "őrizkedik",
    "őrizni": "őriz",
    "őriznék": "őriz",
    "őrizte": "őriz",
    "őriztek": "őriz",
    "őriztem": "őriz",
    "őriztetni": "őriztet",
    "őrizze": "őriz",
    "őrizzem": "őriz",
    "őrjáratban": "őrjárat",
    "őrjáratnak": "őrjárat",
    "őrjáratok": "őrjárat",
    "őrjáratokkal": "őrjárat",
    "őrjáratokra": "őrjárat",
    "őrjítően": "őrjítő",
    "őrjöngésben": "őrjöngés",
    "őrjöngése": "őrjöngés",
    "őrjöngéseik": "őrjöngés",
    "őrjöngésig": "őrjöngés",
    "őrjöngéssé": "őrjöngés",
    "őrködnünk": "őrködik",
    "őrlőben": "őrlő",
    "őrnaszádot": "őrnaszád",
    "őrs-szobában": "őrs-szoba",
    "őrszemet": "őrszem",
    "őrszemnek": "őrszem",
    "őrséget": "őrség",
    "őrségváltásra": "őrségváltás",
    "őrségállással": "őrségállás",
    "őrségünk": "őrség",
    "őrsük": "őrs",
    "őrt": "őr",
    "őrzi": "őriz",
    "őrzik": "őriz",
    "őrzésének": "őrzés",
    "őrzöd": "őriz",
    "őrzött": "őriz",
    "őrzői": "őrző",
    "őrá": "ő",
    "őrök": "őr",
    "őröket": "őr",
    "őrökkel": "őr",
    "őröknek": "őr",
    "őrölnek": "őröl",
    "őröltetni": "őröltet",
    "őrületnek": "őrület",
    "őrült": "őrül",
    "őrültek": "őrült",
    "őrültsége": "őrültség",
    "őrültséget": "őrültség",
    "őrülttel": "őrült",
    "ősbemutatója": "ősbemutató",
    "ősbozótja": "ősbozót",
    "ősei": "ős",
    "őseik": "ős",
    "őserdeiben": "őserdő",
    "őserdőkben": "őserdő",
    "őserőt": "őserő",
    "őshazát": "őshaza",
    "őshöz": "ős",
    "ősidőktől": "ősidő",
    "ősszel": "ősz",
    "ősszemléletéről": "ősszemlélet",
    "őstehetségből": "őstehetség",
    "őstehetségeket": "őstehetség",
    "őstehetségekkel": "őstehetség",
    "őszig": "ősz",
    "őszinteséggel": "őszinteség",
    "őszintébb": "őszinte",
    "őszinték": "őszinte",
    "őszintén": "őszinte",
    "őszintétlenségéért": "őszintétlenség",
    "őszre": "ősz",
    "ősztől": "ősz",
    "őszén": "ősz",
    "őszön": "ősz",
    "őt": "ő",
    "ővele": "ő",
    "ővelük": "ők",
    "űrbe": "űr",
    "űrben": "űr",
    "űreszközöket": "űreszköz",
    "űrhajóvezetőket": "űrhajóvezető",
    "űrszondát": "űrszonda",
    "űröm": "űr",
    "űznek": "űz",
    "űznének": "űz",
    "űzte": "űz",
    "űzte-hajtotta": "űz-hajt",
    "űzzön": "űz",
    "űzött": "űz",
    "űzöttek": "űzött"
}
