# coding: utf8
from __future__ import unicode_literals
ADJECTIVES = set("""
 n-διάστατος µεταφυτρωτικός άβαθος άβαλτος άβαρος άβατος άβαφος άβγαλτος άβιος
 άβλαπτος άβλεπτος άβολος άβουλος άβραστος άβρεχτος άβροχος άβυθος άγαμος
 άγγιχτος άγδαρτος άγδυτος άγευστος άγιος άγλυκος άγλωσσος άγναθος άγναντος
 άγνεστος άγνωμος άγνωρος άγνωστος άγονος άγουρος άγουστος άγραφος άγραφτος
 άγρυπνος άδαρτος άδειος άδειπνος άδενδρος άδεντρος άδετος άδηκτος άδηλος
 άδιωχτος άδολος άδοξος άδοτος άδουλος άδροσος άδωρος άεθνος άεργος άζευκτος
 άζουμος άζυμος άζωστος άηχος άθαφτος άθελος άθεος άθερμος άθηλυς άθικτος
 άθλιος άθολος άθραυστος άθρεπτος άθρεφτος άθρησκος άθυμος άκαιρος άκακος
 άκαπνος άκαρδος άκαρπος άκαυστος άκαυτος άκεντρος άκεφος άκλαυτος άκλητος
 άκλωθος άκλωστος άκομψος άκοσμος άκουρος άκοφτος άκρατος άκριτος άκρος
 άκυρος άκωλος άκων άλαδος άλαλος άλεστος άληκτος άληστος άλικος άλιπος άλιωτος
 άλλαχτος άλογος άλουστος άλπειος άλυπος άλυτος άμαζος άμαθος άμαχος άμεμπτος
 άμεστος άμετρος άμισθος άμισχος άμοιαστος άμοιρος άμορφος άμουσος άμπαλος
 άμωμος άνανδρος άνανθος άναντρος άναρθρος άναρχος άναστρος άναυδος άναυλος
 άνετος άνευρος άνηβος άνθιμος άνθινος άνθυγρος άνιπτος άνισος άνιφτος άνομβρος
 άνοπτος άνοσμος άνοσος άνοστος άνους άντυτος άνυδρος άνωθεν άξαντος άξαφνος
 άξεστος άξιος άξυλος άξυστος άοκνος άοπλος άορνος άοσμος άπαικτος άπαιχτος
 άπας άπαστος άπαστρος άπατος άπατρις άπαυστος άπαυτος άπαχος άπειρος άπειρος
 άπεπτος άπεφθος άπηκτος άπηχτος άπιαστος άπικρος άπιοτος άπιστος άπιωτος
 άπλαστος άπλεκτος άπλερος άπλετος άπλεχτος άπληστος άπλυτος άπνοος άπνους
 άπολις άπονος άπορος άπους άπραγος άπρακτος άπραχτος άπρεπος άπροικος
 άπτερος άπτυχος άπτωτος άπυρος άρατος άραχλος άριος άριστος άρρηκτος άρρην
 άρριζος άρρυθμος άρρωστος άρτιος άσαρκος άσβεστος άσβηστος άσεβος άσειστος
 άσεμνος άσημος άσηπτος άσιαχτος άσιγμος άσιτος άσκαφος άσκαφτος άσκεπος
 άσκεφτος άσκημος άσκοπος άσμιχτος άσοφος άσπαρτος άσπαστος άσπερμος άσπιλος
 άσπλαγχνος άσπλαχνος άσπονδος άσπορος άσπρος άσπρωχτος άστατος άστεγος
 άστεργος άστικτος άστολος άστοργος άστοχος άστρινος άστριφτος άστρωτος άστυλος
 άσφαγος άσφαιρος άσφακτος άσφαλτος άσφαχτος άσφιχτος άσχετος άσχημος άσωστος
 άτακτος άταστος άταφος άταχτος άτεγκτος άτεκνος άτεχνος άτηκτος άτιμος άτιτλος
 άτοκος άτολμος άτονος άτοπος άτρεμος άτρητος άτριφτος άτριχος άτρυγος άτρυπος
 άτρωτος άτσαλος άτσεπος άτυπος άτυχος άυλος άυπνος άφαγος άφαντος άφατος
 άφευκτος άφθαρτος άφθαστος άφθιτος άφθονος άφθορος άφιλος άφκιαστος άφλεκτος
 άφορος άφορτος άφραγκος άφραγος άφρακτος άφραστος άφραχτος άφρονας άφροντις
 άφρυκτος άφρων άφταστος άφτερος άφτιαστος άφτιαχτος άφυλλος άφυλος άφωνος
 άχαρις άχαρος άχλωρος άχνουδος άχολος άχορδος άχραντος άχρηστος άχρονος άχροος
 άχτιστος άχυμος άχωστος άψαλτος άψαχτος άψητος άψηφος άψιλος άψογος άψυκτος
 άωρος άωτος έγγαμος έγγειος έγγραφος έγκαιρος έγκλειστος έγκριτος έγκυος
 έγχορδος έγχρωμος έκδηλος έκδοτος έκθαμβος έκθετος έκθυμος έκκεντρος έκκλητος
 έκνομος έκπαγλος έκπληκτος έκπτωτος έκρυθμος έκτακτος έκτοπος έκτυπος έκφρων
 έλλογος έμβιος έμμεσος έμμετρος έμμηνος έμμισθος έμμονος έμμορφος έμορφος
 έμπιστος έμπλεος έμπρακτος έμπυρος έμφοβος έμφορτος έμφρων έμφυλος έμφυτος
 έναρθρος έναστρος ένδακρυς ένδικος ένδοξος ένζυμος ένθεος ένθερμος ένθετος
 έννομος έννους ένοπλος ένορκος ένοχος ένρινος ένσπερμος ένστικτος ένστολος
 ένταστος έντεχνος έντιμος έντοκος έντονος έντρομος έντυπος ένυδρος έξαλλος
 έξαφνος έξεργο έξεργος έξηχος έξοχος έξτρα έξυπνος έξω έξωμος έπηλυς έρημος
 έρριζος έρρινος έρρυθμος έσχατος έτερος έτοιμος έτυμος έφεδρος έφιππος έφιππος
 έχων έωλος ήδιστος ήμερος ήμισυς ήπιος ήρεμος ήσσων ήσυχος ίλεως ίσαλος
 ίσιος ίσος ίστωρ ίσχαιμος αΐδιος αέναος αέρινος αέριος αήθης αήττητος αίθριος
 αίσιος αβάγιστος αβάδιστος αβάζος αβάπτιστος αβάρετος αβάσιμος αβάσκαντος
 αβάστακτος αβάσταχτος αβάτευτος αβάφτιστος αβέβαιος αβέβηλος αβέλτερος αβέρτος
 αβίωτος αβαθής αβαθμίδωτος αβαθμολόγητος αβαθούλωτος αβαθύρριζος αβαλσάμωτος
 αβανιοκαμένος αβανταδόρικος αβαρής αβαριάτος αβαρικός αβαροσλαβικός
 αβασίλευτος αβγοειδής αβγοκομμένος αβγουλάτος αβγουλωτός αβγωμένος αβδέλυκτος
 αβεβήλωτος αβεβαίωτος αβελόνιαστος αβερνίκωτος αβιογενετικός αβιομηχάνητος
 αβιομηχανοποίητος αβιοτικός αβλάστητος αβλαβέστατος αβλαβής αβλαπτικός αβλεπής
 αβλόγητος αβοήθητος αβολιδοσκόπητος αβομβάρδιστος αβορβόρωτος αβοτάνιστος
 αβουτύρωτος αβούλευτος αβούλητος αβούλωτος αβούρκωτος αβούρτσιστος αβούτηχτος
 αβράδιαστος αβράκωτος αβράχυντος αβρααμικός αβραμιαίος αβροβόστρυχος
 αβρόμιστα αβρόμιστος αβρός αβρόφρων αβυθομέτρητος αβυσσαλέος αβυσσοβενθικός
 αβυσσώδης αβόλευτος αβόρβορος αβύζαχτος αβύθιστος αγάθας αγάλακτος αγάμητος
 αγέλαστος αγέμιστος αγένειος αγέννητος αγένωτος αγέραστος αγέρινος αγέρωχος
 αγαθάρχης αγαθήμερος αγαθαρχικός αγαθιάρης αγαθοβιόλης αγαθοδότης αγαθοεργός
 αγαθομαρία αγαθομαρούσα αγαθομούνης αγαθοπάροχος αγαθοποιός αγαθοπρεπής
 αγαθοπόνηρος αγαθοσύμβουλος αγαθοφανής αγαθοψώλης αγαθούκλας αγαθούλης
 αγαθούτσικος αγαθόβιος αγαθόβουλος αγαθόγνωμος αγαθόδωρος αγαθόκλας
 αγαθόπουλο αγαθόπουλος αγαθός αγαθότροπος αγαθότυπος αγαθόψυχος αγαθώνυμος
 αγαλβάνιστος αγαλμάτινος αγαλματένιος αγαλματώδης αγαλούχητος αγαμογενετικός
 αγανός αγαπημένα αγαπησιάρης αγαπητικός αγαπητός αγαρνίριστος αγαστός αγγίνιο
 αγγειοανοσοβλαστικός αγγειοαποφρακτικός αγγειοβλαστικός αγγειοβριθής
 αγγειογενετικός αγγειογραφικός αγγειοδιασταλτικός αγγειοδραστικός
 αγγειολογικός αγγειοπλαστικός αγγειοσπαστικός αγγειοσυσταλτικός
 αγγειόσπερμος αγγειώδης αγγελικός αγγελοειδής αγγελοκάμωτος αγγελοκαμωμένος
 αγγελομίμητος αγγελοπρόσωπος αγγελοφτιαγμένος αγγελοφτιασμένος αγγελτικός
 αγγελόπλοκος αγγελόψυχος αγγελώνυμος αγγιδιώτικος αγγιχτικός αγγιχτός
 αγγλικός αγγλομαθής αγγλοσαξονικός αγγλοτραφής αγγλόφερτος αγγλόφιλος
 αγγλόφωνος αγδίκιωτος αγειτόνευτος αγελαίος αγελαδένιος αγελαδίσιος αγελαδινός
 αγενής αγερικός αγεροχτυπημένος αγερσανιώτικος αγεφύρωτος αγεωγράφητος
 αγεώργητος αγιάτρευτος αγιοβασιλιάτικος αγιοδημητριάτικος αγιορείτικος
 αγιοτόκος αγιωτικός αγιότοκος αγιώνυμος αγκάθινος αγκαίνιαστος αγκαζέ
 αγκαθερός αγκαθοφόρος αγκαθωτός αγκιστροειδής αγκιστρωτός αγκυλωτός
 αγκυρωτικός αγκύλος αγλαός αγλωσσοφάγωτος αγλύκαντος αγναντιαστός αγνωσιακός
 αγνωστοποίητος αγνός αγνώμων αγνώριστος αγοήτευτος αγονάτιστος αγορίστικος
 αγορανομικός αγοραστικός αγοραστός αγοραφοβικός αγοραφοβικός αγουροξυπνημένος
 αγουρωπός αγράμματος αγρατζούνιστος αγρατσούνιστος αγρεύσιμος αγριλίσιος
 αγριωπός αγριόφωνος αγροίκος αγροβιομηχανικός αγροδίαιτος αγροδιατροφικός
 αγρονομικός αγροτοβιομηχανικός αγροτοδιατροφικός αγροτοκτηνοτροφικός
 αγυάλιστος αγχέμαχος αγχίνους αγχογόνος αγχολυτικός αγχωτικός αγχώδης
 αγωνιστικός αγωνιώδης αγόγγυστος αγύμναστος αγύρευτος αγύριστος αγώγιμος
 αδάμαστος αδάνειστος αδάπανος αδάσυντος αδάσωτος αδέκαρος αδέκαστος αδέξιος
 αδέσποτος αδέψητος αδήλωτος αδήμευτος αδήριτος αδήωτος αδίδακτος αδίδαχτος
 αδίπλωτος αδίστακτος αδίσταχτος αδίχαστος αδίωκτος αδαής αδαμάντινος
 αδαμαντοκόσμητος αδαμαντοποίκιλτος αδαμαντοστόλιστος αδαμαντοφόρος
 αδαμαντόστικτος αδαμιαίος αδαπάνητος αδασκάλευτος αδασμολόγητος αδείλιαστος
 αδειανός αδειούχος αδελέαστος αδελφικός αδελφοκτόνος αδελφός αδεμάτιαστος
 αδενοειδής αδενοπαθής αδενώδης αδερφίστικος αδερφικός αδευτέρωτος
 αδημιούργητος αδημοσίευτος αδηφάγος αδιάβαστος αδιάβατος αδιάβλητος αδιάβροχος
 αδιάδοτος αδιάζευκτος αδιάθετος αδιάκοπος αδιάκριτος αδιάλειπτος αδιάλεχτος
 αδιάλυτος αδιάνθιστος αδιάντροπος αδιάπαυστος αδιάπλαστος αδιάπτωτος
 αδιάρρηκτος αδιάσειστος αδιάσπαστος αδιάσταλτος αδιάστατος αδιάτρητος
 αδιάφθορος αδιάφορος αδιάψευστος αδιέγερτος αδιέξοδος αδιήθητος αδιαίρετος
 αδιαβάθμητος αδιαβίβαστος αδιαβατικός αδιαγούμητος αδιαγούμιστος αδιακήρυκτος
 αδιακανόνιστος αδιακλάδωτος αδιακρίβωτος αδιακόρευτος αδιακόσμητος αδιακώλυτος
 αδιαλόγητος αδιαμέλιστος αδιαμαρτύρητος αδιαμεσολάβητος αδιαμοίραστος
 αδιαμόρφωτος αδιανέμητος αδιανόητος αδιαπέραστος αδιαπαιδαγώγητος αδιαπότιστος
 αδιασάλευτος αδιασάφητος αδιασαφήνιστος αδιασκέδαστος αδιασκεύαστος
 αδιαστρέβλωτος αδιατάρακτος αδιατάραχτος αδιατήρητος αδιατίμητος
 αδιατύπωτος αδιαφέντευτος αδιαφήμιστος αδιαφανής αδιαφιλονίκητος
 αδιαφόρετος αδιαφύλακτος αδιαφύλαχτος αδιαφώτιστος αδιαχώρητο αδιαχώρητος
 αδιεκδίκητος αδιενέργητος αδιερεύνητος αδιευθέτητος αδιευκρίνητος
 αδικαίωτος αδικαιολόγητος αδικομοιρασμένος αδικοπονεμένος αδικοσταυρωμένος
 αδιοίκητος αδιοργάνωτος αδιπικός αδιπλασίαστος αδιχοτόμητος αδιόγκωτος
 αδιόρθωτος αδιόριστος αδιύλιστος αδογμάτιστος αδοκίμαστος αδολίευτος
 αδούλωτος αδρανής αδρανειακός αδρανοβαρυτικός αδρανογόνος αδρασκέλιστος
 αδροδάκτυλος αδρομεγέθης αδρομερής αδρόμισθος αδρός αδρόσιστος αδυνάστευτος
 αδυνατούτσικος αδυσώπητος αδωροδόκητος αδόκητος αδόκιμος αδόλεσχος αδόλωτος
 αδόξαστος αδύναμος αδύνατος αδώρητος αείμνηστος αείφυλλος αειθαλής αεικίνητος
 αειφανής αειφόρος αεράτος αεραγηματικός αεραθλητικός αεραποβατικός αερεπίγειος
 αεριοφόρος αεριούχος αεριτζίδικος αεριώδης αεροΰφαντος αεροβάμων αεροδίνητος
 αεροδρομικός αεροδυναμικός αεροκίνητος αερολιθικός αερολιμενικός αερολόγος
 αεροναυτικός αεροναυτιλιακός αεροναυτιλλόμενος αεροπλανικό αεροπλανικός
 αεροπορικός αεροστατικός αεροστεγής αεροφόρος αεροχτυπημένος αερόβιος
 αερόψυκτος αερώδης αετίσιος αετομάτης αετόμορφος αζάρωτος αζέρικος αζέσταγος
 αζήλευτος αζήμιος αζήτητος αζαχάρωτος αζεμάτιστος αζερικός αζερμπαϊτζανικός
 αζευγάρωτος αζημίωτος αζιμουθιακός αζωγράφητος αζωγράφιστος αζωικός
 αζωτούχος αζύγιαστος αζύγιστος αζύγωτος αζύμωτος αηδής αηδιαστικός
 αηδονόλαλος αηδονόστομος αηδονόφωνος αθάμβωτος αθάμπωτος αθάνατος αθάρρευτος
 αθέλητος αθέμιτος αθέριστος αθέρμαντος αθέσπιστος αθήλαστος αθήλιαστος αθαμβής
 αθειάφιστος αθεμέλιωτος αθεμελίωτος αθεολόγητος αθεράπευτος αθεσμοθέτητος
 αθεϊστικός αθεόφοβος αθεώρητος αθηλύκωτος αθημώνιαστος αθηναίικος
 αθηναϊκός αθησαύριστος αθλητιατρικός αθλητικός αθλομανής αθλοφόρος αθορύβητος
 αθροιστικός αθρυμμάτιστος αθρόος αθυμιάτιστος αθυρόστομος αθωνικός αθωράκιστος
 αθωότης αθόλωτος αθόρυβος αθύμωτος αθώος αθώπευτος αθώρητος αιγαίος αιγαιακός
 αιγαλιώτικος αιγιακός αιγιαλίτης αιγινήτικος αιγοπρόβειος αιγυπτιακός
 αιδήμων αιθέριος αιθαλώδης αιθερικός αιθεριώδης αιθεροβάμων αιθουσονωτιαίος
 αιθυλιούχος αιλουροειδής αιμάτινος αιματηρός αιματικός αιματοβούτηχτος
 αιματολογικός αιματοπότιστος αιματόβρεκτος αιματόβρεχτος αιματόχροος
 αιματώδης αιμοβόρικος αιμοβόρος αιμοδιψής αιμοδυναμικός αιμολυτικός
 αιμομικτικός αιμορραγικός αιμορροφιλικός αιμορροϊκός αιμοσταγής αιμοστατικός
 αιμοφόρος αιμοχαρής αιμοχρωστικός αιμόφιλος αιμόφυρτος αινέσιμος αινετός
 αινιγματώδης αιολικός αιρετός αισθαντικός αισθηματικός αισθησιακός
 αισθησιοκρατικός αισθητήριος αισθητηριακός αισθητικοκινητικός αισθητικός
 αισιόδοξος αισχροκερδής αισχρολογικός αισχρολόγος αισχρός αισχυλικός
 αισχύλειος αισωπικός αισώπειος αιτητικός αιτιάσιμος αιτιακός αιτιατικός
 αιτιοκρατικός αιτιολογικός αιτιοπαθογενετικός αιτιώδης αιτωλικός αιφνίδιος
 αιχμάλωτος αιχμηρός αιωνόβιος αιώνιος ακάθαρτος ακάθεκτος ακάθιστος ακάλεστος
 ακάματος ακάμωτος ακάνθινος ακάπνιστος ακάρπιστος ακάρφωτος ακάτεχος ακάτιος
 ακένωτος ακέραιος ακέραστος ακέριος ακέρωτος ακέφαλος ακήδευτος ακήρατος
 ακήρυχτος ακίβδηλος ακίνδυνος ακίνητος ακαής ακαβάλητος ακαβούρδιστος
 ακαδημαϊκός ακαθάριστος ακαθίδρυτος ακαθιέρωτος ακαθοδήγητος ακαθόριστος
 ακακολόγητος ακαλίγωτος ακαλαίσθητος ακαλαφάτιστος ακαλλιέργητος ακαλλώπιστος
 ακαλοκάρδιστος ακαμάκιαστος ακαμάκιστος ακαμάκωτος ακαμάτης ακαμίνευτος
 ακανθοκυτταρικός ακανθοστεφής ακανθώδης ακανόνιστος ακαπάκωτος ακαπάρωτος
 ακαπήλευτος ακαπίστρωτος ακαπλάντιστος ακαρίκωτος ακαρατόμητος ακαριαίος
 ακαρποφόρητος ακαρύκευτος ακασσιτέρωτος ακατάβρεκτος ακατάβρεχτος ακατάγγελτος
 ακατάδεχτος ακατάκτητος ακατάληκτος ακατάληπτος ακατάλληλος ακατάλυτος
 ακατάπαυτος ακατάρτιστος ακατάσβεστος ακατάσβηστος ακατάστατος ακατάσχετος
 ακατάταχτος ακατάφερτος ακατέβατος ακατέργαστος ακατήχητος ακαταίσχυντος
 ακαταγώνιστος ακαταδίωκτος ακατακρήμνιστος ακατακύρωτος ακαταλαβίστικος
 ακαταλόγιστος ακαταμάχητος ακαταμέτρητος ακατανάλωτος ακατανίκητος ακατανόητος
 ακαταπολέμητος ακαταπόνητος ακατασίγαστος ακατασκεύαστος ακαταστάλακτος
 ακατατόπιστος ακαταφρόνετος ακαταφρόνητος ακαταχώνιαστος ακαταχώρητος
 ακατεδάφιστος ακατεύθυντος ακατεύναστος ακατηγόρητος ακατοίκητος ακατονόμαστος
 ακατράμωτος ακατόρθωτος ακαυτηρίαστος ακαψάλιστος ακερδής ακερικός ακηδής
 ακηλίδωτος ακιδωτός ακλάδευτος ακλήρωτος ακλήτευτος ακλεής ακλείδωτος
 ακλυδώνιστος ακλόνητος ακμάζων ακμαίος ακοίμητος ακοίταχτος ακοιλωματικός
 ακοινοποίητος ακοινώνητος ακολλάριστος ακολουθιακός ακολύμπητος ακομμάτιαστος
 ακονιστικός ακοομετρικός ακοπάνιστος ακορνίζωτος ακορνιζάριστος ακοροΐδευτος
 ακορύφωτος ακοσκίνιστος ακοστολόγητος ακουβάλητος ακουστικός ακουστός
 ακουόμετρο ακούμπωτος ακούνητος ακούραστος ακούρδιστος ακούρευτος ακούρντιστος
 ακούσιος ακράδαντος ακράτητος ακρήμνιστος ακραίος ακραιφνής ακρατής ακριανός
 ακριβοδίκαιος ακριβοθώρητος ακριβολόγος ακριβομίλητος ακριβούτσικος ακριβός
 ακριδοκτόνος ακριμάτιστος ακρινός ακριτικός ακριτόμυθος ακροαματικός
 ακροαστικός ακροβατικός ακρογωνιαίος ακροδεξιός ακροθιγής ακροκεντρικός
 ακροτελεύτιος ακροφωνικός ακρυλικός ακρυστάλλωτος ακρωμιοκλειδικός ακρόλιθος
 ακτέριστος ακτήμονας ακτήμων ακταίος ακτιβιστικός ακτινοβόλος ακτινογραφικός
 ακτινοθεραπευτικός ακτινολογικός ακτινομετρικός ακτινοσκοπικός ακτινοστόλιστος
 ακτινωτός ακτινώδης ακτοπλοϊκός ακτουάριος ακτύπητος ακυβέρνητος ακυκλοφόρητος
 ακυρίευτος ακυρωτικός ακυρώσιμος ακυτταρικός ακωδικοποίητος ακωμώδητος
 ακόλλητος ακόλουθος ακόμιστος ακόνιστος ακόρδωτος ακόρεστος ακόρυφος ακόσμητος
 ακύρωτος ακώλυτος αλάβωτος αλάδωτος αλάθευτος αλάθητος αλάλητος αλάνθαστος
 αλάξευτος αλάργος αλέγρος αλέκιαστος αλέρωτος αλήστευτος αλήτικος αλίμενος
 αλίπαστος αλίχνιστος αλαβάστρινος αλαγάριστος αλαζονικός αλαμπής
 αλανιάρικος αλαργινός αλαργοτάξιδος αλατερός αλατοφόρος αλατούχος αλατόμητος
 αλαφροΐσκιωτος αλαφροκάνταρος αλαφρόμυαλος αλαφρός αλαφρύς αλαφυραγώγητος
 αλβανοσοβιετικός αλβανόφωνος αλγαισθητικό αλγαισθητικός αλγεβρικός αλγεινός
 αλγογόνος αλγοριθμικός αλείαντος αλεηλάτητος αλειτούργητος αλεκτικός αλεξήνεμο
 αλεξίπυρος αλεξίσφαιρος αλεξανδρινός αλεπουδίσιος αλεπτολόγητος αλεστικός
 αλευρίτικος αλευροβιομηχανικός αλευροειδής αλευρούχος αλευρωμένος αλευρώδης
 αλεύκαντος αλεύκαστος αλεύρινος αληθής αληθινός αληθοφανέστερος αληθοφανής
 αλησμόνητος αλιάνιστος αλιβάνιστος αλιγούρευτος αλιευτικός αλιμάριστος
 αλιχούδευτος αλκαλικός αλκαϊκός αλκοολικός αλκοολομετρικός αλκοολούχος
 αλλαντικός αλλαξόπιστος αλλεπάλληλος αλλεργικός αλλεργιογόνος αλλεργιολογικός
 αλληλέγγυος αλληλένδετος αλληλεπιδραστικός αλληλοβοηθητικός αλληλοδιάδοχος
 αλληλοεξοντωτικός αλληλοεπηρεαζόμενος αλληλοεπιδρώμενος αλληλοκεντρικός
 αλληλοπαθής αλληλόφιλος αλληλόχρεος αλλιώτικος αλλογενής αλλοδαπός αλλοεθνής
 αλλοιωτικός αλλοιώσιμος αλλομετρικός αλλοπαθητικός αλλοπαρμένος αλλοπρόσαλλος
 αλλοστερικός αλλοτινός αλλοτριοφάγος αλλοτριοφαγικός αλλοχωριανός αλλόγλωσσος
 αλλόεθνος αλλόθρησκος αλλόκοτος αλλόπιστος αλλότριος αλλότροπος αλλόφρων
 αλλόφωνος αλματώδης αλμυρούτσικος αλμυρός αλογάριαστος αλογήσιος αλογίσιος
 αλογόκριτος αλουλούδιαστος αλουλούδιστος αλουμινένιος αλουστράριστος αλούτερος
 αλπικός αλπινικός αλσατικός αλσώδης αλταζιμουθιακός αλτικός αλτρουιστικός
 αλυσιτελής αλυσοδέσμιος αλυσοειδής αλυσωτός αλυσόδετος αλυτρωτικός αλφαβητικός
 αλφαριθμητικός αλφικός αλχημικός αλχημιστικός αλωνάρης αλωνιάτης αλωνιστικός
 αλόγιαστος αλόγιστος αλύγιστος αλύπητος αλύτρωτος αλώβητος αλώσιμος αμάγευτος
 αμάζευτος αμάθευτος αμάθητος αμάλαγος αμάλαχτος αμάλλιαγος αμάλλιαστος
 αμάντευτος αμάντριστος αμάντρωτος αμάραντος αμάρτυρος αμάσητος αμάτιαστος
 αμάχητος αμέθοδος αμέθυστος αμέριμνος αμέριστος αμέρωτος αμέστωτος αμέταλλος
 αμέτρητος αμήνυτος αμήχανος αμίαντος αμίλητος αμίμητος αμίσθωτος αμαγάριστος
 αμαζονικός αμαζόνειος αμαζόνιος αμαθής αμαθημάτιστος αμακιγιάριστος
 αμαλγαμωτικός αμανίκωτος αμαντάλωτος αμαντάριστος αμαξιτός αμαξωτός
 αμαρκάριστος αμαρτωλός αμαρτύρητος αμασκάρευτος αμαστίγωτος αμαυρός
 αμαύριστος αμβληχρός αμβλυγώνιος αμβλυκόρυφος αμβλυντικός αμβλυωπικός
 αμβλύς αμβλύστομος αμείλικτος αμείλιχτος αμείωτος αμεθόδευτος αμειδίαστος
 αμελής αμελητέος αμερικάνικος αμερικανικός αμερικανοκίνητος
 αμερικανόφιλος αμερόληπτος αμεσίτευτος αμετάβατος αμετάβλητος αμετάγγιστος
 αμετάθετος αμετάκλητος αμετάλαβος αμετάλλακτος αμετάλλαχτος αμετάπειστος
 αμετάπτωτος αμετάτρεπτος αμετάφερτος αμετάφραστος αμεταβίβαστος
 αμεταγύριστος αμετακίνητος αμεταμέλητος αμεταμφίεστος αμεταμόρφωτος
 αμετανόητος αμεταποίητος αμετασχημάτιστος αμετατόπιστος αμεταχείριστος
 αμετροεπής αμιάντινος αμιγής αμικροβιακός αμινοβουτυρικός αμισθοδότητος
 αμλετικός αμμοκίτρινος αμμοστρωμένος αμμουδερός αμμωνιακός αμμωνιούχος αμμώδης
 αμνήμων αμνήστευτος αμνημόνευτος αμνησίκακος αμνησιακός αμνηστεύσιμος αμνιακός
 αμοιβαίος αμοιρολόγητος αμολόγητος αμοντάριστος αμοραλιστικός αμορφοποίητος
 αμούστακος αμπάδι αμπάδικος αμπάλωτος αμπελικός αμπελοοινικός αμπελουργικός
 αμπερομετρικός αμπογιάντιστος αμπογιάτιστος αμπόλιαστος αμυγδαλάτος
 αμυδρός αμυλούχος αμυλώδης αμυντικοβιομηχανικός αμυντικός αμφίαλος αμφίβιος
 αμφίβραχυς αμφίδρομος αμφίθυμος αμφίκοιλος αμφίκυρτος αμφίλογος αμφίπλευρος
 αμφίσημος αμφίστομος αμφιβαρής αμφιβληστροειδής αμφιβραχικός αμφιγραφικός
 αμφιθαλής αμφιθεατρικός αμφιθυμικός αμφικλινής αμφικοιλιακός αμφικτιονικός
 αμφιμονοσήμαντος αμφινευστικός αμφιπαθητικός αμφιπρόστυλος αμφιρρεπής
 αμφιφανής αμφιφυλικός αμφιφυλόφιλος αμφοτερικός αμφοτεροβαρής αμωλώπιστος
 αμόλυβδος αμόλυντος αμόνοιαστος αμόρφωτος αμύητος αμύθητος αμύριστος αμύρωτος
 αμώμητος ανάβαθος ανάβροχος ανάγιαστο ανάγλυφος ανάδελφος ανάδρομος ανάερος
 ανάκατος ανάκουστος ανάλαδος ανάλατος ανάλαφρος ανάλγητος ανάλεστος ανάλλαγος
 ανάλλαχτος ανάλογος ανάμεικτος ανάμειχτος ανάμελος ανάμερος ανάμικτος
 ανάνθιστος ανάντης ανάξιος ανάπηρος ανάπλεκος ανάπλωρος ανάποδος ανάπρυμνος
 ανάπρωρος ανάριθμος ανάριος ανάριχτος ανάρμεγος ανάρμεχτος ανάρμοστος
 ανάρριχτος ανάσκελος ανάσκητος ανάστατος ανάστερος ανάστροφος ανάφεγγος
 ανέγγυος ανέγκλητος ανέγνοιαστος ανέγνωμος ανέγνωρος ανέκδοτος ανέκκλητος
 ανέλεγκτος ανέλπιδος ανέλπιστος ανέμελος ανέμπειρος ανέμπνευστος ανέμυαλος
 ανέντακτος ανένταχτος ανέντιμος ανέξοδος ανέπαγος ανέπαφος ανέραστος ανέρωτος
 ανέσπλαγχνος ανέσπλαχνος ανέστιος ανέτοιμος ανέφελος ανέφικτος ανήθικος
 ανήκουστος ανήλεος ανήλιαγος ανήλιαστος ανήλικος ανήλιος ανήμερος ανήμπορος
 ανήστευτος ανήσυχος ανίατος ανίδεος ανίδρωτος ανίδωτος ανίερος ανίκανος
 ανίσκιος ανίσκιωτος ανίσχυρος αναίμακτος αναίμαχτος αναίρετος αναίσθητος
 αναίτιος αναβαθμίσιμος αναβλητικός αναβολικός αναβράζων αναβραστός
 αναγεννησιακός αναγεννητικός αναγερτός αναγκαίος αναγκαστικός αναγλυφικός
 αναγνωριστικός αναγνωστικός αναγνώσιμος αναγομωμένος αναγουλιαστικός
 αναγωγισμός αναγωγιστικός αναγώγιμος αναδασωτέος αναδεκτός αναδεχτός
 αναδιανεμητικός αναδρομικός αναερόβιος αναζητήσιμος αναζωογονητικός
 αναθεωρητικός αναθηματικός αναιδής αναιμικός αναιρέσιμος αναιρετέος
 αναιρετικός αναισθησιολογικός αναισθητικός αναιτιολόγητος ανακαινιστικός
 ανακατωσούρης ανακατωτός ανακεφαλαιωτικός ανακλαδιστός ανακλαστικός
 ανακλητικός ανακλητός ανακοινώσιμος ανακουφιστικός ανακρεόντειος ανακριβής
 ανακτορικός ανακόλουθος ανακύψιμος αναλγητικός αναληθής αναλημματικός
 αναληπτικός αναλλοίωτος αναλογικός αναλογιστικός αναλυτικός αναλυτικότερος
 αναλφάβητος αναλφαβητικός αναλύσιμος αναλώσιμος αναμαλλιάρης αναμνηστικός
 αναμπάρωτος αναμφίβολος αναμφίλεκτος αναμφίσημος αναμφισβήτητος ανανεωμένος
 ανανεώσιμος ανανθής ανανούριστος αναντίλεκτος αναντίρρητος αναντίστρεπτος
 ανανταπόδεικτος ανανταπόδοτος αναντικατάστατος αναντιπροσώπευτος
 αναξιοπαθής αναξιοπαθών αναξιοποίητος αναξιοπρεπής αναξιόλογος αναξιόπιστος
 αναπάντεχος αναπάντητος αναπαιστικός αναπαλλοτρίωτος αναπαραγωγικός
 αναπασχόλητος αναπαυτικός αναπεπταμένος αναπηρικός αναπλαστικός
 αναπνευστικός αναποδιάρης αναποδιασμένος αναποζημίωτος αναποκατάστατος
 αναπολόγητος αναποτελεσματικός αναποφάσιστος αναποχώριστος αναπροσαρμοζόμενος
 αναπόγραφος αναπόδεικτος αναπόδειχτος αναπόδοτος αναπόδραστος αναπόσπαστος
 αναπόφευγος αναπόφευκτος αναρίθμητος αναριχτός αναρμάτωτος αναρμόδιος
 αναρριχτός αναρροφητικός αναρρωτικός αναρτητέος αναρχικός αναρχοαυτόνομος
 ανασκαφικός ανασκευαστικός ανασκοπικός αναστάσιμος ανασταλτικός ανασταλτός
 αναστεναμένος αναστηλωτικός αναστρέψιμος ανασυνδυασµένος ανασυρτός
 ανασφαλής ανασχετικός ανατάσιμος αναταρασσόμενος ανατιμητικός ανατολίτικος
 ανατομικός ανατρέψιμος ανατρεπτικός ανατριχιαστικός ανατροφοδοτικός
 αναφαίρετος αναφλέξιμος αναφλεκτικός αναφομοίωτος αναφορικός αναφρόδιτος
 αναχρονιστικός αναύλωτος αναύξητος ανδρείος ανδρειωμένος ανδρικός
 ανδρολογικός ανδρομόνοικος ανδροπρεπής ανδρωνυμικός ανδρόγυνος ανδρώδης
 ανείδωτος ανείπωτος ανείσπρακτος ανείσπραχτος ανεβάσταγος ανεβατός ανεγγύητος
 ανεγκρατής ανεγχείρητος ανεγχείριστος ανεδαφικός ανειδίκευτος ανειδοποίητος
 ανειλημμένος ανειλικρινής ανειρήνευτος ανεκδήλωτος ανεκδίκαστος ανεκδίκητος
 ανεκδοτικός ανεκδοτολογικός ανεκκαθάριστος ανεκλάλητος ανεκμετάλλευτος
 ανεκπαίδευτος ανεκπλήρωτος ανεκποίητος ανεκτέλεστος ανεκτίμητος ανεκτικός
 ανεκχώρητος ανελέητος ανελαστικός ανελεήμων ανελεύθερος ανελικτικός
 ανελλιπής ανεμογραφικός ανεμοδεικτικός ανεμομετρικός ανεμπόδιστος ανεμόδαρτος
 ανενεργός ανενημέρωτος ανενθρόνιστος ανενόχλητος ανεξάλειπτος ανεξάντλητος
 ανεξέλεγκτος ανεξέλικτος ανεξέταστος ανεξήγητος ανεξίθρησκος ανεξίκακος
 ανεξαίρετος ανεξακρίβωτος ανεξαργύρωτος ανεξερεύνητος ανεξεταστέος ανεξιλέωτος
 ανεξοικείωτος ανεξόφλητος ανεξύμνητος ανεξύπνητος ανεπάγγελτος ανεπάντεχος
 ανεπίγραφος ανεπίδεκτος ανεπίδεχτος ανεπίδοτος ανεπίκαιρος ανεπίκλητος
 ανεπίλυτος ανεπίσημος ανεπίστρεπτος ανεπίστροφος ανεπίτευκτος ανεπίτρεπτος
 ανεπαίσχυντος ανεπανάληπτος ανεπανόρθωτος ανεπαρκής ανεπαχθής ανεπεξέργαστος
 ανεπιβεβαίωτος ανεπιεικής ανεπιθύμητος ανεπικερδής ανεπικύρωτος ανεπιμέλητος
 ανεπιτήδειος ανεπιτήδευτος ανεπιτήρητος ανεπιτυχής ανεπιφύλακτος ανεπούλωτος
 ανεπρόκοφτος ανεπτυγμένος ανερέθιστος ανερεύνητος ανερμάτιστος ανερμήνευτος
 ανερώτευτος ανεσταλμένος ανετοίμαστος ανετυμολόγητος ανευθύγραμμος ανευλαβής
 ανευρυσματικός ανευρυσματώδης ανευφάνταστος ανευχαρίστητος ανεφάρμοστος
 ανεχτίμητος ανεχτικός ανεχτός ανεχόρταγος ανεόρταστος ανεύθυνος ανεύρετος
 ανεύφλεκτος ανηγμένος ανηλεής ανημέρευτος ανημέρωτος ανημέτερος ανηολόγητος
 ανησυχητικός ανηφορικός ανθεκτικός ανθελληνικός ανθελονοσιακός ανθενωτικός
 ανθιδρωτικός ανθικός ανθισμένος ανθοκομικός ανθοστόλιστος ανθοφόρος ανθρακικός
 ανθρακοφόρος ανθρακούχος ανθρακώδης ανθρωπινός ανθρωπιστικός ανθρωπογενής
 ανθρωποκεντρικός ανθρωποκτόνος ανθρωπολογικός ανθρωπομετρικός ανθρωπομορφικός
 ανθρωποφάγος ανθρωπωνυμικός ανθρωπόμορφος ανθρωπόφιλος ανθρώπειος ανθρώπινος
 ανθυποβρυχιακός ανθυψίφωνος ανθόσπαρτος ανθόστρωτος ανθώδης ανιαρός
 ανιθυφαλλικός ανικανοποίητος ανικτερικός ανιμιστικός ανιοβόλος ανιονικός
 ανισομήκης ανισομεγέθης ανισομερής ανισομετρικός ανισοσκελής ανισοσύλλαβος
 ανιστόρητος ανισόβαρος ανισόμερος ανισόπεδος ανισόπλευρος ανισόρροπος
 ανιχνευτικός ανιχνεύσιμος ανιών ανοίκειος ανοίκιαστος ανοδικός
 ανοικοδομητικός ανοικοδομικός ανοικοδόμητος ανοικοκύρευτος ανοικονόμητος
 ανοικτός ανοιξιάτικος ανοιχτομάτης ανοιχτοχέρης ανοιχτοχέρικος ανοιχτόκαρδος
 ανοιχτόχερος ανοιχτόχρωμος ανολοκλήρωτος ανομοιογενής ανομοιοκατάληκτος
 ανομοιωτικός ανομοιόμορφος ανομολόγητος ανονείρευτος ανοξείδωτος ανοργάνωτος
 ανορθολογικός ανορθολογιστικός ανορθωτικός ανορθόγραφος ανορθόδοξος ανοσιακός
 ανοσοθεραπευτικός ανοσοκατασταλτικός ανοσοκατεσταλμένος ανοσολογικός
 ανοσορυθμιστικός ανοσοτροποποιητικός ανοσοφαρμακολογικός ανοσοϊστοχημικός
 ανοχύρωτος ανοϊκός ανούσιος αντάξιος αντάρτικος αντήλιος αντίδικος αντίζηλος
 αντίθετος αντίθρησκος αντίμαχος αντίξοος αντίπαλος αντίπερα αντίρροπος
 αντίστροφος αντίφα αντίχριστος αντίψυχος ανταγωνιστικός ανταλλάξιμος
 αντανακλαστικός ανταπεργιακός ανταποδοτικός ανταποκρίσιμος ανταποκριτικός
 ανταρτικός ανταρτοπολεμικός ανταρτόπληκτος αντασφαλιστικός αντεθνικός
 αντεκπαιδευτικός αντεμετικός αντενεργών αντεπαναστατικός αντεπιστέλλων
 αντεργατικός αντεργκράουντ αντηχητικός αντηχών αντιαγνωστικός αντιαγροτικός
 αντιαθλητικός αντιαιμορραγικός αντιαισθητικός αντιαλγικός αντιαλκοολικός
 αντιαμερικανικός αντιαναπτυξιακός αντιανεμικός αντιανταρτικός
 αντιαρθριτικός αντιαρματικός αντιασφυξιογόνος αντιατομικός αντιατομιστικός
 αντιαφροδισιακός αντιβαλκανικός αντιβασιλικός αντιβενιζελικός αντιβεντετικός
 αντιβιοτικό αντιβιοτικός αντιβλεννορροιακός αντιγαμητικός αντιγλυκαιμικός
 αντιγονορροϊκός αντιγραφικός αντιγριπικός αντιδάνειος αντιδανειακός αντιδεξιός
 αντιδημοτικός αντιδιαβητικός αντιδιαμετρικός αντιδικτατορικός αντιδιουρητικός
 αντιδιφθεριτικός αντιδογματικός αντιδραστικός αντιδυναστικός αντιεθνικός
 αντιεκπαιδευτικός αντιεκρηκτικός αντιεμετικός αντιεμπορευματικός αντιεμπορικός
 αντιεπιστημονικός αντιευρωπαϊκός αντιεφιδρωτικός αντιηλιακός αντιηρωικός
 αντιθεατρικός αντιθερμαντικός αντιθετικός αντιθρησκευτικός αντιθρομβωτικός
 αντιιδρωτικός αντιιικός αντιικός αντιισταμινικός αντικαθεστωτικός
 αντικανονικός αντικανονιστικός αντικαπνιστικός αντικαρκινικός
 αντικαταναλωτικός αντικατασκοπευτικός αντικατασκοπικός αντικαταστάσιμος
 αντικαταστατός αντικειμενικοποιημένος αντικειμενικός αντικειμενοποιημένος
 αντικληρικός αντικοινοβουλευτικός αντικοινωνικός αντικομματικός
 αντικομουνιστικός αντικομφορμιστικός αντικουνουπικός αντικραδασμικός
 αντικριστός αντικρουόμενος αντικυβερνητικός αντικυκλικός αντικυκλωνικός
 αντιλαϊκός αντιλεκτικός αντιληπτικός αντιληπτός αντιλογιστικός αντιλυρικός
 αντιμέτωπος αντιμαχόμενος αντιμεθυστικός αντιμελοδραματικός αντιμεταθετικός
 αντιμεταφυσικός αντιμετωπίσιμος αντιμηνιγγιτικός αντιμικροβιακός
 αντιμιλιταριστικός αντιμνημονιακός αντιμοναρχικός αντιμονιούχος
 αντιμυκητιασικός αντινεοπλασματικός αντινευρικός αντινεφικός αντινομικός
 αντιοικονομικός αντιολισθητικός αντιοξειδωτικός αντιοφικός αντιπαθέστερος
 αντιπαθητικός αντιπαιδαγωγικός αντιπανωλικός αντιπαραγωγικός αντιπαραθετικός
 αντιπαρασιτικός αντιπαρατάξιμος αντιπατριωτικός αντιπειθαρχικός
 αντιπερισπαστικός αντιπηκτικός αντιπιτυριδικός αντιπληθωρικός
 αντιπλημμυρικός αντιπνευματικός αντιπνευμονικός αντιποιητικός αντιπολεμικός
 αντιπολιτευτικός αντιπολιτικός αντιπροεδρικός αντιπροστατευτικός
 αντιπροσωπεύων αντιπροχθεσινός αντιπροχτεσινός αντιπυραυλικός αντιπυρετικό
 αντιπυρηνικός αντιπυρικός αντιρατσιστικός αντιρρευματικός αντιρρητικός
 αντιρυτιδικός αντισεισμικός αντισεξουαλικός αντισημιτικός αντισηπτικός
 αντισκωριακός αντισοβιετικός αντισπασμωδικός αντισταθμίσιμος αντισταθμιστικός
 αντιστατικός αντιστικτικός αντιστιξιακός αντιστρέψιμος αντιστρατιωτικός
 αντιστυλωμένος αντισυλληπτικός αντισυμβαλλόμενος αντισυμβατικός
 αντισυμμοριακός αντισυνδικαλιστικός αντισυνταγματικός αντισυστημικός
 αντιτάνκ αντιτάξιμος αντιτακτός αντιτετανικός αντιτοξικός αντιτορπιλικός
 αντιτράστ αντιτραπεζικός αντιτριβικός αντιτρομοκρατικός αντιτυφικός
 αντιφασιστικός αντιφατικός αντιφεμινιστικός αντιφθισικός αντιφιλελεύθερος
 αντιφλεγμονώδης αντιφλογιστικός αντιφρονών αντιφυλετικός αντιφυλλοξηρικός
 αντιφυσικός αντιφωνικός αντιχαλαζικός αντιχολερικός αντιχριστιανικός
 αντλησιοταμιευτικός αντλητήριος αντλιοφόρος αντούβιανος αντρίκειος αντρίκιος
 αντρείος αντρειωμένος αντρικός αντρωμένος αντρόπιαστος αντωνυμικός αντωπός
 ανυιοθέτητος ανυμνητικός ανυπάκοος ανυπάκουος ανυπέρβλητος ανυπέρθετος
 ανυποθήκευτος ανυπολόγιστος ανυπομόνευτος ανυποστήρικτος ανυποστήριχτος
 ανυποχώρητος ανυποψίαστος ανυπόγραφος ανυπόδητος ανυπόθετος ανυπόθηκος
 ανυπόληπτος ανυπόμονος ανυπόνοιαστος ανυπόστατος ανυπόσχετος ανυπόταγος
 ανυπόταχτος ανυπόφερτος ανυπόφορος ανυσματικός ανυστερόβουλος ανυψωτικός
 ανωφέλετος ανωφέλευτος ανωφέλητος ανωφελής ανωφελώς ανωφερής ανωφερικός
 ανόθευτος ανόμοιος ανόργανος ανόργητος ανόργιστος ανόργωτος ανόρεκτος
 ανόσιος ανότιστος ανύμφευτος ανύπανδρος ανύπαντρος ανύπαρκτος ανύπαρχτος
 ανύποπτος ανύσταγος ανύστακτος ανύσταχτος ανύχτωτος ανώδυνος ανώμαλος ανώνυμος
 ανώτατος ανώτερος ανώφελος αξάκριστος αξάπλωτος αξάφριστος αξέμπλεχτος
 αξέχαστος αξήγητος αξήλωτος αξίδιαστος αξίνιστος αξεδίψαστος αξεδιάκριτος
 αξεδιάλυτος αξεθύμαστος αξεκαθάριστος αξεκόλλητος αξελόγιαστος αξεμάτιαστος
 αξεμυάλιστος αξεπάστρευτος αξεπέραστος αξεπλέρωτος αξεπλήρωτος αξεπούλητος
 αξεσκάλιστος αξεσκέπαστος αξεσκόλιστος αξετίμητος αξετύλιχτος αξεφιτίλιστος
 αξεφούρνιστος αξεχαρβάλωτος αξεχώριστος αξημέρωτος αξιέπαινος αξιέραστος
 αξιαζούμενος αξιαζόμενος αξιακός αξιανάγνωστος αξιογέλαστος αξιοδάκρυτος
 αξιοζήλευτος αξιοθέατος αξιοθαύμαστος αξιοθησαύριστος αξιοθρήνητος
 αξιοκαταφρόνετος αξιοκαταφρόνητος αξιοκατηγόρητος αξιοκρατικός αξιολάτρευτος
 αξιολογικός αξιολογούμενος αξιολογών αξιολύπητος αξιομίμητος αξιομίσητος
 αξιομνημόνευτος αξιοπαρατήρητος αξιοπερίεργος αξιοπεριφρόνητος αξιοποιήσιμος
 αξιοπρεπής αξιοπρόσεκτος αξιοπρόσεχτος αξιοσέβαστος αξιοσημείωτος
 αξιοτράβηχτος αξιωματικός αξιόλογος αξιόμαχο αξιόμαχος αξιόμεμπτος αξιόμισθος
 αξιόπλοος αξιόποινος αξιόπρεπος αξιότιμος αξιόχρεος αξιώτικος αξομολόγητος
 αξονικός αξονοειδής αξονομετρικά αξονομετρικός αξονοσυμμετρικός αξούριστος
 αξόδευτος αξόδιαστος αξόμπλιαστος αξόρκιστος αξόφλητος αξύλευτος αξύλιστος
 αξύριστος αοίδιμος αοριστικός αοριστολογικός αορτικός αορτολαγόνιος
 απάγγειος απάγκειος απάγκιος απάγωτος απάδων απάλιωτος απάνεμος απάνθρωπος
 απάρθενος απάστρευτος απάστωτος απάτητος απάτορας απάτριος απάτωρ απάχικος
 απένθητος απένταρος απέξω απέραντος απέραστος απέριττος απέταλος απέχων
 απίθανος απίκραντος απίσσωτος απίστευτος απίστωτος απαίδευτος απαίνευτος
 απαγής απαγγελτικός απαγκιστρωτικός απαγορευτικός απαγωγικός απαγωγός
 απαζάρευτος απαθής απαιδαγώγητος απαισιόδοξος απαισιόμορφος απαισιότατος
 απαιτητός απαλάμιστος απαλειπτικός απαλλακτικός απαλλαχτικός απαλλοτριώσιμος
 απαλός απαλόχνουδος απανινός απαντητικός απαντλητικός απανωτός απαξάπας
 απαπούτσωτος απαράβαλτος απαράβατος απαράβλητος απαράγγελτος απαράγραπτος
 απαράγραφτος απαράδεκτος απαράδεχτος απαράδοτος απαράθετος απαράκαμπτος
 απαράλειπτος απαράληπτος απαράλλακτος απαράλλαχτος απαράμιλλος απαράσκευος
 απαρέμφατος απαρένθετος απαραίτητος απαραβίαστος απαραγνώριστος
 απαρακάλεστος απαρακάλετος απαρακίνητος απαρακολούθητος απαρακράτητος
 απαραλλήλιστος απαραμείωτος απαραμύθητος απαραπλάνητος απαραποίητος
 απαρασημοφόρητος απαρασκεύαστος απαρατήρητος απαραφύλακτος απαραφύλαχτος
 απαραχάραχτος απαραχώρητος απαρεμπόδιστος απαρεμφατικός απαρενόχλητος
 απαρηγόρητος απαριθμήσιμος απαριθμητός απαρνητικός απαρομοίαστος απαρουσίαστος
 απαρτικός απαρόμοιαστος απαρόρμητος απαρώδητος απασάλειφτος απασπάλιστος
 απασσάλωτος απαστράπτων απασχολήσιμος απατίκωτος απατεώνικος απατηλός
 απαυτός απείθαρχος απείραγος απείρακτος απείραχτος απεγνωσμένος απειθάρχητος
 απειθαρχικός απεικαστικός απεικονισματικός απεικονιστικός απειλητικός
 απειράριθμος απειροδιάστατος απειροελάχιστος απειρομεγέθης απειροπόλεμος
 απειροστός απειροσύνθετος απειρόγαμος απειρόκαλος απειρότεχνος απειρώνυμος
 απεκκριτήριος απεκκριτικός απελέκητος απελαθείς απελασμένος απελαυνόμενος
 απελευθερωτικός απελπιστικός απενθής απεράτωτος απερίγραπτος απερίγραφτος
 απερίθαλπτος απερίσκεπτος απερίσκεφτος απερίσπαστος απερίτεχνος απερίτμητος
 απερίφραστος απερίφραχτος απεραθίτικος απεργιακός απεργοσπαστικός
 απεριγέλαστος απερινόητος απεριοδικός απεριποίητος απεριόριστος απερπάτητος
 απευκταίος απεχθής απηνής απηχητικός απιδόσχημος απιοειδής απισσάριστος
 απισχναντικός απλάνευτος απλάνιστος απλέρωτος απλήγωτος απλήθυντος απλήρωτος
 απλανής απλειστηρίαστος απλημμύριστος απληροφόρητος απλησίαστος απλογραφικός
 απλοποιημένος απλοποιητικός απλοχέρης απλοϊκός απλούμιστος απλούς απλούστερος
 απλωτός απλός απλόχερος απλόχωρος αποίητος αποίκιλτος αποίμαντος αποβατικός
 αποβιώσας αποβλακωτικός αποβλητέος αποβολιμαίος αποβραδινός αποβροχάρης
 απογαλακτισμένος απογεματινός απογευματινός απογοητευτικός απογραμμικός
 αποδέλοιπος αποδαύτος αποδείξιμος αποδειγμένος αποδεικτικός αποδεικτός
 αποδεκτικός αποδεκτός αποδεχτός αποδημητήρια αποδημητικός αποδιοπομπαίος
 αποδοκιμαστικός αποδομήσιμος αποδομητικός αποδοτικός αποδυναμωτικός αποδόσιμος
 αποθήκευτρα αποθαρρυντικός αποθεματικός αποθετήριος αποθετικός αποθεωτικός
 αποθηκευτικός αποθορυβοποιήσιμος αποικιακός αποικιοκρατικός αποικιστικός
 αποκάτω αποκαλυπτήριος αποκαλυπτικός αποκαρδιωτικός αποκατιανός αποκατινός
 αποκεντρωτικός αποκεφαλισθείς αποκλίνων αποκλειστικός αποκληρωτικός
 αποκορυφωτικός αποκριάτικος αποκριτικός αποκρουστικός αποκρυφικός
 αποκτηνωτικός απολέμητος απολέμιστος απολήψιμος απολίτικος απολίτιστος
 απολεπισμένος απολεπιστικός απολεστικός απολιτίκ απολιτικός απολλαπλασίαστος
 απολογιστικός απολυμαντήριος απολυμαντικός απολυτήριος απολυτρωτικός απολυτός
 απομαχικός απομνημονευματικός απομνημονευματογραφικός απομνημονευτικός
 απομονάχος απομοναχός απομονωμένος απομονωτικός απομυελινωτικός απομυζητικός
 απομόναχος απονήρευτος αποναρκωτικός απονεκρωτικός απονευρωτικός απονύχτερος
 αποξηραντικός αποπανινός αποπεμπτικός αποπλανητικός αποπληθωρισμένος
 αποπνικτικός αποπνιχτικός αποπροσανατολιστικός αποριξιμιός απορρέων
 απορριμματοφόρος απορριξιμιός απορριπτέος απορροφητικός απορρυθμιστικός
 αποσαθρωτικός αποσαφηνιστικός αποσβεσθείς αποσβεστικός αποσιωπητικός
 αποσκιαδερός αποσκληρυντικός αποσμηκτικός αποσμητικός αποσοτικοποίητος
 αποσπασματικός αποσπερνός αποστάξιμος αποστέλλων αποσταγματικός
 αποστακτικός αποστατικός αποστεγνωτικός αποστειρωτικός αποστηματώδης
 αποστομωτικός αποστραγγιστικός αποστρατευτέος αποστρατεύσιμος αποσυμφορητικός
 αποσυνδετικός αποσυνθετικός αποσυρτός αποσχιστικός αποτέτοιος αποταμιευτικός
 αποτελειωμένος αποτελεσμένος αποτελεσματικός αποτελματικός αποτελούμενος
 αποτρεπτικός αποτριχωτικός αποτροπαϊκός αποτρόπαιος αποτυπωτικός αποτυχών
 αποφασιστικός αποφατικός αποφθεγματικός αποφοιτήσας αποφοιτών αποφολιδωτικός
 αποφραχτικός αποφώλιος αποχαιρετιστήριος αποχαιρετιστικός αποχαυνωτικός
 αποχετευτικός αποχιονιστικός αποχρεμπτικό αποχρεμπτικός αποχρωσιακός
 αποχυμένος αποχωματώνω αποχωριστικός αποψεσινός αποψιλωτικός αποψινός
 απούλητος απράγμων απραγμάτωτος απραγματοποίητος απρεπής απριλιάτικος
 απριλινός απριόνιστος απροΐδωτος απροάσπιστος απροίκιστος απροβίβαστος
 απρογραμμάτιστος απροδιαίσθητος απροειδοποίητος απροεξόφλητος απροετοίμαστος
 απροκατάληπτος απρολόγητος απρολόγιστος απρομελέτητος απρονόητος
 απροπαράσκευος απροπαρασκεύαστος απροπόνητος απροσάρμοστος απροσάρτητος
 απροσανατόλιστος απροσγείωτος απροσδιόνυσος απροσδιόριστος απροσδόκητος
 απροσκάλεστος απροσκύνητος απροσμάχητος απροσμέτρητος απροσπέλαστος
 απροσποίητος απροστάτευτος απροσχεδίαστος απροσχημάτιστος απροσωπόληπτος
 απροφύλακτος απροφύλαχτος απροχώρητος απρωτοκόλητος απρωτοκόλλητος απρόβλεπτος
 απρόθεσμος απρόθετος απρόθυμος απρόκλητος απρόκοπος απρόκοφτος απρόοπτος
 απρόσβλητος απρόσεκτος απρόσεχτος απρόσημος απρόσθετος απρόσιτος απρόσκλητος
 απρόσληπτος απρόσμενος απρόσοδος απρόσφορος απρόσωπος απρόφερτος απτικός
 απτός απυρπόλητος απυρόβλητος απωανατολικός απωθητικός απωμάτιστος απόβλητος
 απόγειος απόγκρεμνος απόκεντρος απόκληρος απόκοσμος απόκοτος απόκρημνος
 απόλεμος απόλυτος απόμακρος απόμαχος απόμερος απόμονος απόμπευτος απόντιστος
 απόπληκτος απόπληχτος απόρθητος απόρρητος απόσκεπος απόσκιο απόσκιος απότακτος
 απότιστος απότοκος απότολμος απότομος απόφοιτος απύθμενος απύλωτος απύραυλος
 απύρηνος απύρωτος απώγων απών απώτατος απώτερος αράγιστος αράθυμος αράντιστος
 αρέντιγος αρίγωτος αρίφνητος αραβικός αραβόφωνος αραδιαστός αραιοκατοικημένος
 αραιός αραμαϊκός αραξοβολημένος αραποσίτινος αραχνοΰφαντος αραχνοειδής
 αραχνοκεντημένος αραχνοφοβικός αραχνώδης αρβανίτικος αρβανιτοβλάχικος
 αρβαντοβλάχικος αργίτης αργίτικος αργείος αργείτικος αργιλικός αργιλούχος
 αργοκίνητος αργολικός αργοναυτικός αργοξύπνητος αργοτάξιδος αργούτσικος
 αργυρόλευκος αργυρός αργυρόχροος αργυρώνητος αργόμισθος αργός αργόστροφος
 αργόσχολος αρδευτικός αρδεύσιμος αρειανός αρειμάνιος αρεστός αρετολογικός
 αρευστοποίητος αρζαντέ αρθρικός αρθριτικός αρθρογραφικός αρθροσκοπικός
 αριβίστικος αριβιστικός αριθμήσιμο αριθμητικός αριθμητός αριθμοδεικτικός
 αριστερίστικος αριστεροδέξιος αριστεροτίμονος αριστερός αριστερόστροφος
 αριστοτέλειος αριστοτελικός αριστοτεχνικός αριστουργηματικός αριστοφάνειος
 αριστούχος αριφραδής αριός αρκαδικός αρκετός αρκουδίσιος αρκτικός αρκτικός
 αρμενικός αρμενοβυζαντινός αρμενοφόρος αρμονικός αρμοστικός αρμοστός αρμυρός
 αρμόνιος αρμόσιμος αρνίσιος αρναούτης αρνησίθεος αρνησίθρησκος αρνησίπατρις
 αροκάνιστος αρπακολλατζίδικος αρπακτικός αρπαχτικός αρπαχτός αρρίζωτος αρραγής
 αρρενωπός αρρενόφωνος αρρωστιάρης αρρωστιάρικος αρρωστομανής αρρωστοφοβικός
 αρρύπαντος αρσενικοθήλυκος αρσενικούχος αρσενικός αρτίγονος αρτεσιανός
 αρτηριογραφικός αρτηριοσκληρωτικός αρτηριοφλεβικός αρτηριοφλεβώδης
 αρτιγενής αρτιμελής αρτισύστατος αρτύσιμος αρυμοτόμητος αρυτίδωτος αρφανός
 αρχέγονος αρχέτυπος αρχαίος αρχαγγέλινος αρχαιογεωμορφολογικός αρχαιοελληνικός
 αρχαιολατρικός αρχαιολογικός αρχαιομαθής αρχαιομανής αρχαιοπινής αρχαιοπρεπής
 αρχαιόπρεπος αρχαιόσυλος αρχαιότερος αρχαιότροπος αρχαιότροπος αρχαϊκός
 αρχετυπικός αρχηγικός αρχιδάτος αρχιδουκικός αρχιεπισκοπικός αρχιερατικός
 αρχιλόχειος αρχιμήδειος αρχιτεκτονικός αρχολίπαρος αρχομανής αρχοντικός
 αρχοντοχωριάτικος αρωματικός αρωματώδης αρωμουνικός αρύπαντος αρύς αρώσιμος
 ασάλιωτος ασάπιστος ασέληνος ασέλωτος ασήκωτος ασήμαντος ασίγαστος ασίγητος
 ασίκικος ασίμωτος ασίτευτος ασαβάνωτος ασαβούρωτος ασαγήνευτος ασαμάρωτος
 ασαράντιστος ασατίριστος ασαφήνιστος ασαφής ασβάρνιστος ασβεστολιθικός
 ασβεστώδης ασβολερός ασεβής ασεισμικός ασελγής ασελιδοποίητος ασεξουαλικός
 ασημένιος ασημής ασημείωτος ασημοκαπνισμένος ασημόχρωμος ασηπτικός
 ασθενής ασθενικός ασθματικός ασιανός ασιατικός ασιγούρευτος ασιδέρωτος
 ασκάλωτος ασκέπαστος ασκίαστος ασκανδάλιστος ασκαντάλιστος ασκελής ασκεπής
 ασκημομούρικος ασκημούλης ασκημούτσικος ασκητικός ασκιαγράφητος ασκλάβωτος
 ασκοειδής ασκορβικός ασκοτείνιαστος ασκούντητος ασκούπιστος ασκούριαστος
 ασκόνιστος ασκόπευτος ασκόρπιστος ασκότιστος ασμάλτωτος ασμίκρυντος ασμίλευτος
 ασοβάρευτος ασοβάτιστος ασορτί ασουλούπωτος ασούβλιστος ασούρωτος ασούσσουμος
 ασπέδιστος ασπίλωτος ασπαργάνωτος ασπαρτάριστος ασπαστός ασπιδοφόρος
 ασπούδαχτος ασπριδερός ασπρομάλλης ασπροντυμένος ασπροπρόσωπος ασπρουλιάρης
 ασπροφορεμένος ασπρόμαυρος ασπόνδυλος ασσυριακός ασσυροβαβυλωνιακός αστάθμητος
 αστάρωτος αστέγαστος αστέγνωτος αστέναχτος αστέρευτος αστέρινος αστέριωτος
 αστήριχτος αστίλβωτος ασταθής αστακόχρωμος ασταμάτηγος ασταμάτητος
 ασταύρωτος αστείος αστείρευτος αστερέωτος αστεροειδής αστερωτός αστερόεις
 αστεφάνωτος αστεφής αστηλίτευτος αστιατρικός αστιγμάτιστος αστιγματικός
 αστικός αστοίβαστος αστοίβαχτος αστοιχείωτος αστοχισμένος αστράγγιστος
 αστρίφωτος αστραπιαίος αστραποκαμένος αστραπόμορφος αστρατολόγητος
 αστραφτερός αστρικός αστροβριθής αστροθόλωτος αστρολογικός αστρομετρικός
 αστρονομικός αστροσκέπαστος αστροσκεπής αστροστεφάνωτος αστροστόλιστος
 αστροφυσικός αστροφυσικός αστροφώτιστος αστρόγιομος αστρόσπαρτος αστρόφεγγος
 αστυνομικός αστόλιστος αστόμωτος αστόχαστος ασυγκάλυπτος ασυγκέντρωτος
 ασυγκίνητος ασυγκράτητος ασυγκρότητος ασυγχρόνιστος ασυγχρώτιστος ασυγχώνευτος
 ασυγύριστος ασυζήτητος ασυκοφάντητος ασυλλόγιστος ασυμβίβαστος ασυμβούλευτος
 ασυμμάζωχτος ασυμμετρικός ασυμμόρφωτος ασυμπάθητος ασυμπάθιστος ασυμπίεστος
 ασυμπλήρωτος ασυμπτωματικός ασυμπτωτικός ασυμφιλίωτος ασυμφώνητος ασυμψήφιστος
 ασυνάρτητος ασυνάχωτος ασυνήθης ασυνήθιστος ασυνίζητος ασυναίρετος
 ασυναγώνιστος ασυνδιάλλακτος ασυνδιάλλαχτος ασυνδύαστος ασυνείδητος
 ασυνεπής ασυνεχής ασυνθηκολόγητος ασυννέφιαστος ασυντέλεστος ασυντήρητος
 ασυνταύτιστος ασυντρόφευτος ασυντόνιστος ασυνόδευτος ασυνόρευτος ασυρματοφόρος
 ασυσκότιστος ασυσπείρωτος ασυστηματοποίητος ασυσχέτιστος ασυχώρετος ασφάλτινος
 ασφαλής ασφαλίσιμος ασφαλιστήριος ασφαλιστικός ασφαλτικός ασφαλτούχος
 ασφαλτώδης ασφουγγάριστος ασφούγγιστος ασφούγγιχτος ασφράγιστος ασφυκτικός
 ασφυχτικός ασχεδίαστος ασχημάτιστος ασχημομούρης ασχημομούρικος ασχημούλης
 ασχημούτσικος ασχημότερος ασχολίαστος ασωφρόνιστος ασόβαρος ασόδιαστος
 ασύγκλητος ασύγχρονος ασύδοτος ασύλητος ασύλληπτος ασύμβατος ασύμβλητος
 ασύμπτυκτος ασύμπτωτος ασύμφορος ασύμφωνος ασύνακτος ασύναπτος ασύναχτος
 ασύνειδος ασύνετος ασύνορος ασύντακτος ασύνταχτος ασύντμητος ασύντριπτος
 ασύρματος ασύστατος ασύστολος ασύχαστος ασύχναστος ασώματος ασώπαστος ατάιστος
 ατάρακτος ατάραχος ατάραχτος ατάσθαλος ατάστωτος ατέκμαρτος ατέλειωτος
 ατέντωτος ατέρμονας ατέρμονος ατέρμων ατίθασος ατίμητος ατίναχτος αταίριαγος
 αταίριαχτος αταβάνωτος αταβιστικός ατακτοποίητος αταλάντευτος αταλαιπώρητος
 αταξικός αταξινόμητος αταπείνωτος αταρίχευτος αταχτοποίητος αταύτιστος
 ατεζάριστος ατεκμηρίωτος ατελέσφορος ατελής ατελείωτος ατελειοποίητος
 ατελεύτητος ατελώνιστος ατεμάχιστος ατενής ατερμάτιστος ατζαμής ατζαμίδικος
 ατηγάνιστος ατηλεγράφητος ατημέλητος ατιθάσευτος ατιμαστικός ατιμολόγητος
 ατιμώρητος ατιτλοφόρητος ατλάζινος ατλαζένιος ατλαζωτός ατλαντικός ατμήλατος
 ατμοκίνητος ατμοπλοϊκός ατμοσφαιρικός ατμώδης ατοίμαστος ατοιχοκόλλητος
 ατομικός ατομιστικός ατομοκρατικός ατονικός ατοξικός ατοπικός ατοποθέτητος
 ατρίχωτος ατραγούδητος ατραγούδιστος ατρακάριστος ατρακτοειδής ατρατάριστος
 ατριβής ατροποποίητος ατροφικός ατρόμητος ατρόχιστος ατρύγητος ατρύπητος
 ατσάλινος ατσάπιστος ατσίκνιστος ατσαλένιος ατσεκούρωτος ατσιγάριστος
 ατσουρούφλιστος ατσούγκριστος ατσούμπαλος ατσούτσουνος αττικίζων αττικιστικός
 ατυχής ατόλμητος ατόνιστος ατόρνευτος ατός ατόφιος ατύλιχτος ατύπωτος
 αυγινός αυγοειδής αυγουλάτος αυγουλωτός αυγουστιάτικος αυγουστιανός
 αυγόσχημος αυθάδης αυθάδικος αυθαίρετος αυθαδέστατος αυθεντικός αυθυπόστατος
 αυθύπαρκτος αυθύπαρχτος αυλακωτός αυλικός αυλόδουλος αυξητικός αυξομειωτικός
 αυριανός αυστηρός αυστραλέζικος αυστριακός αυτάρεσκος αυτάρκης αυτήκοος
 αυταπάντητος αυταπόδεικτος αυταπόδειχτος αυταρχικός αυτενέργητος αυτενεργός
 αυτεξούσιος αυτεπάγγελτος αυτιστικός αυτοάνοση αυτοάνοσος αυτοακυρωτικός
 αυτοαναφορικός αυτοαπαρνημένος αυτοβιογραφικός αυτογραφικός αυτοδίδακτος
 αυτοδίκαιος αυτοδημιούργητος αυτοδιαχειριστικός αυτοδικαίωτος αυτοδιοίκητος
 αυτοδιοικούμενος αυτοδιορισθείς αυτοδιόριστος αυτοδραστικός αυτοδύναμος
 αυτοεκπληρούμενος αυτοεκφυλιστικός αυτοεξυπηρετούμαι αυτοεξόριστος
 αυτοκέφαλος αυτοκίνητος αυτοκαθοριστικός αυτοκαταστροφικός αυτοκινητικός
 αυτοκινούμενος αυτοκρατορικός αυτοκριτικός αυτοκτονικός αυτοκυβέρνητος
 αυτοκόλλητος αυτοματικός αυτονομιστικός αυτονόητος αυτοπαθής αυτοπαθητικός
 αυτοπροαίρετος αυτοπροωθούμενος αυτοπρόσωπος αυτοσαρκαστικός αυτοσυγκράτητος
 αυτοσχέδιος αυτοσχεδίαστος αυτοτελής αυτοτροφικός αυτοφυής αυτοχειριαστικός
 αυτούσιος αυτόβουλος αυτόγραφος αυτόδηλος αυτόδραση αυτόκλητος αυτόματος
 αυτόμοιος αυτόνομος αυτόνοος αυτόρριζος αυτότροφος αυτόφυτος αυτόφωρος
 αυτόχθων αυχενικό αυχενικός αυχμηρός αφάγωτος αφάνταστος αφάσκιωτος αφάτνωτος
 αφέσιμος αφίλευτος αφίλητος αφίλιωτος αφίμωτος αφαιρέσιμος αφαιρετέος
 αφαιρετός αφακέλωτος αφανάτιστος αφανέρωτος αφανής αφανιστικός αφασικός
 αφγανικός αφεγγής αφειδής αφειδώλευτος αφελής αφεντάδικος αφεντικός αφερέγγυος
 αφετήριος αφετηριακός αφηγηματικός αφηγητικός αφθονοπάροχος αφθώδης
 αφιεραρχημένος αφιερωματικός αφιερωτήριος αφιερωτικός αφιλάνθρωπος αφιλοκερδής
 αφιλονίκητος αφιλοσόφητος αφιλοχρήματος αφιλτράριστος αφιλόκαλος αφιλόκερδος
 αφιλόξενος αφιλόπατρις αφιλόστοργος αφιλότεχνος αφιλότιμος αφκιασίδωτος
 αφοδράριστος αφομοιωτικός αφομοιώσιμος αφοπλιστικός αφοριστικός αφορμάριστος
 αφούντωτος αφούρνιστος αφράτος αφρεσκάριστος αφρικάνικος αφρικανικός
 αφριστός αφροαμερικανικός αφρογέννητος αφροδίσιος αφροδισιακός αφρονημάτιστος
 αφρούρητος αφρυγάνιστος αφρόντιστος αφρόπλαστος αφρώδης αφτιασίδωτος αφυής
 αφυλετικός αφυπνιστικός αφωνόληκτος αφωνόληχτος αφωταγώγητος αφόρετος αφόρητος
 αφόρτωτος αφύλακτος αφύλαχτος αφύσικος αφύτευτος αφύτρωτος αφώτιστος
 αχάλαγος αχάλαστος αχάραγος αχάρακτος αχάραχτος αχάριστος αχίλλειος αχαΐρευτος
 αχαλιναγώγητος αχαμνός αχανής αχαράκωτος αχαρακτήριστος αχαραχτήριστος
 αχαρτοσήμαντος αχαϊκός αχείμαντος αχείμαστος αχειράφετος αχειρίδωτος
 αχειραφέτητος αχειροποίητος αχειροτόνητος αχειρούργητος αχερόντειος αχερόντιος
 αχθοφορικός αχιόνιστος αχλάμυδος αχλεύαστος αχλωρωτικός αχνιστός αχνοφώτιστος
 αχνούδωτος αχνός αχνόφωτος αχορήγητος αχορτάριαγος αχορτάριαστος αχουζούρευτος
 αχρήματος αχρείαστος αχρείος αχρειόγλωσσος αχρειόστομος αχρεώστητος
 αχρησίμευτος αχρησιμοποίητος αχρονολόγητος αχρωμάτιστος αχρωματικός αχρόνιαγος
 αχρόνιστος αχτένιστος αχτιδωτός αχτύπητος αχυρένιος αχυροστρωμένος αχυρώδης
 αχόλιαστος αχόρταγος αχόρταστος αχύλωτος αχώνευτος αχώρετος αχώρητος αχώριστος
 αψήφιστος αψίθυμος αψίκορος αψίχολος αψαλίδιστος αψαχούλευτος αψεγάδιαστος
 αψηλάφητος αψηλός αψιδοειδής αψιδωτός αψιθυμικός αψιμυθίωτος αψιχάλιστος
 αψυχολόγητος αψυχοπόνετος αψύς αψύχραντος αψύχωτος αψώνιστος αόμματος αόρατος
 αύλειος αύξων αύτανδρος βάκρινος βάναυσος βάρβαρος βάρυπνος βάσιμος βάσκανος
 βέβηλος βέλγικος βέλτιστος βένετος βέρος βίαιος βαβυλωνιακός βαβυλώνιος
 βαγαπόντης βαγαπόντικος βαθμιαίος βαθμιδωτός βαθμολογικός βαθμούχος
 βαθουλωτός βαθουλός βαθυγάλανος βαθυκόκκινος βαθυμετρικός βαθυπράσινος
 βαθυσκαφής βαθυστόχαστος βαθύγνωμος βαθύνους βαθύπλουτος βαθύρριζος βαθύς
 βαθύσκιωτος βαθύτατος βαθύτερος βαθύφωνος βαθύχρωμος βακιλικός βακιλόμορφος
 βακούφικος βακτηριακός βακτηριοκτόνος βακτηριολογικός βακτηριοστατικός
 βακχικός βαλβιδοπλαστικός βαλκανικός βαλλιστικός βαλτικός βαλτός βαμβακένιος
 βαμπακερός βαναδιούχος βανδαλικός βαπορίσιος βαπτιστικός βαρήκοος βαραθρώδης
 βαρβαρικός βαρβαρόφωνος βαρελίσιος βαρεσάρης βαρετός βαρηλάτης βαριούχος
 βαρομετρικός βαρυγενετικός βαρυγεννητικός βαρυγομαρκάρης βαρυονική βαρυονικός
 βαρυπενθών βαρυσήμαντος βαρυστόμαχος βαρυτικός βαρυτοαδράνειος
 βαρυτοαδρανικός βαρυχρονικός βαρύγδουπος βαρύθυμος βαρύνων βαρύς βαρύτατος
 βαρύτιμος βαρύτονος βασαλτικός βασανιστικός βασικοκυτταρικός βασικός βασιλικός
 βασιλόφρονας βασιλόφρων βασκαντικός βασταγερός βατραχοειδής βαττολόγος βατός
 βαυαρικός βαφικός βαφτιστικός βαϊοφόρος βγιενικός βδελλάτος βδελυρός βδελυρός
 βεβαιωτικός βεβαιόπιστος βεβαιότατος βεβαιότερη βεβαιότερο βεβαιότερος
 βεβαρυμένος βεγγαλέζικος βεγγαλικός βεδικός βελγικός βελοειδής βελονοειδής
 βελονωτός βελουδένιος βελουτέ βελούδινος βελτιωτικός βελτιόδοξος βελτιώσιμος
 βενεδικτίνος βενετικός βενετσιάνικος βενζινοκίνητος βενζοϊκός βενθικός
 βενθόβιος βενιζελικός βεραμάν βεριτάμπλ βερμπαλιστικός βεροιώτικος βηματικός
 βησιγοτθικός βιαστικός βιβλιακός βιβλιεκδοτικός βιβλιεμπορικός βιβλικός
 βιβλιογραφικός βιβλιοδετικός βιβλιοκριτικός βιβλιομανής βιβλιοπωλικός
 βιδωτός βιενέζικος βιεννέζικος βιετναμέζικος βιετναμικός
 βικτοριανός βιλλαράς βιντεομανής βιντεοσκοπικός βινυλικός βιοαποδομήσιμος
 βιογενής βιογεωγραφικός βιογραφικός βιοδιασπάσιμος βιοδραστικός βιοδυναμικός
 βιοκλιματικός βιολέ βιολετής βιολετί βιολογικός βιομετρικός
 βιομηχανικός βιομηχανοποιήσιμος βιομοριακός βιονικός βιονομικός βιοποιοτικός
 βιοπτικός βιορυθμικός βιοτεχνικός βιοτεχνολογικός βιοτικός βιοφαρμακευτικός
 βιοψυχοκοινωνικός βιοϊατρικός βιρμανικός βισμουθιούχος βιταλιστικός
 βιταμινούχος βιτριολικός βιτσιόζικος βιτσιόζος βιωματικός βιώσιμος βλάστημος
 βλάχικος βλαβερός βλαισόπους βλαισός βλακώδης βλαξ βλαπτικός βλαστητικός
 βλαχικός βλαχομοδάτος βλαχόφωνος βλαψίφρων βλεννογόνος βλεννολυτικός
 βλεννώδης βλεφαριδοφόρος βλεφαρικός βλητικός βλογιάρης βλογιοκομμένος βλοσυρός
 βοδινός βοερός βοηθητικός βοημικός βοιωτικός βολβοειδής βολβόσχημος βολβώδης
 βολικός βολιώτικος βολταϊκός βολφραμιούχος βομβαρδιστικός βομβιδοφόρος
 βομβυκοτροφικός βοοειδής βορβοροφάγος βορβορώδης βορειανατολικός
 βορειοανατολικός βορειοατλαντικός βορειοαφρικανικός βορειοβιετναμικός
 βορειοειρηνικός βορειοελλαδικός βορειοευρωπαϊκός βορειοηπειρωτικός
 βορειοσιατικός βορικό βορινός βοριούχος βοσκήσιμος βοσνιακός βοστρυχοειδής
 βοστρυχώδης βοτανικός βοτανολογικός βοτουλινικός βοτρυοειδής βοτρυώδης
 βουβαλίσιος βουβωνικός βουβωνοκηλικός βουβός βουδικός βουδιστικός βουερός
 βουλγάρικος βουλγαρικός βουλγαρόφωνος βουλευτικός βουλησιαρχικός βουλητικός
 βουνίσιος βουνώδης βουτηχτός βουτυράτος βουτυρένιος βουτυρικός βουτυρώδης
 βοϊδινός βοϊδομάτης βοώδης βραβεύσιμος βραγχιακός βραδιάτικος βραδιανός
 βραδυκίνητος βραδυφλεγής βραδύγλωσσος βραδύκαυστος βραδύνους βραδύς
 βρακοφόρος βραστερός βραστός βραχιολάτος βραχιόνιος βραχμανικός βραχνός
 βραχοσύντριφτος βραχυγραφικός βραχυκατάληκτος βραχυλογικός βραχυμεσοχρόνιος
 βραχυπρόθεσμος βραχυχρόνιος βραχύβιος βραχύινος βραχύκαννος βραχύκερκος
 βραχύς βραχύσωμος βραχύτερος βραχύφωνος βραχύχρονος βραχώδης βρεγμένος
 βρεγματικός βρετανικός βρετονικός βρεφικός βρεφοκομικός βρεφονηπιακός βρεφώδης
 βρογχικός βρογχοκηλικός βρογχοκυψελιδικός βρογχολογικός βρογχοϋπεζωκοτικός
 βρομιάρης βρομιάρικος βρομογούρουνο βρομοπόδαρος βρομόγλωσσος βρομόστομος
 βροντόφωνος βροντώδης βροχερός βροχομετρικός βρυξελλιώτικος βρυώδης βρωμερός
 βρόμικος βρόχινος βρώμικος βρώσιμος βυζαντινολογικός βυζαντινοπρεπής
 βυζαντινότροπος βυθομετρικός βυθοσκοπικός βυρσοδεψικός βυσσινής βυτιοφόρος
 βόειος βόρειος βύθιος βύρσινος βύσσινος γάνωμα γάργαρος γέμελος γέρικος γήινος
 γίντις γαβαθωτός γαγγλιώδης γαγγραινικός γαγγραινώδης γαδολινιούχος γαζωτός
 γαιοκτητικός γαιοφάγος γαιώδης γαλάζιος γαλάριος γαλήνιος γαλίφης γαλίφικος
 γαλαζοπράσινος γαλαζωπός γαλαθηνός γαλακταγωγός γαλακτερός γαλακτικός
 γαλακτοδίαιτος γαλακτοειδής γαλακτοκομικός γαλακτοπαραγωγικός γαλακτοπαραγωγός
 γαλακτοποιός γαλακτοφόρος γαλακτόχρωμος γαλακτώδης γαλαναδιώτικος γαλανομάτης
 γαλανόλευκος γαλανός γαλαξιακός γαλαξιδιώτικος γαλατερός γαλατικός γαλβανιζέ
 γαληνός γαλλικός γαλλιούχος γαλλομαθής γαλλοτραφής γαλλόφιλος γαλλόφωνος
 γαμάτος γαμήλιος γαμπριάτικος γαμψός γαμψώνυχος γαντζωτός γαντοφορεμένος
 γαργαριστός γαργερός γαρμπάτος γαρμπόζος γαστρίμαργος γαστρεντερικός
 γαστρικός γαστρονομικός γαστροοισοφαγικός γατίσιος γατόφιλος γαϊδουρίσιος
 γαϊδουρόφωνος γαϊτανοφρύδης γαϊτανωτός γδυμνός γδυτός γειρτός γειτονικός
 γελαστικός γελαστός γελοίος γελοιογραφικός γελοιώδης γεμάτος γεματούτσικος
 γενάτος γενέθλιος γεναριάτικος γενεαλογικός γενεσιουργικός γενεσιουργός
 γενετικός γενικευτικός γενικεύσιμος γενικολογικός γενικοσχετικός γενικόλογος
 γενναίος γενναιόδωρος γενναιόκαρδος γενναιόφρων γενναιόψυχος γεννητικός
 γενομικός γενόσημος γερακίσιος γεραλέος γερανοφόρος γεραρός γερμανικός
 γερμανομαθής γερμανοτραφής γερμανόφιλος γερμανόφωνος γερογκρινιάρης
 γεροντίστικος γεροντικός γεροντομπασμένος γεροξεκούτης γεροπαράξενος
 γερουσιαστικός γερτός γερός γευστικός γεφυροπαρεγκεφαλιδικός γεφυρωτικός
 γεωγραφικός γεωδαιτικός γεωδυναμικός γεωθερμικός γεωθερμοηλεκτρικός
 γεωλογικός γεωμαγνητικός γεωμετρικός γεωπολιτικός γεωπονικός γεωργικός
 γεωσύγχρονος γεωτεχνικός γεωτρητικός γεωφυσικός γεωχημικός γεωχωρικός γεώδης
 γηθόσυνος γηπεδούχος γηραιός γηραιότερος γηραλέος γηριατρικός γηροκομικός
 γιαγλίδικος γιακουτικός γιαλαντζί γιαλόκλειστος γιαννιτσιώτικος γιαννιώτικος
 γιαχβικός γιαχνιστός γιγάντειος γιγάντιος γιγαντιαίος γιγαντόσωμος γιγαντώδης
 γινωμένος γιομάτος γιορταστικός γιορτερός γιορτιάτικος γιορτινός
 γιούνισεξ γκαβός γκαγκά γκαιμπελικός γκαμσίζης γκανγκστερικός γκανιάν γκαντέμα
 γκαραντί γκαρδιακός γκεμπελικός γκινιαδόρος γκινιόζος γκλαμουράτος γκουρμέ
 γκρίζος γκρενά γκριζογάλανος γκριζομάλλης γκριζομάτης γκριζοπράσινος γκριζωπός
 γκροτέσκ γκροτέσκος γλήγορος γλίσχρος γλίτσιασμα γλαγολιτικός γλαρός γλαυκός
 γληνός γλιστερός γλιτσερός γλιτσιάζω γλιτσιάρικος γλιτσιασμένος γλοιώδης
 γλυκαιμικός γλυκανάλατος γλυκαντικός γλυκερός γλυκοαίματος γλυκομίλητος
 γλυκοπύρηνος γλυκούλης γλυκούτσικος γλυκόηχος γλυκόλαλος γλυκόμορφος
 γλυκόπικρος γλυκόπιοτος γλυκόπνοος γλυκός γλυκόφωνος γλυκύλαλος γλυκύμορφος
 γλυκύφωνος γλυπτικός γλυπτός γλυφούτσικος γλυφός γλωσσάς γλωσσηματικός
 γλωσσολογικός γλωσσομαθής γλωσσοπλαστικός γνήσιος γναθιαίος γναθικός
 γναθοφόρος γναθοχειρουργικός γνευσιακός γνοιαστικός γνωμικός
 γνωμοδοτικός γνωμολογικός γνωρίζον γνωρίζουσα γνωρίζων γνωσιακός
 γνωσιολογικός γνωσιφόρος γνωστικιστικός γνωστικός γνωστός γνωστότατος γνώριμος
 γοητευτικός γονατιστός γονατώδης γονεϊκός γονιδιωματικός γονικός γονιμοποιός
 γονοτυπικός γονοχωριστικός γονυπετής γοργοεπήκοος γοργοκίνητος γοργοπόδαρος
 γοργός γοργόφτερος γοτθικός γοτθισχιδής γουνάτος γουνοφόρος γουρλίδικος
 γουρλομάτικος γουρλού γουρλωτός γουρουνίσιος γουρουνοειδής γουρουνομαθημένος
 γουρσούζης γουρσούζικος γουστόζικος γούνινος γούρικος γούρμος γρήγορος
 γραμματειακός γραμματιζούμενος γραμματικός γραμματισμένος γραμματολογικός
 γραμμογραφικός γραμμοειδής γραμμοσκίαστος γραμμοσκιασμένος γραμμοϊσοδύναμος
 γραμμώδης γρανίτινος γρανιτένιος γρανιτικός γρανιτώδης γραπτός γρατζουνισμένος
 γραφίστικος γραφειακός γραφειοκρατικός γραφικός γραφιστικός γραφολογικός
 γραώδης γρεβενιώτικος γρετίδικος γρινιάρης γριπικός γριπώδης γριφοειδής
 γροιλανδικός γρουσούζης γρουσούζικος γρυπός γυάλινος γυαλένιος γυαλικός
 γυθειάτικος γυμνασιακός γυμναστικός γυμνικός γυμνοσπέρματος γυμνόρριζος γυμνός
 γυμνόσπερμος γυμνόστερνος γυμνόστηθος γυναίκειος γυναικάρεσκος γυναικίσιος
 γυναικείος γυναικολογικός γυναικοπρεπής γυναικωτός γυναικόσπαρτος γυναικόφωνος
 γυριστός γυρομαγνητικός γυψώδης γωνιαίος γωνιακός γωνιοκόρυφος γωνιωτός
 γόνιμος γόρδιος γύφτικος γύψινος δάνειος δάφνινος δέντρινος δέσμιος δέων δήλος
 δίβολος δίβουλος δίγαμος δίγλυφος δίγλωσσος δίγνωμος δίγραμμος δίδυμο δίδυμος
 δίθυρος δίκαιος δίκαιος δίκαννος δίκαρτος δίκλινος δίκλωνος δίκοπος δίκορκος
 δίκορφος δίκροκος δίκυκλος δίκυτος δίκωπος δίλοβος δίμηνος δίμορφος δίμουρος
 δίπατος δίπλα δίπλευρος δίποδος δίπολος δίπορτος δίπρακτος δίπτερος δίπτυχος
 δίπυρος δίριχτος δίσεκτος δίσεχτος δίσημος δίστηλος δίστιχος δίστοιχος
 δίτιμος δίτομος δίτοξο δίτοξος δίτροχος δίφορος δίφυλλος δίφωνος δίχειλος
 δίχηλος δίχρονος δίχρωμος δίχωρος δίωρος δαήμων δαίδαλος δαγκανιάρης δαγκωτός
 δαιμονιακός δαιμονικός δαιμονιώδης δαιμονολατρικός δαιμονολογικός δαιμονομανής
 δαιμονόληπτος δαιμονόπιστος δαιμονόπνευστος δαιμόνιος δακρυγόνος δακρυογόνος
 δακρυόεις δακρυώδης δακρύβρεκτος δακρύβρεχτος δακτυλικός δακτυλιοειδής
 δακτυλιόσχημος δακτυλογραφικός δακτυλόγραφος δαμαλίσιος δαμαλιώτικος
 δαμασκηνής δαμασκηνός δανέζικος δανακιώτικος δανειακός δανεικός δανειοληπτικός
 δανικός δαντελένιος δαντελλωτός δαντελωτός δαντικός δαπανηρός δασικός
 δασκαλικός δασκαλοκεντρικός δασμοβίωτος δασμολογητέος δασμολογικός
 δασοβιομηχανικός δασοκομικός δασολογικός δασονομικός δασοπονικός
 δασοσκέπαστος δασοσκεπής δασωτός δασόβιος δασός δασόφυτος δασύθριξ δασύς
 δασύφυλλος δασώδης δαφνηφόρος δαφνοστεφάνωτος δαφνοστεφής δαφνοστεφανωμένος
 δαφνοφόρος δαχτυλιδένιος δαχτυλικός δαψιλής δείλαιος δεδομενοκεντρικός
 δειγματοληπτικός δεικτικός δειλινός δειλός δειλόψυχος δεινός δεισιδαίμονας
 δεισιδαιμονικός δειχτικός δεκάβαθμος δεκάγωνος δεκάδιπλος δεκάρικος δεκάτομος
 δεκάχρονος δεκάωρος δεκαήμερος δεκαδικός δεκαεξαδικός δεκαεξασέλιδος
 δεκαετής δεκαμελής δεκαμερής δεκαμηνιαίος δεκαοκτάχρονος δεκαοκταετής
 δεκαπενθήμερος δεκαπενταετής δεκαπενταπλάσιος δεκαπεντασύλλαβος
 δεκαπλάσιος δεκαπλός δεκατιαίος δεκατρείς δεκατρισύλλαβος δεκαψήφιος
 δεκεμβριάτικος δεκεμβριανός δεκτικός δεκτός δελεαστικός δελταπτέρυγος
 δελφικός δενδρικός δενδριτικός δενδροειδής δενδροκομικός δενδρόβιος δεντρικός
 δεξής δεξιοτίμονος δεξιοτεχνικός δεξιός δεξιόστροφος δεοντικός δεοντολογικός
 δερμάτινος δερματικός δερματολογικός δερματόδετος δερματώδης δεσμευτικός
 δετικός δετός δευτερεύων δευτεριάτικος δευτεροβάθμιος δευτεροβαπτισμένος
 δευτεροετής δευτεροκλασάτος δευτεροπαθής δευτερόκλιτος δευτερότοκος δεχτός
 δηζελοκίνητος δηκτικός δηλητηριώδης δηλιακός δηλωτικός δημαγωγικός δημαρχιακός
 δημευτικός δημιουργικός δημογραφικός δημοκοπικός δημοκρατικός δημοπρατικός
 δημοσιογραφικός δημοσιολογικός δημοσιονομικός δημοσιοσχετιστικός
 δημοσυνεταιριστικός δημοσυντήρητος δημοτικιστικός δημοτικός δημοφιλής
 δημόσιος δημώδης διάβροχος διάδοχος διάκριτος διάλιθος διάμεσος διάνοικτος
 διάπλατος διάπλοκος διάπυρος διάσημος διάσπαρτος διάστερος διάστικτος
 διάτονος διάτορος διάτρητος διάττοντας διάφανος διάφεγγος διάφοροι διάφορος
 διάχρυσος διάχυτος διήμερος διίστιος διαβαλκανικός διαβατάρικος διαβατήριος
 διαβατός διαβεβαιωτικός διαβητικός διαβητολογικός διαβιβάσιμος διαβιβαστικός
 διαβλητός διαβολεμένος διαβολικός διαβρογχικός διαβρωσιγενής διαβρωτικός
 διαγαλακτικός διαγαλαξιακός διαγενεακός διαγνωστικός διαγραφείς διαγωνάλ
 διαδερμικός διαδημοτικός διαδικαστικός διαδικτυακός διαδογματικός διαδοχικός
 διαδριατικός διαεπαγγελματικός διαζευκτικός διαζευχτικός διαθέσιμος
 διαθετικός διαθηκώος διαθλαστικός διαθρησκειακός διαθωρακικός διαιρέσιμος
 διαιρετικός διαιρετός διαισθαντικός διαισθητικός διαιτητικός διαιώνιος διακαής
 διακεκαυμένος διακεκομμένος διακηρυκτικός διακινήσιμος διακινητικός διακινητός
 διακλαδικός διακοινοτικός διακομματικός διακονικός διακοσάρης διακοσιαπλάσιος
 διακοσμητικός διακρίσιμος διακρανιακός διακρατικός διακριβωτέος διακριβωτικός
 διακρυϊκός διακυβερνητικός διακός διακόσιοι διαλεκτικός διαλεκτός
 διαλεχτός διαλλακτικός διαλλαχτικός διαλογικός διαλογιστικός διαλυτικός
 διαλφαβητικός διαμάντινος διαμήκης διαμαντέ διαμαντένιος διαμαντοκόλλητος
 διαμελιστικός διαμεσολαβητικός διαμεταγωγικός διαμετακομιστικός διαμετρικός
 διαμονητήριος διαμορφωτής διαμορφωτικός διαμπερής διανεμητικός διανθής
 διανοητός διανοουμενίστικος διανυσματικός διαπεραστικός διαπερατός
 διαπιστωτικός διαπλανητικός διαπλαστικός διαπνευστικός διαπολιτισμικός
 διαπραγματεύσιμος διαπρεπής διαπροσωπικός διαπρωκτικός διαπρύσιος διαπτικός
 διαρθρωτικός διαρκής διαρρεύσας διαρρηκτός διαρροϊκός διαρρυθμιστικός
 διασαφηνιστικός διασαφητικός διασκεδαστικός διασκεπτικός διασκευαστικός
 διασταλτικός διασταλτός διαστατός διασταυρούμενος διαστημικός διαστολικός
 διαστρικός διαστροφικός διαστρωματικός διασυμμαχικός διασυμπαντικός
 διασυνδετικός διασυνοριακός διασφαλιστικός διασχίσιμος διασωθείς
 διασωστικός διατακτικός διαταρακτικός διατεταρτημοριακός διατηρήσιμος
 διατμητικός διατονικός διατρητικός διατροπικός διατροφικός διατυμπανισμένος
 διαφανής διαφημιστικός διαφορίσιμος διαφορετικός διαφορικός διαφορτωτικός
 διαφυλετικός διαφυλικός διαφωτιστικός διαφώτιστος διαχειριστικός διαχρονικός
 διαχωρίσιμος διαχωριστικός διγενής διγλώχιν διδάξιμος διδακτέος διδακτικός
 διδακτός διδασκαλικός διδαχτικός διεγέρσιμος διεγερτικός διεγχειρητικός
 διεθνικός διεθνιστικός διεισδυτικός διεκδικήσιμος διεκδικητικός
 διεμφυλικός διεμφυλικός διεξοδικός διεπαφικός διεπιστημονικός διεργεννοιακός
 διερμηνευτικός διεστραμμένος διετής διευθετήσιμος διευθετημένος διευθυντικός
 διευκρινιστικός διζυγωτικός διζυγώτης διζωνικός διηγηματικός διηθήσιμος
 διηθητός διηλεκτρικός διηνεκής διηπειρωτικός διθέσιος διθυραμβικός διιστορικός
 δικάσιμος δικάταρτος δικέφαλος δικαιικός δικαιοκρατικός δικαιοκρατούμενος
 δικαιολογήσιμος δικαιολογητικός δικαιοπάροχος δικαιοπρακτικός δικαιωματικός
 δικαστικός δικατάληκτος δικαϊκός δικηγορίστικος δικηγορικός δικινητήριος
 δικομματικός δικονομικός δικοτυλήδονος δικτατορικός δικτυακός δικτυοκεντρικός
 δικόρυφος δικότυλος διλεκτικός διλημματικός διμέτωπος διμελής διμερής
 διμεταλλικός διμηνίτικος διμηνιαίος διογκωτικός διοικητικός διοικών
 διολισθαίνων διονυσιακός διοπτρικός διοπτροφόρος διορατικός διοργανωτικός
 διοριστήριος διουρηθρικός διουρητικός διοφθαλμικός διοχετεύσιμος διπλάσιος
 διπλανός διπλοβάπτιστος διπλοβαπτισμένος διπλογραφικός διπλοκάρενος
 διπλοπρόσωπος διπλοτρόπιδος διπλοφουρνιστός διπλωματικός διπλωματούχος
 διπλός διπλότυπος διπλόφαρδος διπολικός διπρόσωπος διπτέρυγος διπυριτικός
 δισέλιδος δισήμαντος δισδιάστατος δισθενής δισκογραφικός δισκόβαθμο δισμύριοι
 διστακτικός δισταχτικός δισυπόστατος δισχίλιοι δισχιδής δισύλλαβος διτάξιος
 διττός διυπουργικός διφασικός διφυής διφωσφορυλικός διφωσφορυλιούχος διχαλωτός
 διχειλικός διχοτομικός διχρονίτικος διχτυωτός διψήφιος διψαλέος διωνυμικός
 διώνυμος διώροφος δογματικός δοκησίσοφος δοκιμαστικός δολερός δολιχοκέφαλος
 δομικός δομοκεντρικός δομοστοιχειωτός δονκιχωτιστής δοξαρωτός δοξαστικός
 δοριάλωτος δορυφορικός δοσομετρικός δοτικός δοτός δουλεμπορικός δουλικός
 δουλοπρεπής δουλωτικός δουλόπρεπος δουλόφρων δουνάβιος δούρειος δρακόντειος
 δραματολογικός δραματουργικός δραστήριος δραστικός δραχμικός δραχμοβίωτος
 δραχμολαγνικός δραχμοσυντήρητος δρεπανηφόρος δρεπανοειδής δρεπανοκυτταρικός
 δριμύς δρομαίος δρομικός δροσάτος δροσερός δροσιστικός δρύινος δυαδικός
 δυναμιτιστικός δυναμογόνος δυναμοηλεκτρικός δυναμωτικός δυναστευτικός
 δυνατός δυνητικός δυσάλωτος δυσάρεστος δυσέλεγκτος δυσήκοος δυσήλατος δυσήλιος
 δυσανάγνωστος δυσανάλογος δυσαναπλήρωτος δυσανεκτικός δυσαπόδεικτος
 δυσαρίθμητος δυσαρμονικός δυσβάστακτος δυσβάσταχτος δυσγενής δυσδιάκριτος
 δυσδιοίκητος δυσειδής δυσενδοκρινικός δυσεντερικός δυσεξάλειπτος δυσεξέλεγκτος
 δυσεξίτηλος δυσεξιχνίαστος δυσεπίλυτος δυσεπίσχετος δυσεπίτευκτος
 δυσεπιχείρητος δυσεπούλωτος δυσερμήνευτος δυσεφάρμοστος δυσεύρετος
 δυσηχαγωγός δυσθεράπευτος δυσθερμαγωγός δυσθεώρητος δυσκίνητος δυσκατέργαστος
 δυσκολοβάσταχτος δυσκολονόητος δυσκολοχώνευτος δυσκολόπιστος δυσκρασικός
 δυσλεκτικός δυσλεξικός δυσμάσητος δυσμενής δυσμικός δυσνόητος δυσξήμβλητος
 δυσπαράπλευστος δυσπερίγραπτος δυσπλασικός δυσπροσάρμοστος δυσπρόσβλητος
 δυσπρόφερτος δυσπόρθητος δυστράχηλος δυστυχής δυσφασικός δυσφημιστικός
 δυσφωτικός δυσχερής δυσώδης δυσώνυμος δυτικοευρωπαϊκός δυτικός δυτικότροπος
 δυτικόφρων δυφιoστρεφής δυφιακός δυφιοδιαφανής δυϊκός δυϊστικός δωδεκάγωνος
 δωδεκάκωπος δωδεκάλογος δωδεκάμηνος δωδεκάσκαλμος δωδεκάχρονος δωδεκάωρος
 δωδεκαδάκτυλος δωδεκαδάχτυλος δωδεκαδακτυλικός δωδεκαδικός δωδεκαετής
 δωδεκαμελής δωδεκανησιακός δωδεκαπλάσιος δωδεκαψήφιος δωδωναίος δωρικός
 δόκιμος δόλιος δόλιος δύσβατος δύσερως δύσθυμος δύσκαμπτος δύσκολος δύσληπτος
 δύσμορφος δύσνους δύσοσμος δύσπεπτος δύσπιστος δύσρευστος δύστηκτος δύστηνος
 δύστροπος δύστυχος δύσχρηστος δύσχυμος εαρινός εβένινος εβαπορέ εβδομαδιάτικος
 εβδομηκονταετής εβδομηντάχρονος εβραίικος εβραϊκός εγγαρίτικος εγγαστρίμυθος
 εγγενής εγγλέζικος εγγράμματος εγγράψιμος εγγυητικός εγγύτατος εγγύτερος
 εγερτικός εγκάθειρκτος εγκάθετος εγκάρδιος εγκάρσιος εγκαιροφλεγής
 εγκαρδιωτικός εγκατεσπαρμένος εγκεφαλικός εγκεφαλολογικός εγκεφαλονωτιαίος
 εγκληματογόνος εγκληματολογικός εγκλητικός εγκλιτικός εγκρατής εγκριτικός
 εγκωμιαστικός εγκόλλητος εγκόσμιος εγκύκλιος εγχάρακτος εγχειρήσιμος
 εγχειρητικός εγχρήματος εγχώριος εγωιστικός εγωκεντρικός εγωπαθής εδαφιαίος
 εδαφοβελτιωτικός εδαφοκλιματικός εδαφολογικός εδαφοϋδατικός εδεμικός
 εδικός εδραίος εδραιωτής εδώδιμος εθελοντικός εθελούσιος εθελόδουλος
 εθιμικός εθιμοτυπικός εθιστικός εθναρχικός εθνεγερτικός εθνικιστικός
 εθνικοσοσιαλιστικά εθνικοσοσιαλιστικός εθνικός εθνικόφρονας εθνικόφρων
 εθνογραφικός εθνοκεντρικός εθνοκτόνος εθνολογικός εθνοπρεπής εθνοπρόβλητος
 εθνοτικός εθνοφθόρος εθνοφοβικός εθνωφελής εθνόφοβος ειδεχθής ειδησεογραφικός
 ειδητικός ειδικευμένος ειδικοποιημένος ειδικός ειδικότερος ειδοειδικός
 ειδοποιητικός ειδοποιός ειδυλλιακός ειδωλολατρικός εικάζων εικαστικός
 εικονιστικός εικονογραφικός εικονοκλαστικός εικονολατρικός εικονόφιλος
 εικοσάχρονος εικοσαβάθμιος εικοσαετής εικοσαπλάσιος εικοσιτετράωρος
 εικοτολογικός ειλητός ειλικρινής ειρηνευτικός ειρηνικός ειρηνιστικός
 ειρηνοποιός ειρηνοφόρος ειρηνόφιλος ειρωνικός εισαγγελικός εισαγωγικός
 εισακτέος εισηγητικός εισιτήριος εισοδηματικός εισπνευστικός εισπράξιμος
 εισπρακτικός εισρέων εισροϊκός εκάτερος εκατοντάχρονος εκατονταβάθμιος
 εκατονταπλάσιος εκατοστιαίος εκατοχρονίτικος εκατόχρονος εκβιαστικός
 εκδηλωτικός εκδικητικός εκδοτικός εκδρομικός εκδόσιμος εκηβόλος εκθέσιμος
 εκθειαστικός εκθεμελιωτικός εκθετικός εκθλιπτικός εκκαθαρισθής εκκαθαριστικός
 εκκεντροφόρος εκκενωτικός εκκινητήριος εκκλησιαζόμενος εκκλησιαστικός
 εκκολαπτικός εκκρεμής εκκριτικός εκκωφαντικός εκλέξιμος εκλαμπρότατος
 εκλεκτικιστικός εκλεκτικός εκλεκτορικός εκλεκτός εκλεχτός εκλιπών
 εκλογικός εκλογοαπολογιστικός εκλογοθηρικός εκλυτής εκλόγιμος εκμαυλιστικός
 εκμεταλλεύσιμος εκμηδενιστικός εκμισθωτικός εκμυστηρευτικός εκνευριστικός
 εκπέσιμος εκπαιδευτικός εκπεστέος εκπιέζω εκπιπτέος εκπληκτικός εκπνευστικός
 εκπολιτιστικός εκπρόθεσμος εκπτωτικός εκρέων εκρήξιμος εκρηκτικός εκρηξιγενής
 εκροϊκός εκστατικός εκστρατευτικός εκσυγχρονιστικός εκσφενδονισμένος εκτατήρας
 εκτατός εκτελέσιμος εκτελεστικός εκτελεστός εκτελωνιστικός εκτενής εκτιμηθής
 εκτιμητικός εκτονωτικός εκτοξευτικός εκτρωματικός εκτρωτικός εκτυπωτικός
 εκτυφλωτικός εκφερικός εκφοβητικός εκφοβιστικός εκφορητικός εκφορτωτικός
 εκφυλιστικός εκχιονιστικός εκχυδαϊστικός εκχωρητικός εκών ελάσιμος ελάσσων
 ελάχιστος ελέγξιμος ελαιοαπωθητικός ελαιοκομικός ελαιουργικός ελαιοφοβικός
 ελαιόφυτος ελαιώδης ελασμάτινος ελασματοειδής ελασματοποιήσιμος ελαστικός
 ελαττωματικός ελατός ελαφένιος ελαφίσιος ελαφοειδής ελαφρούτσικος ελαφρυντικός
 ελαφρόνους ελαφρός ελαφρύς ελαφρύτερος ελαϊκός ελβετικός ελεήμονας ελεήμων
 ελεγειακός ελεγκάν ελεγκτικολογιστικός ελεγκτικός ελεεινός ελεημονητικός
 ελεητικός ελεκτρίκ ελευθέριος ελευθεριάζων ελευθεριακός ελευθεριοκτόνος
 ελευθεροποιός ελευθερόβουλος ελευθερόστομος ελευθερόφρων ελευσίνιος
 ελεφάντινος ελεφαντένιος ελεύθερος ελεύτερος ελεών ελικοειδής ελικοφόρος
 ελισαβετιανός ελιτίστικος ελιτιστικός ελκτικός ελκυστικός ελκώδης ελλαδικός
 ελλανόδικος ελλειμματικός ελλειπτικός ελλειψοειδής ελληνικός ελληνιστικός
 ελληνοκεντρικός ελληνομαθής ελληνοπρεπής ελληνορωμαϊκός ελληνοτουρκικός
 ελληνόγλωσσος ελληνόκτητος ελληνόμορφος ελληνότροπος ελληνόφοβος ελληνόφωνος
 ελλοβόκαρπος ελλογιμότατος ελλογιμώτατος ελλόγιμος ελονοσιακός ελουβιακός
 ελπιδοφόρος ελπιστικός ελυτικός ελυτροειδής ελόβιος ελώδης εμαγιέ
 εμβληματικός εμβολοφόρος εμβριθής εμβρυακός εμβρυογενής εμβρυοειδής
 εμβρυολογικός εμβρυομητρικός εμβρυοφθόρος εμβρυϊκός εμβρυώδης εμβρόντητος
 εμετικός εμετοκαθαρτικός εμετολογικός εμμανής εμμελής εμμηνοπαυσιακός
 εμμονικός εμπαθής εμπαικτικός εμπειρικός εμπειροπόλεμος εμπερίστατος
 εμπλουτιστικός εμπορευματικός εμπορεύσιμος εμπορικός εμποροκρατικός
 εμπορορραπτικός εμποροϋπαλληλικός εμπράγματος εμπρεσιονιστικός εμπρηστικός
 εμπροσθοβαρής εμπροσθογεμής εμπρόθεσμος εμπρόθετος εμπρόσθιος εμπόλεμος
 εμφανέστατος εμφανής εμφανίσιμος εμφαντικός εμφατικός εμφυλιοπολεμικός
 εμψυχωτικός ενάλιος ενάμισης ενάντιος ενάρετος ενάριθμος ενέγγυος ενέσιμος
 ενήλιξ ενήμερος εναέριος εναίσιμος εναγής εναγώνιος εναλλάξιμος εναλλακτικός
 ενανθρακωτικός εναντιωματικός εναντιόμορφος εναντιότροπος εναργές εναργής
 εναρμονισμένος εναρμόνιος ενδαγγειακός ενδαυλικός ενδεής ενδεδυμένος
 ενδεκασύλλαβος ενδελεχής ενδεχόμενος ενδημικός ενδημοεπιδημικός ενδιάθετος
 ενδιαφέρων ενδικοφανής ενδοαγροτικός ενδοαορτικός ενδοαστρικός ενδοαυλικός
 ενδογενής ενδογλωσσικός ενδοδαπέδιος ενδοδερμικός ενδοδιαδικαστικός
 ενδοεθνικός ενδοεταιρικός ενδοημερήσιος ενδοηπατικός ενδοηπειρωτικός
 ενδοθηλιακός ενδοθωρακικός ενδοιαστικός ενδοκαρδιακός ενδοκλαδικός
 ενδοκοινοτικός ενδοκομματικός ενδοκράνιος ενδοκρανιακός ενδοκρατικός
 ενδοκρινικός ενδοκρινολογικός ενδοκυβερνητικός ενδοκυττάριος ενδοκυτταρικός
 ενδομυϊκός ενδονοσοκομειακός ενδοοικογενειακός ενδοομιλικός ενδοπεϊκός
 ενδοσηραγγώδης ενδοσκοπικός ενδοστεφανιαίος ενδοσυνεδριακός ενδοσχολικός
 ενδοτικός ενδοφθάλμιος ενδοφλέβιος ενδοφλεβικός ενδοχώριος ενδοϋαλοειδικός
 ενδυναμωτικός ενδόμυχος ενδόσιμος ενδότατος ενδότερος ενδώτιος ενεδρευτικός
 ενεργειακός ενεργητικός ενεργητισμός ενεργοβόρος ενεργοποιητικός ενεργός
 ενετικός ενεχυρικός ενεχυροδανειστικός ενεχυρούχος ενεχόμενος ενεός ενζωοτικός
 ενθαρρυντικός ενθετικός ενθουσιασμένος ενθουσιαστικός ενθουσιώδης
 ενθρονιστικός ενθυμητικός ενιαίος ενιαύσιος ενιούσιος ενιστικός ενισχυτικός
 εννεατής εννιάχρονος εννιακοσιοστός εννιακόσιοι εννιαψήφιος εννοιοκρατικός
 εννοιόλεξο ενοικιαστήριος ενοικιοστασιακός ενοποιητικός ενοποιός ενορατικός
 ενοχικός ενοχλητικός ενοχοποιητικός ενστικτώδης ενσυναίσθητος ενσυνείδητος
 ενσύρματος ενσώματος εντάφιος ενταξιακός εντατικός ενταφιαστικός εντεκάχρονος
 εντερικός εντεροπαθογόνος εντεταμένος εντεψίζικος εντομοαπωθητικός
 εντομοκτόνος εντομολογικός εντομοφάγος εντοπίσιμος εντοπιστικός εντροπαλός
 εντυπωσιακός εντυπωτικός εντόπιος ενυπόγραφος ενυπόθηκος ενυπόστατος ενωτικός
 ενύπαρκτος ενύπνιος εξάγωνος εξάεδρος εξάκτινος εξάκωπος εξάμετρος εξάμηνος
 εξάστηλος εξάστιχος εξάστυλος εξάτομος εξάχορδος εξάχρονος εξάωρος εξίτηλος
 εξαίρετος εξαίσιος εξαγγελτήριος εξαγγελτικός εξαγνιστήριος εξαγνιστικός
 εξαγριωτικός εξαγωγικός εξαγωγός εξαγωνικός εξαγώγιμος εξαδάκτυλος εξαδάχτυλος
 εξαετής εξαιρέσιμος εξαιρετέος εξαιρετικός εξαιρετός εξακολουθητικός
 εξακοσιοστός εξακριβωτικός εξακόσιοι εξακύλινδρος εξαλειπτικός εξαμβλωματικός
 εξαμερής εξαμηνίτικος εξαμηνιαίος εξαναγκαστικός εξανθηματικός εξαντλητικός
 εξαπλάσιος εξαπλός εξαργυρώσιμος εξαρθρωτικός εξαρτημένος εξαρτησιογόνος
 εξασέλιδος εξασθενητικός εξασφαλιστικός εξατάξιος εξεζητημένος εξελίξιμος
 εξελικτικός εξερευνητικός εξερχόμενος εξετασιοκεντρικός εξεταστέος
 εξεταστικός εξευγενιστικός εξευμενιστικός εξευτελιστικός εξηγήσιμος εξηγητικός
 εξηκονταετής εξηλασμένος εξημερωτικός εξημερώσιμος εξηντάχρονος εξηνταδικός
 εξιδρωματικός εξιδρωτικός εξιλαστήριος εξιλεωτικός εξισορροπητικός εξισωτικός
 εξοβελιστέος εξολισθητικός εξολοθρευτικός εξομοιωτικός εξομολογητικός
 εξοντωτικός εξονυχιστικός εξοπλιστικός εξοργιστικός εξορκιστικός εξορμητικός
 εξουθενωτικός εξουσιαστικός εξουσιομανής εξουσιοφρενής εξοφερικός εξοφλητέος
 εξοχικός εξπρεσιονιστικός εξτρά εξτραβαγκάν εξτρεμαδουρικός εξτρεμιστικός
 εξυγιαντικός εξυμνητικός εξυπηρετικός εξυπνακίστικος εξυπνότερος εξυψωτικός
 εξωατμοσφαιρικός εξωγήινος εξωγενής εξωδιαδικαστικός εξωδικαστικός εξωεδαφικός
 εξωθερμικός εξωθεσμικός εξωιδρυματικός εξωκοινοβουλευτικός εξωκομματικός
 εξωκυττάριος εξωκυτταρικός εξωλέμβιος εξωλογικός εξωλογιστικός εξωμήτριος
 εξωπολιτικός εξωπραγματικός εξωπυραμιδικός εξωραϊστικός εξωστικός εξωστρεφής
 εξωσυστημικός εξωσχολικός εξωσωματικός εξωτερικός εξωτικός εξωφρενικός
 εξόριστος εξόφθαλμος εξώγαμος εξώδικος εξώθερμος εξώλης εξώπροικος εξώτατος
 εξώφτερνος εοκικός εορτάσιμος εορταστικός εορτινός επάκτιος επάλληλος επάξιος
 επάργυρος επήκοος επίβουλος επίγειος επίγονος επίδικος επίδοξος επίζηλος
 επίκαιρος επίκεντρος επίκληρος επίκοινος επίκουρος επίκτητος επίλεκτος
 επίμαχος επίμεμπτος επίμονος επίμορτος επίμοχθος επίορκος επίπαστος επίπεδος
 επίπλοκος επίπονος επίρραπτος επίσημος επίστεγος επίσωτρος επίτιμος επίτοκος
 επίφθονος επίφοβος επίχαρις επίχριστος επίχρυσος επαίσχυντος επαγγελματικός
 επαγγελτικός επαγωαναγωγικός επαγωγικός επαγωγός επαγώγιμος επαινετέος
 επαινετός επακριβής επακτή επακτός επακόλουθος επαληθευτικός επαληθεύσιμος
 επαναληπτικός επαναπατρίσιμος επαναστατικός επανασυσκευασμένος
 επανορθωτικός επανορθώσιμος επανωτός επαρκής επαρχιακός επαρχικός επαρχιώτικος
 επείγων επείσακτος επεισοδιακός επεκτάσιμος επεκτατικός επενδυμικός
 επεξεργάσιμος επεξεργαστικός επεξηγηματικός επεξηγητικός επετειακός
 επιβατήριος επιβατηγός επιβατικός επιβεβαιωτικός επιβλαβής επιβλητικός
 επιβραδυντικός επιγενετικός επιγενόμενος επιγονατιδικός επιγραμματικός
 επιγραφικός επιδέξιος επιδαπέδιος επιδεής επιδεικτικός επιδειξιμανής
 επιδεκτικός επιδερμικός επιδημητικός επιδημικός επιδημιολογικός επιδιαιτητικός
 επιδιορθώσιμος επιδοκιμαστικός επιδοματικός επιδοσιπαγής επιδραστικός
 επιεικής επιζήμιος επιζήτητος επιζωοτικός επιθαλάσσιος επιθανάτιος επιθετικός
 επιθηλιακός επιθυμητικός επιθυμητός επικήδειος επικίνδυνος επικαθείμενος
 επικατάρατος επικατασκευαστικός επικερδέστερος επικερδής επικλινής
 επικοινωνιακός επικολυρικός επικονιαστικός επικουρικός επικούρειος
 επικρατής επικρατών επικρεμάμενος επικριτικός επικυρίαρχος επικυριαρχικός
 επικυρώσιμος επικός επιλέξιμος επιλήνιος επιλήσμονας επιλήσμων επιλήψιμος
 επιλεκτικός επιληπτικός επιλόχειος επιμήκης επιμελής επιμελητηριακός
 επιμνημόσυνος επιμορφωτικός επινήιος επινίκιος επινεμητικός επινοητικός
 επιπαγής επιπεδομετρικός επιπεδόκοιλος επιπεδόκυρτος επιπληκτικός επιπρόσθετος
 επιπόλαιος επιρρεπής επιρρηματικός επισιτιστικός επισκέψιμος επισκευάσιμος
 επισκληρίδιος επισκοπικός επισπεύδων επιστήθιος επιστημικός επιστημονικοφανής
 επιστολικός επιστολογραφικός επιστρατευτικός επιστρεπτέος επισφαλής
 επισχετικός επισωρευτικός επιτάφιος επιτήδειος επιτακτικός επιτατικός
 επιτελής επιτελικός επιτευκτός επιτεύξιμος επιτιμητικός επιτραπέζιος
 επιτρεπτός επιτροπικός επιτυχής επιτυχημένος επιτυχών επιτόπιος επιτύμβιος
 επιφανειακός επιφανειοδραστικός επιφυλακτικός επιφωνηματικός επιχειρηματικός
 επιχειρησιακός επιχρωματισμένος επιχώριος επιψευδαργυρωμένος εποικιστικός
 επονείδιστος εποξειδικός εποξικός εποπτικός επουλωτικός επουλώσιμος επουράνιος
 εποχιακός εποχικός επτάμηνος επτάστερος επτάστιχος επτάφωτος επτάωρος
 επταετής επτακοσιοστός επτακόσιοι επταμελής επτανησιακός επταπλάσιος
 επταψήφιος επωαστικός επωδικός επωφελής επόμενος επώδυνος επώνυμος εράσμιος
 εραλδικός ερανικός ερανισματικός ερασιτεχνικός ερασμιακός ερατεινός εργάσιμος
 εργασιακός εργασιομανής εργαστηριακός εργατικός εργατοϋπαλληλικός εργοδοτικός
 εργολαβικός εργοληπτικός εργομετρικός εργονομικός εργοστασιακός εργώδης
 ερεθισμένος ερεθιστικός ερειστικός ερευνητικός ερημικός ερημοδικήσας
 εριστικός ερματιστός ερμαφρόδιτος ερμαϊκός ερμηνευτικός ερμηνευόμενος
 ερμητικός ερπετοειδής ερπετομορφικός ερπετόμοφος ερπυστριοφόρος ερρωμένος
 ερυθηματώδης ερυθροειδής ερυθροσταυρικός ερυθρωπός ερυθρόλαιμος ερυθρόλευκος
 ερυθρός ερωτεύσιμος ερωτηματικός ερωτητικός ερωτιάρης ερωτιάρικος ερωτικός
 ερωτοπονεμένος ερωτοχτυπημένος ερωτόληπτος ερώμενος εσθονικός εσκεμμένος
 εσπεραντικός εσπερινός εστεμμένος εστιακός εσχατολογικός εσω-εξωλέμβιος
 εσωκομματικός εσωλέμβιος εσωλογιστικός εσωστρεφής εσωτερικός εσώκλειστος
 εσώτερος εσώψυχος ετήσιος εταιρικός εταστικός ετεροαναφορικός ετεροβίωτος
 ετεροβιωμένος ετεροβιωματικός ετερογενής ετεροειδής ετεροθαλής ετεροκίνητος
 ετερομήκης ετερομερής ετεροσκεδαστικός ετεροσωματικός ετεροφυλόφιλος
 ετερόγλωσσος ετερόδοξος ετερόκεντρος ετερόκλητος ετερόκλιτος ετερόμορφος
 ετερόπτωτος ετερόρρυθμος ετερόσημος ετερότοπος ετερότροφος ετερόφυλος
 ετερόφωτος ετερόχθων ετερόχρονος ετερώνυμος ετησιοποιημένος ετοιματζήδικος
 ετοιμοθάνατος ετοιμοπαράδοτος ετοιμοπόλεμος ετοιμόγεννος ετοιμόλογος
 ετρουσκικός ετσιθελικός ετυμικός ετυμολογικός ευάερος ευάλωτος ευάρεστος
 ευάρμοστος ευέλικτος ευέξαπτος ευήθης ευήκοος ευήλατος ευήλιος ευαίσθητος
 ευαγγελικός ευανάγνωστος ευαπόδεικτος ευαπόκτητος ευβοϊκός ευγενέστερος
 ευγενικός ευγνώμονας ευγνώμων ευδαίμων ευδαιμονικός ευδιάθετος ευδιάκριτος
 ευδιαχώριστος ευδόκιμος ευειδής ευεξάλειπτος ευεξήγητος ευεπίδεκτος ευεπίφορος
 ευερέθιστος ευεργετικός ευερμήνευτος ευετηριακός ευζωνικός ευηλεκτραγωγός
 ευθαρσής ευθερμαγωγός ευθηνός ευθυμογραφικός ευθυμολογικός ευθυνόφοβος
 ευθύβολος ευθύγραμμος ευθύς ευκίνητος ευκαιριακός ευκατάληπτος ευκατάστατος
 ευκλεής ευκλείδειος ευκοίλιος ευκολοβάσταγος ευκολοδιάβαστος ευκολοδιάκριτος
 ευκολονόητος ευκολοπλησίαστος ευκολοχώνευτος ευκολόπαρτος ευκολόπιστος
 ευκρινής ευκτήριος ευκταίος ευλίμενος ευλαβής ευλαβητικός ευλαβικός
 ευλογητός ευλογοφανής ευμάλακτος ευμαθής ευμαρής ευμεγέθης ευμενέστατος
 ευμετάβλητος ευμετάβολος ευμετάδοτος ευμετάπειστος ευμεταχείριστος
 ευνομούμενος ευνοϊκός ευνόητος ευξείνιος ευοίωνος ευπαθής ευπαρουσίαστος
 ευπρεπής ευπροσάρμοστος ευπροσήγορος ευπρόσβλητος ευπρόσδεκτος ευπρόσδεχτος
 ευπρόσωπος ευπόρθητος ευπώλητος ευρετικός ευρηματικός ευριπίδειος ευρυγώνιος
 ευρυμαθής ευρυπρόσωπος ευρωβόρος ευρωενωσιακός ευρωζωνικός ευρωλιγούρης
 ευρωσκεπτικιστικός ευρύς ευρύστερνος ευρύτερος ευρύχωρος ευσεβής ευσεβιστικός
 ευσπλαχνικός ευσταθής ευσταλής ευσταχιανός ευστόμαχος ευσυγκίνητος
 ευσχήμων ευσύνοπτος ευτελής ευτράπελος ευτραφής ευτυχής ευυπόληπτος
 ευφημιστικός ευφλόγιστος ευφορικός ευφραδής ευφραντικός ευφρόσυνος ευφυέστατος
 ευφωνικός ευφωτικός ευχάριστος ευχαριστήριος ευχείρωτος ευχερής ευχετήριος
 ευχητήριος ευωδερός ευωδιαστός ευόφθαλμος ευώδης ευώνυμος εφάμιλλος εφέσιμος
 εφήμερος εφίστιος εφαρμοστέος εφαρμοστικός εφαρμοστός εφαρμόσιμος εφεδρικός
 εφεσίβλητος εφετζίδικος εφετικός εφετινός εφευρετικός εφηβικός εφησυχαστικός
 εφιδρωτικός εφικτός εφοδιασμένος εφοδιαστικός εφοπλιστικός εφορευτικός
 εφτάγερος εφτάδιπλος εφτάμηνος εφτάχορδος εφτάψυχος εφτάωρος εφταήμερος
 εφτακόσιοι εφταμελής εφταμηνίτικος εφταπλάσιος εφταπλός εφτασύλλαβος εχέγγυος
 εχέφρων εχθρικός εψεσινός εωθινός εωσφορικός εόρτιος εύανδρος εύβουλος
 εύγλωττος εύγραμμος εύδιος εύδρομος εύηχος εύθετος εύθικτος εύθραυστος
 εύθυμος εύκαιρος εύκαμπτος εύκολος εύκοσμος εύκρατος εύληπτος εύλογος εύμορφος
 εύορκος εύοσμος εύπεπτος εύπιστος εύπλαστος εύπορος εύρυθμος εύρωστος εύσαρκος
 εύσπλαγχνος εύσπλαχνος εύστοχος εύστροφος εύσχημος εύσωμος εύτακτος εύτηκτος
 εύτονος εύτρωτος εύφημος εύφλεκτος εύφορος εύφωνος εύχαρις εύχρηστος εύχυμος
 εὐάρεστος εὐρύπρωκτος εὐτράπελος ζάμπλουτος ζάπλουτος ζαβολιάρης ζαβός
 ζαμπούνης ζαντός ζαρίφικος ζαρκαδίσιος ζαρομπασμένος ζαφειρένιος ζαχαράτος
 ζαχαροζυμωμένος ζαχαροπλαστικός ζαχαρούχος ζαχαρωτός ζαχαρώδης ζείδωρος
 ζεβλωμένος ζελατινώδης ζεματιστός ζεμπέκικος ζενδικός ζενιθιακός ζενιθικός
 ζερβόδεξος ζερβός ζεστούτσικος ζεστός ζευγαρωτός ζευκτήριος ζευκτός ζευσικός
 ζεύξιμος ζηλευτός ζηλιάρης ζηλότυπος ζηλόφθονος ζημιάρης ζημιογόνος ζημιωμένος
 ζογκλερικός ζοριλίδικος ζορμπαλίδικος ζουγλός ζουμερός ζουμπουρλούδικος
 ζοφερός ζοφώδης ζοχαδιακός ζούδιαρης ζούφιος ζυγοσταθμιστικός ζυγωματικός
 ζυγός ζυμοειδής ζυμολογικός ζυμοτεχνικός ζυμωσιογόνος ζυμωτικός ζυμωτός
 ζωγραφικός ζωγραφιστός ζωδιακός ζωεμπορικός ζωεμπόριο ζωηρός ζωηρόχρωμος
 ζωνικός ζωντανός ζωογονητικός ζωογόνος ζωοδόχος ζωολατρικός ζωολογικός
 ζωοποιός ζωοτεχνικός ζωοτόκος ζωοφοβικός ζωροαστρικός ζωστικός ζωτικός
 ζωόφιλος ζωόφοβος ζωώδης ζόρικος ηβικός ηγγυημένος ηγεμονικός ηγετικός
 ηδονικός ηδονιστικός ηδονοθηρικός ηδονόπληκτος ηδονόχαρος ηδυλόγος ηδυντικός
 ηδύγλωσσος ηδύς ηδύφωνος ηδύφωτος ηθικοδιδακτικός ηθικοθρησκευτικός
 ηθικοκρατικός ηθικολογικός ηθικοπλαστικός ηθικός ηθμοειδής ηθμώδης ηθογραφικός
 ηθολογικός ηθοπλαστικός ηλίθιος ηλεκτραγωγός ηλεκτρεγερτικός ηλεκτρικός
 ηλεκτροανατομικός ηλεκτροβόρος ηλεκτρογόνος ηλεκτροδυναμικός ηλεκτροκίνητος
 ηλεκτρολυτικός ηλεκτρομαγνητικός ηλεκτρομηχανικός ηλεκτρομηχανολογικός
 ηλεκτρονικός ηλεκτροπαραγωγικός ηλεκτροπαραγωγός ηλεκτροπτικός ηλεκτροστατικός
 ηλεκτροφόρος ηλεκτροφώτιστος ηλεκτροχημικός ηλιακός ηλιθιώδης ηλιογέννητος
 ηλιογραφικός ηλιοθερμικός ηλιοκαμένος ηλιοκεντρικός ηλιολατρικός ηλιοστεφής
 ηλιοφώτιστος ηλιοψημένος ηλιόλουστος ηλιόμορφος ηλιόπληκτος ηλιόφιλος
 ηλιόφωτος ηλιόχαρος ηλύσιος ημέτερος ημίγλυκος ημίγυμνος ημίδιπλος ημίκλαστος
 ημίκλιντος ημίλευκος ημίμαυρος ημίπληκτος ημίρρευστος ημίσκληρος ημίτονος
 ημίωρος ημαρτημένος ημεδαπός ημερήσιος ημερινός ημερολογιακός ημερομίσθιος
 ημιάγριος ημιέτοιμος ημιαμφίδρομος ημιαναίσθητος ημιαυτόματος ημιβάρβαρος
 ημιδιάφανος ημιδιανοιχθέν ημιδιαπερατός ημιδιαφανής ημιδιώροφος
 ημιεπίσημος ημιεπαγγελματικός ημιθανής ημικρατικός ημικυκλικός ημικύκλιος
 ημιμαθής ημιορεινός ημιπάρθενος ημιπαράλυτος ημιπαράφρων ημιπερατός
 ημιπολύτιμος ημιπροεδρικός ημιρυμουλκούμενος ημισεληνοειδής ημισφαιρικός
 ημιτελικός ημιυπόγειος ημιφάτνωτος ημιφανής ηπατικός ηπατολογικός ηπειρωτικός
 ηπιότερος ηράκλειος ηρακλείτειος ηρακλειώτικος ηρεμιστικός ηρωικός ηρωινομανής
 ησυχαστικός ηττοπαθής ηφαίστειος ηφαιστειακός ηφαιστειογενής ηφαιστειολογικός
 ηχήεις ηχερός ηχηρός ηχητικός ηχοαπορροφητικός ηχοβολιστικός ηχοβόλος
 ηχομετρικός ηχομιμητικός ηχομονωτικός ηχοποίητος ηχοφοβικός ηχόφοβος ηωζωικός
 θέσμιος θήλυς θαθατζής θαλάσσιος θαλαμοειδής θαλαμωτός θαλασσής θαλασσαιμικός
 θαλασσοβρεγμένος θαλασσοδερμένος θαλασσοφίλητος θαλασσόβρεχτος θαλασσόδαρτος
 θαλασσόχρωμος θαλερός θαλλιούχος θαλπερός θαμαστός θαματουργός θαμβωτικός
 θαμνοειδής θαμνοσκεπής θαμνόβιος θαμνόφυτος θαμνώδης θαμπερός θαμπωτικός
 θανάσιμος θανατερός θανατηφόρος θανατικός θανών θαρραλέος θαρρετός θασίτικος
 θαυμαστικός θαυμαστός θαυματουργικός θαυματουργός θαφτός θεάρεστος θείος
 θεατρικός θεατρινίστικος θεατρομανής θεατρόφιλος θεατός θειαφένιος θειικός
 θειούχος θειότατος θειώδης θεληματικός θελκτικός θελξίνοος θελξίνους
 θεμέλιος θεματικός θεμελιακός θεμελιωτικός θεμελιώδης θεμιτός θεοβάδιστος
 θεογέννητος θεογενής θεοδώρητος θεοειδής θεοκάπηλος θεοκατάρατος θεοκρατικός
 θεολογικός θεομάχος θεομίσητος θεομητορικός θεονήστικος θεοπάλαβος
 θεοσεβής θεοσκεπής θεοσκοτωμένος θεοσκότεινος θεοστεφής θεοτικός θεουργικός
 θεοφίλητος θεοφιλέστατος θεοφιλής θεοφόρος θεοφύλακτος θεοφώτιστος θεράπων
 θεραπεύσιμος θεριζοαλωνιστικός θερινός θεριστικός θερμαγωγός θερμαλιστικός
 θερμαντικός θερμασμένος θερμιδικός θερμιδογόνος θερμιδομετρικός θερμικός
 θερμιώτικος θερμογόνος θερμοδυναμικός θερμοηλεκτρικός θερμοκέφαλος
 θερμομαγνητικός θερμομετρικός θερμομηχανικός θερμομονωτικός θερμοπυρηνικός
 θερμοσκοπικός θερμοτηκόμενος θερμοτροπικός θερμουργός θερμοφιλικός
 θερμοφόρος θερμοχρωματικός θερμόαιμος θερμός θερμόφιλος θερμόφοβος
 θεσμικός θεσμοδίαιτος θεσπέσιος θεσπρωτικός θεσσαλικός θετικιστικός θετικός
 θετός θεωρητικός θεϊκός θεϊστικός θεόγυμνος θεόκλειστος θεόκλητος θεόκουφος
 θεόληπτος θεόμορφος θεόμουρλος θεόπεμπτος θεόπλαστος θεόπνευστος θεόρατος
 θεόσταλτος θεόστενος θεόστραβος θεότρελος θεότυφλος θεόφτωχος θηβαίικος
 θηλαίος θηλαστικός θηλοειδής θηλυγονικός θηλυκός θηλυμανής θηλυπρεπής θηραϊκός
 θηρεύσιμος θηριόμορφος θηριώδης θιβετικός θλαστικός θλιβερός θλιπτικός
 θνησιγενής θνησιμαίος θνητός θολερός θολοειδής θολοσκέπαστος θολοσκεπής
 θολωτός θολός θοριούχος θορυβικός θορυβοποιός θορυβώδης θρήσκος θρακικός
 θρασύδειλος θραψερός θρεπτικός θρεφτικός θρεψερός θρηνητικός θρηνώδης
 θρησκευτικός θρησκευόμενος θρησκομανής θρησκοφοβικός θρησκόληπτος θρησκόφοβος
 θριαμβικός θρομβολυτικός θρομβοστατικός θρομβώδης θρυλικός θρυπτικός
 θυελλώδης θυλακοειδής θυμαρίσιος θυμελικός θυμικός θυμοειδής θυμοσοφικός
 θυμωτσιάρης θυμόσοφος θυμώδης θυρεοειδής θυρεοτρόπος θυρσοφόρος θυσανοειδής
 θυσανόμορφος θωπευτικός θωρακικός θωρακικός θωρακοσκοπικός θωρακοφόρος
 θωρακωτός θωρηκτός ιάσιμος ιάσμινος ιαβέρειος ιαβαϊκός ιακωβιανός ιαματικός
 ιαμβικός ιαπετικός ιαπωνικός ιατρικός ιατροβιολογικός ιατρογενής
 ιατροκεντρικός ιατρομηχανολογικός ιατρονοσηλευτικός ιατροτεχνολογικός
 ιατός ιβηρικός ιβοριανός ιβουάρ ιγμόρειος ιγνυακός ιδανικός ιδεακός ιδεαλίζων
 ιδεατός ιδεογραφικός ιδεοκινητικός ιδεοκρατικός ιδεοληπτικός
 ιδεολογικοπολιτικός ιδεολογικός ιδεοτυπικός ιδεώδης ιδιάζων ιδιαίτατος
 ιδικός ιδιοδεκτικός ιδιοκατοίκητος ιδιοκτησιακός ιδιομεταλλικός ιδιοπαθής
 ιδιοσυντήρητος ιδιοσύστατος ιδιοτελής ιδιοφυής ιδιωματικός ιδιωτικοοικονομικός
 ιδιωφελής ιδιόβουλος ιδιόγραφος ιδιόκλιτος ιδιόκτητος ιδιόμελος ιδιόμορφος
 ιδιότροπος ιδιότυπος ιδιόχειρος ιδιόχρωμος ιδιώνυμος ιδρυματικός ιδρυτικός
 ιδρωτοποιός ιερακοειδές ιερακοειδής ιεραποστολικός ιεραρχικός ιερατικός
 ιεροεξεταστικός ιεροκοκκυγικός ιεροκρατικός ιεροκτόνος ιερολογικός ιεροπρεπής
 ιερουργικός ιερός ιερόσυλος ιεχωβικός ιεχωβιτικός ιζηματογενής ιζηματογόνος
 ιησουιτικός ιθαγενής ιθυφαλλικός ιθύνων ιικός ικάριος ικανοποιητικός ικανός
 ικετήριος ικετευτικός ικετικός ικτερικός ιλαροτραγικός ιλαρυντικός ιλαρός
 ιλιγγιώδης ιλλυρικός ιλουστρασιόν ιλυγενής ιλυώδης ιμερτός ιμιτασιόν
 ιμπρεσιονιστικός ινδιάνικος ινδικός ινδοευρωπαϊκός ινδονησιακός ινδουιστικός
 ινιακός ινολυτικός ινοοπτικός ινοπυριτικός ινώδης ιξώδης ιοβόλος ιογενής
 ιονοσφαιρικός ιοντικός ιοστεφής ιουδαϊκός ιουλιανός ιουνιανός ιουστινιάνειος
 ιππαγωγός ιππευτικός ιππικός ιπποδρομιακός ιπποδρομικός ιπποκράτειος ιπποτικός
 ιρακινός ιρανικός ιρασιοναλιστικός ιριδίζων ιριδικός ιριδιούχος ιριδωτός
 ισάδελφος ισάξιος ισάριθμος ισανώμαλος ισαρχέγονος ισθμιακός ισκιερός
 ισλαμιστικός ισλανδικός ισοβάθμιος ισοβαθής ισοβαρής ισογώνιος ισοδύναμος
 ισοθερμικός ισοκυανικός ισοκόρυφος ισομήκης ισομεγέθης ισομερής ισομορφικός
 ισοπαχής ισοπεδωτικός ισοπληθής ισορροπημένος ισορροπητικός ισοσθενής
 ισοσταθμικός ισοστατικός ισοσύλλαβος ισοταχής ισοτελής ισοτονικός ισοφασικός
 ισπανικός ισπανομαθής ισπανοτραφής ισπανόφωνος ισραηλινός ισραηλιτικός
 ιστιοδρομικός ιστιοπλοϊκός ιστιοφόρος ιστολογικός ιστολυτικός
 ιστορικός ιστοριογραφικός ιστοριοδιφικός ιστοριομετρικός ιστοχημικός
 ισχιακός ισχιαλγικός ισχναντικός ισχνός ισχνόφωνος ισχυογενής ισχυρογνώμονας
 ισχυρός ισχυρότερος ισόβαθμος ισόβαρος ισόβιος ισόθεος ισόθερμος ισόκυρος
 ισόμετρος ισόμοιρος ισόμορφος ισόνομος ισόπαλος ισόπεδος ισόπλευρος ισόποσος
 ισότιμος ισότονος ισόφωνος ισόχρονος ισόψηφος ιταλιάνικος ιταλικός ιταλομαθής
 ιταλόφωνος ιταμός ιχθυηρός ιχθυοβόρος ιχθυογενετικός ιχθυοειδής ιχθυολογικός
 ιχθυοτροφικός ιχθυοφάγος ιχθυόεις ιχθύμορφος ιχνηλάσιμος ιχνηλατήσιμος
 ιχνογραφικός ιψενικός ιωαννιώτικος ιωδιούχος ιωνικός ιόνιος ιόχρους ιώβειος
 ιώνιος κάγκανος κάθετος κάθιδρος κάθυγρος κάκιστος κάκοσμος κάλλιος κάλλιστος
 κάρυνος κάτασπρος κάτισχνος κάτω κάτωχρος κέδρινος κέρινος κίβδηλος κίκινος
 καίριος καβάφικος καβαλιστικός καβαλιώτικος καβαφικός καββαλιστικός
 καβδιανός καβοντορίτικος καβουρδισμένος καβουρδιστός καβουρντισμένος
 καβύλος καγκελωτός καγκελόφραχτος καδμείος καδοφόρος καζουιστικός καημενούλης
 καθάριος καθήμενος καθαιρετικός καθαρευουσιάνικος καθαροδευτεριάτικος
 καθαρτήριος καθαρτικός καθαρόαιμος καθαρός καθεδρικός καθεστωτικός καθηγητικός
 καθημερνός καθησυχαστικός καθιερωτικός καθιστικός καθιστός καθοδηγητικός
 καθολικός καθοριστικός καθυστερημένος καινοζωικός καινοπρεπής καινοτόμος
 καινοφανής καινούργιος καινούριος καινός καινότροπος καιρικός καιροσκοπικός
 κακάσχημος κακέκτυπος κακέμφατος κακαριστός κακεντρεχής κακοήθης
 κακογέννητη κακογεννήτρα κακογράφος κακογραμμένος κακοδαίμων κακοδιάθετος
 κακοδούλευτος κακοζώητος κακοθάλασσος κακοθάνατος κακοκαμωμένος κακολόγος
 κακομαθημένος κακομοίρα κακομοίρης κακομοίρικος κακομοιρασμένος κακομοιρούλης
 κακοντυμένος κακοξυσμένος κακοπίχερος κακοποιητικός κακοποιός κακοπράγμων
 κακοπόδαρος κακορίζικος κακοσήμαδος κακοσούρης κακοστρωμένος κακοστόμαχος
 κακοτράχαλος κακοχώνευτος κακτοειδής κακόβολος κακόβουλος κακόβραστος
 κακόγλωσσος κακόγνωμος κακόγουστος κακόδοξος κακόζηλος κακόηχος κακόθυμος
 κακόκεφος κακόλογος κακόμοιρος κακόμορφος κακόνομος κακόπιστος κακόπραγος
 κακόσαρκος κακόσημος κακόστομος κακόσχημος κακότεχνος κακότροπος κακότυχος
 κακόφωνος κακόχυμος κακόψυχος κακώνυμος καλάμινος καλαίσθητος καλαβρέζικος
 καλαισθητικός καλαμένιος καλαματιανός καλαμοειδής καλαμοπόδαρος
 καλαμποκένιος καλαμποκίσιος καλαμπόρτζος καλαμωτός καλαμώδης καλειδοσκοπικός
 καλλίγραμμος καλλίκνημος καλλίκομος καλλίμορφος καλλίνικος καλλίπυγος
 καλλίτερος καλλίφωνος καλλιγραφικός καλλιεπής καλλιεργήσιμος καλλιεργητικός
 καλλιμάρμαρος καλλιπάρειος καλλιρροϊκός καλλιτεχνικός καλλωπιστικός καλοήθης
 καλοβαλμένος καλογερίστικος καλογερικός καλογραμμένος καλοδιάθετος
 καλοθάλασσος καλοθρεμμένος καλοκάγαθος καλοκαιριάτικος καλοκαιρινός
 καλοκαρδιστικός καλολογικός καλομίλητος καλομαγειρεμένος καλομοίρης
 καλοντυμένος καλοξυρισμένος καλοξυσμένος καλοπίχερος καλοπροαίρετος
 καλορίζικος καλοστεκάμενος καλοστεκούμενος καλοσυνάτος καλοσχεδιασμένος
 καλοτάξιδος καλοταϊσμένος καλοτυπωμένος καλοφορεμένος καλοφούρτουνος
 καλοφόρετος καλούτσικος καλπαστικός καλπονοθευτικός καλπουζάνικος καλυβόσπιτο
 καλυκοειδής καλυκοφόρος καλυμνιώτικος καλυπτήριος καλωδιακός καλόβολος
 καλόβραστος καλόγεννος καλόγλωσσος καλόγνωμος καλόγουστος καλόδεχτος
 καλόμοιρος καλόπιστος καλός καλόστρωτος καλότροπος καλότυχος καλόχυμος καλών
 καμαρωτός καματερός καμηλίσιος καμινευτικός καμπίσιος καμπανιστός καμπανοειδής
 καμπούρικος καμπριολέ καμπυλοειδής καμπυλωτός καμπυλόγραμμος καμπόσος καμπύλος
 καναδέζικος καναδικός κανακεμένος καναρινής κανδηλανάπτης κανελής κανηφόρος
 κανιστροειδής κανναβένιος κανονικός κανονισμένος κανονιστικός καντιανός
 καουμπόικος καουτσουκένιος καπακωτός καπηλευτικός καπηλικός καπιταλιστικός
 καπναγωγός καπνεργατικός καπνικός καπνιστικός καπνιστός καπνοβόρος καπνογόνος
 καπούτ καπριτσιόζος καπριτσόζος καραβίσιος καραγκιόζικος καραγκούνικος
 καραμπινάτος καραφλός καραϊβικός καρβονικός καρβουνιάρικος καρδιαγγειακός
 καρδιοαναπνευστικός καρδιογραφικός καρδιοειδής καρδιολογικός καρδιοπνευμονικός
 καρδιοχειρουργικός καρδιτσιώτικος καρδιόσχημος καρκινιάρης καρκινικός
 καρκινοειδής καρκινολυτικός καρκινοπαθής καρκινωματώδης καρκινώδης καρλής
 καρμίρικος καρναβαλίστικος καρναβαλικός καρντέ καροτής καρπερός καρπιαίος
 καρποφόρος καρσινός καρστικός καρτερικός καρτεσιανός καρτοκινητός
 καρυδάτος καρυδένιος καρφωτός καρχηδονιακός καρχηδονικός καρωτικός κασιδιάρης
 κασμιρικός κασσιτέρινος καστανέρυθρος καστανομάλλης καστανόξανθος καστανός
 καστόρι καστόρινος κατάβρεκτος κατάδηλος κατάδρομος κατάθαμβος κατάκλειστος
 κατάκοπος κατάκορφος κατάκρυος κατάλευκος κατάλληλος κατάλοιπος κατάμαυρος
 κατάμονος κατάντης κατάξανθος κατάξερος κατάξηρος κατάπικρος κατάπληκτος
 κατάπλωρος κατάπρυμος κατάπτυστος κατάρατος κατάρρυτος κατάσκιος κατάσπαρτος
 κατάστερος κατάστικτος κατάστιχτος κατάφορτος κατάφρακτος κατάφυτος κατάφωρος
 κατάχλομος καταβλητικός καταγάλανος καταγέλαστος καταγγελτικός καταγραφικός
 καταδεχτικός καταδικάσιμος καταδικαστέος καταδικαστικός καταδικός
 καταδιωκτικός καταδιωχτικός καταδολιευτικός καταδρομικός καταδυναστευτικός
 καταθετικός καταθλιπτικός καταιγιδοφόρος καταιγιστικός κατακίτρινος
 κατακαίνουριος κατακαημένος κατακλυσμιαίος κατακλυσμικός κατακριτέος
 κατακόκκινος κατακόρυφος καταλανικός καταληκτικός καταληπτικός καταληπτός
 καταλογιστός καταλυτικός καταμήνιος καταμαγεύω καταμόναχος καταναγκαστικός
 κατανεμητέος κατανοητός κατανυκτικός κατανυχτικός καταπειστικός καταπιεστικός
 καταπληχτικός καταποδιαστός καταπονητικός καταπράσινος καταπραϋντικός
 καταραμένος καταρρακτώδης καταρροϊκός κατασβεστικός κατασκέπαστος
 κατασκοπευτικός κατασκότεινος κατασταλακτός κατασταλαχτός κατασταλτικός
 καταστρεπτικός καταστροφικός κατασχέσιμος κατασχετήριος κατασχετός
 κατατεθείς κατατονικός κατατοπιστικός κατατυραννικός καταφανής καταφατικός
 καταφώτιστος καταχαρούμενος καταχθόνιος καταχρηστικός καταχτητικός
 καταψυκτικός κατεβατός κατεδαφιστικός κατεργάρης κατεργάρικος κατεργάσιμος
 κατερχόμενος κατευθυντήριος κατευναστικός κατεχόμενος κατηγορηματικός
 κατηγορικός κατηφής κατηφορικός κατηχητήριος κατηχητικός κατιονικός
 κατοικίδιος κατοπινός κατοπτευτικός κατοπτρικός κατορθωτός κατουρλιάρης
 κατοχυρωτικός κατσανάτος κατσαρομάλλης κατσαρωτός κατσαρός κατσικίσιος
 κατσικοπόδαρος κατσικοπόδης κατσούφης κατσούφικος κατωφερής κατόχρονος
 κατώτερος καυδιανός καυκάσιος καυλιάρης καυλιάρικος καυλόσχημος καυστικός
 καυτός καυχησιάρης καυχησιάρικος καφέ καφασωτός καφεδής καφενόβιος καφετής
 καφεϊνούχος καφκικός καχεκτικός καχύποπτος καψαλιστός καψερός καψοκαλύβας
 καύσιμος κβαντικός κβαντοδυναμικός κβαντοδυφιακός κβαντομηχανικός
 κειμενικός κεκαθαρμένος κεκαλυμμένος κεκηρυγμένος κεκλιμένος κεκοιμημένος
 κελτικός κεντητός κεντρικοποιημένος κεντρικός κεντροαριστερός κεντροβαρής
 κεντρομόλος κεντροφιλελεύθερος κεντροφόρος κεντρόφυγος κεντρόφυξ κεντρώος
 κενός κενόσοφος κενόσπουδος κεράδικο κεράτινος κερένιος κεραμιδής κεραμιδωτός
 κεραμιώτικος κεραμοσκεπής κεραμωτός κερασένιος κερασής κερασφόρος κερατένιος
 κεραυνοβόλος κεραυνόπληκτος κεραύνιος κερδομανής κερδοσκοπικός κερδοφόρος
 κερκοειδής κερκοφόρος κερκυραίικος κερκυραϊκός κεφάτος κεφαλίσιος κεφαλαίος
 κεφαλαιοκρατικός κεφαλαιοποιηθείς κεφαλαιοποιητικός κεφαλαιουχικός κεφαλαιώδης
 κεφαλικός κεφαλληνιακός κεφαλλονίτικος κεφαλομετρικός κεχηνώς κεχριμπαρένιος
 κηδεμονικός κηδευτικός κηκογόνος κηπευτικός κηπευτός κηπεύσιμος κηπουρικός
 κηροπλαστικός κηρωτός κηρώδης κητοειδής κιβωτιοφόρος κιβωτιόσχημος κιβωτοειδής
 κιναισθητικός κινδυνολογικός κινδυνώδης κινεζικός κινηματική κινηματογραφικός
 κινησιοθεραπευτικός κινητήριος κινητικός κινητός κιονίτης κιονοειδής κιρκάδιος
 κιρκαδιανός κιρκαδικός κιρρωτικός κιρσώδης κισσοστεφής κιτρικός κιτρινιάρης
 κιτρινόμαυρος κιτρινόφαιος κιτρινόχρους κιτς κιτσαριό κιτσοβόγκ κλέφτικος
 κλαδευτικός κλαδικός κλαδωτός κλανιάρης κλαρωτός κλασικός κλασματικός
 κλαυτός κλαψιάρης κλαψιάρικος κλειδωτός κλεινός κλεις κλειστός κλειτοριδικός
 κλεπτώνυμος κλεφτός κλεψίγαμος κλεψίτυπος κλεψιμαίικος κλημάτινος κληματένιος
 κληρονομικός κληρονομούμενος κληρωσάμενος κληρωτός κλητήριος κλητικός κλητός
 κλιμακοποιημένος κλιμακοφόρος κλιμακτηρικός κλιμακωτός κλιματικός
 κλιματολογικός κλινήρης κλινικός κλιτικός κλιτός κλοπιμαίος κλούβιος κλωστικός
 κλωστοϋφαντουργικός κνημαίος κνημιαίος κοίλος κογχοειδής κοζάκικος κοζανίτικος
 κοιλιακός κοιλιόδουλος κοιλόκυρτος κοιμήσης κοιμήσικος κοιμητηριακός
 κοινοβιακός κοινοβουλευτικός κοινολεκτικός κοινοπρακτικός κοινοσυντήρητος
 κοινωνιακός κοινωνικοασφαλιστικός κοινωνικοεπαγγελματικός κοινωνικοοικονομικός
 κοινωνικοπολιτικός κοινωνικοπολιτιστικός κοινωνικοπρακτικός κοινωνικός
 κοινωνιολογικός κοινωνιονομικός κοινωφελής κοινός κοινότοπος κοινότυπος
 κοιταματολογικός κοκάλινος κοκέτης κοκαλένιος κοκαλιάρης κοκαϊνομανής
 κοκκινομάλλης κοκκινοτρίχης κοκκινωπός κοκκιώδης κοκκολιθοφόρος κοκκομετρικός
 κοκκυγικός κοκκώδης κοκορόμυαλος κολάσιμος κολακευτικός κολασμένος κολεγιακός
 κολλητικός κολλητός κολλοειδής κολλώδης κολοβός κολοκυθένιος κολονάτος
 κολπατζίδικος κολπικός κολποειδής κολποκοιλιακός κολυμβητικός κολυμπητός
 κομματιαστός κομματικός κομμουνιστικός κομμωτικός κομουνιστικός κομπαστικός
 κομπλέ κομπλεξικός κομπλιμεντόζος κομπογιαννίτικος κομπορρήμων
 κομφορμιστικός κομψευόμενος κομψοεπής κομψός κονδυλοφόρος κονδυλώδης
 κονισαλέος κοντακιανός κοντινός κοντοκουρεμένος κοντομάνικος κοντοπίθαρος
 κοντοφάρδουλος κοντοχωριανός κοντούλης κοντούτσικος κοντυλένιος
 κοντόθωρος κοντόκαννος κοντόμερος κοντόμυαλος κοντόουρος κοντόπαχος κοντόπνοος
 κοντότερος κοντόφθαλμος κοντόχοντρος κοντόχρονος κοντύτερος κοπαδιάρης
 κοπαδιαστός κοπανιστός κοπιαστικός κοπιώδης κοπρολάγνος κοπροφάγος κοπτερός
 κοράλλινος κορακάτος κορακοζώητος κοραλλένιος κοραλλιογενής κοραλλιοειδής
 κορδωτός κορεατικός κορινθιακός κοριτσίστικος κοροϊδίστικος κοροϊδευτικός
 κορτιζονούχος κορτικοειδής κορυβαντικός κορυνηφόρος κορυφαίος κορφιάτικος
 κορωπιώτικος κοσμαγάπητος κοσμηματογραφικός κοσμητικός κοσμικός κοσμιότατος
 κοσμοβριθής κοσμογονικός κοσμογραφικός κοσμογυρισμένος κοσμοζωικός
 κοσμοκρατορικός κοσμολογικός κοσμοξάκουστος κοσμοπολίτικος κοσμοπολιτικός
 κοσμοσωτήριος κοσμοϊστορικός κοστοβόρος κοτίσιος κοτζάμ κοτσανάτος κοτσονάτος
 κουκλίστικος κουκλοθεατρικός κουκουλάρικος κουλοχέρης κουλτουριάρης
 κουλός κουμανταδόρικος κουμπωτός κουνιστός κουραστικός κουρδικός κουρδιστός
 κουρελής κουρελιάρης κουρευτικός κουρλός κουρμπαριστός κουρουπιαστός κουρού
 κουσελιάρης κουστουμαρισμένος κουτοπόνηρος κουτούτσικος κουτρούλης
 κουτσαβάκικος κουτσοβλαχικός κουτσομπολίστικος κουτσομπόλικος κουτσονούρης
 κουτσοχέρης κουτσός κουτός κουφικός κουφιοκέφαλος κουφονησιώτικος κουφωτός
 κουφόνους κουφός κοφτερός κοφτός κοχλιαίος κοχλιακός κοχλιοειδής κοχλιοφόρος
 κούτσικος κούφιος κούφος κράτιστος κρίθινος κρίσιμος κραδαστικός κρανένιος
 κρανιδιώτικος κρανιοεγκεφαλικός κρανιολογικός κρανιομετρικός κρανιοπροσωπικός
 κρανοειδής κρανοφόρος κρασάτος κραταιός κρατερός κρατικοδίαιτος
 κρατικός κρατοκεντρικός κραυγαλέος κρεάτινος κρείσσων κρεατής κρεατερός
 κρεατωμένος κρεμανταλάδικος κρεμαστός κρεμεζής κρεμώδης κρεοφάγος κρημνώδης
 κρητιδικός κρητιδικός κρητικός κριθαρένιος κριθαρίσιος κρικοειδής κρικωτός
 κρινένιος κρινοδάκτυλος κρινοδάχτυλος κρινοειδής κρινόλευκος κρισογόνος
 κριόμορφος κροατικός κροκάτος κροκαλοπαγής κροκοβαφής κροκοδείλιος
 κροκοειδής κροκωτός κροσσάρω κροσσωτός κροταφιαίος κροταφικός κροταφογναθικός
 κρουσιφλεγής κρουσταλλένιος κρουστικός κρουστός κρυερός κρυμμένος κρυοσκοπικός
 κρυοσυντηρημένος κρυούτσικος κρυπτογαμικός κρυπτογραφικός κρυπτολογικός
 κρυστάλλινος κρυσταλλένιος κρυσταλλικός κρυσταλλογραφικός κρυσταλλοειδής
 κρυσταλλώδης κρυφτός κρυφός κρυψίβουλος κρυψίγαμος κρυψίνους κρυόμπλαστος
 κρόκινος κρόνιος κρύος κρύφιος κτηματικός κτηματοκεντρικός κτηματομεσιτικός
 κτηνοτροφικός κτηνοφοβικός κτηνόμορφος κτηνώδης κτηριακός κτηριολογικός
 κτητορικός κτιριακός κτιστός κτιτορικός κτυπητός κυανωπός κυανόλευκος κυανός
 κυβερνήσιμος κυβερνητικός κυβερνοαναζητήσιμος κυβικός κυβιστικός κυβοειδής
 κυκλαδίτικος κυκλαδικός κυκλικός κυκλοειδής κυκλοθυμικός κυκλοπυριτικός
 κυκλοφοριακός κυκλοφορικός κυκλωνικός κυκλωτικός κυκλόσχημος κυκλώπειος
 κυλινδροειδής κυλινδρωτός κυλιστός κυλιόμενος κυλλός κυματικός κυματιστός
 κυματογόνος κυματοειδής κυματώδης κυνηγάρης κυνηγετικός κυνηγιάρικος κυνικός
 κυπαρίσσινος κυπαρίσσινος κυπαρισσένιος κυπελλοειδής κυπελλούχος κυπελλόσχημος
 κυπραίικος κυπραίος κυπριακός κυπριώτικος κυρίαρχος κυρηναϊκός κυριακάτικος
 κυριαρχικός κυριλέ κυριλλικός κυριολεκτικός κυρτός κυρωτικός κυστεοκολπικός
 κυστικός κυστοειδής κυτοπλασματικός κυτταρικός κυτταρογόνος κυτταροειδής
 κυτταρολυτικός κυτταροπλασματικός κυτταροστατικός κυφωτικός κυφός κυψελοειδής
 κωδωνοειδής κωλοπετσωμένος κωλόφαρδος κωματώδης κωμιακίτικος κωμικοτραγικός
 κωνικός κωνοειδής κωνοφόρος κωπήλατος κωπήρης κωπηλατικός κωφάλαλος κωφός
 κόκκινος κόλουρος κόμοδος κόσμιος κύκλιος κύκνειος κύριος κώος κώτικος λάβρος
 λάγνος λάιτ λάλος λάσκος λέσβιος λίγος λίθινος λίμπερο λίχνος λαίμαργος
 λαβυρινθώδης λαγαρός λαγωχειλικός λαγόκαρδος λαγόνιος λαδής λαδί λαδερός
 λαθρεμπορικός λαθρόβιος λαθρόγαμος λαιλαπώδης λαιμικός λακανικός λακαρισμένος
 λακωνικός λαλίστατος λαλητός λαμαρινένιος λαμιακός λαμιώτικος λαμπαδηφόρος
 λαμπερός λαμπριάτικος λαμπροφόρος λαμπρός λαμπρόφωνος λαξευτός λαογραφικός
 λαοκρατικός λαομίσητος λαοπρόβλητος λαοσωτήριος λαοφίλητος λαοφιλής
 λαπλασιανός λαρισαϊκός λαρυγγικός λαρυγγολογικός λαρυγγόφωνος λασιθιώτικος
 λασπολόγος λασπώδης λαστιχένιος λατεριτικός λατινικός λατινοαμερικανικός
 λατινογραφημένος λατινοπρεπής λατομικός λατρευτικός λατρευτός λαφρύς λαχανί
 λαχταριστός λαϊκίστικος λαϊκιστικός λαϊκός λαϊκότροπος λείος λεβέντικος
 λεβεντόκορμος λεγκάτο λειαντικός λειμώνιος λειπανάβατος λειράτος λειτουργικός
 λειχηνοειδής λειχηνόμορφος λειχούδης λειψανάβατος λειψερός λειψός λεκανοειδής
 λεκτικός λεμβουχικός λεμονάτος λεμονής λεμφαδενικός λεμφατικός λεμφικός
 λεμφοκυτογόνος λεμφοκυτταρικός λεμφοφόρος λενινιστικός λεξαριθμικός
 λεξικολογικός λεξικός λεξιλογικός λεοντόθυμος λεοντόκαρδος λεοντόμορφος
 λεπιδοφόρος λεπιδωτός λεπιδόσχημος λεπρωτικός λεπρός λεπταίσθητος
 λεπτοδουλεμένος λεπτοκαμωμένος λεπτοκυρτωτός λεπτολογικός λεπτολόγος
 λεπτομερής λεπτομερειακός λεπτοτεχνικός λεπτοφυής λεπτούτσικος λεπτόγαιος
 λεπτόκοκκος λεπτόκυρτος λεπτόπαχος λεπτόρρευστος λεπτός λεπτόσωμος λεπτότεχνος
 λεπτόφωνος λεπτύκυρτος λερναίος λερός λεσβιακός λεττονικός λευκαδίτικος
 λευκαντικός λευκαυγής λευκοκυτταρικός λευκοντυμένος λευκοπυρώμενος
 λευκορωσικός λευκοσιδηρούς λευκοφορεμένος λευκοφόρος λευκωματικός
 λευκωματούχος λευκωματώδης λευκός λευκός λευκόφαιος λευκόχρους λευτικός
 λευχείμων λεωνιδιώτικος λεωφορειακός λεόντειος λεύκινος λεύτερος ληθαργικός
 ληξιαρχικός ληξιπρόθεσμος ληξουριώτικος λησμονιάρης ληστευμένος ληστρικός
 λιανικός λιανός λιαστός λιβαδίσιος λιβαδικός λιβανικός λιβανωτός λιβιδινικός
 λιγδερός λιγδιάρης λιγδιάρικος λιγνιτοφόρος λιγνός λιγοήμερος λιγοζώητος
 λιγοσέλιδος λιγοστός λιγουρευτός λιγούρης λιγυρός λιγυρόφωνος λιγωμένος
 λιγόλεπτος λιγόλογος λιγόπιστος λιγότερος λιγόφαγος λιγόχρονος λιγόψυχος
 λιθαγωγός λιθανθρακοφόρος λιθογλυφικός λιθογραφικός λιθογόνος λιθοδομικός
 λιθοκόλλητος λιθομετέωρος λιθομετεωριτικός λιθοσφαιρικός λιθοτομικός λιθοτόμος
 λιθόβλητος λιθόδμητος λιθόκτιστος λιθόστρωτος λιθόχτιστος λικνιστικός λιλά
 λιμάρης λιμάρικος λιμενικός λιμενοβιομηχανικός λιμνίσιος λιμναίος λιμνόβιος
 λιμπιστικός λιμώδης λινομέταξος λινοτυπικός λινόδετος λινός λινόχρους λιξούρης
 λιονταρόψυχος λιοπερίχυτη λιπανάβατος λιπαντικός λιπαρός λιπιδαιμικός
 λιποδιαλυτός λιποειδής λιποθυμικός λιπόβαρος λιπόθυμος λιπόσαρκος λιπόψυχος
 λιτοδίαιτος λιτός λιχουδιάρης λιχουδιάρικος λιχούδης λιχούδικος λιόκαλος
 λιόχαρος λογαριθμικός λογικοφανής λογικός λογισθείς λογιστικός λογιότατος
 λογογραφικός λογοκρατικός λογοκριτικός λογοτεχνικός λογχοειδής λογχοφόρος
 λοιμικός λοιμογόνος λοιμωξιολογικός λοιμό λοιμώδης λοιπός λονδρέζικος
 λοξός λουδοβίκειος λουθηρανικός λουθηρανός λουκούλλειος λουλακάτος λουλακής
 λουλουδένιος λουλουδιστά λουλουδιστός λουλούδινος λουξ λουριδωτός λουσάτος
 λουόμενος λοφώδης λούγκο λούμπεν λούτος λούτρινος λυγερόκορμος λυγερός
 λυγμικός λυγουριώτικος λυδικός λυκόμορφος λυμφατικός λυπηρός λυπητερός
 λυρικός λυσίκομος λυσίπονος λυσιγόνος λυσιτελής λυσσάρης λυσσάρικος λυσσαλέος
 λυσσιάρικος λυσσόδηκτος λυσσώδης λυτρωτικός λυτρώσιμος λυτός λωβιάρης λωλός
 λωτοφάγος λόγιος λύγινος λύγκειος λύδιος μάγκικος μάλλινος μάξι μάταιος
 μέγας μέγιστος μέλαινα μέλας μέλινος μέλλων μέσα μέσος μέτριος μήλειος μήλινος
 μίνι μίσανδρος μίσθαρνος μίσθιος μαβής μαγγανευτικός μαγγανιούχος μαγειρευτός
 μαγευτικός μαγιάτικος μαγικός μαγκούφης μαγματικός μαγματογενής μαγνησιούχος
 μαγνητογυρικός μαγνητοηλεκτρικός μαγνητοθερμικός μαγνητοστατικός μαδαροκέφαλος
 μαζικός μαζοχιστικός μαζωχτός μαθηματικός μαθησιακός μαθητευόμενος μαθητικός
 μαιάνδριος μαιανδρικός μαιευτικός μαιονίδης μακάβριος μακάριος μακαρίτης
 μακαριστός μακεδονίτικος μακεδονικός μακιαβελικός μακραίων μακραίωνος μακρινός
 μακροβίοτος μακροκάνης μακροκατάληκτος μακροκοσμικός μακρολαίμης μακρολόγος
 μακρομάλλης μακρομαλλούσα μακρομοριακός μακροοικονομικός μακροπρόθεσμος
 μακροπόδαρος μακροσκελής μακροσκοπικός μακρουλός μακροχέρης μακροχρόνιος
 μακρυμάνικος μακρόβιος μακρόθυμος μακρόινος μακρόπνοος μακρόπνους μακρόπους
 μακρόστενος μακρόσυρτος μακρόφωνος μακρόχειρ μακρόχρονος μακρύκαννος
 μακρύς μακρύτερος μακό μαλακισμένος μαλακοτρίφτης μαλακούτσικος μαλακτικός
 μαλαματένιος μαλαχτικός μαλαϊκός μαλγασικός μαλθακός μαλλιαρός μαλλοβάμβακος
 μαλλομέταξος μαλλωτός μαλτέζικος μαμμόθρεπτος μαμμόθρεφτος μαμούχαλος μανάτος
 μανδαλωτός μανιάτικος μανιακός μανικός μανιοκαταθλιπτικός μανιχαϊκός μανιώδης
 μαντευτικός μαντζουριανός μαντηλοφόρος μαντικός μανός μαξιμαλιστικός
 μαοϊκός μαραγκούδικο μαραζιάρης μαραζιάρικος μαραθώνιος μαρασμώδης
 μαργαριτοφόρος μαργαρώδης μαργιόλης μαργιόλικος μαρινάτος μαρκέ μαρμάρινος
 μαρμαροειδής μαρμαρυγιακός μαρμαρόστρωτος μαρξιστικός μαροκινός μαρουσιώτικος
 μαρτιάτικος μαρτυριάρης μαρτυριάρικος μαρτυρικός μασητήριος μασκέ μασκοφόρος
 μαστιγοφόρος μαστιγωτικός μαστικός μαστιχοφόρος μαστοειδής μαστορικός
 μαστούρης μαστροδούλεφτος μασχαλιαίος ματ ματαβιβάσιμος ματαιόδοξος
 ματαιόφρονας ματαιόφρων ματαριστικός ματεριαλιστικός ματζόβολος ματζόρε ματσό
 μαυριτανικός μαυρογάλανος μαυρογένης μαυροκίτρινος μαυρομάλλης μαυρομάνικος
 μαυροντυμένος μαυροφορεμένος μαυροφόρος μαφιόζικος μαχητικός μαχητός
 μαϊμουδίσιος μαϊμουδίστικος μαύρος μείζων μείζων μείων μεγάθυμος μεγάλος
 μεγάτιμος μεγακέφαλος μεγαλειώδης μεγαλεπήβολος μεγαλιθικός μεγαλοαστικός
 μεγαλογράμματος μεγαλοδύναμος μεγαλοκαμωμένος μεγαλομάτης μεγαλομανής
 μεγαλοπαρασκευιάτικος μεγαλοπράγμων μεγαλοπρεπής μεγαλορρήμων μεγαλοσχήμων
 μεγαλοφάνταστος μεγαλοφυής μεγαλοϊδεάτικος μεγαλοϊδεατικός μεγαλούτσικος
 μεγαλόθυμος μεγαλόκαρδος μεγαλόπνευστος μεγαλόπρεπος μεγαλόστομος μεγαλόσχημος
 μεγαλόφθαλμος μεγαλόφρων μεγαλόφωνος μεγαλόψυχος μεγαλύτερος μεγαλώνυμος
 μεγαρίτικος μεγεθικός μεγεθυντικός μεζεκλήδικος μεζεκλίδικος μεθανίτικος
 μεθεπόμενος μεθευρετικός μεθεόρτιος μεθοδευτικός μεθοδικός μεθοδολογικός
 μεθυλικός μεθυστικός μεθόριος μεικτός μειλίχιος μειοδοτικός μειονεκτικός
 μειχτός μειωτέος μειωτικός μειόκαινος μελάγχρους μελάτος μελένιος μελής
 μελίφθογγος μελίχρυσος μελαγχολικός μελαγχρωστικός μελαμψός μελανίτικος
 μελανηφόρος μελανωπός μελανόδερμος μελανόμορφος μελανός μελανόφθαλμος
 μελαψός μελετηρός μελετητικός μελικός μελισσοκομικός μελισσοτροφικός
 μελιστάλακτος μελιστάλαχτος μελιταίος μελιτζανής μελιτοφόρος μελιτόχρους
 μελιχρός μελλοθάνατος μελλοντικός μελλούμενος μελοδραματικός μελωδικός μελό
 μεμπτός μεμψίμοιρος μενεξεδένιος μενεξεδής μενεξελής μενετός μενσεβικικός
 μεξικανικός μερακλίδικος μεραρχιακός μεριδιούχος μερικός μερισματούχος
 μεροληπτικός μερσεριζέ μερωνυμικός μεσάτος μεσήλικος μεσήλιξ μεσίστιος μεσαίος
 μεσανατολικός μεσεγγυητικός μεσευρωπαϊκός μεσημβρινός μεσημεριάτικος
 μεσιακός μεσιανός μεσιτικός μεσοαστικός μεσοβέζικος μεσοβδομαδιάτικος
 μεσογειακός μεσοδακτύλιος μεσοζωικός μεσοκοιλιακός μεσοκολπικός μεσοκυρτωτός
 μεσολαβητικός μεσολογγίτικος μεσομακροπρόθεσμος μεσομακροχρόνιος μεσομοριακός
 μεσοπλεύριος μεσοπολεμικός μεσοποτάμιος μεσοπρόθεσμος μεσοσπονδύλιος
 μεσοτονικός μεσοφυλικός μεσοφωνηεντικός μεσοχρόνιος μεσσηνιακός μεσσιανικός
 μεσόβιος μεσόγαιος μεσόγειος μεσόκοπος μεσόκυρτος μετάλλινος μετάξινος
 μετάρσιος μετέπειτα μετέωρος μεταβατικός μεταβιβάζων μεταβιβάσιμος
 μεταβιομηχανικός μεταβλητός μεταβολικός μεταβυζαντινός μεταγγίσιμος
 μεταγραφειοκρατικός μεταγραφικός μεταγωγικός μεταδημοκρατικός μεταδοτικός
 μεταεισαγωγικός μεταθέσιμος μεταθανάτιος μεταθεραπευτικός μεταθετικιστικός
 μεταθετός μεταιχμιακός μετακαπιταλιστικός μετακεντρικός μετακινήσιμος
 μετακλασικός μετακλητός μετακοινοβουλευτικός μετακρατικός μεταλαμπαδεύσιμος
 μεταλλευτικός μεταλλικός μεταλλογενετικός μεταλλογραφικός μεταλλοειδής
 μεταλλουργικός μεταλλοφόρος μεταλυκειακός μεταμαγικός μεταμεσημβρινός
 μεταμνημονιακός μεταμοντέρνος μεταμοντερνιστικός μεταμορφικός μεταμορφωσιγενής
 μεταμορφώσιμος μεταμφιεσμένος μεταναισθητικός μεταναστευτικός μετανιτσεϊκός
 μεταξάς μεταξένιος μεταξοΰφαντος μεταξοειδής μεταξοκλωστικός μεταξοπαραγωγός
 μεταπασχαλινός μεταπλαστικός μεταπλαστό μεταπλαστός μεταποιήσιμος
 μεταπολεμικός μεταπολιτευτικός μεταπρατικός μεταπτωτικός μεταρηματικός
 μεταρρυθμιστικός μεταρσιωτικός μετασεισμικός μετασκευαστικός μετασταθής
 μετασυναπτικός μετασχηματιστικός μετασχολικός μετατρέψιμος μετατραυματικός
 μεταφερτός μεταφορικός μεταφράσιμος μεταφραστέος μεταφραστικός μεταφυσικός
 μεταχειρισμένος μεταχρονολογημένος μεταψυχικός μεταψυχροπολεμικός μετεκλογικός
 μετεξεταστέος μετεπιθετικός μετευρετικός μετεωρίτικος μετεωρικός μετεωριτικός
 μετεωρολογικός μετεωροσκοπικός μετουσιαστικός μετοχικός μετρήσιμος μετρητικός
 μετριαστικός μετρικός μετριοπαθής μετριόφρονας μετριόφρων μετρολογικός
 μετωνυμικός μετωπιαίος μετωπικός μετωποκροταφικός μεφιστοφελικός μεφιτικός
 μηδαμινός μηδενικός μηδενιστικός μηδικός μηλίτης μηλικογαλακτικός μηλικός
 μηλοφόρος μημειακός μηνιαίος μηνιγγικός μηνιγγιτικός μηνοειδής μηνυτήριος
 μηρυκαστικός μητριαρχικός μητρικός μητρολογικός μητροπολιτικός μητρωνυμικός
 μηχανικός μηχανιστικός μηχανογραφικός μηχανοκίνητος μηχανολογικός
 μηχανουργικός μηχανοφόρος μηχανόβιος μιαρός μιασματικός μιγαδικός μιθριδατικός
 μικρασιατικός μικροαερόφιλος μικροαστικός μικροβιακός μικροβιοκτόνος
 μικροβιομηχανικός μικροβιοφόρος μικρογράμματος μικρογραφικός μικροδάκτυλος
 μικροκάμωτος μικροκέφαλος μικροκαμωμένος μικροκατεργάρης μικροκομματικός
 μικρολόγος μικρομέγαλος μικρομεσαίος μικρομετρικός μικρομούρης
 μικροπαραγοντικός μικροπαραταξιακός μικροπολιτικός μικροπρεπής μικροπρόσωπος
 μικροσκοπικός μικροτεχνικός μικροφιλόδοξος μικροφιλότιμος μικροφυής μικροχαρής
 μικρούλης μικρούλικος μικρούτσικος μικρόβιος μικρόγλωσσος μικρόθυμος
 μικρόμυαλος μικρόνους μικρός μικρόστομος μικρόσχημος μικρόσωμος μικρότερος
 μικρόφωνος μικρόχαρος μικρόψυχος μικτοβαρής μικτός μιλανέζικος μιλιμετρέ
 μιλιότονος μιμηματικός μιμητικός μιμικός μινιμαλιστικός μινιόν μινωικός μινόρε
 μισάνοιχτος μισάρικος μισαλλόδοξος μισελληνικός μισερός μισητός μισθοδίαιτος
 μισθολογικός μισθοσυντήρητος μισθοφορικός μισθωτικός μισθωτός μισθόβιος
 μισικός μισοάδειος μισογεμάτος μισοδουλεμένος μισοκαμένος μισοξαπλωμένος
 μισοπεθαμένος μισοψημένος μισόγυμνος μισόκλειστος μισόξενος μισός μισότρελος
 μιτροειδής μιχτός μνημειώδης μνημονιακός μνημονικός μνημοσυναισθηματικό
 μνησίκακος μοβ μοβόρικος μοβόρος μογγολικός μοδάτος μοιραίος μοιραστικός
 μοιρολατρικός μοιρόγραφτος μοιχικός μολασικός μολασσικός μολδαβικός
 μολυβένιος μολυβής μολυβδαινιούχος μολυβδούχος μολυβδόχρους μολυντικός
 μολύβδινος μονάζων μονάκριβος μονάλμπουρος μονάρμπουρος μονάχος μονέλικος
 μονήρης μοναδιαίος μοναδικός μοναρχικός μοναστηρίσιος μοναστηριακός μοναστικός
 μοναχικός μοναχός μονεμβασιώτικος μονεταριστικός μονιάτικος μονιστικός
 μονοαπευθυντικός μονοατομικός μονοβλαστικός μονογαμικός μονογενής
 μονοεδρικός μονοερωτικός μονοετής μονοζυγωτικός μονοζυγώτης μονοθάλαμος
 μονοθεϊστικός μονοκάταρτος μονοκέρατος μονοκατάληκτος μονοκινητήριος
 μονοκομματικός μονοκοτυλήδονος μονοκρυσταλλικός μονοκυτταρικός μονοκόκαλος
 μονοκότυλος μονοκύλινδρος μονοκύτταρος μονολεκτικός μονολεχτικός μονολιθικός
 μονολογικός μονομανής μονομελής μονομερής μονομερίτικος μονομεριάτικος
 μονομετοχικός μονοπέταλος μονοπίθανος μονοπαραγωγικός μονοπαραταξιακός
 μονοπλοειδής μονοποικιλιακός μονοπρόσωπος μονοπυρηνικός μονοπωλιακός
 μονοπύρηνος μονοσάνδαλος μονοσάνταλος μονοσέπαλος μονοσήμαντος μονοσεξουαλικός
 μονοστιβαδικός μονοσυλλαβικός μονοσύλλαβος μονοτάξιος μονοτονικός μονοτοπικός
 μονοτόκος μονοφασικός μονοφυής μονοφυσιτικός μονοφωνικός μονοχρωματικός
 μονοψωνιακός μονοϋβριδικός μονοϋδρικός μοντέρνος μοντερνιστικός μοντεσσοριανός
 μονόγαμος μονόγλωσσος μονόκαννος μονόκιλος μονόκλιτος μονόκλωνος μονόκωπος
 μονόπατος μονόπλευρος μονόπολος μονόπους μονόπρακτος μονόπτερος μονόριχτος
 μονόσημος μονόσπερμος μονόστηλος μονόστιχος μονότομος μονότονος μονότοξος
 μονόφθαλμος μονόφθογγος μονόφρων μονόφυλλος μονόφωνος μονόχηλος μονόχνοτος
 μονόχορδος μονόχρωμος μονόχωρος μονώνυχος μονώροφος μοραϊτικος μοργανατικός
 μορσικός μορτιτικός μορφικός μορφινομανής μορφογενετικός μορφολογικός
 μορφοσυντακτικός μορφωματικός μορφωτικός μοσκαναθρεμμένος μοσκαρίσιος
 μοσχαρήσιος μοσχαρίσιος μοσχοβίτικος μοσχοβόλος μοσχομυριστός μουγγός μουγκός
 μουλαρίσιος μουλλωχτός μουλωχτός μουντζούρης μουντιαλικός μουντρούχος μουντός
 μουρμουριστός μουρμούρης μουρντάρης μουρντάρικος μουρόχαυλος μουσάτος
 μουσαντένιος μουσειακός μουσειολογικός μουσικοθεατρικός μουσικοκριτικός
 μουσικός μουσκφός μουσοτραφής μουσουλμανικός μουστέριος μουσόληπτος μουσόφιλος
 μουχρός μοχθηρός μοχλικός μούλικος μούλος μούτικος μούτος μπάνικος μπάσος
 μπάσταρδος μπέικος μπέλος μπαγάσικος μπαγαμπόντικος μπαγαπόντης μπαγαπόντικος
 μπαγιονέτ μπακάλικος μπακαλίστικος μπακιρένιος μπακλαβαδωτός μπαλαρινέ
 μπαμπακένιος μπαμπακερός μπανάλ μπας κλας μπασκετικός μπασμένος μπαστάρδικος
 μπατάλικος μπατακτσής μπαταξής μπαταχτσής μπεζ μπεηλίδικος μπεκιάρικος
 μπεμπέ μπεμπεδίστικος μπερεκετιλήδικος μπερεκετλήδικος μπερεκετλίδικος
 μπερκετλίδικος μπερμπάντικος μπερξονικός μπεϋζιανή μπεϋζιανός μπηχτός
 μπινιάρης μπιρμπιλομάτης μπιστικός μπλάβος μπλαζέ μπλαμπλάς μπλε μπλεμαρέν
 μποέμικος μπολσεβίκικος μπολσεβικικός μπορετός μπορντελιάρης μπουγιόζικος
 μπουμπουνοκέφαλος μπουφόνικος μπούζι μπραιζέ μπρεζέ μπριόζος μπροσέ μπροστινός
 μπρούμυτος μπρούντζινος μπρούσικος μπρούσκος μπρούτζινος μπόλικος μπόσικος
 μυαλγικός μυαλωμένος μυασθενικός μυατροφικός μυγδαλάτος μυγιάγγιχτος μυελικός
 μυελοειδής μυελώδης μυζητικός μυθικός μυθιστορηματικός μυθιστορικός
 μυθογραφικός μυθολογικός μυθομανής μυθοπλαστικός μυθοποιητικός μυθώδης
 μυκηναϊκός μυκητοειδής μυκητοκτόνος μυκητολογικός μυκητώδης μυκονιάτικος
 μυλένιος μυλλωμένος μυξαδενικός μυξιάρης μυξώδης μυοδερματικός μυοκτόνος
 μυοσυντονιστικός μυριάκριβος μυριαρίφνητος μυριοστός μυριστικός μυριόνεκρος
 μυριόστομος μυριόφωνος μυρμηγκικός μυρμηκικός μυροβόλος μυροφόρος μυρτοειδής
 μυρωδάτος μυρωδικός μυσαρός μυστήριος μυσταγωγικός μυστακοφόρος μυστηριακός
 μυστικιστικός μυστικοπαθής μυστικός μυτερός μυωπικός μυϊκός μυώδης
 μωβ μωροπίστευτος μωροφιλόδοξος μωρόπιστος μωρός μωρόσοφος μωσαϊκός μόνιμος
 μόνος μόρσιμος μόρτικος μόσχειος μύξης μύριοι μύρτινος μύχιος μώνυχος νέγρικος
 νέτος νήδυμος νήνεμος ναβάχο ναζιάρης ναζιάρικος ναζιστικός ναζωραίος
 νανομελής νανοτεχνολογικός νανουριστικός νανουριστός νανοφυής νανοφυία
 νανώδης ναξιακός ναξιώτικος ναπολεόντειος ναπολιτάνικος ναρκαλιευτικός
 ναρκομανής ναρκωτικός ναρκωτισμός ναστός νατουραλιζέ νατουραλιστικός νατοϊκός
 ναυαγοσωστικός ναυαγό ναυαγός ναυαρχικός ναυκληρικός ναυλομεσιτικός
 ναυπηγήσιμος ναυπηγικός ναυπηγοεπισκευαστικός ναυπλιώτικος ναυταθλητικός
 ναυτικός ναυτιλιακός ναυτιλλόμενος ναυτιών ναυτολογήσιμος ναυτολογικός
 νεαντερτάλειος νεαρός νεαττικός νεγκλιζέ νεγροειδής νεκρικός νεκρογέννητος
 νεκροδόχος νεκροφάγος νεκροφαγικός νεκροφανής νεκροφοβικός νεκρωτικός νεκρός
 νεκρόφιλος νεκρόψυχος νεκρώσιμος νεοέλθων νεοανθρωπιστικός νεοαποικιοκρατικός
 νεοαφιχθείς νεογέννητος νεογενής νεογιλός νεογνικός νεογνολογικός νεογοτθικός
 νεοδίδακτος νεοδιόριστος νεοεβραϊκός νεοελληνικός νεοεμπρεσιονιστικός
 νεοκαπιταλιστικός νεοκλασικός νεολαιίστικος νεολαμπής νεολατινικός νεολιθικός
 νεομνημονιακός νεοναζιστικός νεονικοτινοειδής νεοπαγής νεοπαγανιστικός
 νεοπλασματικός νεοπλατωνικός νεορεαλιστικός νεορομαντικός νεοσκαφής
 νεοτουρκικός νεοτόκος νεοφανής νεοφασιστικός νεοφερμένος νεοφιλελεύθερος
 νεοφροϋδικός νεοφυής νεοφυτικός νεοφύτευτος νεοφώτιστος νεοϊμπρεσιονιστικός
 νεραϊδογέννητος νεραϊδογεννημένος νεραϊδοπαρμένος νεριτικός νεροκαμένος
 νερόβραστος νερόχαρος νερώνειος νετρονικός νευραλγικός νευραξονικός
 νευρασθενικός νευρειληματικός νευριαστικός νευρικός νευροαναπτυξιακός
 νευροεκφυλιστικός νευροενδοκρινολογικός νευροληπτικός νευρολογικός νευρομυικός
 νευροπαθής νευροπαθητικός νευροπαθολογικός νευροφυτικός νευροψυχιατρικός
 νευροψυχολογικός νευρωνικός νευρωσικός νευρωτικός νευρώδης νευτόνιος
 νεφάριος νεφελοβάμων νεφελοειδής νεφελοσκέπαστος νεφελοσκεπής νεφελώδης
 νεφοσκεπής νεφοσκοπικός νεφοϋπολογιστικός νεφράτος νεφραγγειακός νεφραλγικός
 νεφριδικός νεφρικός νεφριτικός νεφροειδής νεφρολιθικός νεφρολογικός νεφροπαθής
 νεωτερικός νεωτεριστικός νεόβγαλτος νεόδμητος νεόκοπος νεόκτιστος νεόνυμφος
 νεόπτωχος νεότατος νεότερος νεότευκτος νεότοκος νεόφερτος νεόφυτος νεόχτιστος
 νεώτερος νηκτικός νηλεής νημάτινος νηματοειδής νηματοποιητικός νηματώδης
 νηπενθής νηπιακός νηπιώδης νηπτικός νησιωτικός νησιώτικος νησοπυριτικός
 νηστικός νηφάλιος νηόμορφος νιγηριανός νικέλινος νικήσιμος νικελιούχος
 νικηφόρος νικοτινικός νικοτινοειδής νιοβιούχος νιογέννητος νιος νιοστός
 νισυριώτικος νιτρικός νιτροκυτταρινικός νιτρώδης νιτσεϊκός νιχιλιστικός
 νιόπαντρος νιόφερτος νιώτικος νοήμονας νοήμων νοεμβριάτικος νοεμβριανός νοερός
 νοησιαρχικός νοητικός νοητός νοθογενής νοικοκυρίστικος νοκ-άουτ νομαδικός
 νομικίστικος νομικοπολιτικός νομικοταξικός νομικοτεχνικός νομικός
 νομιμοφανής νομιμόφρων νομιναλιστικός νομισματικός νομισματοκοπικός
 νομοθετικός νομοκατεστημένος νομοκρατούμενος νομολογικός νομοπαρασκευαστικός
 νομοτελειακός νομοτελεστικός νομοτεχνικός νομότυπος νοολογικός νορβηγικός
 νορμανδικός νοσηλευτικός νοσηρός νοσογόνος νοσοκομειακός νοσοκομειοκεντρικός
 νοσομανής νοσοφόρος νοσταλγικός νοστιμούλης νοστιμούλικος νοστιμούτσικος
 νοτερός νοτιανατολικός νοτινός νοτιοαμερικανικός νοτιοανατολικός
 νοτιοατλαντικός νοτιοαφρικανικός νοτιοβιετναμικός νοτιοδυτικός νοτιοειρηνικός
 νοτιοκορεατικός νουνεχής ντέρτικος ντίβα νταμαρήσιος νταμαρίσιος νταμωτός
 νταντελωτός ντεκαποτάμπλ ντεκαφεϊνέ ντεκλαρέ ντεκλασέ ντεκουπαριστός
 ντεμοντέ ντενεκεδένιος ντεπασέ ντετερμινιστικός ντεψίζης ντεϊστικός ντηνιακός
 ντιστεγκές ντοπέ ντουμ-ντουμ ντουμπλ φας ντούζικος ντούρος ντρέτος ντρίτος
 ντρεξουδιάρης ντροπαλός ντροπιάρης ντροπιαστικός ντόμπρος ντόπιος νυκτερινός
 νυκτός νυμφαίος νυμφικός νυμφομανής νυν νυσταλέος νυφιάτικος νυφικός νυχάτος
 νυχτιάτικος νυχτόβιος νωδός νωθρός νωπός νωτιαίος νωχελής νωχελικός νόβιαλ
 νόμιμος νόστιμος νότιος νύκτιος νύχτιος ξάγρυπνος ξάστερος ξέγνοιαστος
 ξέθαρρος ξέθωρος ξέμακρος ξέμπαρκος ξέμπλεκος ξένιος ξένοιαστος ξένος ξέντυτος
 ξέπλεγος ξέπλεκος ξέπλεχτος ξέπνοος ξέσκεπος ξέστηθος ξέστρωτος ξέφραγος
 ξέφυλλος ξέφωτος ξέχειλος ξέχωρος ξίκικος ξαγκαθιά ξακουσμένος ξακουστός
 ξανθοκόκκινος ξανθομάλλα ξανθομάλλης ξανθομάλλικο ξανθομούστακος ξανθοτρίχης
 ξανθωπός ξανθόμαλλος ξανθός ξανθότριχος ξαντικός ξαντός ξαπλωμένος ξαπλωτός
 ξασπρουλιάρης ξαφνικός ξεβούλωτος ξεβράκωτος ξεγάνωτος ξεγυριστός ξεγύμνωτος
 ξεδιάντροπος ξεδοντιάρης ξεθεωτικός ξεθηλύκωτος ξεκάθαρος ξεκάλτσωτος
 ξεκαπάκωτος ξεκαπέλωτος ξεκαπίστρωτος ξεκαρδιστικός ξεκαύλωτος ξεκλείδωτος
 ξεκουτιάρης ξεκούδουνος ξεκούμπωτος ξεκούραστος ξεκούρδιστος ξεκούρντιστος
 ξεκρέμαστος ξεκωλιάρης ξεκόλλητος ξεμέθυστος ξεμαλλιάρης ξεμαλλιασμένος
 ξεματιασμένος ξεμπράτσωτος ξενέρωτος ξενηστικωμένος ξενικός ξενοίκιαστος
 ξενοκίνητος ξενοκρατικός ξενομανής ξενοπρεπής ξενοφανής ξενοφοβικός
 ξενόγλωσσος ξενόδουλος ξενότροπος ξενόφερτος ξενόφιλος ξενόφοβος ξενόφωνος
 ξερικός ξεροκέφαλος ξεροψημένος ξερός ξεσέλωτος ξεσαβούρωτος ξεσαμάρωτος
 ξεσκέπαστος ξεσκούφωτος ξεστός ξετσίπωτος ξεφούσκωτος ξεχαρβάλωτος
 ξεχασιάρης ξεχτένιστος ξεχωριστός ξεψάρωτος ξημαρισμένος ξηραντικός
 ξηρός ξηρόφιλος ξιδάτος ξινισμένος ξινούτσικος ξινόγλυκος ξινός ξιπασιάρης
 ξιφήρης ξιφοειδής ξιφοφόρος ξομπλιαστός ξορκισμένος ξούτσκος ξυλάρμενος
 ξυλεμπορικός ξυλογλυπτικός ξυλογραφικός ξυλοειδής ξυλοπόδαρος ξυλοσκέπαστος
 ξυλοφάγος ξυλοχρωστικός ξυλόγλυπτος ξυλόσοφος ξυλόστρωτος ξυλόφρακτος ξυλώδης
 ξυπνός ξυπόλητος ξυπόλυτος ξυριστικός ξυστικός ξυστός ξωτικός ξύλινος ξύπνιος
 ξώφτερνος οβάλ οβελιαίος ογαμικός ογδοηκονθήμερος ογδοηκονταετής ογδοντάχρονος
 ογκομετρικός ογκωδέστερος ογκώδης ογλήγορος ογρός οδηγητικός οδηγικός οδικός
 οδομετρικός οδοντιατρικός οδοντικός οδοντογραφικός οδοντοειδής
 οδοντοπρόφερτος οδοντορραγικός οδοντοτεχνικός οδοντοφατνιακός οδοντοφόρος
 οδοντόφωνος οδοποιητικός οδυνηρός οδυσσειακός οδωνυμικός οζαινικός οζαινώδης
 οζοντομετρικός οζώδης οθνείος οθωμανικός οθωνικός οθώνειος οιακοφόρος οιδαλέος
 οιδιπόδειος οικήσιμος οικείος οικειοθελής οικιακός οικιστικός οικογενειακός
 οικοδίαιτος οικοδομήσιμος οικοδομικός οικοδομοτεχνικός οικολογικός
 οικονομικός οικονομολογικός οικονομοτεχνικός οικονόμος οικοσημικός
 οικοτεχνικός οικοτουριστικός οικουμενικός οικουρός οικτίρμων οικτρός οικόσιτος
 οινοβαρής οινοβαφής οινοειδής οινολογικός οινομανής οινομετρικός οινοπαραγωγός
 οινοπνευματοποιήσιμος οινοπνευματούχος οινοπνευματώδη οινοπνευματώδης
 οινοχαρής οινόφιλος οινώδης οισοφάγειος οισοφαγικός οιστρήλατος οκαδιάρικος
 οκνός οκτάγωνος οκτάεδρος οκτάμηνος οκτάπλευρος οκτάπους οκτάστηλος οκτάστιχος
 οκτάτευχος οκτάτομος οκτάφωνος οκτάχορδος οκτάχρονος οκτάωρος οκταήμερος
 οκταδικός οκταετής οκτακοσιοστός οκτακόσιοι οκταμελής οκταπλάσιος οκταπλούς
 οκτασέλιδος οκτασύλλαβος οκταψήφιος οκταώροφος οκτωβριάτικος οκτωβριανός
 ολάκερος ολάνοιχτος ολάρφανος ολάσπρος ολέθριος ολίγιστος ολίγος ολιγάνθρωπος
 ολιγαρκής ολιγαρχικός ολιγοέξοδος ολιγοήμερος ολιγοβαρής ολιγογράμματος
 ολιγοδάπανος ολιγοδίαιτος ολιγοδύναμος ολιγοεδρικός ολιγοετής ολιγοκτήμων
 ολιγομελής ολιγομερής ολιγοπράγμων ολιγοσέλιδος ολιγοστός ολιγοσύλλαβος
 ολιγοφάγος ολιγοχρήματος ολιγοχρόνιος ολιγόζωος ολιγόθερμος ολιγόκαρδος
 ολιγόκοσμος ολιγόλεπτος ολιγόλογος ολιγόνους ολιγόπιστος ολιγόσιτος
 ολιγόστιχος ολιγόταστος ολιγότεκνος ολιγόχρονος ολιγόψυχος ολιγόωρος ολικός
 ολιστικός ολλανδέζικος ολλανδικός ολοήμερος ολογάλανος ολογλήγορος ολογραφικός
 ολοζώντανα ολοζώντανος ολοκάθαρος ολοκαίνουργος ολοκαίνουριος ολοκληρωμένος
 ολοκληρώσιμος ολοκλησικός ολοκυκλικός ολοκόκκινος ολομέταξος ολομέτωπος
 ολομερής ολομόναχος ολονύκτιος ολονύχτιος ολοπαγής ολοπαθής ολοπράσινος
 ολοπόρφυρος ολοσκέπαστος ολοσκότεινος ολοστρόγγυλος ολοστόλιστος ολοσυστημικός
 ολοφάνερος ολοφανής ολοφυρόμενος ολυμπιακός ολυνθιακός ολόασπρος ολόγεμος
 ολόγιομος ολόγλυκος ολόγλυφος ολόγραφος ολόγυμνος ολόγυρος ολόδροσος ολόημερος
 ολόθυμα ολόθυμος ολόιδιος ολόισος ολόκαρδος ολόκλειστος ολόκληρος ολόκορμος
 ολόλευκος ολόμαλλος ολόμαυρος ολόμοιος ολόξανθος ολόξενος ολόπλευρος ολόπρωτος
 ολόσκεπος ολόστεγνος ολόστρωτος ολόσωμος ολόφρεσκος ολόφωτος ολόχαρος
 ολόχρωμος ολόψυχος ολύμπιος ομήλικος ομήλιξ ομήρειος ομαδικός ομαλός ομηρικός
 ομιχλιασμένος ομιχλώδης ομοαξονικός ομογάλακτος ομογάλαχτος ομογάστριος
 ομογενειακός ομογενοποιημένος ομογονεϊκός ομογραφικός ομοεθνής ομοειδής
 ομοετής ομοζυγωτικός ομοζυγώτης ομοιογενής ομοιοεπαγγελματικός ομοιοκάταρκτος
 ομοιοκατάληχτος ομοιομερής ομοιοπαθής ομοιοπαθητικός ομοιοπολικός
 ομοιοτροπικός ομοιούσιος ομοιωματικός ομοιόβαθμος ομοιόγραφος ομοιόθερμος
 ομοιόπτωτος ομοιόσχημος ομοιότροπος ομοιότυπος ομοιόφωνος ομοιόχρονος
 ομοκεντρικός ομολογητικός ομολογιακός ομολογιούχος ομομήτριος ομοούσιος
 ομοπλαστικός ομορφοφτιαγμένος ομορφότατος ομορφότερος ομοσκεδαστικός
 ομοταγής ομοτράπεζος ομοτυπικός ομοφοβικός ομοφυλοφιλικός ομοφυλόφιλος
 ομπρελοειδής ομφάλιος ομφαλικός ομφαλοειδής ομφαλοκυστικός ομφαλοπλακουντιακός
 ομφαλώδης ομόγλωσσος ομόγονος ομόγραφος ομόδικος ομόδοξος ομόζυγος ομόηχος
 ομόθυμος ομόκεντρος ομόλογος ομόρριζος ομόρρυθμος ομόσημος ομόσιτος ομόσπονδος
 ομότιμος ομότιτλος ομότοιχος ομότονος ομότροπος ομότροφος ομότυπος ομόφρων
 ομόφωνος ομόχρονος ομόχρωμος ομόψηφος ομόψυχος ομώνυμος ονδουρικός
 ονειρευτός ονειρικός ονειρογέννητος ονειροκριτικός ονειροπαρμένος
 ονειροπολικός ονειροπόλος ονειρωκτικός ονειρόπλαστος ονειρώδης ονικός ονλάιν
 ονομαστικός ονομαστός ονοματικός ονοματοκρατικός ονοματολογικός ονοματοποίητος
 οντολογικός οντουλέ ονυχαίος ονυχοειδής ονυχοφόρος οξένιος οξαλικός οξεάντοχος
 οξειδωτικός οξειδώσιμος οξιδωτικός οξιδώσιμος οξικός οξιτανικός οξονικός
 οξυγονικός οξυγονούχος οξυγώνιος οξυδερκής οξυκέφαλος οξυκόρυφος οξυμετρικός
 οξύγναθος οξύθυμος οξύινος οξύληκτος οξύμαχος οξύμωρος οξύνους οξύρρυγχος οξύς
 οξύφυλλος οξύφωνος οξύχηος οπάκ οπίσθιος οπαίος οπαλιοειδής οπαλιόχρους
 οπιομανής οπιοφάγος οπιούχος οπισθοβατικός οπισθογεμής οπισθοδρομικός
 οπισθοφύλακας οπισθοχωρητικός οπισθόβουλος οπισθόγραφος οπιώδης οπλομαχητικός
 οπορτουνιστής οπορτουνιστικός οπτικοακουστικός οπτικός οπτιμιστικός οπτός
 οπωροφόρος οπώδης ορατικός ορατός οργίλος οργανικός οργανογενής
 οργανογραφικός οργανογόνος οργανοειδής οργανοληπτικός οργανολογικός
 οργανοχημικός οργανωτικοδιοικητικός οργανωτικός οργανώσιμος οργασμικός
 οργιστικός οργιώδης οργώσιμος ορειβατικός ορεινός ορειχάλκινος ορειχαλκόχρους
 ορεξάτος ορεογραφικός ορεομετρικός ορεσίβιος ορεχτικός ορθάνοιχτος
 ορθογραφικός ορθογώνιος ορθοδοντικός ορθοεπής ορθολογικός ορθολογιστικός
 ορθοπαιδικός ορθοπεδικός ορθοπρωκτικός ορθοπτικός ορθοπυριτικός ορθοσκοπικός
 ορθρινός ορθόβουλος ορθόδοξος ορθόδρομος ορθός ορθόστοιχος ορθότοπος οριακός
 ορισμένος ορισματικός οριστέος οριστικός ορκοδοτικός ορκωτός ορμέμφυτο
 ορμητικός ορμογόνος ορμονικός ορμονολογικός ορνιθοειδής ορνιθοκομικός
 ορνιθόμορφος ορνιθόμυαλος ορνιθόρρυγχος οροαιματώδης ορογενετικός ορογραφικός
 ορολογικός ορομετρικός οροφιαίος ορτός ορυκτογεωλογικός ορυκτογραφικός
 ορυκτοτεχνικός ορυκτός ορφανικός ορφανός ορφικός ορφνός ορχηστικός ορχηστρικός
 ορχιτικός ορώδης οσκαρικός οσμήρης οσμανικός οσμηγόνος οσμηρός οσμικός
 οσμογόνος οσμομετρικός οσπριοειδής οσπριοφάγος οστέινος οστεοαρθρικός
 οστεογόνος οστεοειδής οστεολογικός οστεολυτικός οστεομετρικός οστεομυελικός
 οστεοφόρος οστεωδυνικός οστεωτικός οστεόμορφος οστεώδης οστικός οστρακοειδής
 οστρακόδερμος οστρακώδης οστρογοτθικός οσφραντικός οσφρητικός οσφυαλγικός
 οσφυϊκός οτρηρός ουαλικός ουαλονικός ουγγαρέζικος ουγγρικός ουδέτερος
 ουδετερόφιλος ουκρανικός ουλόθριξ ουλώδης ουμανιστικός ουνιταριανός ουνιτικός
 ουραίος ουραλοαλταϊκός ουρανής ουρανικός ουρανισκόφωνος ουρανοβάμων
 ουρανογραφικός ουρανοκατέβατος ουρανομήκης ουρανόπεμπτος ουρανόσταλτος
 ουρηθρικός ουρηθροεντερικός ουρηθροκολπικός ουρηθροσκοπικός ουρητηροκολπικός
 ουρητικός ουρικός ουρογεννητικός ουροδόχος ουρολάγνος ουρολογικός
 ουροποιογεννητικός ουροσκοπικός ουρουγουανικός ουροφόρος ουσιαστικός ουσιώδης
 ουτοπικός ουτοπιστικός οφειλετικός οφθαλμιατρικός οφθαλμικός οφθαλμολογικός
 οφθαλμοφανής οφθαλμοφανώς οφιοειδής οφιολιθικός οφιόδηκτος οφλάιν οφτός
 οχηματαγωγός οχλαγωγικός οχληρός οχλοκρατικός οχτάγωνος οχτάεδρος οχτάμηνος
 οχτάστηλος οχτάστιχος οχτάστυλος οχτάτομος οχτάχρονος οχτάωρος οχταήμερος
 οχτακοσιοστός οχτακόσιοι οχταμελής οχταπλάσιος οχταπλός οχτασύλλαβος
 οχτωβριανός οχυρωματικός οχυρωτικός οχυρός οψίπλουτος οψιγενής οψιμαθής ούλος
 οὐσιαστικός πάγιος πάγκαλος πάγκοινος πάλλευκος πάμπλουτος πάμπολλοι πάμφθηνος
 πάμφωτος πάναγνος πάνδημος πάνινος πάνοπλος πάνσεπτος πάνσοφος πάρεργος
 πάρθιος πάριος πάρωρος πάτριος πένθιμος πέτρινος πέτσικος πέτσινος πήλινος
 πίβουλος πίσω πίτσικος παγανιστικός παγγερμανιστικός παγερός παγετωνικός
 παγιωτής παγιωτοπικός παγκάκιστος παγκαλόμορφος παγκατευθυντικός
 παγκρεατικός παγκρητικός παγκυπριακός παγκόσμιος παγοδρομικός παγοθραυστικός
 παγχαλκιδικός παγωμένος παγόπληκτος παζαρίσιος παζαριάτικος παθητικοεπιθετικός
 παθιάρης παθιάρικος παθογόνος παθολογικός παθολογοανατομικός παθοπλάνταχτος
 παιδαγωγικός παιδαριώδης παιδεραστικός παιδευτικός παιδιάστικος παιδιάτικος
 παιδιακίστικος παιδιατρικός παιδικός παιδοκομικός παιδολογικός παιδομετρικός
 παινεσιάρης παιχνιδιάρης παιχνιδιάρικος πακιστανικός παλίλλογος παλίμβουλος
 παλίμψηστος παλίνδρομος παλαίτυπος παλαίφατος παλαβός παλαιικός
 παλαιογεωγραφικός παλαιογραφικός παλαιοεθνολογικός παλαιοζωικός
 παλαιοκομματικός παλαιολιθικός παλαιοντολογικός παλαιοπωλικός
 παλαιστίνιος παλαιστικός παλαιστινιακός παλαιός παλαιότατος παλαιότερος
 παλαμικός παλαμοειδής παλαμοκροτώ παλαμοσχιδής παλατιανός παλικαρίσιος
 παλινδρομικός παλιομοδίτικος παλιομουράτος παλιρροιακός παλιρροϊκός παλιός
 παλλακωνικός παλλαμιακός παλλαϊκός παλληκαρίσιος παλμικός παμβαλκανικός
 παμμέγιστος παμμαγνησιακός παμμακεδονικός παμμαύρος παμμεσηνιακός παμπάλαιος
 παμπειραϊκός παμπελοποννησιακός παμπληθής παμπόνηρος παμφάγος πανάγαθος
 πανάθλιος πανάκριβος πανάμωμος πανάρχαιος πανάσχημος πανάχραντος πανέ
 πανένδοξος πανέξυπνος πανέρημος πανέρμος πανέτοιμος πανίερος πανίσχυρος
 παναθηναϊκός παναιτωλικός πανακαρνανικός παναμερικανικός παναμώμητος
 παναραβικός παναργολικός παναρκαδικός πανασιατικός παναττικός παναφρικανικός
 πανδημικός πανδραμαϊκός πανεδεσσαϊκός πανεθνικός πανελλήνιος πανελλαδικός
 πανεπιστημιακός πανεργατικός πανευβοϊκός πανευδαίμων πανευρωπαϊκός πανευτυχής
 πανηγυρικός πανηγυριώτικος πανηλειακός πανηλικιακός πανηπειρωτικός
 πανθεσσαλικός πανθεϊστικός πανθρακικός πανικόβλητος πανινός πανιώνιος
 πανομοιότυπος πανοραματικός πανοραμικός πανορθοδοξιακός πανορθόδοξος
 πανουκλιασμένος πανούργος πανσεβάσμιος πανσερραϊκός πανσλαβικός πανσλαβιστικός
 παντέρημος παντέρμος παντελής παντελεήμων παντοίος παντοδαπός παντοδύναμος
 παντοθενικός παντοκατευθυντικός παντοκρατορικός παντομιμικός παντοτινός
 παντοφλέ παντοφοβικός παντρεμένος πανωλόβλητος πανόδετος πανόμοιος πανόσιος
 πανώριος παπίσιος παπαγαλίστικος παπαδίστικος παπανδρεϊκός παπικός
 παπουτσωμένος παππουδίστικος παπυρικός παπυρογραφικός παπυρολογικός παπύρινος
 παράβυστος παράγωγος παράγωνος παράδοξος παράθυρος παράκαιρος παράκεντρος
 παράκουος παράκτιος παράλιος παράλληλος παράλογος παράλος παράλυτος παράμερος
 παράνθιος παράνομος παράνους παράξενος παράουρος παράπλευρος παράπλευστος
 παράσπονδος παράταιρος παράτολμος παράτονος παράτροπος παράτυπος παράφορος
 παράφωνος παράχορδος παρένθετος παρέστιος παρήγορος παρήκοος παρήλικος
 παρήμερος παρίσθμιος παραίτιος παραβαλβιδικός παραβατικός παραβιωτικός
 παραβρασμένος παραγγελιοδοχικός παραγγελτικός παραγεμιστός παραγοντίστικος
 παραγωγίσιμος παραγωγικός παραδασόβιος παραδείσιος παραδειγματικός
 παραδεισιακός παραδεκτός παραδεχτός παραδοξολόγος παραδοσιακός παραδοτέος
 παραδόπιστος παραεκκλησιαστικός παραθαλάσσιος παραθεριστικός παραθετικός
 παραινετικός παραισθησιογόνος παραισθητικός παρακάτω παρακαλεστικός
 παρακαλετός παρακαμπτήριος παρακαμπτικός παρακατιανός παρακείμενος
 παρακεντέδικος παρακεντρικός παρακινδυνευτικός παρακινητικός παρακλαδικός
 παρακλινικός παρακμάζων παρακμιακός παρακοιμώμενος παρακρατικός παραλίμνιος
 παραληρητικός παραλιακός παραλλακτικός παραλληλεπίπεδος παραλληλόγραμμος
 παραλογιστικός παραλυτικός παραμήτριος παραμαγνητικός παραμακρύς παραμεθόριος
 παραμεσόγειος παραμετρικός παραμετροποιήσιμος παραμητρικός παραμικρός
 παραμυθένιος παραμυθητικός παραμόνιμος παρανεφρικός παρανιός παρανοειδής
 παρανοϊκός παραξόνιος παραπανήσιος παραπανίσιος παραπανιστός παραπειστικός
 παραπλήσιος παραπλανητικός παραπληκτικός παραπληρωματικός παραπολιτικός
 παραπονιάρικος παραποτάμιος παραρίνιος παραρρίνιος παραρρίνιων παραρριξιμιός
 παρασημαντικός παρασημοφορημένος παρασιτικός παρασιτοκτόνος παρασιτολογικός
 παρασκηνιακός παρασούσουμος παρασπονδυλικός παραστατικός παραστρατιωτικός
 παρασυγγενικός παρασυμπαθητικός παρασύνθετος παρατακτικός παραταξιακός
 παρατετραμμένος παρατηρητικός παρατυφικός παραφιλικός παραφραστικός παραφυλία
 παραφυλλωματικός παραφυσικός παραχειμαστικός παραχριστιανικός παραχωρητικός
 παραϊατρικός παρδαλός παρείσακτος παρεγκεφαλιδικός παρεγχυματικός
 παρειακός παρεκβατικός παρεκκλίνων παρελθοντικός παρελκυστικός παρελκόμενος
 παρεμφατικός παρεμφερής παρενδυτικός παρενθετικός παρενοχλητικός παρεντερικός
 παρεξηγησιάρης παρεπίδημος παρεπιδημών παρεστιγμένος παρετυμολογικός
 παρηγορητικός παρηχητικός παρθένος παρθενικός παρθενωπός παρθικός παριανός
 παρισινός παρλιακός παρμένος παρνασσιακός παροδικός παροιμιακός παροιμιώδης
 παροντικός παροξυντικός παροξυσμικός παροξύτονος παρορμητικός παροτρυντικός
 παροχετευτικός παρρησιαστικός παρτιζάνικος παρτσακλός παρυδάτιος παρωδιακός
 παρόμοιος παρόμοιος παρόχθιος παρών παρώνυμος πασέ πασίγνωστος πασίδηλος
 πασαλίδικος πασιφανής πασιφιστικός πασπάτης πασπαλισμένος πασπαλιστός
 πασσαλόκτιστος πασσαλόπηκτος παστρικός παστός πασχαλιάτικος πασχαλινός
 πατεντάτος πατερναλιστικός πατητός πατικωμένος πατμιακός πατραϊκός
 πατρικός πατρινός πατριωτικός πατρογονικός πατρολογικός πατροπαράδοτος
 πατρωνυμικός πατρώος πατσόκοιλος παυσίλυπος παυσίπονος παφιλένιος
 παχουλός παχυλός παχυντικός παχύδερμος παχύρρευστος παχύς παχύσαρκος παχύσκος
 παχύτερος παχύφυλλος πείσμων πεδιλωτός πεδινός πεζικός πεζογραφικός
 πεζολογικός πεζοναυτικός πεζοπορικός πεζοπόρος πεζόμορφος πεζός πεθαμένος
 πειθήνιος πειθαρχικός πειναλέος πειραιώτικος πειρακτικός πειραματικός
 πειραχτικός πειραϊκός πεισιθάνατος πεισματάρης πεισματάρικος πεισματικός
 πειστικός πειστικότερος πελάγιος πελαγίσιος πελαγικός πελαγοδρόμος πελασγικός
 πελατοκεντρικός πελεκητός πελεκυφόρος πελελός πελιδνός πελματιαίος πελματικός
 πελώριος πεμπταίος πεμπτιάτικος πεμπτουσιώδης πενηντάρης πενηντάρικος
 πενηνταπεντάχρονος πενθήμερος πενθερικός πενθημιμερής πενιέ πενιχρός
 πεντάγωνος πεντάδιπλος πεντάεδρος πεντάκλιτος πεντάκλωνος πεντάκλωστος
 πεντάλεπτος πεντάμετρος πεντάμηνος πεντάμορφος πεντάξενος πεντάπλευρος
 πεντάπρακτος πεντάπυλος πεντάρικος πεντάρφανος πεντάσημος πεντάστιχος
 πεντάτομος πεντάφυλλος πεντάφωνος πεντάφωτος πεντάχορδος πεντάχρονος
 πεντάωρος πενταήμερος πενταβρωμιούχος πενταγωνικός πενταγώνιος πενταδάκτυλος
 πενταδικός πενταετής πεντακάθαρος πεντακοσιοστός πεντακόσιοι πεντακόσοι
 πενταμερής πεντανικός πεντανόστιμος πενταπέταλος πενταπλάσιος πενταπλούς
 πεντασύλλαβος πενταψήφιος πεντελίσιος πεντελικός πεντηκονθήμερος
 πεντοζάλης πεντόκλιτος πεπιεσμένος πεπλανημένος πεπολιτισμένος πεπονοειδής
 πεπρωμένος πεπτικός περήφανος περίακτος περίβλεπτος περίγλυφος περίδακρυς
 περίδοξος περίεργος περίκλειστος περίκομψος περίλαμπρος περίλειστος περίλυπος
 περίοπτος περίπλοκος περίπτερος περίπτυστος περίπυστος περίσκεπτος περίσκιος
 περίσσος περίστρεπτος περίστυλος περίτεχνος περίτμητος περίτονος περίτρανος
 περίφημος περίφοβος περίφρακτος περίφραχτος περίφροντις περίχαρος περίχρυσος
 περαστικός περαστός περατός περβολάρικος περβολαρίσιος περγαμηνοειδής
 περιαιρετός περιαλγής περιαρθρικός περιαστικός περιαυγής περιαυτολόγος
 περιβαλλοντικός περιβαλλοντολογικός περιβολάρικος περιβολίσιος περιβολαρίσιος
 περιγάμητος περιγέλαστος περιγελαστικός περιγεννητικός περιγραφικός
 περιδεής περιεδρικός περιεκτικός περιεμφραγματικός περιεχτικός περιζήτητος
 περιθηλαίος περιθωριακός περικαλλής περικαρδικός περικαρπιακός περικαρπικός
 περικλεής περιλάλητος περιλαμπής περιληπτικός περιλιμπανόμενος περιμάχητος
 περιμητρικός περιοδεύον περιοδικός περιοδοντικός περιορίσιμος περιοριστικός
 περιουσιακός περιοχικός περιούσιος περιπαθής περιπαικτικός περιπαιχτικός
 περιπετειώδης περιπλανητικός περιποιητικός περιπολικός περιπόθητος περιρρέων
 περισκωληκοειδικός περισπούδαστος περισσευάμενος περισσευούμενος περισσός
 περισταλτικός περιστασιακός περιστατικός περιστερίσιος περιστροφικός
 περιτραχήλιος περιττοδάκτυλος περιττολόγος περιττοσύλλαβος περιττωματικός
 περιφανής περιφερής περιφερειακός περιφερικός περιφλεγής περιφραστικός
 περιφρονητικός περιχαρής περιχυτός περιώνυμος περμανάντ περονιαίος περονοφόρος
 περπατάρης περσικός περσινός περσότερος περυσινός πεσιμιστικός πεσμένος
 πεταλοειδής πεταλωτικός πεταλωτός πεταχτούλης πεταχτός πετεινόμυαλος πετρένιος
 πετραρχικός πετρελαιοειδής πετρελαιοκίνητος πετρελαιοπιθανός πετρελαιοφόρος
 πετρογενετικός πετρογραφικός πετροφυής πετροχημικός πετρωτός πετρόλ πετρόψυχος
 πετσένιος πετσετέ πετσετένιος πετυχημένος πευκόφυτος πεόμορφος πεόσχημος
 πηγαίος πηγαδίσιος πηδαλιουχούμενος πηδητικός πηδηχτός πηκτικός πηκτός
 πηλώδης πηροδάκτυλος πηρομελής πηχεοκαρπικός πηχτός πηχυαίος πιανιστικός
 πιδέξιος πιεζοηλεκτρικός πιεσμένος πιεστικός πιεστός πιθανικός
 πιθανοστατιστικός πιθανοτικός πιθανός πιθηκικός πιθηκοειδής πιθηκόμορφος
 πικέ πικραμένος πικραντικός πικρικός πικροαίματος πικροθρήνητος πικρούτσικος
 πικρόγλωσσος πικρόκαρδος πικρός πικρόχολος πικτουρέσκ πιλοτικός πινακογραφικός
 πινδαρικός πιπεράτος πιπιλιστός πιρουνάτος πισινός πισσωτός πιστευτός
 πιστοληπτικός πιστοποιητικός πιστούχος πιστωτικός πιστός πιστότερος πισώπλατος
 πιτσιλιστός πιτσιλωτός πιτυριδικός πιτυρούχος πιωμένος πιότερος πλάγιος πλάνης
 πλέριος πλήθιος πλήρης πλίθινος πλίνθινος πλαγιαστός πλαγινός πλαγιοδετημένος
 πλαγκτονικός πλαδαρός πλακάτος πλακέ πλακομύτης πλακουτσωτός πλακουτσός
 πλακόστρωτος πλακώδης πλανεμένος πλανερός πλανημένος πλανητικός πλανητοειδής
 πλανόδιος πλασαριστός πλασματικός πλασμωδιακός πλαστικοποιητικός πλαστικός
 πλαστός πλατειαστικός πλατινέ πλατινένιος πλατινοειδής πλατσουκωτός
 πλατυκέφαλος πλατυκυρτωτός πλατυμέτωπος πλατυπόδαρος πλατυπύθμενος
 πλατωνικός πλατύγυρος πλατύκερως πλατύκυρτος πλατύποδας πλατύπους πλατύρρινος
 πλατύστερνος πλατύστομος πλατύσωμος πλατύτερος πλατύφυλλος πλατύχωρος πλαϊνός
 πλείων πλείων πλειοδοτικός πλειοψηφικός πλειόμορφος πλεκτικός πλεκτός
 πλεονασματικός πλεοναστικός πλεονεκτικός πλευρικός πλευριτικός πλευροκοπικός
 πλεχτικός πλεχτός πλεύσιμος πληγωτικός πληθικός πληθυντικός πληθυσμιακός
 πληθωρικός πληθωριστικός πληκτικός πληκτροφόρος πλημμελής πλημμεληματικός
 πληρεξούσιος πληροφοριακός πληροφορικός πληρωτέος πληρωτικός πλησίος
 πλησιέστερος πλησιοπαράλληλος πλησιφαής πλησιόχωρος πληχτικός πλινθοδομικός
 πλινθόκτιστος πλιότερος πλοηγικός πλοιοκεντρικός πλουμιστός πλουραλιστικός
 πλουτοκρατικός πλουτολογικός πλουτοπαραγωγικός πλουτοφόρος πλουτώνιος πλοϊκός
 πλυντήριος πλυντικός πλωριός πλωτικός πλωτός πλόιμος πνευματικός
 πνευματοκτόνος πνευματώδης πνευμονικός πνευμονογαστρικός πνευμονογραφικός
 πνευστός πνιγηρός πνιχτικός πνιχτός ποδήρης ποδαράτος ποδηλατικός ποδικός
 ποδοκνημικός ποδοσφαιρικός ποζάτος ποζολανικός ποθεινός ποθεινότατος ποθερός
 ποιητικός ποικίλος ποικιλτικός ποικιλόγραμμος ποικιλόθερμος ποικιλόμορφος
 ποικιλόσχημος ποικιλότροπος ποικιλόφωνος ποικιλόχρωμος ποικιλώνυμος
 ποιμαντορικός ποιμενίς ποιμενικός ποινικός ποιοτικός πολέμιος πολίτικος
 πολεμιστήριος πολεμοκάπηλος πολεμοπαθής πολεμοποιός πολεμοχαρής πολεμόχαρος
 πολεομορφικός πολεοτικός πολικός πολιομυελιτικός πολιορκητικός πολιτειακός
 πολιτικοδικαστικός πολιτικοδιοικητικός πολιτικοκοινωνικός πολιτικομανής
 πολιτικοστρατιωτικός πολιτικός πολιτισμένος πολιτισμικός πολιτιστικός πολιός
 πολλαπλασιαστικός πολλαπλός πολλοστός πολτοειδής πολτώδης πολυάνθρωπος
 πολυάστερος πολυάσχολος πολυέλεος πολυέξοδος πολυήμερος πολυαίματος πολυαίωνος
 πολυαγγειακός πολυαισθητηριακός πολυακόρεστος πολυανδρικός πολυανθής
 πολυαρχικός πολυβάλβιδος πολυβασανισμένος πολυγαμικός πολυγαστρικός
 πολυγραφικός πολυγραφότατος πολυγωνικός πολυδάκρυτος πολυδάκτυλος πολυδάπανος
 πολυδαίδαλος πολυδιάστατος πολυδιαστρωματωμένος πολυδόξαστος πολυδύναμος
 πολυεθνικός πολυειδής πολυεπιστημονικός πολυεστερικός πολυεστιακός πολυετής
 πολυεύσπλαγχνος πολυεύσπλαχνος πολυζήλευτος πολυζήτητος πολυζηλεμένος
 πολυηχής πολυθέλγητρος πολυθεϊκός πολυθεϊστικός πολυθρήνητος πολυθρύλητος
 πολυκάτεχος πολυκέλαδος πολυκέφαλος πολυκαιρίτικος πολυκαιρινός
 πολυκεντρικός πολυκερδής πολυκλαδικός πολυκομματικός πολυκριτηριακός
 πολυκυστικός πολυκυτταρικός πολυκύλινδρος πολυκύμαντος πολυκύτταρος
 πολυλεκτικός πολυλογάδικος πολυμέριμνος πολυμέτωπος πολυμήχανος πολυμαθής
 πολυμερής πολυμερικός πολυμεταβλητός πολυμετοχικός πολυμορφικός πολυνησιακός
 πολυξακουσμένος πολυοζώδης πολυουρεθανικός πολυουρικός πολυπέταλος
 πολυπαθής πολυπαραγοντικός πολυπαραμετρικός πολυπαραταξιακός πολυπλάνητος
 πολυπληθής πολυπλόκαμος πολυποίκιλος πολυπολιτισμικός πολυπονεμένος
 πολυπραγματικός πολυπρόσωπος πολυπυρηνικός πολυπόθητος πολυπύρηνος πολυσέλιδος
 πολυσήμαντος πολυσκελής πολυστένακτος πολυσυλλεκτικός πολυσυμπαντικός
 πολυσύλλαβος πολυσύνδετος πολυσύνθετος πολυσύχναστος πολυτάλαντος πολυτάραχος
 πολυτασικός πολυτελής πολυτεχνικός πολυτμήματος πολυτμηματικός πολυτομικός
 πολυτοπικός πολυτροπικός πολυτόκος πολυφάγος πολυφίλητος πολυφασικός πολυφυής
 πολυφωνικός πολυχρήματος πολυχρόνιος πολυψήφιος πολυωνυμικός πολυύμνητος
 πολυώροφος πολφικός πολωνέζικος πολωνικός πολωτικός πολύαιμος πολύανδρος
 πολύαστρος πολύβλαστος πολύβοος πολύβουλος πολύβουος πολύγαμος πολύγλωσσος
 πολύγνωρος πολύγονος πολύγραμμος πολύγωνος πολύδακρυς πολύδεντρος πολύδροσος
 πολύεδρος πολύηχος πολύθρησκος πολύκαρπος πολύκλαδος πολύκλαυστος πολύκλαυτος
 πολύκροτος πολύλαλος πολύλογος πολύμορφος πολύμοχθος πολύνευρος πολύξερος
 πολύπαθος πολύπειρος πολύπλευρος πολύπλοκος πολύποδος πολύπονος πολύπορος
 πολύπτυχος πολύπτωτος πολύριζος πολύρριζος πολύς πολύσαρκος πολύσημος
 πολύσπορος πολύστηλος πολύστικτος πολύστιχος πολύστροφος πολύστυλος
 πολύταστος πολύτεκνος πολύτεχνος πολύτιμος πολύτμητος πολύτοκος πολύτομος
 πολύτριχος πολύτροπος πολύυδρος πολύφερνος πολύφημος πολύφθογγος πολύφροντις
 πολύφωνος πολύφωτος πολύχορδος πολύχρονος πολύχρυσος πολύχρωμος πολύχυμος
 πολύωρος πομπικός πομπώδης πονεμένος πονεσιάρης πονετικός πονηρός ποντιακός
 ποντικοκτόνος ποντικοφαγωμένος ποντιφικός ποντοπόρος πονόκαρδος πονόψυχος
 πορευτικός ποριστικός ποριώτικος πορνικός πορνογραφικός πορνό ποροσκοπικός
 πορτογαλέζικος πορτογαλικός πορτοκαλής πορτοκαλί πορτοκαλόχρους πορφυρένιος
 πορφυρογέννητος πορφυρός πορφυρόχρους πορφυρόχρωμος πορώδης ποσέ ποσαπλάσιος
 ποσοστιαίος ποσοστιαίως ποσοστικός ποσοτικοποιήσιμος ποσοτικός ποτάμιος
 ποταμογενής ποταμοχειμάρρειος ποταπός ποτιστικός πουπουλένιος πουριτανικός
 πουτανίστικος πουτανιάρης πούρος πούστικος ποώδης πράος πράσινος πρίμος
 πραγματιστικός πραγματογνωστικός πραγματοκρατικός πραγματολογικός
 πραιτορικός πραιτωρικός πρανής πραξεολογικός πραξικοπηματικός πρασινογάλαζος
 πρασινομάτης πρασινωπός πραχτικός πραϋντικός πρεβεζιάνικος πρεμνοφυής
 πρεσβευτικός πρεσβυγενής πρεσβυτικός πρεσβυωπικός πρεσβύτερος πρεσοκομμένος
 πριάπειος πριβέ πριγκιπικός πριμιτιβιστικός πρινένιος πριονιστός πριονοειδής
 πρισματικός πρισματοειδής πριστή πριστός προαγοραστικός προαγωγικός
 προαιρετικός προαιώνιος προακτέος προανακριτικός προαντιπροσωπευτικός
 προβατίσιος προβατικός προβεβηκώς προβενσιανός προβηγκιανός προβλέψιμος
 προβληματικός προβληματιστικός προβληματογόνος προβλητέος προβοκατόρικος
 προβοσκιδοφόρος προβουλκανισμένος προγάμιος προγαμιαίος προγενέστερος
 προγναθικός προγνωρίζων προγνωστικός προγνώμων προγονικός προγονολατρικός
 προγραμματικός προγραμματιστικός προδημοκρατικός προδικαστικός προδοτικός
 προδυναστικός προεγχειρητικός προεδρικός προεδροδημοκρατικός προειδοποιητικός
 προεισπραττόμενος προεκλογικός προεκτοπιστικός προελληνικός προεμμηνορροϊκός
 προεξαγγελτικός προεξοφλήσιμος προεξοφλητέος προεξοφλητικός προεξοφλητός
 προεπενδυτικός προερωτικός προεφηβικός προεόρτιος προηγούμενος προθεατρικός
 προθετικός προθυμότερος προθωρακικός προικιάτικος προικώος προκάρδιος προκάτ
 προκαλυπτικός προκαπιταλιστικός προκαταβολικός προκατακλυσμιαίος
 προκατασκευαστικός προκβαντικός προκεχωρημένος προκλασικός προκλητικός
 προκλινής προκοίλης προκολομβιανός προκριματικός προκυκλικός προλεταριακός
 προλογικός προμήκης προμεσημβρινός προμεταμοσχευτικός προμετωπίδιος
 προμηθευτικός προμηθεϊκός προμινωικός προμνημονιακός προνοητικός προνοιακός
 προνομιούχος προνομοθετημένος προνοσοκομειακός προξενικός προοδευτικός
 προοπτικός προορατικός προοριστικός προπέρσινος προπαγανδιστικός
 προπαρασκευαστικός προπαροξύτονος προπατορικός προπεμπτήριος προπεμπτικός
 προπεριτοναϊκός προπερσινός προπερυσινός προπετής προπηλακιστικός προπληρωτέος
 προπονητικός προσάνεμος προσάντης προσήλιος προσήλυτος προσήνεμος προσίστιος
 προσαρμοσμένος προσαρμοστικός προσαρμόσιμος προσαυξητικός προσβάσιμος
 προσβεβλημένος προσβλημένος προσβλητικός προσδιοριστικός προσδόκιμος
 προσειλημμένος προσεκτικός προσεξουαλικός προσεταιριστικός προσεχής
 προσηγορικός προσηλιακός προσηλυτίσιμος προσηλυτιστικός προσημασμένος προσηνής
 προσθετικός προσθετός προσθιοπίσθιος προσιτός προσκαιρινός προσκείμενος
 προσκυνηματικός προσλημμένος προσληπτέος προσληπτικός προσληφθείς προσοδοφόρος
 προσοφθάλμιος προσπελάσιμος προσποιητικός προσποιητός προστήσας προστακτικός
 προστατευόμενος προστατικός προσταχτικός προστερνίδιο προστιθέμενος
 προσυλλογιστικός προσυμβατικός προσυμπτωματικός προσυμπτωματολογικός
 προσυνταξιοδοτικός προσφιλής προσφυής προσφυγικός προσχηματικός προσχωματικός
 προσχωτικός προσωδιακός προσωκρατικός προσωπιδοφόρος προσωπικός
 προσωπογραφικός προσωποκεντρικός προσωπομετρικός προσωποπαγής προσωρινός
 προτακτικός προτελευταίος προτελωνειακός προτεραίος προτερόχρονος
 προτεταμένος προτιθέμενος προτιμησιακός προτιμητέος προτιμότερος προτρεπτικός
 προυχοντικός προυχρόνιος προφέρσιμος προφανής προφαντός προφητικός προφορικός
 προφυλακτικός προφυλαχτικός προφυματικός προχειρολόγος προχθεσινός
 προχτεσινός προχωρητικός προχώ προψεσινός προωθητικός προωστήριος προωστικός
 προϊστορικός προϋπάρχων προϋφιστάμενος πρυμήσιος πρυμιός πρυμνήσιος πρυμναίος
 πρυμνόδετος πρυτανικός πρωθυπουργικός πρωθυπουργοκεντρικός
 πρωθύστερος πρωινός πρωκτικός πρωκτολογικός πρωραίος πρωρατικός πρωσικός
 πρωτάρης πρωτάρικος πρωταγωνιστικός πρωταπριλιάτικος πρωταρχικός
 πρωτευουσιάνικος πρωτευουσιάνος πρωτεϊκός πρωτεϊνικός πρωτεϊνούχος πρωτινός
 πρωτοβάθμιος πρωτοβυζαντινός πρωτογέννητος πρωτογενής πρωτογεωμετρικός
 πρωτοελλαδικός πρωτοετής πρωτοκαιρίτικος πρωτοκλασάτος πρωτοκορινθιακός
 πρωτομαγιάτικος πρωτομαρτιάτικος πρωτομινωικός πρωτονικός πρωτοπαθής
 πρωτοποριακός πρωτοσέλιδος πρωτοσύστατος πρωτοτάξιδος πρωτοταγής πρωτοτόκος
 πρωτοφανέρωτος πρωτοφανής πρωτοφανήσιμος πρωτοφόρετος πρωτοχρονιάτικος
 πρωτυτερινός πρωτόβαλτος πρωτόβγαλτος πρωτόγεννος πρωτόγερος πρωτόγνωρος
 πρωτόδικος πρωτόθετος πρωτόκλητος πρωτόκλιτος πρωτόλειος πρωτόλουβος
 πρωτόπειρος πρωτόπιαστος πρωτότοκος πρωτότυπος πρωτόφαντος πρωτόχυτος
 πρόβειος πρόβιος πρόγναθος πρόδηλος πρόδρομος πρόθυμος πρόνοος πρόξενος
 πρόσγειος πρόσεδρος πρόσηβος πρόσθετος πρόσθιος πρόσκαιρος πρόστυλος πρόστυχος
 πρόσφορος πρόσχαρος πρότερος πρότυπο:παραθετικά πρότυπο:παραθετικά
 πρότυπος πρόχειλος πρόχειρος πρόωρος πρύμος πρώην πρώιμος πρώτιστος πτεροειδής
 πτερυγοειδής πτερυγωτός πτερωτός πτερόεις πτηνοτροφικός πτητικός πτιλωτός
 πτυκτός πτυχιακός πτυχιούχος πτυχωσιγενής πτυχωτός πτωματικός πτωτικός
 πτωχικός πτωχοπροδρομικός πτωχός πτωχόταστος πυγαίος πυγμαίος πυγμαχικός
 πυελοουρητηρικός πυθαγόρειος πυθικός πυκνογραμμένος πυκνοδομημένος
 πυκνοκατοικημένος πυκνομετρικός πυκνωτικός πυκνόρρευστος πυκνός πυκνόφυλλος
 πυλαίος πυλωρικός πυογόνος πυορροϊκός πυράντοχος πυρίκαυστος πυρίμαχος
 πυραμιδικός πυραμιδοειδής πυραμιδωτός πυραμοειδής πυρασφαλιστικός πυραυλικός
 πυραυλοφόρος πυργιώτικος πυργοεδής πυργοειδής πυργωτός πυρετικός πυρετογόνος
 πυρηναϊκός πυρηνικός πυρηνοειδής πυρηνοκίνητος πυριγενής πυριτικός πυριτιούχος
 πυροβατικός πυροβολικός πυρογενής πυρογραφικός πυροδοτικός πυροηλεκτρικός
 πυροκλαστικός πυροκυτταρινικός πυρολατρικός πυρολιθικός πυρολυτικός
 πυρομανής πυρομαχικός πυρομεταλλουργικός πυρομετρικός πυροπαθής πυροσβεστικός
 πυροφορικός πυρπολικός πυρρόθριξ πυρρόξανθος πυρρός πυρρόχρους πυρφόρος
 πυρόπληκτος πυρώδης πυώδης πωγωνάτος πωγωνοφόρος πόντιος πόσιμος πότιμος
 πύξινος πύρινος πύρρειος πώρινος ράθυμος ρέζιγος ρέμπελος ρέστος ραβδοειδής
 ραβδοφόρος ραβδωτός ραβινικός ραγδαίος ραγιάδικος ραδιενεργός ραδινός
 ραδιογωνιομετρικός ραδιοηλεκτρικός ραδιοηλεκτρολογικός ραδιοθεραπευτικός
 ραδιομετεωρολογικός ραδιοναυτιλιακός ραδιοπειρατικός ραδιοπυρηνικός
 ραδιοτεχνικός ραδιοτηλεγραφικός ραδιοτηλεοπτικός ραδιοτηλεφωνικός ραδιοφαρικός
 ραδιοφωνικός ραδιοχημικός ραδιοϊσοτοπικός ραδιούργος ραδιούχος ραιβοσκελής
 ραιβός ραιτορομανικός ρακένδυτος ρακοφόρος ραμφοειδής ραμφοφόρος ραμφόστομος
 ραπτικός ρασιοναλιστικός ρατσιστικός ραφινάτος ραφινέ ραφτικός ραχατλίδικος
 ραχιτικός ραχοειδής ραψωδικός ρεαλιστικός ρεβανσιστικός ρεβιζιονιστικός
 ρεζερβέ ρεθεμνιώτικος ρεθυμνιώτικος ρεμβώδης ρεμπέτικος ρεολογικός ρεοστατικός
 ρεπουμπλικανικός ρετροσπεκτιβικός ρετρό ρετσινάτος ρευματικός ρευματοειδής
 ρευματώδης ρευστομηχανικός ρευστοποιήσιμος ρευστός ρεφλέξ ρεφορμιστικός
 ρηγματώδης ρημαδιακός ρηματικός ρηξιγενής ρηξικέλευθος ρητινικός ρητινοφόρος
 ρητινώδης ρητορικός ρητός ρηχός ριγέ ριγανάτος ριγηλός ριγωτός ριζίτικο
 ριζικάρης ριζικός ριζιμιός ριζοειδής ριζομορφικός ριζοσπαστικός ριζοτροπικός
 ριζόμορφος ριζώδης ρικνός ριναίος ρινικός ρινολαρυγγικός ρινολογικός
 ρινοσκοπικός ρινοφαρυγγικός ρινόφωνος ριπίταστος ριπαίος ριπιδίταστος
 ριπιδωτός ριπιδόταστος ριχτός ριψοκίνδυνος ρογιάτικος ροδής ροδίτικος ροδαλός
 ροδοειδής ροδοζυμωμένος ροδοζύμωτος ροδοκόκκινος ροδομάγουλος ροδομύριστος
 ροδοπεριχυμένος ροδοστεφάνωτος ροδοστεφής ροδοστεφανωμένος ροδοψημένος
 ροδόχρους ροδόχρωμος ροζ ροζέ ροζιάρης ροζιάρικος ροζιασμένος ρομ ρομανικός
 ρομβικός ρομβοειδής ρομβωτός ρομποτικός ρομφαιοφόρος ροπαλοφόρος ροταριανός
 ρουκετοφόρος ρουμάνικος ρουμανικός ρουμελιώτικος ρουμπινής ρουνικός ρουστίκ
 ρουτινιέρικος ρουφηχτός ροφητός ρούσικος ρούσος ρυγχοειδής ρυγχοφόρος ρυγχωτός
 ρυθμιστής ρυθμιστικός ρυμοτομικός ρυπαντικός ρυπαρός ρυπογόνος ρυτιδιασμένος
 ρωμαίικος ρωμαιοκαθολικός ρωμαλέος ρωμανικός ρωμαντικός ρωμαϊκό ρωμαϊκός
 ρωσομαθής ρωσόφιλος ρόδινος ρόδιος ρόπαλο ρώσικος σάπιος σάρκινος σέκος σένιος
 σέρβικος σέρτικος σίγουρος σίτινος σίφνιος σαββατιάτικος σαββατιανός
 σαββατογεννημένος σαβουρολάγνος σαγηνευτικός σαγκριώτικος σαδιστικός
 σαθρός σαικσπηρικός σαιξπηρικός σακάτικος σακοειδής σακουλίσιος σακχαροειδής
 σακχαρώδης σαλιάρης σαλικυλικός σαλπιγγικός σαλπιγγοειδής σαλός σαμαρειτικός
 σαματατζίδικος σαμιακός σαμιώτικος σαμπανιζέ σανατορικός σανιδένιος
 σανιδωτός σανιδόφραχτος σανσκριτικός σαντορινιός σαντορινιώτικος σαξ σαξονικός
 σαουδικός σαπρογόνος σαπροφάγος σαπροφυτικός σαπρός σαπφείρινος σαπφειροειδής
 σαπωνοειδής σαράφικος σαρακοστιάτικος σαρακοστιανός σαρακοφαγωμένος
 σαρανταήμερος σαρδελοφάγος σαρδόνιος σαρκαστικός σαρκερός σαρκικός σαρκοβόρος
 σαρκοειδής σαρκοφάγος σαρκοφαγικός σαρκωματώδης σαρκώδης σαρωτικός σασκίνης
 σατινέ σατινένιος σατιρικός σατούρνιος σατράπικος σατραπικός σατυρικός
 σαφέστερος σαφής σαφηνής σαφηνιστικός σαφρακιασμένος σαχλός σβέλτος σβεστός
 σβουνοπασάλειφτος σβουριχτός σβωλιαστός σγουρομάλλης σγουρόμαλλος σγουρός
 σεβασμιότατος σεβασμιώτατος σεβαστικός σεβαστός σεβνταλίδικος σειληνικός
 σειραϊκός σειριακός σειρόδετος σεισμικός σεισμογενής σεισμογραφικός
 σεισμολογικός σεισμομετρικός σεισμοπαθής σεισμόπληκτος σειστός σεκταριστικός
 σελασφόρος σεληναίος σεληνιακός σεληνιούχος σεληνογραφικός σεληνοειδής
 σεληνοτοπογράφος σεληνοτοπογραφικός σεληνοφώτιστος σεληνόφωτος σελωτός
 σεμιναριακός σεμνολόγος σεμνοπρεπής σεμνός σεμνότυφος σεμπρικός σενεγαλέζικος
 σενιάν σεντεφένιος σεξιστικός σεξολογικός σεξομανής σεξουαλικός σεξπιρικός
 σεπτεμβριάτικος σεπτεμβριανός σεπτός σερέτικος σεραφικός σερβικός
 σερβοκροατικός σερνάμενος σερνικοθήλυκος σερνικός σερπετός σερραίικος
 σερσέμης σερσέμικος σεχταριστικός σηκωτός σημαδευτός σημαδιακός
 σημαντικός σημαντικότατος σημασιολογικός σηματοτεχνικός σημειακός
 σημειολογικός σημειωτέος σημειωτικός σημειωτός σημερινός σημερνός σημιτικός
 σηρικός σηροτροφικός σησαμόπαστος σητειακός σηψαιμικός σηψιγόνος σθεναρός
 σιαλαγωγός σιαλικός σιαλογόνος σιαλοφόρος σιαλώδης σιαμέζικος σιαμαίος
 σιβηρικός σιβυλλικός σιγαλός σιγαλόφωνος σιγανός σιγηλός σιγμοειδής σιδεράτος
 σιδεροκέφαλος σιδερωτός σιδερός σιδερόφραχτος σιδηροδέσμιος σιδηροδρομικός
 σιδηροπαγής σιδηροπενικός σιδηρουργικός σιδηρούς σιδηρούχος σιδηρόφραχτος
 σικ σικάτος σικέ σικελικός σιληνικός σιλοφόρος σιμιγδαλένιος σιμοτινός
 σιμός σιναλεζικός σιναπούχος σιναϊτικός σινιέ σινικός σινοελληνικός
 σινοσοβιετικός σιντεφένιος σιούτος σιροπιαστός σισύφειος σιτάρκης σιταγωγός
 σιταρίσιος σιταροειδής σιταρόχρωμος σιτευτός σιτικός σιτοπαραγωγικός σιτοφόρος
 σιφνέικος σιφνιώτικος σιφωνιάτικος σιχαμερός σιχασιάρης σιωνιστικός σιωπηλός
 σκάνταλος σκάρτος σκέτος σκαδιώτικος σκαιός σκακιστικός σκαληνός σκαλιστικός
 σκαλωτός σκαμπρόζικος σκαμπρόζος σκανδαλιάρης σκανδαλιάρικος σκανδαλιστικά
 σκανδαλοθηρικός σκανδαλολογικός σκανδαλοπλόκος σκανδαλοποιός σκανδαλώδης
 σκανδιναυϊκός σκανδόγλωσσος σκανταλιάρης σκανταλιάρικος σκαπτικός σκαπτός
 σκαρφαλωτός σκαστός σκατένιος σκατιάρης σκατοκέφαλος σκατολογικός σκατοφάγος
 σκαυϊκός σκαφευτικός σκαφιδωτός σκαφοειδής σκαφτικός σκαφτός σκεβρός
 σκελετικός σκελετολογικός σκελετωμένος σκελετώδης σκεπαστικός σκεπαστός
 σκεπτικός σκεπός σκερτσόζα σκερτσόζικος σκερτσόζος σκευαγωγός σκευομορφικός
 σκηνικός σκηνογραφικός σκηνοθετικός σκηπτούχος σκιάθιος σκιαγραφικός σκιαζάρης
 σκιερός σκιστός σκιτζίδικος σκιόφιλος σκιόφοβος σκιώδης σκληραγωγημένος
 σκληρογόνος σκληροκέφαλος σκληροκόκαλος σκληρομετρικός σκληροπυρηνικός
 σκληρυντικός σκληρωτικός σκληρόδερμος σκληρόκαρδος σκληρόπετσος σκληρός
 σκληρόφλουδος σκληρόφυλλος σκληρόψυχος σκληρώδης σκοινένιος σκολιάτικος
 σκολιωτικός σκοπελίτικος σκοπευμένος σκοπευτικός σκορβουτικός σκορδόπιστος
 σκοροφαγωμένος σκορπιστός σκοταδερός σκοταδιστικός σκοτεινούτσικος σκοτεινός
 σκοτικός σκοτοενεργειακός σκοτοϋλικός σκοτσέζικος σκοτωμένος σκουλάτος
 σκουληκιάρικος σκουληκομυρμηγκοτρυποειδής σκουληκοφαγωμένος σκουντημένος
 σκουροκόκκινος σκουροπράσινος σκουρόχρωμος σκουφάτος σκούρος σκυθικός
 σκυλίσιος σκυλοδόντης σκυλοκέφαλος σκυλομούρης σκυλόψυχος σκυρωτός σκυφτός
 σκωληκοφάγος σκωληκόβρωτος σκωπτικός σκωτικός σκωτσέζικος σκόπιμος σκόρπιος
 σκύτινος σλάβικος σλαβικός σλαβόφιλος σλαβόφωνος σλαυόφιλος σλοβακικός
 σμαράγδινος σμαραγδένιος σμαραγδοειδής σμαραγδόχρους σμηγματικός σμηγματογόνος
 σμηκτικός σμικρός σμιλευτός σμιχτοφρύδης σμιχτός σμυριδεργατικός σμυριδικός
 σμυρναϊκός σμυρνιώτικος σνομπ σνομπιστικός σοβαροφανής σοβαρός σοβαρότερος
 σοβινιστικός σοβράνος σοδομικός σοδομιτικός σοκαριστικός σοκινιανός σοκολά
 σοκολατής σοκολατούχος σολομώντειος σολωμικός σολώνιος σομφός σομφώδης σομόν
 σορβικός σοροπιαστός σος σοσιαλδημοκρατικός σοσιαλιστικός σουβλερός σουβλιστός
 σουδανέζικος σουδανικός σουηδέζικος σουηδικός σουλιώτικος σουλτανικός
 σουμερικός σουμπρετίστικος σουνιτικός σουξεδιάρης σουρεαλιστικός σουρλωτός
 σουσαμάτος σουσαμένιος σουσαμωτός σουσουδίστικος σουφικός σοφιστικός
 σοφολογιώτατος σοφόκλειος σοφός σοϊλής σοϊλίδικος σοϊλίτικος σούκο σούμπιτος
 σπάνιος σπάρτινος σπάταλος σπέσιαλ σπαγγοραμένος σπαγγοραμμένος σπαγκοραμμένος
 σπαθοειδής σπαθωτός σπανιότατος σπανιότερος σπανός σπαρακτικός σπαραξικάρδιoς
 σπαραχτικός σπαργωτός σπαρταριστός σπαρτιάτικος σπαρτιατικός σπαρτικός σπαρτός
 σπασμωδικός σπασμώδης σπαστικός σπειροειδής σπειρωτός σπερματαγωγός
 σπερματογόνος σπερματοδίκαιος σπερματοδόχος σπερματοκτόνος σπερματολογικός
 σπερματοτοξικός σπερματοφάγος σπερματοφόρος σπερματούχος σπερμικός σπερμογόνος
 σπερμολογικός σπερμοτοξικός σπερμοφάγος σπερμοφυής σπερμοφόρος σπερνός
 σπηλαίος σπηλαιολογικός σπηλαιόβιος σπηλαιώδης σπιθαμιαίος σπιλωτικός
 σπινθηροβόλος σπινθηρογραφικός σπιράλ σπιρτόζος σπιτίσιος σπιτικός σπλαγχνικός
 σπλαγχνολογικός σπλαχνικός σπληνιάρης σπληνικός σπληνογραφικός σπληνολογικός
 σπογγογενής σπογγοειδής σπογγώδης σπονδειακός σπονδυλικός σπονδυλωτός σπορ
 σποριάρης σποριάρικος σπορογόνος σπορτίφ σπουδαίος σπουδαιοφανής σπουδασμένος
 σπουδαχτικός σπυριάρης σπυρωτός σπόριμος σπόρκος σράναν στάσιμος στέρεος
 σταβέντο σταβέτ σταγονομετρικός σταδιακός σταδιομετρικός σταθεροποιητικός
 σταθμητός στακτός σταλακτικός σταλακτός σταλαχτός σταλινικός σταλινοειδής
 σταμνόσχημος σταμπάτος σταμπωτός στανιαρισμένος στανικός σταράτος σταρένιος
 σταρόχρωμος στασιαστικός στατικός στατιστικοποιήσιμος στατιστικός
 σταυρανθής σταυρεπίστεγος σταυρικός σταυροαναστάσιμος σταυροειδής
 σταυροπηγιακός σταυρωτός σταυρόσχημος σταυρότυπος σταυρώσιμος σταφιδικός
 σταφυλοκοκκικός σταχτής σταχτερός σταχτοκίτρινος σταχτόχρωμος στεάτινος
 στεατικός στεατοπυγικός στεατώδης στεγάσιμος στεγανωτικός στεγανός στεγαστικός
 στεγνός στενάχωρος στενογραφικός στενοκέφαλος στενομέτωπος στενοπρόσωπος
 στενόθωρος στενόκαρδος στενόμακρος στενόμυαλος στενόπορος στενός στενόστομος
 στενόφυλλος στενόχωρος στενόψυχος στερεογραφικός στερεοελλαδίτικος
 στερεοσκοπικός στερεοστατικός στερεοτακτικός στερεοτατικός στερεοτυπικός
 στερεοφωτογραφικός στερεοχημικός στερεοχρωμικός στερεοϊσομερής στερεωτικός
 στερεότυπος στερητικός στεριανός στερνίσιος στερνικός στερνοκλειδικός
 στερνός στερρός στεφανηφόρος στεφανιαίος στεφανωτός στηθικός στηθοσκοπικός
 στηρικτικός στητός στιβαρός στιγματικός στιγμιαίος στικτός στιλάτος
 στιλιστικός στιλπνός στιπλ στιφρός στιφτός στιχηρός στιχογραφικός
 στιχουργικός στοιβαχτός στοιχειακός στοιχειοθετικός στοιχειοχυτικός
 στολοδρομικός στοματικός στοματογναθοπροσωπικός στοματολογικός στοματολόγος
 στομαχικός στομφώδης στοργικός στουμπιστός στουμπουλός στουπένιος στοχαστικός
 στράπλες στραβικός στραβοδίβολος στραβοκάνης στραβοκέφαλος στραβολαίμης
 στραβοπόδης στραβός στραβόταστος στραγγαλιστικός στραγγιστικός στραγγιστός
 στραταρχικός στρατεύσιμος στρατηγικός στρατιωτικός στρατογεμής στρατοκρατικός
 στρατόκαβλος στρατόκαυλος στρεβλός στρεμματικός στρεπτοκοκκικός στρεπτός
 στριγκός στριμμένος στριμωχτός στριμόκωλος στριφογυριστός στριφτός
 στροβιλοειδής στροβοσκοπικός στρογγυλοπρόσωπος στρογγυλοφέγγαρος
 στρογγυλόμακρος στρογγυλός στροντιούχος στρουμπουλός στρουμφολογικός
 στρυφνός στρωματοποιημένος στρωτός στρόγγυλος στυγερός στυγνός στυπτικός
 στυφούτσικος στυφτικός στυφός στωικός στωικότερος στωμύλος συβαριτικός
 συγγενικός συγγνωστός συγγραφικός συγκάτοχος συγκαιρινός συγκαταβατικός
 συγκατανευτικός συγκείμενος συγκεντρωμένος συγκεντρωτικός συγκεφαλαιωτικός
 συγκινησιακός συγκινητικός συγκλίνων συγκλητικός συγκλονιστικός συγκοινωνιακός
 συγκολλητικός συγκρίσιμος συγκρητικός συγκριτικός συγκρουσιακός συγκυβερνητέος
 συγκυριακός συγχαρητήριος συγχρονικός συγχρονιστικός συγχυσμένος συγχυτικός
 συγχωρητήριος συγχωρητικός συζευγμένος συζευκτικός συζητήσιμος συζητητικός
 συζυγικός συθέμελος συκοφαντικός συλλήψιμος συλλαβικός συλλαβιστικός
 συλλαβογραφικός συλλεκτικός συλλεχτικός συλληπτήριος συλλογικός συλλογισμένος
 συλλυπητήριος συμέμελος συμβασιοκρατικός συμβασιούχος συμβατικός συμβατός
 συμβιωτικός συμβολαιακός συμβολαιογραφικός συμβολικός συμβουλατορικός
 συμμέτοχος συμμαζεμένος συμμαχικός συμμεταβλητός συμμετοχικός συμμετρικός
 συμμορίτικος συμμοριτικός συμμοριόπληκτος συμμορφούμενος συμπαγής συμπαθής
 συμπαθητικός συμπαντικός συμπαράγωγος συμπαραταξικός συμπεθερικός
 συμπεριφορικός συμπεριφοριστικός συμπιεσμένος συμπιεστικός συμπιεστός
 συμπλεκτικός συμπλεχτικός συμπληρωματικός συμπληρωτικός συμπολημερής
 συμπονετικός συμποσιακός συμποσιαστικός συμποτικός συμπτωματικός
 συμπυκνωτικός συμπότης συμπύρηνος συμφασικός συμφεροντολογικός συμφερτικός
 συμφορητικός συμφραστικός συμφυής συμφυρματικός συμφυτικός συμφωνημένος
 συμφωνόληκτος συμφωνόλητκος συμψηφιστικός συμψιφησθείς συνάλληλος συνένοχος
 συναίτιος συναγωνιστικός συναδελφικός συναινετικός συναιρόμενος
 συναισθητικός συνακόλουθος συναλλάξιμος συναλλαγματικός συναλλακτικός
 συναπτικός συναπτός συναρμόδιος συναρπαστικός συναρτησιακός συνασπιστικός
 συνδεσμικός συνδεσμοπλαστικός συνδετήριος συνδετικός συνδιαλλακτικός
 συνδικαλιστικός συνδρομητικός συνδυαστικός συνεγγυητικός συνειδησιακός
 συνειρμικός συνεκδοχικός συνεκτικός συνεπής συνεπικουρούμενος συνεπικρατών
 συνεργατικός συνεργικός συνεσταλμένος συνεστραμμένος συνεταιρικός
 συνετός συνεχής συνεχόμενος συνηθέστερος συνηθισμένος συνημμένος συνηχητικός
 συνθετικός συνθηματικός συνθηματολογικός συννεφώδης συνοδευτικός συνοδικός
 συνοικιακός συνολικός συνομήλικος συνομετρικός συνομοσπονδιακός
 συνονόματος συνοπτικός συνοριακός συντάξιμος συνταγματικός συνταγογραφικός
 συνταξιοδοτικός συνταρακτικός συνταραχτικός συνταχτικός συντελεστικός
 συντεχνιακός συντηρητικός συντμημένο συντομογραφικός συντομότερος
 συντριπτικός συντροφιαστός συντροφικός συνυπεύθυνος συνωμοσιολογικός
 συνωνυμικός συνώνυμος συριακός συριανός συριγγώδης συριζαϊκός συριστικός
 συρματένιος συρματόπλεκτος συρματόπλεχτος συρταρωτός συρτός συσσωρευτικός
 συσταλτός συστατικός συστημένος συστηματικός συστημικός συστολική συστολικός
 συσχετιστικός συφερτικός συφιλιδικός συφοριασμένος συχνός συχνότερος σφαγίτιδα
 σφαδαστικός σφαιρικός σφαιροειδής σφακιώτικος σφαλερός σφαλιστός
 σφαχτός σφηνοειδής σφηνωτός σφιγκτός σφικτός σφιχτοχέρης σφιχτόκωλος σφιχτός
 σφοδρότερος σφουγγαράδικος σφραγιστικός σφραγιστός σφριγηλός σφυγμικός
 σφυριχτός σχεδιαστικός σχεδιοποιημένος σχετικιστικός σχετικός σχετλιαστικός
 σχιζοειδής σχιζοφρενής σχιζοφρενικός σχισματικός σχισμοειδής σχιστολιθικός
 σχιστός σχοίνινος σχοινοβατικός σχοινοτενής σχολάζων σχολαστικός σχολιαστικός
 σχωρεμένος σωβινιστικός σωκρατικός σωληνοειδής σωληνωτός σωματειακός
 σωματικός σωματολογικός σωματομετρικός σωματοτρόπος σωματώδης σωρευτικός
 σωροπυριτικός σωσίβιος σωστικός σωστός σωτήριος σωτηριολογικός σωφρονιστικός
 σόλο σόλοικος σύγκαιρος σύγκορμος σύγχρονος σύκινος σύμμεικτος σύμμειχτος
 σύμμορφος σύμπας σύμπηκτος σύμπλοκο σύμπλοκος σύμφορος σύμφυρτος σύμφυτος
 σύνθετος σύννομος σύννους σύνολος σύνοφρυς σύντομος σύντονος σύνωρος σύξυλος
 σύσπαστος σύσσωμος σύστοιχος σύψυχος σώος σώφρων τάλας τάλε κουάλε τάχιστος
 τέλειος τέως τίμιος τίτσιρος ταβερνόβιος ταγγός ταγκός ταγμένος ταγματικός
 ταζέτικος ταινιοειδής ταινιωτός ταινιόμορφος ταινιόπλεκτος ταιριαστός τακερός
 τακτικός τακτικότερος τακτός ταλαίπωρος ταλαντευτικός ταλαντούχος ταλμουδικός
 ταμαχκιάρης ταμειακός ταμειολογιστικός ταμιακός ταμιευτικός ταναγραίος τανικός
 ταξιδιάρης ταξιδιάρικος ταξιδιωτικός ταξιδιώτικος ταξικός ταξινομικός
 ταπεινός ταπεινόφρονας ταπεινόφρων ταραχοποιός ταραχώδης ταριχευμένος
 ταριχευτός ταρσικός ταρτάρ τασμανικός ταστωτός ταστός ταταρικός ταυροειδής
 ταυρόμορφος ταυτάριθμος ταυτογράμματος ταυτολογικός ταυτολόγος ταυτομερές
 ταυτοπρόσωπος ταυτόαιμος ταυτόσημος ταυτόφωνος ταυτόχρονος ταυτώνυμος ταφικός
 ταχινός ταχτικός ταχυβόλος ταχυγραφικός ταχυδακτυλουργικός ταχυδρομικός
 ταχυεργός ταχυθάνατος ταχυκίνητος ταχυκαής ταχυμετρικός ταχυπόρος ταχύγλωσσος
 ταχύπλοος ταχύπορος ταχύπους ταχύρρυθμος ταχύρυθμος ταχύς ταχύτερος
 ταύρειος τεζαριστός τεθνεώς τεθωρακισμένος τεκμαρτός τεκμηριωτικός
 τεκτονικός τεκτοπυριτικός τελειοθηρικός τελειοποιήσιμος τελειοποιημένος
 τελειωμένος τελειωτικός τελεολογικός τελεσίδικος τελεσιγραφικός τελεστικός
 τελετουργικός τελευταίος τελικός τελματικός τελματόβιος τελματώδης τελολογικός
 τεμπέλης τεμπέλικος τεναγώδης τενεκεδένιος τενιστικός τεντωτός τεντώσιμος
 τεξανός τεράστιος τερατογονικός τερατογόνος τερατοειδής τερατολογικός
 τερατώδης τερβιούχος τερεφθαλικός τερματικός τερμιτοξενία τερμιτοφιλία
 τερμιτόφιλος τερνερική τερνερικός τερπνός τερψίθυμος τερψιλαρύγγιο
 τερώδης τεσσαράγωνος τεσσαρακάντουνος τεσσαρακονθήμερος τεσσαρακονταετής
 τεσσαρακοστός τεσσεροκάντουνος τεταγμένος τετανικός τετανοειδής τεταρταίος
 τεταρτογενής τεταρτοκυκλικός τετράβαθμος τετράβιβλος τετράγκωνος τετράγλωσσος
 τετράγραμμος τετράγωνος τετράδιπλος τετράδραχμος τετράεδρος τετράθυρος
 τετράιχνος τετράκαννος τετράκερος τετράκιλος τετράκλαστος τετράκλιμος
 τετράκλιτος τετράκλωνος τετράκνημος τετράκολπος τετράκορφος τετράκρουνος
 τετράκυκλος τετράκωπος τετράλεκτος τετράλιτρος τετράλοφος τετράμετρος
 τετράμοιρος τετράμορος τετράμορφος τετράξανθος τετράξονος τετράοδος τετράορος
 τετράπαχος τετράπεδος τετράπηχος τετράπλαστος τετράπλατος τετράπλεθρος
 τετράπλοκος τετράποδος τετράπολος τετράπορος τετράπορτος τετράπρακτος
 τετράπτερος τετράπτιλος τετράπτυχος τετράπτωτος τετράπυλος τετράπυργος
 τετράριθμος τετράρραβδος τετράρριζος τετράρρινος τετράρριχτος τετράρρυθμος
 τετράσειρος τετράσημος τετράσκαλμος τετράστεγος τετράστερος τετράστηλος
 τετράστοιχος τετράστομος τετράστοος τετράστροφος τετράστυλος τετράσχιστος
 τετράσωμος τετράτεκνος τετράτομος τετράτονος τετράτροπος τετράτροχος
 τετράυνος τετράφαλος τετράφατσος τετράφθαλμος τετράφορος τετράφυλλος
 τετράφωνος τετράφωτος τετράχειρος τετράχηλος τετράχορδος τετράχρονος
 τετράχυτρος τετράχωρος τετράψηλος τετράψιδος τετράωρος τετράωτος τετραέμβολος
 τετραΰφαντος τετρααιθυλικός τετρααιθυλιούχος τετρααλογονούχος
 τετρααρσενικούχος τετραβάθμιδος τετραβάλβιδος τετραβαρής τετραβορικός
 τετραβρωμικός τετραβρωμιούχος τετραβρωμιωμένος τετραγράμματος τετραγωνικός
 τετραδάκτυλος τετραδάχτυλος τετραδιάτικος τετραδικός τετραδύστυχος
 τετραεθνής τετραετής τετραετηρικός τετραζυγής τετραζωτούχος τετραθέσιος
 τετραθειούχος τετρακάμαρος τετρακάναλος τετρακέρατος τετρακέφαλος
 τετρακισχίλιοι τετρακλαδικός τετρακοσιοστός τετρακτινωτός τετρακυκλικός
 τετρακόρωνος τετρακόσιοι τετρακόσοι τετρακόχλιος τετρακύλινδρος τετραλεκτικός
 τετραμεθυλικός τετραμεθυλιούχος τετραμεθυλιωμένος τετραμελής τετραμερής
 τετραμηνιάτικος τετραμηνιαίος τετραμιγής τετρανιτρικός τετρανιτρωμένος
 τετρανύκτιος τετραξονικός τετραξωνικός τετραοίδιος τετραπάλαιστος τετραπάλαμος
 τετραπέδιλος τετραπέρατος τετραπέταλος τετραπήχης τετραπίστονος
 τετραπερασμένος τετραπηχυαίος τετραπλάσιος τετραπλέλικος τετραπληγικός
 τετραπλούς τετραπλός τετραπολικός τετραπολιτειακός τετραπρόσωπος τετραπτέρυγος
 τετραπτερύγιος τετραπυρολικός τετραπόταμος τετραπύργιος τετραπύρηνος
 τετρασέλιδος τετρασέπαλος τετρασθενής τετρασκελής τετρασπίθαμος τετραστάδιος
 τετραστρέμματος τετρασύλλαβος τετρασώματος τετρατάξιος τετρατομικός τετραυγής
 τετραφάρμακος τετραφθορικός τετραφθοριούχος τετραφτέρουγος τετραφυής
 τετραφωσφορικός τετραφωσφορούχος τετραφωσφορυλικός τετραφωσφορυλιούχος
 τετραχλωρικός τετραχλωριούχος τετραχορδικός τετραψήφιος τετραωνυμικός
 τετραϋδροφολικός τετραϋπόστατος τετραόργυιος τετραώνυμος τετραώροφος
 τεφροειδής τεφρός τεφρώδης τεχνητός τεχνικοεφοδιαστικός τεχνικός τεχνοκρατικός
 τεχνολογικός τεχνοοικονομικός τεχνουργικός τεχνόμορφος τζαμένιος τζαμπέ
 τζαμωτός τζαναμπέτα τζαναμπέτης τζιμάνι τζιν τζιώτικος τζούφιος τηγανητός
 τηκτικός τηλαυγής τηλεγραφικός τηλεκατευθυνόμενος τηλεκινητικός τηλεμετρικός
 τηλεοπτικός τηλεορασόπληκτος τηλεπαθητικός τηλεπικοινωνιακός τηλεσκοπικός
 τηλεφωνικός τηλεφωτογραφικός τηλεχειριζόμενος τηνιακός τιγροειδής τιμαλφής
 τιμαριωτικός τιμητικός τιμοκρατικός τιμολογιακός τιμωρητέος τιμωρητικός
 τιρκουάζ τιτάνιος τιτανικός τιτανιούχος τιτλομανής τιτλούχος τμηματικός
 τμητός τοιχογραφικός τοιχοκολλητός τοκογλυφικός τοκοφόρος τοκοχρεολυτικός
 τομέα τομαρένιος τομεακός τομεοποιημένος τομογραφικός τονικός τονούμενος
 τοξικολογικός τοξικομανής τοξικοφόρος τοξικός τοξινικός τοξινοειδής
 τοξοβόλος τοξοειδής τοξοφόρος τοξωτός τοπιακός τοπικιστικός τοπικός
 τοπογραφικός τοποκεντρικός τοπομαχικός τοποστατικός τοπωνυμικός τορευτικός
 τορνευτικός τορνευτός τοροειδής τορπιλικός τορπιλοβλητικός τορπιλοειδής
 τοσοδούλης τοσοδούλικος τοσουλάκης τοσούλης τοσούτσικος τοτεμικός
 τουλουμίσιος τουρανικός τουριστικός τουρκικός τουρκμενικός τουρκογενής
 τουρκομαθής τουρκομερίτης τουρκομερίτικος τουρκοπατημένος τουρκοσπορίτης
 τουρκόφωνος τουρλωτός τουρτουριάρης τουφωτός τοχαρικός τούλινος τούρκικος
 τράγιος τρέχων τρήση τρίβηλο τρίβηλος τρίβραχυς τρίγαμος τρίγλυφος τρίγλωσσος
 τρίδιπλος τρίδυμος τρίεδρος τρίεθνος τρίκλινος τρίκλιτος τρίκλωνος τρίκορφος
 τρίλεπτος τρίμερος τρίμετρος τρίμηνος τρίμορφος τρίξιμο τρίπατος τρίπλευρος
 τρίπρακτος τρίπραχτος τρίριχτος τρίσβαθος τρίσημος τρίστηλος τρίστιχος
 τρίτομος τρίτροχος τρίφυλλος τρίφωνος τρίχινος τρίχορδος τρίχρονος τρίχρωμος
 τραβεστί τραβηχτικός τραβηχτός τραγίσιος τραγανιστός τραγανός τραγελαφικός
 τραγοειδής τραγοπόδαρος τραγοπώγων τραγουδιστικός τραγουδιστός τραγόμορφος
 τρακαδόρικος τρακικοκωμικός τρακτερωτός τραμπουκικός τραμπούκικος τρανς
 τρανσεξουαλικός τρανσπαράν τρανταχτός τρανός τραπατσούλης τραπεζικός
 τραπεζιτικός τραπεζοασφαλιστικός τραπεζοειδής τραπεζομεσιτικός
 τραπεζόεδρος τραυλός τραυλός τραυματικός τραυματολογικός τραχειακός
 τραχειοτομικός τραχηλάτος τραχηλιαίος τραχηλικός τραχηλισμός τραχωματικός
 τραχύς τραχύφωνος τρεις τρελούτσικος τρελός τρεμάμενος τρεμουλιάρης
 τρεμουλιαστός τρεχάμενος τρεχάτος τρεχούμενος τρηματώδης τριάρμενος τριήμερος
 τριαδικός τριαινοειδής τριακονθήμερος τριακονταετής τριακονταπλάσιος
 τριακοσιοπλάσιος τριακοσιοστός τριακόσιοι τριακόσοι τριανδρικός τριαντάρης
 τριανταφυλλένιος τριανταφυλλής τριανταφυλλί τριβρωμιούχος τριβόμενος τριγενής
 τριγλώχινος τριγυρινός τριγωνικός τριγωνομετρικός τριεθνής τριετής τριζάτος
 τρικάταρτος τρικέφαλος τρικαλινός τρικαλιώτικος τρικατάληκτος τρικινητήριος
 τρικομματικός τρικούβερτος τρικυμιώδης τρικόρυφος τριλεκτικός τριμελής
 τριμηνιαίος τριούσιος τριπάλαιστος τριπάλαστος τριπίθαμος τριπαλαιστιαίος
 τριπλέλικος τριπλούς τριπλός τριπλότυπος τριπολικός τριπολιτσιώτικος
 τρισάγιος τρισάθλιος τρισέγγονος τρισέλιδος τρισένδοξος τρισαποτελούμενος
 τρισδιάστατος τρισευγενικός τρισευδαίμων τρισευτυχισμένος τρισεύγενος
 τρισκότεινος τρισμέγιστος τρισμακάριστος τρισπήλαιος τρισπίθαμος
 τρισυπόστατος τρισχειρότερος τρισχιδής τρισχιλιετής τρισόλβιος τρισύλλαβος
 τριταίος τριτοβάθμιος τριτογενής τριτοετής τριτοκοσμικός τριτοπρόσωπος
 τριτότοκος τριφασικός τριφτός τριφυλλόσχημος τριφωσφορυλικός τριφωσφορυλιούχος
 τριχτός τριχωτός τριψήφιος τριώνυμος τριώροφος τρομακτικός τρομαχτικός
 τρομοκρατικός τρομώδης τροπαιοφόρος τροπαιούχος τροπιδοειδής τροπικός
 τρουλαίος τρουλλωτός τρουλοσκεπής τρουλωτός τροφαντός τροφικός τροφιμογενής
 τροφολογικός τροχήλατος τροχαίος τροχαϊκός τροχιακός τροχιοδεικτικός
 τροχοειδής τροχοφόρος τρυγλοδυτικός τρυπανοφόρος τρυπητός τρυπιοχέρης τρυφερός
 τρωαδίτικος τρωαδικός τρωγλοδυτικός τρωικός τρωκτικός τρωτός τρόμπας τρύπιος
 τσέτουλος τσέχικος τσίγκινος τσίλικος τσίτσιδος τσίφτικος τσαγανός τσαγκός
 τσακιστός τσακωνικός τσακωτός τσακώνικος τσαμπατζής τσαμπουκαλίδικος τσαπαρλής
 τσαπατσούλικος τσαρικός τσαχπίνης τσαχπίνικος τσεκουράτος τσευδός τσεχικός
 τσεχοσλοβακικός τσιγαρισμένος τσιγαριστός τσιγγάνικος τσιγγούνης τσιγγούνικος
 τσιγκούνικος τσικνισμένος τσιλιγκρός τσιμέντινος τσιμεντένιος τσιμενταρισμένος
 τσιμπλιάρικος τσινιάρης τσιπλάκης τσιριγώτικος τσιριχτός τσιρλιάρης τσιτωτός
 τσιφούτικος τσολιάδικος τσολιαδίστικος τσουρουφλιστός τσουρούκης τσουρούτικος
 τσόχινος τυλιχτός τυλοφθόρος τυλώδης τυμπανιαίος τυμπανικός τυμπανογραφικός
 τυνησιακός τυπικός τυπογραφικός τυποκλοπικός τυποκτόνος τυπολατρικός
 τυπωτικός τυραννικός τυροκομικός τυροφάγος τυρρηνικός τυρφώδης τυφικός
 τυφλός τυφοειδής τυχάρπαστος τυχαίος τυχοδιωκτικός τυχοδιωχτικός τυχών τωρινός
 τόπλες τότε τόφαλος υάλινος υαλικός υαλογραφικός υαλοειδής υαλοσκεπής
 υαλουργικός υαλουρονικός υαλωτός υαλόφρακτος υαλόφραχτος υαλώδης υβρεοφοβικός
 υβριστικός υβός υγειονομικός υγιέστατος υγιής υγιεινός υγράλατος υγραεριοφόρος
 υγρομετρικός υγροποιήσιμος υγροποιητικός υγροσκοπικός υγρόληκτος υγρόληχτος
 υγρόφιλος υδάτινος υδαρής υδαταγωγός υδατικός υδατογραφικός υδατοδιαλυτός
 υδατομετρικός υδατοσκοπικός υδατοστεγής υδατώδης υδραίικος υδραιμικός
 υδραργυρούχος υδραυλικός υδρενεργειακός υδρευτικός υδροβιολογικός
 υδρογονοκίνητος υδρογονούχος υδρογραφικός υδροδιαλυτός υδροδοτικός
 υδροηλεκτρικός υδροθειικός υδροθειούχος υδροθεραπευτικός υδροθερμικός
 υδροκίνητος υδροκεφαλικός υδροκηλικός υδροκριτικός υδροκυανικός υδρολογικός
 υδρονομικός υδροπνευματικός υδροπονικός υδροσκοπικός υδροστατικός υδροστεγής
 υδροτροπικός υδροφθορικός υδροφοβικός υδροφόρος υδροχαρής υδροχλωρικός
 υδρωπικός υδρόβιος υδρόγειος υδρόφιλος υδρόφοβος υδρόχαρος υδρόψυκτος υιικός
 υλικός υλιστικός υλοζωικός υλοποιήσιμος υλοτομικός υμενικός υμενοειδής
 υμνητικός υμνογραφικός υμνολογικός υοειδής υπάλληλος υπάρξιμος υπέγγυος
 υπέργειος υπέργηρος υπέρθερμος υπέρθυρος υπέρκαλος υπέρλαμπρος υπέρλεπτος
 υπέρμαχος υπέρμετρος υπέρογκος υπέροχος υπέρπυκνος υπέρσοφος υπέρτατος
 υπέρτονος υπέρυθρος υπέρφορτος υπήνεμος υπαίθριος υπαίτιος υπαγορευτικός
 υπακτικός υπαλληλικός υπανάπτυκτος υπαρκτικός υπαρκτός υπαρξιακός υπαρξιστικός
 υπεδάφιος υπεναντίος υπεξούσιος υπεράγαθος υπεράνθρωπος υπεράξιος υπεράριθμος
 υπερένδοξος υπερήλικος υπερήλιξ υπερήμερος υπερήφανος υπερήψυλος υπεραγία
 υπεραισθητικός υπεραιωνόβιος υπερακραίος υπεραλμυρός υπεραναλυτικός
 υπεραρκετός υπερασπίσιμος υπερασπιστικός υπεραστικός υπερατλαντικός
 υπεραυτόματος υπερβέβαιος υπερβαρύς υπερβατικός υπερβατός υπερβιταμινούχος
 υπερβόρειος υπεργεωγραφικός υπεργλυκαιμικός υπερδεξιός υπερδισύλλαβος
 υπερεκλεκτικός υπερεκτεταμένος υπερεξοπλισμένος υπερεπαρκής υπερευαίσθητος
 υπερηχογραφικός υπερθεμελιωδέστατος υπερθετικός υπεριστορικός υπεριώδης
 υπερκανονικός υπερκειμενικός υπερκινητικός υπερκομματικός υπερκονδύλιος
 υπερμέτρωψ υπερμεγέθης υπερμοντέρνος υπερογδοντάχρονος υπεροπτικός
 υπερουράνιος υπερούσιος υπερπλήρης υπερπολυτελής υπερπροσοντούχος
 υπερπόντιος υπερρεαλιστικός υπερσιβηρικός υπερσυγκεντρωτικός υπερσυμβατικός
 υπερσυμπαντικός υπερσυντηρητικός υπερσύγχρονος υπερτέλειος υπερτασικός
 υπερτοπικός υπερτραφής υπερτροφικός υπερτυχερός υπερυδροφοβικός υπερυδρόφοβος
 υπερφίαλος υπερφαλαγγίζων υπερφυής υπερφυσικός υπερφωσφορικός υπερφωτονικός
 υπερωκεάνιος υπερωριακός υπερώιος υπερώριμος υπεύθυνος υπηρεσιακός υπναλέος
 υπνοβατικός υπνολογικός υπνοφόρος υπνωτιστικός υποαλλεργικός υποατομικός
 υποβαθμιστικός υποβλητικός υποβοηθητικός υποβολιμαίος υποβρυχιακός υποβρύχιος
 υπογειωμένος υπογλυκαιμικός υπογλυκαιμικός υπογλώσσιος υπογνάθιος υπογόνιμος
 υποδεέστερος υποδειγματικός υποδερμικός υποδόριος υποευτηκτοειδής υποθαλάμιος
 υποθερμικός υποθετικός υποθηκευμένος υποθηκεύσιμος υποθηκικός υποκίτρινος
 υποκείμενος υποκειμενικός υποκινήσιμος υποκινητικός υποκλείδιος υποκλινικός
 υποκριτικός υποκύανος υπολειμματικός υπολειπόμενος υπολειτουργών υπολειφθής
 υπολογιστικός υπομάζιος υπομικροσκοπικός υπομνηματικός υπομνηστικός
 υπομονητικός υπονομευτικός υπονοούμενος υποουλικός υποπολλαπλάσιος υποσέλιδος
 υποσελίδιος υποσημειακός υποστασιακός υποστατικός υποστηρικτικός υποστυλωτικός
 υποσχετικός υποτακτικός υποτασικός υποταχτικός υποτελής υποτιμητικός
 υποτροπιάζων υποτροπικός υποτυπώδης υπουργήσιμος υπουργικός υποφερτός
 υποχείριος υποχθόνιος υποχλωριώδης υποχονδριακός υποχοντριακός υποχρεωτικός
 υποχόνδριος υποχόντριος υποψήφιος υπωρόφιος υπόγειος υπόγλυκος υπόδικος
 υπόθερμος υπόκαυστος υπόκωφος υπόλευκος υπόλογος υπόλοιπος υπόξανθος υπόξινος
 υπόπυκνος υπόρρητος υπόσκαφος υπόσπονδος υπόστροφος υπόστυλος υπότονος
 υπότροφος υπόφαιος υπόχρεος υπόχρεως υπόχρυσος υπόψυχρος υστεραίος υστερικός
 υστερνός υστεροβυζαντινός υστερογενής υστεροελλαδικός υστερομεσαιωνικός
 υστερόβουλος υστερότοκος υστερόχρονος υφάλμυρος υφέρπων υφέσιμος υφαντικός
 υφαντουργικός υφαντός υφασμάτινος υφασματικός υφεσιακός υφηγητικός υψίκορμος
 υψίφωνος υψηλόβαθμος υψηλόκορμος υψηλόμισθος υψηλός υψηλόσωμος υψηλότερος
 υψηλόφωνος υψιπέτης υψιπετής υψιπετής υψιτενής υψομετρικός υψοφοβικός φάλτσος
 φέρελπις φίλαθλος φίλανδρος φίλαρχος φίλαυτος φίλεργος φίλερις φίλιος φίλιππος
 φίλτατος φίλυδρος φίλυπνος φίνος φίσκα φαβιανός φαγάδικος φαγανός φαγεδαινικός
 φαγεσωρογόνος φαγοκυτταρικός φαγώσιμος φαεινός φαιδρολόγος φαιδρυντικός
 φαινολικός φαινομενικός φαινομενολογικός φαιοκίτρινος φαιοχίτων φαιός
 φακιδιάρης φακιρικός φακοειδής φαλαγγίτικος φαλαγγιτικός φαλαινοειδής
 φαλακρός φαληρικός φαληριώτικος φαλλικός φαλλοκρατικός φαλλομορφικός
 φαλλόσχημος φαλτσαριστός φαναριώτικος φανατικός φανατισμένος φανελένιος
 φανερόγαμος φανερός φανταγμένος φανταιζί φανταρίστικος φαντασιακός
 φαντασιόπληκτος φαντασιόπληχτος φαντασιώδης φαντασμένος φαντασμαγορικός
 φανταχτερός φανταχτός φαντεζί φαντός φανφαρονίστικος φαραγγώδης φαραωνικός
 φαρδουλός φαρδύς φαρδύτερος φαρικός φαρισαϊκός φαρμακερός φαρμακευτικός
 φαρμακογνωστικός φαρμακοδυναμικός φαρμακοεπιδεσμικός φαρμακοκινητικός
 φαρμακομανής φαρμακομύτης φαρμακοτεχνικός φαρμακόγλωσσος φαρμακώδης
 φαρυγγικός φαρφουρένιος φασάτος φασίζων φασαριόζικος φασαριόζος φασικός
 φασιστοειδής φασκιωμένος φασματικός φασματοσκοπικός φασματοφωτομετρικός
 φατνιακός φατνωτός φατριακός φατριαστικός φαυλεπίφαυλος φαυλοκρατικός
 φαφλατάδικος φαφούτικος φαύλος φαύνος φεβρουαριάτικος φεβρουαριανός
 φεγγαρίσιος φεγγαριάτικος φεγγαροντυμένος φεγγαροπρόσωπος φεγγαροστολισμένος
 φεγγαρόλουστος φεγγαρόφωτος φεγγερός φεγγοβόλος φεγγριστός φειδιακός φειδωλός
 φελιαστός φελλάτος φελλένιος φελλωτός φελλώδης φελπένιος φελπεδένιος
 φενακιστικός φεντεραλιστικός φεουδαλικός φεουδαρχικός φερέγγυος φερέοικος
 φερώνυμος φετινός φετιχικός φετιχιστικός φευγάτος φευγαλέος φευκτός
 φθαλικός φθαρτικός φθαρτός φθειρικός φθειροκτόνος φθηνιάρικος φθηνούτσικος
 φθινοπωριάτικος φθινοπωρινός φθισικός φθογγικός φθογγογραφικός φθογγολογικός
 φθορίζων φθοριούχος φθοριωμένος φθοροποιός φιαλοειδής φιαλωτός φιγουράτος
 φιδένιος φιδίσιος φιδωτός φιλάλληλος φιλάνθρωπος φιλάργυρος φιλάρεσκος
 φιλάσθενος φιλέκδικος φιλέορτος φιλέραστος φιλέρημος φιλήδονος φιλήκοος
 φιλίστωρ φιλαλήθης φιλανδέζικος φιλανδικός φιλανθρωπικός φιλαπόδημος
 φιλειρηνιστικός φιλεκπαιδευτικός φιλελεύθερος φιλελληνικός φιλεπιστήμων
 φιλεύσπλαγχνος φιλεύσπλαχνος φιλικός φιλιππικός φιλιωμένος φιλμικός
 φιλοαγροτικός φιλοβαλκανικός φιλοβασιλικός φιλοδίκαιος φιλοδασικός φιλοδυτικός
 φιλοζωικός φιλοθεάμων φιλοκατήγορος φιλοκερδής φιλοκυβερνητικός φιλολακωνικός
 φιλολογικός φιλομαθής φιλομειδής φιλοπερίεργος φιλοπεριβαλλοντικός φιλοπράγμων
 φιλοπόλεμος φιλοσοβιετικός φιλοσοφημένος φιλοσοφικός φιλοτελής φιλοτελικός
 φιλοτουρκικός φιλοφρονητικός φιλοχρήματος φιλτραρισμένος φιλωτίτικος φιλόδικος
 φιλόζωος φιλόθεος φιλόθρησκος φιλόκαλος φιλόκροτος φιλόμουσος φιλόνομος
 φιλόπατρις φιλόπονος φιλόπρωτος φιλόπτωχος φιλόστοργος φιλότεκνος φιλότεχνος
 φιλόφρων φιλόχριστος φιλόψογος φιλόψυχος φιλύποπτος φιμέ φινετσάτος
 φινλανδικός φιννικός φιξ φιστικής φιστικωμένος φκιασιδωμένος φλαμανδικός
 φλασκωτός φλεβαριάτικος φλεβικός φλεβοκομβικός φλεβοτομικός φλεβώδης
 φλεγματώδης φλεγμονικός φλεγμονώδης φλογάτος φλογερός φλογιστικός φλογοβόλος
 φλογωτικός φλογόλευκος φλογώδης φλοιακός φλοιικός φλοιώδης φλοκάτος φλοκιαστός
 φλοράλ φλου φλουδερός φλυκταινώδης φλωρεντινός φλωρινιώτικος φλωροκαπνισμένος
 φλύαρος φοβερός φοβητσιάρης φοβητσιάρικος φοβικός φοιβόληπτος φοινικικός
 φοιτητικός φολιδωτός φολκλορικός φονικός φορειοφόρος φορετός φορητός
 φοροδοτικός φοροεισπρακτικός φοροελεγκτικός φορολογήσιμος φορολογητέος
 φορομπηχτικός φοροτελής φοροτεχνικός φορσέ φορτηγός φορτικός φορτσάτος
 φορτωτικός φουκαριάρης φουκαριάρικος φουλ φουλαριστός φουντωτός φουριόζικος
 φουρνιστός φουρνιώτικος φουσκομάγουλος φουσκωτός φουτουριστικός φράγκικος
 φρέσκος φραντσέζικος φραξιονιστικός φρασεολογικός φραστικός φρεζάτος φρενήρης
 φρενικός φρενιτικός φρενιτιώδης φρενοβλαβής φρενολογικός φρενοπαθής
 φρεσκοβαμμένος φρεσκογυαλισμένος φρεσκοκομμένος φρεσκοπασαλειμμένος
 φρεσκοψημένος φρικαλέος φρικιαστικός φρικτός φρικώδης φριχτός φρονηματιστικός
 φρουριακός φροϋδικός φρούδος φρυγανισμένος φρυγανώδης φρυγικός φρυδάτος
 φρόνιμος φτενός φτενόφλουδος φτεροπόδαρο φτεροπόδαρος φτερωτός φτηνιάρικος
 φτηνός φτιασιδωμένος φτιαστός φτιαχτός φτυστός φτωχικός φτωχομεσαίος
 φτωχούλα φτωχούλης φτωχούτσικος φτωχός φτωχότερος φυγοκεντρικός φυγοπόλεμος
 φυγόκοσμος φυγόμαχος φυγόποινος φυγόπονος φυκόστρωτος φυλακτικός φυλετικός
 φυλλοειδής φυλλοξηρικός φυλλοπυριτικός φυλλοσκεπής φυλλοστρωμένος φυλλοφάγος
 φυλλώδης φυλογενετικός φυλογονικός φυμέ φυματικός φυματιολογικός φυματιώδης
 φυρός φυσητικός φυσητός φυσικοθεραπευτικός φυσικομαθηματικός φυσικοχημικός
 φυσιογνωμικός φυσιογνωστικός φυσιογραφικός φυσιοδιφικός φυσιοθεραπευτικός
 φυσιολατρικός φυσιολογικός φυτευτικός φυτευτός φυτικός φυτογεωγραφικός
 φυτολογικός φυτοπαθολογικός φυτοτεχνικός φυτοφάγος φυτοφαγικός φυτρωτικός
 φωνακλάς φωνακλού φωνακλούδικο φωναχτός φωνηεντικός φωνηεντόληκτος φωνηματικός
 φωνητικός φωνογραφικός φωνοκινητικός φωνοληπτικός φωνολογικός φωνομετρικός
 φωστηρικός φωσφορίζων φωσφοριζέ φωσφορικός φωσφορομολυβδαινικός φωσφορούχος
 φωσφορυλιούχος φωταγωγικός φωτεινός φωτεινότερος φωτερός φωτιοκαμένος
 φωτοακουστικός φωτοαντιγραφικός φωτοβολταϊκό φωτοβολταϊκός φωτοβόλος φωτογενής
 φωτογραφικός φωτογόνος φωτοδιαπερατός φωτοευαίσθητος φωτοευπαθής
 φωτοκαταλυτικός φωτομετρικός φωτομηχανικός φωτοοπτικός φωτορεαλιστικός
 φωτοτηλεγραφικός φωτοτυπικός φωτοφανής φωτοφοβικός φωτοφόρος φωτοχημικός
 φωτόφοβος χάλκινος χάρτινος χάσικος χέρσος χίλιοι χίπικος χαβανέζικος χαδιάρης
 χαζοβιόλης χαζοχαρούμενος χαζούλης χαζός χαιρέκακος χαιρετιστήριος
 χαλαζόπληχτος χαλαρωτικός χαλαρός χαλδαϊκός χαλεπός χαλικερός χαλικοστρωμένος
 χαλικόστρωτος χαλικώδης χαλκέντερος χαλκευτικός χαλκιδιώτικος χαλκογραφικός
 χαλκοπλαστικός χαλκοπράσινος χαλκοπόδαρος χαλκοστρωμένος χαλκοτυπικός
 χαλκοφόρος χαλκούς χαλκούχος χαλκωματένιος χαλκόδετος χαλκόξανθος χαλκόστρωτος
 χαλύβδινος χαμάλικος χαμερπής χαμηλοβλέφαρος χαμηλοθώρα χαμηλοθώρης
 χαμηλοτάκουνος χαμηλούτσικος χαμηλόβαθμος χαμηλόμισθος χαμηλόρρυθμος χαμηλός
 χαμηλόφωνος χαμιτικός χαμογελαστός χαναανικός χαναανιτικός χανιώτικος
 χαοτικός χαρίεις χαρακτηριστικός χαρακτικός χαρακωτός χαραμοφάγος χαρισάμενος
 χαριστικός χαριτολόγος χαριτόβρυτος χαριτόμορφος χαριτόπλαστος χαρμόσυνος
 χαρτένιος χαρτεμπορικός χαρτζιλικωμένος χαρτογραφικός χαρτομανής
 χαρτοπαιχτικός χαρτοσημασμένος χαρτόδετος χαρτώος χαρωπός χασάπικος χασεδένιος
 χασμουριάρης χατιρικός χαυνωτικός χαχόλικος χαϊδευτικός χαύνος χαώδης
 χειλεόφωνος χειλικός χειλοδοντικός χειλόφωνος χειμέριος χειμαρρώδης χειμερινός
 χειμωνικός χειράφετος χειραγωγήσιμος χειραλικός χειριδωτός χειριστικός
 χειρογραφικός χειροδύναμος χειροκίνητος χειροπιαστός χειροποίητος
 χειροτονημένος χειρουργήσιμος χειρουργικός χειρωνακτικός χειρόγραφος
 χελίσιος χελωνίσιος χελωνιάρης χελωνοειδής χεροδύναμος χεροκάμωτος χερουβικός
 χετιτικός χηλοειδής χημειοθεραπευτικός χημειοσυνθετικός χημικοθεραπευτικός
 χημικός χηνίσιος χηράμενος χηρευάμενος χηρεύων χθαμαλός χθεσινοβραδινός
 χθόνιος χιαστός χιλιάκριβος χιλιάρικος χιλιανός χιλιαπλάσιος χιλιοειπωμένος
 χιλιοφορεμένος χιλιοχρονίτικος χιλιόφωνος χιλιόχρονος χιμαιρικός
 χιονάτος χιονένιος χιονοβόλος χιονοδρομικός χιονοσκέπαστος χιονοσκεπής
 χιονόλευκος χιονόμαλλος χιονώδης χιουμοριστικός χιτλερικός χιόνι χιώτικος
 χλεμπονιάρης χλεμπονιασμένος χλευασμένος χλευαστικός χλιαρός χλιδάτος χλιος
 χλομός χλωμός χλωρικός χλωριούχος χλωροφορμικός χλωρός χνουδάτος χνουδερός
 χοίρειος χοίρινος χοανοειδής χοηφόρος χοιραδικός χοιρινός χολαιμικός
 χολερικός χολερόβλητος χοληδόχος χοληφόρος χολιαστικός χολιγουντιανός χολικός
 χονδρεμπορικός χονδρικός χονδροειδής χονδροπεταλωμένος χονδροποιός χονδρός
 χοντραλεσμένος χοντρικός χοντροαλεσμένος χοντρογούρουνο χοντροδουλεμένος
 χοντροκαύκαλος χοντροκομμένος χοντροκόκαλος χοντροκώλα χοντρομπαλάς
 χοντρουλός χοντροφτιαγμένος χοντρούλης χοντρούτσικος χοντρόκοκκος χοντρόμυαλος
 χοντρός χοντρόφλουδος χοντρόφωνος χορειακός χορευτικός χορευτός χορηγητικός
 χορικός χοριοειδής χορογραφικός χοροπηδηχτός χοροστατικός χοροστατών χορτάτος
 χορταστικός χορτοκοπτικός χορτολιβαδικός χορτοφάγος χορωδιακός χουλιγκανικός
 χουντικός χουντοβασιλικός χουχουλιάρης χουχουλιάρικος χοϊκός χούρδος χρήσιμος
 χρεοκοπικός χρεωλυτικός χρεωστικός χρηματικός χρηματισμένος χρηματιστηριακός
 χρηματοδοτικός χρηματοκαπιταλιστικός χρηματολογικός χρηματοοικονομικός
 χρησάμενος χρησιμοθηρικός χρησιμοκρατικός χρησιμοποιήσιμος χρησμολόγος
 χρηστήριος χρηστικός χρηστοήθης χρηστός χριστεπώνυμος χριστιανικός
 χριστουγεννιάτικος χριστός χρονίζων χρονιάρης χρονιάρικος χρονιάτικος χρονικός
 χρονογραφικός χρονολογικός χρονομεριστικός χρονομετρικός χρονορρυθμιστικός
 χρυσαφένιος χρυσαφής χρυσελεφάντινος χρυσεπίβαπτος χρυσοΰφαντος χρυσοθηρικός
 χρυσοκίτρινος χρυσοκόκκινος χρυσοκόλλητος χρυσομάλλης χρυσομάλλικος
 χρυσοποίκιλτος χρυσοποικιλτικός χρυσοπράσινος χρυσοπόρφυρος χρυσοστεφάνωτος
 χρυσοστόλιστος χρυσοφόρος χρυσοχοϊκός χρυσωπός χρυσωτικός χρυσωτός χρυσόδετος
 χρυσόμαλλος χρυσόξανθος χρυσόπλεχτος χρυσός χρυσόφτερος χρυσόφωνος χρωματικός
 χρωματιστός χρωματογόνος χρωματοφόρος χρωμικός χρωμιούχος χρωμογόνος
 χρωμολιθογραφικός χρωμοσφαιρικός χρωμοσωμικός χρωμοφόρος χρως χρωστικός
 χτίκιασμα χτεσινοβραδινός χτεσινός χτικιάρης χτικιάρικος χτιστός χτυπητός
 χυδαιόγλωσσος χυλώδης χυμογόνος χυμώδης χυτός χωλός χωμάτινος χωματένιος
 χωνευτικός χωνευτός χωνοειδής χωρητικός χωριάτικος χωρικός χωριστικός χωριστός
 χωρονομικός χωροταξικός χωροφυλακίστικος χωστός χόνδρινος ψάθινος ψαθυρός
 ψαλιδισμένος ψαλιδιστός ψαλιδοειδής ψαλιδωτός ψαλμικός ψαλμωδικός ψαλτικός
 ψαμμιακός ψαμμιτικός ψαμμόφιλος ψαμμώδης ψαράδικος ψαρικός ψαροφάγος ψαρωτικός
 ψαρός ψαφαρός ψαχνός ψαχουλευτός ψεδνός ψειριάρης ψειριάρικος ψεκτός ψελλός
 ψεσινός ψευδής ψευδαισθητικός ψευδαληθής ψευδανθρακικός ψευδαργυρικός
 ψευδαρμόνιος ψευδεπίγραφος ψευδεπιστημονικός ψευδοδιλημματικός
 ψευδολόγιος ψευδολόγος ψευδοπαράλληλος ψευδοσοφικός ψευδοτυχαίος ψευδόθεος
 ψευδόφιλος ψευδώνυμος ψευτολόγιος ψευτοφαγωμένος ψεύδορκος ψεύτικος ψηλαφητός
 ψηλοκρεμαστός ψηλομύτης ψηλοτάβανος ψηλοτάκουνος ψηλόλιγνος ψηλόπλωρος
 ψηλός ψηλόσωμος ψηλότερος ψητός ψηφιακός ψηφιδοφόρος ψηφιδωτός ψηφοθηρικός
 ψιλοάθεος ψιλοκαμωμένος ψιλοκομμένος ψιλωτικός ψιλός ψιλόφλουδος ψιχαλιστός
 ψιψιριάρης ψοφοδεής ψοφώδης ψυγείο ψυγμένος ψυκτικός ψυχαγωγικός
 ψυχαναληπτικός ψυχαναλυτικός ψυχανώμαλος ψυχασθενής ψυχασθενικός ψυχεδελικός
 ψυχιατροδικαστικός ψυχικάρης ψυχικός ψυχοαναληπτικός ψυχοβιολογικός ψυχοβλαβής
 ψυχογενής ψυχογενετικός ψυχογραφικός ψυχοδιαγνωστικός ψυχοδιανοητικός
 ψυχοδραματικός ψυχοδραστικός ψυχοδυναμικός ψυχοθεραπευτικός ψυχοκινητικός
 ψυχοκοινωνιολογικός ψυχοκτόνος ψυχοληπτικός ψυχολογικός ψυχομετρικός
 ψυχονοητικός ψυχοπαθής ψυχοπαθολογικός ψυχοπαιδαγωγικός ψυχοπλάνος
 ψυχοπνευματικός ψυχοπονιάρης ψυχοπονιάρικος ψυχοσωματικός ψυχοσωτήριος
 ψυχοτονικός ψυχοτρόπος ψυχοφθόρος ψυχοφυσικός ψυχοφυσιολογικός ψυχοχημικός
 ψυχραμένος ψυχραντικός ψυχρομετρικός ψυχροπολεμικός ψυχρούτσικος ψυχρόαιμος
 ψυχρόφιλος ψυχτικός ψυχωσικός ψυχωτικός ψυχωφελής ψυχόπονος ψωραλέος ψωριάρης
 ψωριασικός ψωροειδής ψωροπερήφανος ψωροφιλότιμος ψόφιος ψύχραιμος ωαγωγικός
 ωθητικός ωκεάνιος ωκεανογραφικός ωκεανολογικός ωκεανοπλοϊκός ωκυτόκιος
 ωκύπους ωκύπτερος ωλεκράνιος ωλεκρανικός ωλενικός ωμιαίος ωμικός ωμοβόρος
 ωμοφάγος ωμός ωογόνος ωοειδής ωοζωοτόκος ωοθηκικός ωοτόκος ωοφάγος ωοφόρος
 ωραιοπαθής ωραιόπαθος ωραιόπλουμος ωραιότατος ωραιότερος ωριαίος ωρισμένος
 ωριός ωρολογιακός ωρολόγιος ωρομίσθιος ωσμωτικός ωστικός ωτακουστικός
 ωτιαίος ωτικός ωτοειδής ωτολογικός ωτορινολαρυγγολογικός ωφέλιμος
 ωφελιμοθηρικός ωχρινοτρόπος ωχροκίτρινος ωχροκόκκινος ωχρομέλας ωχροπρόσωπος
 ωχρόλευκος ωχρός ωχρόφαιος ωώδης όλβιος όλκιμος όλος όμαιμος όμβριος όμοιος
 όμορφος όνειος όξινος όρθιος όσιος όφκαιρος όψια όψιμος ύπανδρος ύπατος
 ύπουλος ύπτιος ύστατος ύστερος ύψιστος ώριμος ώριος ἀγκυλωτός ἀκαταμέτρητος
 ἄπειρος ἄτροπος ἐλαφρός ἐνεστώς ἐνυπόστατος ἔναυλος ἥττων ἰσχυρός ἵστωρ
""".split())
